.f5 {
    font-size: 10pt !important;
}

.ritz .waffle a { 
    color: inherit; 
}
.ritz .waffle .s7{
    border-bottom:1px SOLID #000000;border-right:1px SOLID #000000;background-color:#ffffff;text-align:center;font-weight:bold;color:#000000;font-family:'Arial';font-size:12pt;vertical-align:middle;white-space:nowrap;direction:ltr;padding:2px 3px 2px 3px;
}
.ritz .waffle .s0{
    border-bottom:1px SOLID #000000;border-right:1px SOLID #000000;background-color:#ffffff;text-align:left;font-weight:bold;color:#000000;font-family:'Arial';font-size:10pt;vertical-align:middle;white-space:nowrap;direction:ltr;padding:2px 3px 2px 3px;
}
.ritz .waffle .s2{
    border-bottom:1px SOLID #000000;
    border-right:1px SOLID #000000;
    background-color:#f1f1f1;
    text-align:center;
    font-weight: bold;
    color:#000000;
    font-family:'Arial';font-size:15pt;
    vertical-align:middle;
    white-space:nowrap;
    direction:ltr;
    padding:2px 3px 2px 3px;
}
.ritz .waffle .s3{
    border-bottom:1px SOLID #000000;
    border-right:1px SOLID #000000;
    background-color:#ffffff;text-align:left;font-weight:bold;color:#000000;font-family:'Arial';font-size:10pt;vertical-align:top;white-space:nowrap;direction:ltr;padding:2px 3px 2px 3px;
    }
.ritz .waffle .s4{
    border-bottom:1px SOLID #000000;border-right:1px SOLID #000000;background-color:#ffffff;text-align:center;font-weight:bold;color:#000000;font-family:'Arial';font-size:10pt;vertical-align:top;white-space:nowrap;direction:ltr;padding:2px 3px 2px 3px;}.ritz .waffle .s6{border-bottom:1px SOLID #000000;border-right:1px SOLID #000000;background-color:#ffffff;text-align:center;font-weight:bold;color:#000000;font-family:'Arial';font-size:11pt;vertical-align:middle;white-space:nowrap;direction:ltr;padding:2px 3px 2px 3px;
    }
.ritz .waffle .s5{
    border-bottom:1px SOLID #000000;
    border-right:1px SOLID #000000;
    background-color:#f1f1f1;
    text-align:center;
    font-weight: bold;
    color:#000000;
    font-family:'Arial';
    font-size:15pt;
    vertical-align:middle;
    white-space:nowrap;
    direction:ltr;
    padding:2px 3px 2px 3px;
}
.ritz .waffle .s1{border-bottom:1px SOLID #000000;border-right:1px SOLID #000000;background-color:#ffffff;text-align:center;font-weight:bold;color:#000000;font-family:'Arial';font-size:10pt;vertical-align:middle;white-space:nowrap;direction:ltr;padding:2px 3px 2px 3px;
}

.f2 {
    font-size: 12pt;
    text-align: center;
    font-weight: bold;
}
.f3 {
    font-size: 15pt;
    text-align: center;
    font-weight: bold;
}
a {
    text-decoration: none
}
a:link {
    color: #15c
}
a:visited {
    color: #61c
}
a:active {
    color: #d14836
}
a:hover {
    text-decoration: underline
}
.quantumIconsIcon {
    font-family: 'Material Icons Extended';
    font-weight: normal;
    font-style: normal;
    font-size: 24px;
    line-height: 1;
    letter-spacing: normal;
    text-rendering: optimizeLegibility;
    text-transform: none;
    display: inline-block;
    word-wrap: normal;
    direction: ltr;
    font-feature-settings: 'liga' 1;
    -webkit-font-smoothing: antialiased
}
html[dir="rtl"] .quantumIconsRtlIcon {
    -moz-transform: scaleX(-1);
    -o-transform: scaleX(-1);
    -webkit-transform: scaleX(-1);
    transform: scaleX(-1);
    filter: FlipH;
    -ms-filter: "FlipH"
}
.ac-renderer {
    font: normal 13px Arial, sans-serif;
    position: absolute;
    background: #fff;
    border: 1px solid #666;
    -moz-box-shadow: 2px 2px 2px rgba(102, 102, 102, .4);
    -webkit-box-shadow: 2px 2px 2px rgba(102, 102, 102, .4);
    width: 300px
}
.ac-row {
    cursor: pointer;
    padding: .4em
}
.ac-highlighted {
    font-weight: bold
}
.ac-active {
    background-color: #b2b4bf
}
.goog-inline-block {
    position: relative;
    display: -moz-inline-box;
    display: inline-block
}
* html .goog-inline-block {
    display: inline
}
*:first-child+html .goog-inline-block {
    display: inline
}
.jfk-button {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    cursor: default;
    font-size: 11px;
    font-weight: bold;
    text-align: center;
    white-space: nowrap;
    margin-right: 16px;
    height: 27px;
    line-height: 27px;
    min-width: 54px;
    outline: 0px;
    padding: 0 8px
}
.jfk-button-hover {
    -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, .1);
    -moz-box-shadow: 0 1px 1px rgba(0, 0, 0, .1);
    box-shadow: 0 1px 1px rgba(0, 0, 0, .1)
}
.jfk-button-selected {
    -webkit-box-shadow: inset 0px 1px 2px rgba(0, 0, 0, 0.1);
    -moz-box-shadow: inset 0px 1px 2px rgba(0, 0, 0, 0.1);
    box-shadow: inset 0px 1px 2px rgba(0, 0, 0, 0.1)
}
.jfk-button .jfk-button-img {
    margin-top: -3px;
    vertical-align: middle
}
.jfk-button-label {
    margin-left: 5px
}
.jfk-button-narrow {
    min-width: 34px;
    padding: 0
}
.jfk-button-collapse-left,
.jfk-button-collapse-right {
    z-index: 1
}
.jfk-button-collapse-left.jfk-button-disabled {
    z-index: 0
}
.jfk-button-checked.jfk-button-collapse-left,
.jfk-button-checked.jfk-button-collapse-right {
    z-index: 2
}
.jfk-button-collapse-left:focus,
.jfk-button-collapse-right:focus,
.jfk-button-hover.jfk-button-collapse-left,
.jfk-button-hover.jfk-button-collapse-right {
    z-index: 3
}
.jfk-button-collapse-left {
    margin-left: -1px;
    -moz-border-radius-bottomleft: 0;
    -moz-border-radius-topleft: 0;
    -webkit-border-bottom-left-radius: 0;
    -webkit-border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    border-top-left-radius: 0
}
.jfk-button-collapse-right {
    margin-right: 0px;
    -moz-border-radius-topright: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-top-right-radius: 0;
    -webkit-border-bottom-right-radius: 0;
    border-top-right-radius: 0;
    border-bottom-right-radius: 0
}
.jfk-button.jfk-button-disabled:active {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none
}
.jfk-button-action {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: #4d90fe;
    background-image: -webkit-linear-gradient(top, #4d90fe, #4787ed);
    background-image: -moz-linear-gradient(top, #4d90fe, #4787ed);
    background-image: -ms-linear-gradient(top, #4d90fe, #4787ed);
    background-image: -o-linear-gradient(top, #4d90fe, #4787ed);
    background-image: linear-gradient(top, #4d90fe, #4787ed);
    border: 1px solid #3079ed;
    color: #fff
}
.jfk-button-action.jfk-button-hover {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: #357ae8;
    background-image: -webkit-linear-gradient(top, #4d90fe, #357ae8);
    background-image: -moz-linear-gradient(top, #4d90fe, #357ae8);
    background-image: -ms-linear-gradient(top, #4d90fe, #357ae8);
    background-image: -o-linear-gradient(top, #4d90fe, #357ae8);
    background-image: linear-gradient(top, #4d90fe, #357ae8);
    border: 1px solid #2f5bb7;
    border-bottom-color: #2f5bb7
}
.jfk-button-action:focus {
    -webkit-box-shadow: inset 0 0 0 1px #fff;
    -moz-box-shadow: inset 0 0 0 1px #fff;
    box-shadow: inset 0 0 0 1px #fff;
    border: 1px solid #fff;
    border: rgba(0, 0, 0, 0) solid 1px;
    outline: 1px solid #4d90fe;
    outline: rgba(0, 0, 0, 0) 0
}
.jfk-button-action.jfk-button-clear-outline {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    outline: none
}
.jfk-button-action:active {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    background: #357ae8;
    border: 1px solid #2f5bb7;
    border-top: 1px solid #2f5bb7
}
.jfk-button-action.jfk-button-disabled {
    background: #4d90fe;
    filter: alpha(opacity=50);
    opacity: 0.5
}
.jfk-button-contrast {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: #f5f5f5;
    background-image: -webkit-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -o-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: linear-gradient(top, #f5f5f5, #f1f1f1);
    color: #333;
    border: 1px solid #dcdcdc;
    border: 1px solid rgba(0, 0, 0, 0.1)
}
.jfk-button-contrast.jfk-button-hover,
.jfk-button-contrast.jfk-button-clear-outline.jfk-button-hover {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: #f8f8f8;
    background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -o-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
    border: 1px solid #c6c6c6;
    color: #111
}
.jfk-button-contrast:active,
.jfk-button-contrast.jfk-button-hover:active {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    background: #f8f8f8
}
.jfk-button-contrast.jfk-button-selected,
.jfk-button-contrast.jfk-button-clear-outline.jfk-button-selected {
    background-color: #eee;
    background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -o-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
    border: 1px solid #ccc;
    color: #333
}
.jfk-button-contrast.jfk-button-checked,
.jfk-button-contrast.jfk-button-clear-outline.jfk-button-checked {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    background-color: #eee;
    background-image: -webkit-linear-gradient(top, #eee, #e0e0e0);
    background-image: -moz-linear-gradient(top, #eee, #e0e0e0);
    background-image: -ms-linear-gradient(top, #eee, #e0e0e0);
    background-image: -o-linear-gradient(top, #eee, #e0e0e0);
    background-image: linear-gradient(top, #eee, #e0e0e0);
    border: 1px solid #ccc;
    color: #333
}
.jfk-button-contrast:focus {
    border: 1px solid #4d90fe;
    outline: none
}
.jfk-button-contrast.jfk-button-clear-outline {
    border: 1px solid #dcdcdc;
    outline: none
}
.jfk-button-contrast.jfk-button-disabled {
    background: #fff;
    border: 1px solid #f3f3f3;
    border: 1px solid rgba(0, 0, 0, 0.05);
    color: #b8b8b8
}
.jfk-button-contrast .jfk-button-img {
    opacity: .70
}
.jfk-button-contrast.jfk-button-checked .jfk-button-img,
.jfk-button-contrast.jfk-button-selected .jfk-button-img,
.jfk-button-contrast.jfk-button-hover .jfk-button-img {
    opacity: 0.9
}
.jfk-button-contrast.jfk-button-disabled .jfk-button-img {
    filter: alpha(opacity=33);
    opacity: 0.333
}
.jfk-button-default {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: #3d9400;
    background-image: -webkit-linear-gradient(top, #3d9400, #398a00);
    background-image: -moz-linear-gradient(top, #3d9400, #398a00);
    background-image: -ms-linear-gradient(top, #3d9400, #398a00);
    background-image: -o-linear-gradient(top, #3d9400, #398a00);
    background-image: linear-gradient(top, #3d9400, #398a00);
    border: 1px solid #29691d;
    color: #fff;
    text-shadow: 0px 1px rgba(0, 0, 0, 0.1)
}
.jfk-button-default.jfk-button-hover {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: #368200;
    background-image: -webkit-linear-gradient(top, #3d9400, #368200);
    background-image: -moz-linear-gradient(top, #3d9400, #368200);
    background-image: -ms-linear-gradient(top, #3d9400, #368200);
    background-image: -o-linear-gradient(top, #3d9400, #368200);
    background-image: linear-gradient(top, #3d9400, #368200);
    border: 1px solid #2d6200;
    border-bottom: 1px solid #2d6200;
    text-shadow: 0px 1px rgba(0, 0, 0, 0.3)
}
.jfk-button-default:focus {
    -webkit-box-shadow: inset 0 0 0 1px #fff;
    -moz-box-shadow: inset 0 0 0 1px #fff;
    box-shadow: inset 0 0 0 1px #fff;
    border: 1px solid #fff;
    border: rgba(0, 0, 0, 0) solid 1px;
    outline: 1px solid #3d9400;
    outline: rgba(0, 0, 0, 0) 0
}
.jfk-button-default.jfk-button-clear-outline {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    outline: none
}
.jfk-button-default:active {
    -webkit-box-shadow: inset 0px 1px 2px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: inset 0px 1px 2px rgba(0, 0, 0, 0.3);
    box-shadow: inset 0px 1px 2px rgba(0, 0, 0, 0.3);
    background: #368200;
    border: 1px solid #2d6200;
    border-top: 1px solid #2d6200
}
.jfk-button-default.jfk-button-disabled {
    background: #3d9400;
    filter: alpha(opacity=50);
    opacity: 0.5
}
.jfk-button-primary {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: #d14836;
    background-image: -webkit-linear-gradient(top, #dd4b39, #d14836);
    background-image: -moz-linear-gradient(top, #dd4b39, #d14836);
    background-image: -ms-linear-gradient(top, #dd4b39, #d14836);
    background-image: -o-linear-gradient(top, #dd4b39, #d14836);
    background-image: linear-gradient(top, #dd4b39, #d14836);
    border: 1px solid transparent;
    color: #fff;
    text-shadow: 0px 1px rgba(0, 0, 0, 0.1);
    text-transform: uppercase
}
.jfk-button-primary.jfk-button-hover {
    -webkit-box-shadow: 0px 1px 1px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 1px 1px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 1px 1px rgba(0, 0, 0, 0.2);
    background-color: #c53727;
    background-image: -webkit-linear-gradient(top, #dd4b39, #c53727);
    background-image: -moz-linear-gradient(top, #dd4b39, #c53727);
    background-image: -ms-linear-gradient(top, #dd4b39, #c53727);
    background-image: -o-linear-gradient(top, #dd4b39, #c53727);
    background-image: linear-gradient(top, #dd4b39, #c53727);
    border: 1px solid #b0281a;
    border-bottom-color: #af301f
}
.jfk-button-primary:focus {
    -webkit-box-shadow: inset 0 0 0 1px #fff;
    -moz-box-shadow: inset 0 0 0 1px #fff;
    box-shadow: inset 0 0 0 1px #fff;
    border: 1px solid #fff;
    border: rgba(0, 0, 0, 0) solid 1px;
    outline: 1px solid #d14836;
    outline: rgba(0, 0, 0, 0) 0
}
.jfk-button-primary.jfk-button-clear-outline {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    outline: none
}
.jfk-button-primary:active {
    -webkit-box-shadow: inset 0px 1px 2px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: inset 0px 1px 2px rgba(0, 0, 0, 0.3);
    box-shadow: inset 0px 1px 2px rgba(0, 0, 0, 0.3);
    background-color: #b0281a;
    background-image: -webkit-linear-gradient(top, #dd4b39, #b0281a);
    background-image: -moz-linear-gradient(top, #dd4b39, #b0281a);
    background-image: -ms-linear-gradient(top, #dd4b39, #b0281a);
    background-image: -o-linear-gradient(top, #dd4b39, #b0281a);
    background-image: linear-gradient(top, #dd4b39, #b0281a);
    border: 1px solid #992a1b;
    border-top: 1px solid #992a1b
}
.jfk-button-primary.jfk-button-disabled {
    background: #d14836;
    filter: alpha(opacity=50);
    opacity: 0.5
}
.jfk-slideToggle {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    -webkit-box-shadow: inset 0px 1px 2px 0 rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0px 1px 2px 0 rgba(0, 0, 0, .1);
    box-shadow: inset 0px 1px 2px 0 rgba(0, 0, 0, .1);
    background-color: #f5f5f5;
    background-image: -webkit-linear-gradient(top, #eee, #e0e0e0);
    background-image: -moz-linear-gradient(top, #eee, #e0e0e0);
    background-image: -ms-linear-gradient(top, #eee, #e0e0e0);
    background-image: -o-linear-gradient(top, #eee, #e0e0e0);
    background-image: linear-gradient(top, #eee, #e0e0e0);
    border: 1px solid #ccc;
    color: #666;
    font-weight: bold;
    height: 27px;
    line-height: 27px;
    margin-right: 16px;
    outline: none;
    overflow: hidden;
    padding: 0;
    position: relative;
    width: 94px
}
.jfk-slideToggle-on,
.jfk-slideToggle-off,
.jfk-slideToggle-thumb {
    display: inline-block;
    text-align: center;
    text-transform: uppercase;
    width: 47px
}
.jfk-slideToggle-on {
    -webkit-box-shadow: inset 0 1px 2px 0 rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 1px 2px 0 rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 2px 0 rgba(0, 0, 0, .1);
    background-color: #398bf2;
    background-image: -webkit-linear-gradient(top, #3b93ff, #3689ee);
    background-image: -moz-linear-gradient(top, #3b93ff, #3689ee);
    background-image: -ms-linear-gradient(top, #3b93ff, #3689ee);
    background-image: -o-linear-gradient(top, #3b93ff, #3689ee);
    background-image: linear-gradient(top, #3b93ff, #3689ee);
    color: #fff;
    height: 27px
}
.jfk-slideToggle-off {
    -webkit-border-radius: 2px 2px 0 0;
    -moz-border-radius: 2px 2px 0 0;
    border-radius: 2px 2px 0 0
}
.jfk-slideToggle-thumb {
    -webkit-box-shadow: 0px 1px 2px 0 rgba(0, 0, 0, .1);
    -moz-box-shadow: 0px 1px 2px 0 rgba(0, 0, 0, .1);
    box-shadow: 0px 1px 2px 0 rgba(0, 0, 0, .1);
    background-color: #f5f5f5;
    background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -o-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
    -webkit-transition: all .130s ease-out;
    -moz-transition: all .130s ease-out;
    -o-transition: all .130s ease-out;
    transition: all .130s ease-out;
    border: 1px solid #ccc;
    display: block;
    height: 27px;
    left: -1px;
    position: absolute;
    top: -1px
}
.jfk-slideToggle-thumb::after {
    content: '';
    background-image: -webkit-linear-gradient(left, #ccc 50%, transparent 50%), -webkit-linear-gradient(left, #ccc 50%, transparent 50%), -webkit-linear-gradient(left, #ccc 50%, transparent 50%), -webkit-linear-gradient(left, #ccc 50%, transparent 50%), -webkit-linear-gradient(left, #ccc 50%, transparent 50%);
    background-image: -moz-linear-gradient(left, #ccc 50%, transparent 50%), -moz-linear-gradient(left, #ccc 50%, transparent 50%), -moz-linear-gradient(left, #ccc 50%, transparent 50%), -moz-linear-gradient(left, #ccc 50%, transparent 50%), -moz-linear-gradient(left, #ccc 50%, transparent 50%);
    background-image: -ms-linear-gradient(left, #ccc 50%, transparent 50%), -ms-linear-gradient(left, #ccc 50%, transparent 50%), -ms-linear-gradient(left, #ccc 50%, transparent 50%), -ms-linear-gradient(left, #ccc 50%, transparent 50%), -ms-linear-gradient(left, #ccc 50%, transparent 50%);
    background-image: -o-linear-gradient(left, #ccc 50%, transparent 50%), -o-linear-gradient(left, #ccc 50%, transparent 50%), -o-linear-gradient(left, #ccc 50%, transparent 50%), -o-linear-gradient(left, #ccc 50%, transparent 50%), -o-linear-gradient(left, #ccc 50%, transparent 50%);
    background-image: linear-gradient(left, #ccc 50%, transparent 50%), linear-gradient(left, #ccc 50%, transparent 50%), linear-gradient(left, #ccc 50%, transparent 50%), linear-gradient(left, #ccc 50%, transparent 50%), linear-gradient(left, #ccc 50%, transparent 50%);
    background-position: 0 0, 0 2px, 0 4px, 0 6px, 0 8px;
    background-repeat: repeat-x;
    background-size: 2px 1px;
    display: block;
    height: 9px;
    left: 15px;
    position: absolute;
    top: 9px;
    width: 17px
}
.jfk-slideToggle.jfk-slideToggle-checked .jfk-slideToggle-thumb {
    left: 47px
}
.jfk-slideToggle:focus {
    border: 1px solid #4d90fe
}
.jfk-slideToggle.jfk-slideToggle-clearOutline {
    border: 1px solid #ccc
}
.jfk-button-standard {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: #f5f5f5;
    background-image: -webkit-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -o-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: linear-gradient(top, #f5f5f5, #f1f1f1);
    color: #333;
    border: 1px solid #dcdcdc;
    border: 1px solid rgba(0, 0, 0, 0.1)
}
.jfk-button-standard.jfk-button-hover,
.jfk-button-standard.jfk-button-clear-outline.jfk-button-hover {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: #f8f8f8;
    background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -o-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
    border: 1px solid #c6c6c6;
    color: #111
}
.jfk-button-standard:active,
.jfk-button-standard.jfk-button-hover:active {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    background: #f8f8f8;
    color: #111
}
.jfk-button-standard.jfk-button-selected,
.jfk-button-standard.jfk-button-clear-outline.jfk-button-selected {
    background-color: #eee;
    background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -o-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
    border: 1px solid #ccc;
    color: #333
}
.jfk-button-standard.jfk-button-checked,
.jfk-button-standard.jfk-button-clear-outline.jfk-button-checked {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    background-color: #eee;
    background-image: -webkit-linear-gradient(top, #eee, #e0e0e0);
    background-image: -moz-linear-gradient(top, #eee, #e0e0e0);
    background-image: -ms-linear-gradient(top, #eee, #e0e0e0);
    background-image: -o-linear-gradient(top, #eee, #e0e0e0);
    background-image: linear-gradient(top, #eee, #e0e0e0);
    border: 1px solid #ccc;
    color: #333
}
.jfk-button-standard:focus {
    border: 1px solid #4d90fe;
    outline: none
}
.jfk-button-standard.jfk-button-clear-outline {
    border: 1px solid #dcdcdc;
    border: 1px solid rgba(0, 0, 0, 0.1);
    outline: none
}
.jfk-button-standard.jfk-button-disabled {
    background: #fff;
    border: 1px solid #f3f3f3;
    border: 1px solid rgba(0, 0, 0, 0.05);
    color: #b8b8b8
}
.jfk-button-standard .jfk-button-img {
    opacity: .70
}
.jfk-button-standard.jfk-button-checked .jfk-button-img,
.jfk-button-standard.jfk-button-selected .jfk-button-img,
.jfk-button-standard.jfk-button-hover .jfk-button-img {
    opacity: 0.9
}
.jfk-button-standard.jfk-button-disabled .jfk-button-img {
    filter: alpha(opacity=33);
    opacity: 0.333
}
.jfk-button-flat {
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    border-radius: 0;
    border: 1px solid transparent;
    font-size: 13px;
    font-weight: normal;
    height: 21px;
    line-height: 21px;
    margin-right: 1px;
    min-width: 0;
    padding: 0
}
.jfk-button-flat.jfk-button-hover,
.jfk-button-flat.jfk-button-selected,
.jfk-button-flat:focus,
.jfk-button-flat:active {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none
}
.jfk-button-flat .jfk-button-img {
    height: 21px;
    opacity: .70;
    width: 21px
}
.jfk-button-flat .jfk-button-label {
    display: inline-block;
    margin: 0;
    padding: 0 1px
}
.jfk-button-flat.jfk-button-selected .jfk-button-img,
.jfk-button-flat.jfk-button-hover .jfk-button-img {
    opacity: 0.9
}
.jfk-button-flat.jfk-button-disabled .jfk-button-img {
    filter: alpha(opacity=33);
    opacity: 0.333
}
.jfk-button-flat:focus {
    border: 1px solid #4d90fe
}
.jfk-button-flat.jfk-button-clear-outline {
    border: 1px solid transparent
}
.jfk-button-mini {
    background-color: #f5f5f5;
    background-image: -webkit-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -o-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: linear-gradient(top, #f5f5f5, #f1f1f1);
    border: 1px solid #dcdcdc;
    border: 1px solid rgba(0, 0, 0, 0.1);
    color: #333;
    height: 17px;
    line-height: 17px;
    min-width: 22px;
    text-shadow: 0px 1px rgba(0, 0, 0, 0.1)
}
.jfk-button-mini.jfk-button-hover,
.jfk-button-mini.jfk-button-clear-outline.jfk-button-hover {
    background-color: #f8f8f8;
    background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -o-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
    border: 1px solid #c6c6c6;
    text-shadow: 0px 1px rgba(0, 0, 0, 0.3)
}
.jfk-button-mini:active {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1)
}
.jfk-button-mini.jfk-button-checked,
.jfk-button-mini.jfk-button-clear-outline.jfk-button-checked {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    background-color: #e0e0e0;
    background-image: -webkit-linear-gradient(top, #eee, #e0e0e0);
    background-image: -moz-linear-gradient(top, #eee, #e0e0e0);
    background-image: -ms-linear-gradient(top, #eee, #e0e0e0);
    background-image: -o-linear-gradient(top, #eee, #e0e0e0);
    background-image: linear-gradient(top, #eee, #e0e0e0);
    border: 1px solid #ccc;
    color: #333
}
.jfk-button-mini:focus {
    border: 1px solid #4d90fe
}
.jfk-button-mini.jfk-button-clear-outline {
    border: 1px solid #dcdcdc
}
.jfk-button-mini.jfk-button-disabled {
    background: #fff;
    border: 1px solid #f3f3f3;
    border: 1px solid rgba(0, 0, 0, 0.05);
    color: #b8b8b8
}
.goog-modalpopup,
.modal-dialog {
    -webkit-box-shadow: 0 4px 16px rgba(0, 0, 0, .2);
    -moz-box-shadow: 0 4px 16px rgba(0, 0, 0, .2);
    box-shadow: 0 4px 16px rgba(0, 0, 0, .2);
    background: #fff;
    background-clip: padding-box;
    border: 1px solid #acacac;
    border: 1px solid rgba(0, 0, 0, .333);
    outline: 0;
    position: absolute
}
.goog-modalpopup-bg,
.modal-dialog-bg {
    background: #fff;
    left: 0;
    position: absolute;
    top: 0
}
div.goog-modalpopup-bg,
div.modal-dialog-bg {
    filter: alpha(opacity=75);
    -moz-opacity: .75;
    opacity: .75
}
.modal-dialog {
    color: #000;
    padding: 30px 42px
}
.modal-dialog-title {
    background-color: #fff;
    color: #000;
    cursor: default;
    font-size: 16px;
    font-weight: normal;
    line-height: 24px;
    margin: 0 0 16px
}
.modal-dialog-title-close {
    height: 11px;
    opacity: 0.7;
    padding: 17px;
    position: absolute;
    right: 0px;
    top: 0px;
    width: 11px
}
.modal-dialog-title-close:after {
    content: '';
    background: url(//ssl.gstatic.com/ui/v1/dialog/close-x.png);
    position: absolute;
    height: 11px;
    width: 11px;
    right: 17px
}
.modal-dialog-title-close:hover {
    opacity: 1
}
.modal-dialog-content {
    background-color: #fff;
    line-height: 1.4em;
    word-wrap: break-word
}
.modal-dialog-buttons {
    margin-top: 16px
}
.modal-dialog-buttons button {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    background-color: #f5f5f5;
    background-image: -webkit-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -o-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: linear-gradient(top, #f5f5f5, #f1f1f1);
    border: 1px solid #dcdcdc;
    border: 1px solid rgba(0, 0, 0, 0.1);
    color: #333;
    cursor: default;
    font-family: inherit;
    font-size: 11px;
    font-weight: bold;
    height: 29px;
    line-height: 27px;
    margin: 0 16px 0 0;
    min-width: 72px;
    outline: 0;
    padding: 0 8px
}
.modal-dialog-buttons button:hover,
.modal-dialog-buttons button:active {
    -webkit-box-shadow: 0px 1px 1px rgba(0, 0, 0, 0.1);
    -moz-box-shadow: 0px 1px 1px rgba(0, 0, 0, 0.1);
    box-shadow: 0px 1px 1px rgba(0, 0, 0, 0.1);
    background-color: #f8f8f8;
    background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -o-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
    border: 1px solid #c6c6c6;
    color: #111
}
.modal-dialog-buttons button:active {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1)
}
.modal-dialog-buttons button:focus {
    border: 1px solid #4d90fe
}
.modal-dialog-buttons button[disabled] {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background: #fff;
    background-image: none;
    border: 1px solid #f3f3f3;
    border: 1px solid rgba(0, 0, 0, 0.05);
    color: #b8b8b8
}
.modal-dialog-buttons .goog-buttonset-action {
    background-color: #4d90fe;
    background-image: -webkit-linear-gradient(top, #4d90fe, #4787ed);
    background-image: -moz-linear-gradient(top, #4d90fe, #4787ed);
    background-image: -ms-linear-gradient(top, #4d90fe, #4787ed);
    background-image: -o-linear-gradient(top, #4d90fe, #4787ed);
    background-image: linear-gradient(top, #4d90fe, #4787ed);
    border: 1px solid #3079ed;
    color: #fff
}
.modal-dialog-buttons .goog-buttonset-action:hover,
.modal-dialog-buttons .goog-buttonset-action:active {
    background-color: #357ae8;
    background-image: -webkit-linear-gradient(top, #4d90fe, #357ae8);
    background-image: -moz-linear-gradient(top, #4d90fe, #357ae8);
    background-image: -ms-linear-gradient(top, #4d90fe, #357ae8);
    background-image: -o-linear-gradient(top, #4d90fe, #357ae8);
    background-image: linear-gradient(top, #4d90fe, #357ae8);
    border: 1px solid #2f5bb7;
    color: #fff
}
.modal-dialog-buttons .goog-buttonset-action:active {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3)
}
.modal-dialog-buttons .goog-buttonset-action:focus {
    -webkit-box-shadow: inset 0 0 0 1px #fff;
    -moz-box-shadow: inset 0 0 0 1px #fff;
    box-shadow: inset 0 0 0 1px #fff;
    border: 1px solid #fff;
    border: rgba(0, 0, 0, 0) solid 1px;
    outline: 1px solid #4d90fe;
    outline: rgba(0, 0, 0, 0) 0
}
.modal-dialog-buttons .goog-buttonset-action[disabled] {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background: #4d90fe;
    color: #fff;
    filter: alpha(opacity=50);
    opacity: 0.5
}
.jfk-alert,
.jfk-confirm,
.jfk-prompt {
    width: 512px
}
.jfk-textinput {
    -webkit-border-radius: 1px;
    -moz-border-radius: 1px;
    border-radius: 1px;
    border: 1px solid #d9d9d9;
    border-top: 1px solid #c0c0c0;
    font-size: 13px;
    height: 25px;
    padding: 1px 8px
}
.jfk-textinput:focus {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    border: 1px solid #4d90fe;
    outline: none
}
.jfk-textinput::-ms-clear {
    display: none
}
.apps-action-shortcut-icon {
    direction: ltr;
    text-align: left;
    overflow: hidden;
    position: relative;
    vertical-align: middle
}
.apps-action-shortcut-img:before {
    content: url(//ssl.gstatic.com/docs/common/shortcut_sprite1.png)
}
.apps-action-shortcut-img {
    height: 95px;
    position: absolute;
    width: 21px
}
.apps-action-shortcut-back {
    left: 0;
    top: -63px
}
.apps-action-shortcut-back-white {
    left: 0;
    top: -21px
}
.apps-action-shortcut-close-x {
    left: 0;
    top: -84px
}
.apps-action-shortcut-search {
    left: 0;
    top: -42px
}
.apps-action-shortcut-search-white {
    left: 0;
    top: 0
}
.apps-ui-material-slide-toggle-container {
    -ms-flex-align: center;
    -webkit-align-items: center;
    align-items: center;
    background: none;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    height: 21px;
    outline: 0;
    position: relative;
    width: 35px
}
.apps-ui-material-slide-toggle-thumb {
    -webkit-transition-duration: 0.28s;
    -moz-transition-duration: 0.28s;
    -o-transition-duration: 0.28s;
    transition-duration: 0.28s;
    -webkit-transition-property: all;
    -moz-transition-property: all;
    -o-transition-property: all;
    transition-property: all;
    -webkit-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    left: 0;
    right: inherit;
    top: 0;
    will-change: background-color
}
.apps-ui-material-slide-toggle-container-checked .apps-ui-material-slide-toggle-thumb {
    left: inherit;
    right: 0
}
.apps-ui-material-slide-toggle-container-disabled {
    cursor: not-allowed
}
.apps-ui-material-slide-toggle-track {
    background-color: #000;
    border-radius: 7px;
    height: 14px;
    opacity: 0.26;
    width: 35px
}
.apps-ui-material-slide-toggle-container-checked .apps-ui-material-slide-toggle-track {
    opacity: 0.5
}
.apps-ui-material-slide-toggle-thumb {
    background-color: #f1f1f1;
    border-radius: 100%;
    box-shadow: 0 0 2px rgba(0, 0, 0, .12), 0 2px 4px rgba(0, 0, 0, .24);
    height: 20px;
    width: 20px;
    position: absolute
}
.apps-ui-material-slide-toggle-container-focused .apps-ui-material-slide-toggle-thumb {
    box-shadow: 0 0 4px rgba(0, 0, 0, .14), 0 4px 8px rgba(0, 0, 0, .28)
}
.apps-ui-material-slide-toggle-container-hover .apps-ui-material-slide-toggle-thumb {
    box-shadow: 0 0 6px rgba(0, 0, 0, .16), 0 6px 12px rgba(0, 0, 0, .32)
}
.apps-shortcutshelppopup {
    top: 0;
    z-index: 1002;
    color: #212121;
    font-family: roboto, arial, sans-serif;
    font-size: 13px;
    position: fixed;
    text-align: center;
    background: #fafafa none repeat scroll 0;
    overflow: hidden;
    box-shadow: rgba(255, 255, 255, .9) 0px 1px 0px inset, rgba(0, 0, 0, .03) 0px -1px 0px inset, rgba(0, 0, 0, .15) 0 15px 10px, rgba(0, 0, 0, .3) 0 8px 36px;
    border: 1px solid transparent
}
.apps-shortcutshelppopup input {
    font-family: roboto, arial, sans-serif
}
@media print {
    .apps-shortcutshelppopup {
        display: none
    }
}
.apps-shortcutshelppopup-bg {
    display: none;
    left: 0;
    top: 0;
    position: absolute
}
.apps-shortcutshelppopup-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    padding: 16px 32px;
    width: 800px;
    height: 600px
}
.apps-shortcutshelppopup-header,
.apps-shortcutshelppopup-content {
    border-collapse: collapse;
    width: 100%
}
.apps-shortcutshelppopup-header {
    -ms-flex: 0 0 auto;
    -webkit-flex: 0 0 auto;
    flex: 0 0 auto;
    border-bottom: 1px solid #e5e5e5;
    text-align: left
}
.apps-shortcutshelppopup-content {
    font-size: 13px;
    outline-offset: -1px
}
.apps-shortcutshelppopup-header-element {
    display: inline-block;
    vertical-align: middle;
    height: 48px
}
.apps-shortcutshelppopup-title-container {
    white-space: nowrap;
    text-align: left
}
.apps-shortcutshelppopup-dialog-title {
    font-size: 16px;
    color: #212121;
    display: inline-block;
    vertical-align: middle
}
.apps-shortcutshelppopup-input {
    font-size: 13px;
    margin-left: 16px;
    margin-right: 0px;
    padding: 0px 5px;
    vertical-align: middle;
    border-right: none;
    width: 250px;
    height: 27px;
    box-sizing: border-box
}
.apps-shortcutshelppopup-input-button-img {
    height: 21px;
    width: 21px;
    display: inline-block
}
.apps-shortcutshelppopup-input-button {
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    cursor: pointer;
    display: inline-block;
    margin-left: 0px;
    vertical-align: middle;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    line-height: 25px
}
.apps-shortcutshelppopup-tearoff-link {
    font-size: 13px;
    cursor: pointer;
    text-decoration: underline;
    color: #4581ff;
    vertical-align: middle;
    display: block;
    padding: 16px 0 13px 0;
    font-weight: bold
}
.apps-shortcutshelppopup-close {
    position: absolute;
    top: 0;
    right: 0;
    padding-right: 30px;
    padding-top: 30px
}
.apps-shortcutshelppopup-close svg {
    fill: #5f6368
}
.apps-shortcutshelppopup-close-nav-widget-enabled {
    padding-right: 18px;
    padding-top: 20px
}
.apps-shortcutshelppopup-dialog .modal-dialog-title-close {
    cursor: pointer;
    position: static;
    padding: 0px;
    margin: 0;
    margin-left: 32px;
    vertical-align: middle
}
.apps-shortcutshelppopup-dialog .modal-dialog-title-close:after {
    background: none;
    display: none
}
.apps-shortcutshelppopup-search-banner {
    -ms-flex: 0 0 auto;
    -webkit-flex: 0 0 auto;
    flex: 0 0 auto;
    text-align: left;
    height: 48px;
    padding-top: 12px;
    box-sizing: border-box
}
.apps-shortcutshelppopup-search-banner.apps-shortcutshelppopup-empty-search {
    position: relative;
    left: 0px;
    right: 0px;
    text-align: center;
    top: 113px;
    height: 48px
}
.apps-shortcutshelppopup-reset-search-button {
    cursor: pointer;
    text-decoration: underline;
    position: relative;
    width: 21px;
    min-width: 21px;
    display: inline-block;
    margin-right: 8px
}
.apps-shortcutshelppopup-reset-search-button-icon {
    height: 21px;
    width: 21px
}
.apps-shortcutshelppopup-search-label {
    margin: 0;
    position: relative;
    font-size: 15px;
    display: inline-block;
    vertical-align: middle
}
.apps-shortcutshelppopup-result-container {
    -ms-flex: 1 1 auto;
    -webkit-flex: 1 1 auto;
    flex: 1 1 auto;
    overflow: auto
}
.apps-shortcutshelppopup-content-header {
    height: 48px;
    padding-top: 25px;
    text-align: left;
    font-size: 13px;
    color: #212121;
    white-space: nowrap;
    margin: 0px;
    -moz-box-sizing: border-box;
    box-sizing: border-box
}
.apps-shortcutshelppopup-content-header.apps-shortcutshelppopup-content-header-first {
    height: 32px;
    padding-top: 8px
}
.apps-shortcutshelppopup-content-element {
    text-align: left;
    vertical-align: middle;
    padding-top: 0.15em;
    border-bottom: 1px solid #ececec;
    height: 32px;
    white-space: nowrap;
    -moz-box-sizing: border-box;
    box-sizing: border-box
}
.apps-shortcutshelppopup-shortcut-desc {
    color: #757575
}
.apps-shortcutshelppopup-shortcut-key {
    font-weight: bold
}
.apps-shortcutshelppopup-ac-renderer {
    z-index: 1003;
    font-family: Arial, sans-serif;
    font-size: 13px;
    position: absolute;
    background: #fff;
    border: 1px solid #666;
    box-shadow: 2px 2px 2px rgba(102, 102, 102, .4);
    width: 250px;
    box-sizing: border-box
}
.apps-shortcutshelppopup-ac-row {
    cursor: pointer;
    padding: .4em
}
.apps-shortcutshelppopup-ac-renderer .ac-active {
    background-color: #eee
}
.apps-shortcutshelpcontentimpl-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    background-color: white;
    height: 600px;
    width: 800px
}
@media screen and (max-width:832px) {
    .apps-shortcutshelpcontentimpl-container {
        max-width: 95vw
    }
}
@media screen and (max-height:632px) {
    .apps-shortcutshelpcontentimpl-container {
        height: 95vh
    }
}
.apps-shortcutshelpcontentimpl-header {
    -ms-flex: 0 0 auto;
    -webkit-flex: 0 0 auto;
    flex: 0 0 auto;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    text-align: left;
    border-collapse: collapse;
    width: 100%;
    padding: 16px 24px;
    box-sizing: border-box
}
.apps-shortcutshelpcontentimpl-header-element {
    display: inline-block;
    vertical-align: middle
}
.apps-shortcutshelpcontentimpl-title-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    white-space: nowrap;
    text-align: left
}
.apps-shortcutshelpcontentimpl-dialog-title {
    font-size: 18px;
    color: rgba(0, 0, 0, .87);
    display: inline-block;
    vertical-align: middle;
    padding: 16px 0;
    margin: 0;
    font-weight: 500
}
.apps-shortcutshelpcontentimpl-search {
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    border-radius: 4px;
    margin-left: 16px;
    margin-right: 24px;
    vertical-align: middle;
    height: 48px;
    padding: 0;
    background-color: rgba(0, 0, 0, 0.05);
    border: 1px solid transparent
}
.apps-shortcutshelpcontentimpl-search-icon {
    width: 24px;
    height: 24px;
    margin: 12px 8px 0 16px
}
.apps-shortcutshelpcontentimpl-search-icon svg {
    fill: #80868b
}
.apps-shortcutshelpcontentimpl-hc-black .apps-shortcutshelpcontentimpl-search-icon svg {
    fill: #fff
}
.apps-shortcutshelpcontentimpl-hc-white .apps-shortcutshelpcontentimpl-search-icon svg {
    fill: #000
}
.apps-shortcutshelpcontentimpl-search-focused {
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.24);
    background-color: #fff;
    transition: background-color 75ms
}
.apps-shortcutshelpcontentimpl-input {
    border: none;
    background-color: transparent;
    padding: 0 10px;
    flex-grow: 1;
    font-size: 14px;
    height: 46px;
    outline: none;
    box-shadow: none
}
.apps-shortcutshelpcontentimpl-input:focus {
    border: none;
    box-shadow: none
}
.apps-shortcutshelpcontentimpl-tearoff-link-container {
    -ms-flex: 0 0 auto;
    -webkit-flex: 0 0 auto;
    flex: 0 0 auto;
    padding: 10px;
    border-top: 1px solid rgba(0, 0, 0, 0.12);
    display: -webkit-inline-box;
    display: -moz-inline-box;
    display: -ms-inline-flexbox;
    display: -webkit-inline-flex;
    display: inline-flex;
    justify-content: center;
    align-items: center
}
.apps-shortcutshelpcontentimpl-tearoff-link-container-override-enabled {
    -ms-flex: 0 0 50%;
    -webkit-flex: 0 0 50%;
    flex: 0 0 50%;
    padding: 10px 0;
    display: -webkit-inline-box;
    display: -moz-inline-box;
    display: -ms-inline-flexbox;
    display: -webkit-inline-flex;
    display: inline-flex;
    justify-content: center;
    align-items: center
}
.apps-shortcutshelpcontentimpl-tearoff-link-container-legacy-enabled {
    display: -webkit-inline-box;
    display: -moz-inline-box;
    display: -ms-inline-flexbox;
    display: -webkit-inline-flex;
    display: inline-flex;
    justify-content: center;
    align-items: center;
    padding: 10px 20px;
    text-transform: uppercase
}
.apps-shortcutshelpcontentimpl-link {
    font-size: 13px;
    cursor: pointer;
    padding: 9px 16px;
    border-radius: 2px;
    font-weight: 500
}
.apps-shortcutshelpcontentimpl-link,
.apps-shortcutshelpcontentimpl-link:active {
    color: #1a73e8
}
.apps-shortcutshelpcontentimpl-link:hover {
    outline: none
}
.apps-shortcutshelpcontentimpl-link:focus {
    text-decoration: underline
}
.apps-shortcutshelpcontentimpl-link:visited {
    color: #1a73e8
}
.apps-shortcutshelpcontentimpl-override-shortcut-link {
    text-transform: uppercase
}
.apps-shortcutshelpcontentimpl-legacy-shortcut-link {
    display: -webkit-inline-box;
    display: -moz-inline-box;
    display: -ms-inline-flexbox;
    display: -webkit-inline-flex;
    display: inline-flex;
    justify-content: center;
    align-items: center
}
.apps-shortcutshelpcontentimpl-override-shortcut-link-disabled {
    cursor: inherit;
    opacity: 0.6
}
.apps-shortcutshelpcontentimpl-link.apps-shortcutshelpcontentimpl-override-shortcut-link-disabled:focus,
.apps-shortcutshelpcontentimpl-link.apps-shortcutshelpcontentimpl-override-shortcut-link-disabled:hover {
    text-decoration: none
}
.apps-shortcutshelpcontentimpl-search-banner {
    text-align: left;
    box-sizing: border-box;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    padding: 26px 0
}
.apps-shortcutshelpcontentimpl-reset-search-button {
    cursor: pointer;
    text-decoration: underline;
    position: relative;
    width: 21px;
    min-width: 21px;
    display: inline-block;
    margin: 0 8px;
    padding: 0 8px 0 4px;
    border-color: transparent;
    background-color: transparent;
    background-image: none
}
.apps-shortcutshelpcontentimpl-override-banner {
    padding: 5px 0 0 20px;
    line-height: 16px;
    white-space: pre;
    color: rgba(0, 0, 0, .87)
}
.apps-shortcutshelpcontentimpl-override-shortcut-key {
    font-weight: bold
}
.apps-shortcutshelpcontentimpl-reset-search-button-icon {
    display: inline-block;
    vertical-align: middle;
    height: 22px;
    width: 21px
}
.apps-shortcutshelpcontentimpl-reset-search-button-img {
    position: absolute
}
.apps-shortcutshelpcontentimpl-reset-search-button-img:before {
    content: url('//ssl.gstatic.com/images/icons/material/system/svg/keyboard_arrow_left_24px.svg')
}
.apps-shortcutshelpcontentimpl-search-label {
    margin: 0;
    position: relative;
    font-size: 19px;
    display: inline-block;
    vertical-align: middle;
    color: rgba(0, 0, 0, .87)
}
.apps-shortcutshelpcontentimpl-ac-renderer {
    z-index: 1003;
    font-family: Arial, sans-serif;
    font-size: 13px;
    font-weight: normal;
    position: absolute;
    background: #fff;
    border: 1px solid #666;
    box-shadow: 2px 2px 2px rgba(102, 102, 102, .4);
    width: 250px;
    box-sizing: border-box
}
.apps-shortcutshelpcontentimpl-ac-row {
    cursor: pointer;
    padding: .4em
}
.apps-shortcutshelpcontentimpl-ac-renderer .ac-active {
    background-color: #eee
}
.apps-shortcutshelpcontentimpl-content-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -ms-flex: 1 1 auto;
    -webkit-flex: 1 1 auto;
    flex: 1 1 auto;
    overflow: auto
}
.apps-shortcutshelpcontentimpl-sidebar {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -ms-flex: 0 0 192px;
    -webkit-flex: 0 0 192px;
    flex: 0 0 192px;
    vertical-align: top;
    position: relative;
    border-right: 1px solid rgba(0, 0, 0, 0.12);
    overflow-x: hidden;
    overflow-y: auto
}
.apps-shortcutshelpcontentimpl-shortcut-content {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -ms-flex: 1 1 auto;
    -webkit-flex: 1 1 auto;
    flex: 1 1 auto;
    overflow: auto
}
.apps-shortcutshelpcontentimpl-bottom-bar {
    -ms-flex: 0 0 auto;
    -webkit-flex: 0 0 auto;
    flex: 0 0 auto;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    border-top: 1px solid rgba(0, 0, 0, 0.12)
}
.apps-shortcutshelpcontentimpl-override-container {
    -ms-flex: 0 0 50%;
    -webkit-flex: 0 0 50%;
    flex: 0 0 50%;
    display: -webkit-inline-box;
    display: -moz-inline-box;
    display: -ms-inline-flexbox;
    display: -webkit-inline-flex;
    display: inline-flex;
    justify-content: center;
    align-items: center;
    box-sizing: border-box;
    border-left: 1px solid rgba(0, 0, 0, 0.12);
    border-collapse: collapse;
    padding: 10px 0
}
.apps-shortcutshelpcontentimpl-legacy-help-container {
    display: -webkit-inline-box;
    display: -moz-inline-box;
    display: -ms-inline-flexbox;
    display: -webkit-inline-flex;
    display: inline-flex;
    -ms-flex: 0 0 50%;
    -webkit-flex: 0 0 50%;
    flex: 0 0 50%;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    justify-content: flex-end
}
.apps-shortcutshelpcontentimpl-override-button-container {
    padding-left: 16px
}
.apps-shortcutshelpcontentimpl-override-label {
    padding: 0 5px 0 17px;
    font-weight: 500;
    color: rgba(0, 0, 0, .87)
}
.apps-shortcutshelpcontentimpl-legacy-label {
    color: rgba(0, 0, 0, .87);
    font-weight: 500;
    padding: 0 15px 0 17px
}
.apps-shortcutshelpcontentimpl-legacy-toggle-container {
    align-items: center;
    box-sizing: border-box;
    display: -webkit-inline-box;
    display: -moz-inline-box;
    display: -ms-inline-flexbox;
    display: -webkit-inline-flex;
    display: inline-flex;
    -ms-flex: 0 0 50%;
    -webkit-flex: 0 0 50%;
    flex: 0 0 50%;
    justify-content: flex-start;
    padding: 0 5px 0 17px
}
.apps-actiondatawidget {
    -ms-flex: 1 1 auto;
    -webkit-flex: 1 1 auto;
    flex: 1 1 auto;
    overflow: auto;
    position: relative;
    display: inline-block;
    outline: none;
    padding: 0 5px 0 16px
}
.apps-actiondatawidget-key-focused {
    outline: rgba(0, 0, 0, .87) solid 1px;
    outline-offset: -1px
}
.apps-actiondatawidget-content {
    font-size: 13px;
    outline-offset: -1px;
    table-layout: fixed;
    border-spacing: 0
}
.apps-actiondatawidget-content-header {
    height: 48px;
    padding-top: 25px;
    text-align: left;
    font-size: 13px;
    color: rgba(0, 0, 0, .87);
    white-space: nowrap;
    margin: 0px;
    -moz-box-sizing: border-box;
    box-sizing: border-box
}
.apps-actiondatawidget-content-element {
    text-align: left;
    vertical-align: middle;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    white-space: nowrap;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    padding: 11px 0
}
.apps-actiondatawidget-shortcut-desc {
    font-weight: normal;
    color: rgba(0, 0, 0, .87);
    word-wrap: break-word;
    white-space: normal;
    width: 240px;
    vertical-align: top
}
.apps-actiondatawidget-shortcut-key {
    color: rgba(0, 0, 0, .87);
    width: 310px
}
.apps-actiondatawidget-key-extra-padding {
    display: block;
    padding-bottom: 11px
}
.apps-actiondatawidget-override-keys-on {
    color: rgba(0, 0, 0, .87);
    display: block
}
.apps-actiondatawidget-last-item {
    margin-bottom: 2px
}
.apps-actiondatawidget-last-item-override-enabled {
    margin-bottom: 2px
}
.apps-actiondatawidget-last-row {
    height: 100%
}
.apps-actiondatawidget-override-keys-off {
    color: #bbbbbb;
    display: block
}
.apps-actiondatawidget-override-info-icon {
    height: 17px;
    width: 17px;
    float: right;
    display: block
}
.apps-actiondatawidget-override-info-svg {
    height: 17px;
    width: 17px;
    fill: #bbbbbb
}
.apps-shortcutshelpcontentimpl-hc-black .apps-actiondatawidget-override-info-svg {
    fill: white
}
.apps-actiondatawidget-override-keys-on .apps-actiondatawidget-override-info-svg {
    fill: #1a73e8
}
.jfk-tooltip.apps-actiondatawidget-override-info-icon-tooltip,
.jfk-tooltip.apps-actiondatawidget-override-info-icon-tooltip-unsupported,
.jfk-tooltip.apps-actiondatawidget-override-info-icon-tooltip-legacy {
    background-color: #727272;
    padding: 7px 8px
}
.jfk-tooltip.apps-actiondatawidget-override-info-icon-tooltip {
    width: 230px
}
.jfk-tooltip.apps-actiondatawidget-override-info-icon-tooltip-unsupported {
    width: 182px
}
.jfk-tooltip.apps-actiondatawidget-override-info-icon-tooltip-legacy {
    width: 190px
}
.apps-actiondatawidget-override-tooltip-text {
    line-height: 17px
}
.apps-actiondatawidget-override-info-icon-tooltip .jfk-tooltip-arrowdown .jfk-tooltip-arrowimplafter {
    border-color: #727272 transparent
}
.apps-actiondatawidget-override-browser-behavior-msg {
    color: #c5dbff
}
.apps-navigationwidget {
    -ms-flex: 1 1 auto;
    -webkit-flex: 1 1 auto;
    flex: 1 1 auto;
    display: inline-block;
    vertical-align: top;
    text-align: left;
    padding-top: 4px;
    color: rgba(0, 0, 0, .87);
    outline: transparent
}
.apps-navigationwidget-item {
    min-height: 33px;
    line-height: 24px;
    padding: 12px 1px 1px 24px
}
.apps-navigationwidget-item-selected {
    color: #1a73e8;
    font-weight: 500;
    outline: 1px solid transparent;
    outline-offset: -2px
}
.apps-navigationwidget-item-hover {
    cursor: pointer;
    background-color: #eee;
    outline: 1px dotted transparent;
    outline-offset: -2px
}
.apps-navigationwidget-item-disabled {
    opacity: 0.2
}
div.CSS_SHORTCUTS_HELP_POPUP {
    left: 10%;
    width: 80%;
    top: 10%;
    z-index: 1002;
    color: #fff;
    position: fixed;
    text-align: center;
    text-shadow: #000 1px 1px 7px;
    font-weight: bold;
    background: #000 none repeat scroll 0;
    overflow: hidden
}
@media print {
    div.CSS_SHORTCUTS_HELP_POPUP {
        display: none!important
    }
}
div.CSS_SHORTCUTS_HELP_POPUP_CONTAINER {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    max-height: inherit;
    overflow: auto;
    padding: 1em
}
table.CSS_SHORTCUTS_HELP_POPUP_HEADER,
table.CSS_SHORTCUTS_HELP_POPUP_CONTENT {
    width: 100%
}
.CSS_SHORTCUTS_HELP_POPUP_HEADER_TABLE_ELEMENT {
    padding-bottom: 0.8ex
}
.CSS_SHORTCUTS_HELP_POPUP_TITLE {
    font-size: 15px;
    white-space: nowrap;
    text-align: left
}
.CSS_SHORTCUTS_HELP_POPUP_TEAROFF_LINK_CONTAINER {
    color: #dd0;
    text-align: right
}
.CSS_SHORTCUTS_HELP_POPUP_TEAROFF_LINK_WRAPPER {
    position: absolute;
    top: 0;
    right: 0;
    padding-right: 32px;
    padding-top: 16px
}
.CSS_SHORTCUTS_HELP_CLOSE_PLACEHOLDER {
    height: 11px;
    width: 11px;
    padding: 6px;
    margin: 24px
}
.CSS_SHORTCUTS_HELP_POPUP_TEAROFF_LINK {
    font-size: 15px;
    cursor: pointer;
    text-decoration: underline;
    color: #dd0
}
table.CSS_SHORTCUTS_HELP_POPUP_CONTENT {
    border-top: 1px solid #999;
    font-size: 13px
}
.CSS_SHORTCUTS_HELP_POPUP_CONTENT_HEADER {
    color: #dd0;
    padding-top: 1em;
    text-align: left
}
.CSS_SHORTCUTS_HELP_POPUP_CONTENT_ELEMENT {
    vertical-align: top;
    padding-top: 0.15em
}
table.CSS_SHORTCUTS_HELP_POPUP_CONTENT td.CSS_SHORTCUTS_HELP_POPUP_KEY {
    font-weight: bold;
    padding-right: 0.5em;
    text-align: right;
    white-space: nowrap
}
table.CSS_SHORTCUTS_HELP_POPUP_CONTENT td.CSS_SHORTCUTS_HELP_POPUP_DESCRIPTION {
    font-weight: normal;
    text-align: left
}
span.CSS_SHORTCUTS_HELP_POPUP_KEY_MNEMONIC {
    font-family: "Courier New";
    color: #dd0
}
.CSS_SHORTCUTS_HELP_POPUP_PREF_CONTAINER {
    border-top: 1px solid #999;
    padding: .5em 0
}
.CSS_SHORTCUTS_HELP_POPUP_PREF_CONTENT {
    background: #dd0;
    color: #000;
    padding: 3px 7px;
    text-align: left;
    font-size: 13px;
    text-shadow: none
}
.CSS_SHORTCUTS_HELP_POPUP_PREF_ENABLED .CSS_SHORTCUTS_HELP_POPUP_PREF_CONTENT {
    background: none;
    color: #fff
}
.CSS_SHORTCUTS_HELP_POPUP_PREF_LINK {
    cursor: pointer;
    text-decoration: underline
}
.CSS_SHORTCUTS_HELP_POPUP_PREF_ENABLED .CSS_SHORTCUTS_HELP_POPUP_PREF_LINK {
    color: #dd0
}
.shortcuts-modalpopup-bg {
    display: none;
    left: 0;
    top: 0;
    position: absolute
}
@keyframes spin-clockwise {
    0% {
        transform: rotate(0deg)
    }
    100% {
        transform: rotate(360deg)
    }
}
.docs-save-indicator-animated {
    animation: spin-clockwise 2s linear infinite;
    transform-origin: center
}
.docs-save-indicator .docs-icon {
    margin: 3px
}
.docs-gm .docs-save-indicator {
    border-radius: 4px;
    font-size: 12px;
    color: #5f6368;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500
}
.docs-gm .docs-save-indicator:hover {
    background-color: #f1f3f4
}
.docs-gm .docs-save-indicator:active,
.docs-gm .docs-save-indicator.docs-save-indicator-selected {
    background-color: #e6f4ea;
    color: #188038
}
.docs-gm .docs-save-indicator-caption {
    padding-left: 3px;
    padding-right: 5px;
    vertical-align: middle
}
.docs-save-indicator-container .goog-control {
    outline: none
}
.docs-save-indicator.docs-save-indicator-unsaved-changes {
    background-color: #fce8e6;
    color: #d93025
}
.docs-save-indicator.docs-save-indicator-unsaved-changes:hover {
    background-color: #fadfdd;
    color: #d93025
}
.docs-save-indicator.docs-save-indicator-unsaved-changes:active,
.docs-save-indicator.docs-save-indicator-unsaved-changes.docs-save-indicator-selected {
    background-color: #f5cfce;
    color: #d93025
}
.docs-save-indicator-popup {
    width: 300px
}
.docs-save-indicator-popup.jfk-bubble {
    outline: none
}
.docs-save-indicator-popup .jfk-bubble-arrow {
    display: none
}
.docs-gm-dialogs .docs-save-indicator-popup-header {
    padding: 0;
    background-color: #e6f4ea;
    height: 40px
}
.docs-gm-dialogs .docs-save-indicator-popup-title-container {
    padding: 0 16px
}
.docs-material .docs-save-indicator-popup-title {
    font-size: 14px;
    font-weight: 500;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    margin: 0;
    color: #188038;
    line-height: 40px
}
.docs-material .docs-save-indicator-popup-icon {
    margin-right: 14px;
    width: 24px;
    height: 24px
}
.docs-save-indicator-popup-subtitle {
    font-size: 12px;
    font-weight: 500;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    color: #3c4043;
    padding: 10px 16px 0 16px
}
.docs-save-indicator-popup-text {
    font-size: 12px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    color: #3c4043;
    line-height: 16px;
    padding: 16px 16px 24px 16px
}
.docs-gm-dialogs .docs-save-indicator-popup.jfk-bubble {
    padding: 0;
    overflow: hidden;
    border: 0;
    border-radius: 4px
}
.docs-save-indicator-popup .docs-material-button.docs-save-indicator-popup-button {
    margin-bottom: 24px;
    margin-left: 16px;
    text-transform: none;
    height: 24px;
    padding: 4px 12px
}
.docs-save-indicator-unsaved-changes .docs-save-indicator-popup-header {
    background-color: #fce8e6
}
.docs-save-indicator-unsaved-changes .docs-save-indicator-popup-title {
    color: #d93025
}
.docs-save-indicator-unsaved-changes .docs-save-indicator-popup-button {
    background-color: #d93025
}
.docs-save-indicator-unsaved-changes .docs-save-indicator-popup-button.docs-material-button-hover,
.docs-save-indicator-unsaved-changes .docs-save-indicator-popup-button.docs-material-button-focused {
    background-color: #db4036
}
.docs-save-indicator-unsaved-changes .docs-save-indicator-popup-button.docs-material-button-active {
    background-color: #e5716a
}
.docs-save-indicator-unsaved-changes .docs-save-indicator-popup-button.docs-material-button-disabled {
    background-color: #f1f3f4
}
.docs-companion-app-switcher-container {
    background-color: white;
    border-top: 1px solid #d9d9d9;
    box-sizing: border-box;
    height: calc(100% - 60px);
    position: absolute;
    right: 0;
    top: 60px;
    width: 56px;
    z-index: 1
}
.docs-companion-app-switcher-container.docs-companion-app-switcher-container-collapsed {
    width: 0;
    z-index: 1001
}
.docs-material.docs-companion-app-switcher-container {
    height: calc(100% - 64px);
    top: 64px
}
.docs-material.docs-companion-app-switcher-container.docs-companion-app-switcher-container-collapsed {
    width: 0
}
.docs-companion-app-switcher-container.docs-app-switcher-container-hidden {
    display: none
}
.companion-about-panel-button.app-switcher-button {
    bottom: 0;
    position: absolute
}
.companion-about-panel-menu-header,
.companion-about-panel-menu-text {
    color: #3c4043
}
.companion-about-panel-menu-header {
    font-size: 18px;
    font-weight: 500;
    line-height: 24px;
    padding: 6px 24px 2px
}
.companion-about-panel-menu-separator {
    border-top: 1px solid #f1f3f4;
    margin: 8px 0
}
.companion-about-panel-menu-item {
    border: none;
    cursor: pointer;
    height: 48px;
    padding: 0
}
.companion-about-panel-menu-item-highlight {
    background: #f1f3f4
}
.companion-about-panel-menu-item-icon-container {
    height: 20px;
    padding: 14px 16px 14px 24px;
    position: absolute;
    width: 20px
}
.companion-about-panel-menu-item-disabled .companion-about-panel-menu-item-icon {
    fill: #dadce0
}
.companion-about-panel-menu-text {
    font-size: 14px;
    letter-spacing: .2px;
    line-height: 20px;
    padding: 13px 24px 11px 60px
}
.companion-about-panel-menu-item-disabled .companion-about-panel-menu-text {
    color: #dadce0;
    cursor: default
}
.companion-app-switcher-container {
    background-color: white;
    border-left: 1px solid #dadce0;
    box-sizing: border-box;
    display: flex;
    flex-direction: column;
    height: 100%;
    position: relative;
    width: 56px
}
.companion-app-switcher-guest-container {
    display: flex;
    flex: 1 0 auto;
    flex-direction: column;
    margin-bottom: 56px
}
.companion-app-switcher-add-on-container {
    display: flex;
    flex: 0 1 100%;
    flex-direction: column;
    overflow: hidden;
    padding-top: 16px
}
.companion-app-switcher-separator,
.companion-app-switcher-add-on-container::before {
    border-top: 1px solid #dadce0;
    content: '';
    display: block;
    flex: 1 0 auto;
    margin: 0 auto;
    padding-bottom: 16px;
    width: 20px
}
.companion-app-switcher-separator {
    margin-top: 16px
}
.companion-theme-dark.companion-app-switcher-container,
.companion-theme-light.companion-app-switcher-container {
    background-color: transparent
}
.companion-theme-dark.companion-app-switcher-container,
.companion-theme-dark .companion-app-switcher-separator,
.companion-theme-dark .companion-app-switcher-add-on-container::before {
    border-color: rgba(255, 255, 255, .12)
}
.companion-theme-light.companion-app-switcher-container,
.companion-theme-light .companion-app-switcher-separator,
.companion-theme-light .companion-app-switcher-add-on-container::before {
    border-color: rgba(100, 121, 143, .12)
}
.companion-guest-app-switcher {
    flex-grow: 1;
    height: 100px;
    outline: none
}
.companion-app-switcher-loading-indicator {
    padding: 16px 0
}
.companion-app-switcher-loading-indicator-dot {
    -webkit-animation: dotLoadingAnimation 1.0s infinite ease-in-out both;
    animation: dotLoadingAnimation 1.0s infinite ease-in-out both;
    height: 8px;
    background-color: #757575;
    border-radius: 50%;
    margin: 0 auto 12px;
    width: 8px
}
.companion-theme-dark .companion-app-switcher-loading-indicator-dot {
    background-color: #fff
}
.companion-app-switcher-loading-indicator-dot:last-child {
    margin-bottom: 0
}
.companion-app-switcher-loading-indicator-dot-1 {
    -webkit-animation-delay: -0.5s;
    animation-delay: -0.5s
}
.companion-app-switcher-loading-indicator-dot-2 {
    -webkit-animation-delay: -0.25s;
    animation-delay: -0.25s
}
@-webkit-keyframes dotLoadingAnimation {
    0%,
    80%,
    100% {
        opacity: 0.5
    }
    40% {
        opacity: 1.0
    }
}
@keyframes dotLoadingAnimation {
    0%,
    80%,
    100% {
        opacity: 0.5
    }
    40% {
        opacity: 1.0
    }
}
.app-switcher-button {
    cursor: pointer;
    height: 56px;
    outline: none;
    pointer-events: none;
    position: relative;
    transition: all .3s cubic-bezier(.4, 0, .2, 1);
    width: 56px
}
.app-switcher-button-disabled {
    cursor: default;
    opacity: .38
}
.app-switcher-button-focused .app-switcher-button-icon-background,
.app-switcher-button-focused.app-switcher-button-hover .app-switcher-button-icon-background,
.companion-theme-light .app-switcher-button-hover .app-switcher-button-icon-background,
.companion-theme-light .app-switcher-button-open .app-switcher-button-icon-background,
.companion-theme-light .app-switcher-button-selected.app-switcher-button-hover .app-switcher-button-icon-background {
    background-color: #e8eaed
}
.app-switcher-button-hover .app-switcher-button-icon-background,
.app-switcher-button-open .app-switcher-button-icon-background,
.companion-theme-light .app-switcher-button-selected .app-switcher-button-icon-background,
.companion-theme-light .app-switcher-button-focused .app-switcher-button-icon-background {
    background-color: #f1f3f4
}
.companion-theme-dark .app-switcher-button-selected .app-switcher-button-icon-background,
.companion-theme-dark .app-switcher-button-focused .app-switcher-button-icon-background {
    background-color: rgba(255, 255, 255, .24)
}
.companion-theme-dark .app-switcher-button-hover .app-switcher-button-icon-background,
.companion-theme-dark .app-switcher-button-open .app-switcher-button-icon-background,
.companion-theme-dark .app-switcher-button-selected.app-switcher-button-hover .app-switcher-button-icon-background {
    background-color: rgba(255, 255, 255, .12)
}
.app-switcher-button-icon-container {
    background-color: transparent;
    background-repeat: no-repeat;
    background-position: center;
    background-size: 20px 20px;
    border-radius: 50%;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    height: 40px;
    left: 8px;
    pointer-events: auto;
    position: absolute;
    top: 8px;
    transition: all .3s cubic-bezier(.4, 0, .2, 1);
    width: 40px
}
.app-switcher-button-icon-background {
    border-radius: 50%;
    display: -webkit-flex;
    display: flex;
    height: 40px;
    left: 8px;
    position: absolute;
    top: 8px;
    transition: all .3s cubic-bezier(.4, 0, .2, 1);
    width: 40px
}
.app-switcher-button-icon {
    display: block;
    fill: #5f6368;
    margin: auto;
    transition: all .3s cubic-bezier(.4, 0, .2, 1)
}
.companion-theme-dark .app-switcher-button-icon {
    fill: #fff
}
.app-switcher-button-presence .app-switcher-button-icon-background.app-switcher-button-icon-background-inner {
    -webkit-animation: presence-scale-inner 3s cubic-bezier(0.05, 0.69, 0.67, 1) infinite normal;
    animation: presence-scale-inner 3s cubic-bezier(0.05, 0.69, 0.67, 1) infinite normal;
    height: calc(40px - 8px);
    width: calc(40px - 8px);
    left: calc((8px/2) + 8px);
    top: calc((8px/2) + 8px)
}
.app-switcher-button-presence .app-switcher-button-icon-background.app-switcher-button-icon-background-outer {
    -webkit-animation: presence-scale-outer 3s cubic-bezier(0.05, 0.69, 0.67, 1) infinite normal;
    animation: presence-scale-outer 3s cubic-bezier(0.05, 0.69, 0.67, 1) infinite normal;
    background-color: transparent;
    border-style: solid;
    border-width: calc(8px/2);
    height: 40px;
    width: 40px;
    left: calc(8px - (8px/2));
    top: calc(8px - (8px/2))
}
.app-switcher-button-inksplash .app-switcher-button-icon-background.app-switcher-button-icon-background-inner {
    -webkit-animation: inksplash-scale-background 2s cubic-bezier(0.05, 0.69, 0.67, 1) infinite normal;
    animation: inksplash-scale-background 2s cubic-bezier(0.05, 0.69, 0.67, 1) infinite normal
}
.app-switcher-button-inksplash .app-switcher-button-icon-container {
    -webkit-animation: inksplash-scale-icon 2s cubic-bezier(0.05, 0.69, 0.67, 1) infinite normal;
    animation: inksplash-scale-icon 2s cubic-bezier(0.05, 0.69, 0.67, 1) infinite normal
}
@keyframes presence-scale-inner {
    0% {
        opacity: 0;
        transform: scale(0.57);
        visibility: hidden
    }
    15% {
        opacity: 0;
        transform: scale(0.57);
        visibility: visible
    }
    35% {
        opacity: 1;
        transform: scale(1)
    }
    60% {
        opacity: 0;
        transform: scale(0.57)
    }
    100% {
        opacity: 0;
        transform: scale(0.57);
        visibility: hidden
    }
}
@keyframes presence-scale-outer {
    0% {
        opacity: 0;
        transform: scale(0.75);
        visibility: hidden
    }
    34% {
        opacity: 0;
        transform: scale(0.75);
        visibility: visible
    }
    36% {
        opacity: 0.99
    }
    65% {
        opacity: 1
    }
    90% {
        transform: scale(1)
    }
    100% {
        opacity: 0;
        transform: scale(1);
        visibility: hidden
    }
}
@keyframes inksplash-scale-background {
    0% {
        opacity: 0;
        transform: scale(0.00)
    }
    35% {
        opacity: 0;
        transform: scale(0.40)
    }
    50% {
        opacity: 1
    }
    80% {
        transform: scale(2.05)
    }
    100% {
        opacity: 0;
        transform: scale(0.00)
    }
}
@keyframes inksplash-scale-icon {
    0% {
        transform: scale(1.00)
    }
    20% {
        transform: scale(1.00)
    }
    30% {
        transform: scale(1.10)
    }
    40% {
        transform: scale(1.00)
    }
    100% {
        transform: scale(1.00)
    }
}
.app-switcher-menu {
    background: #fff;
    border: 1px solid rgba(0, 0, 0, .2);
    border-radius: 8px;
    box-shadow: 0 1px 2px 0 rgba(60, 64, 67, .30), 0 2px 6px 2px rgba(60, 64, 67, .15);
    min-width: 180px;
    outline: none;
    overflow-y: auto;
    padding: 8px 0;
    position: absolute;
    z-index: 999
}
.companion-collapser-button-container {
    bottom: 0;
    display: -webkit-flex;
    display: flex;
    height: 56px;
    overflow: hidden;
    position: absolute;
    right: 0;
    width: 56px
}
.companion-collapser-button-container.companion-collapser-button-container-elevated {
    margin-bottom: 24px
}
.companion-collapser-button {
    bottom: 0
}
.companion-collapser-button .app-switcher-button-icon-container,
.companion-collapser-button .app-switcher-button-icon-background {
    border-radius: calc(56px - 8px - 10px)
}
.companion-collapser-button.app-switcher-button-checked .app-switcher-button-icon-background,
.companion-theme-light .companion-collapser-button.app-switcher-button-checked .app-switcher-button-icon-background {
    background-color: #fff
}
.companion-collapser-button.app-switcher-button-checked.app-switcher-button-hover .app-switcher-button-icon-background,
.companion-theme-light .companion-collapser-button.app-switcher-button-checked.app-switcher-button-hover .app-switcher-button-icon-background {
    background-color: #f1f3f4
}
.companion-theme-dark .companion-collapser-button.app-switcher-button-checked .app-switcher-button-icon-background {
    background-color: #595959
}
.companion-collapser-button.app-switcher-button-checked.app-switcher-button-focused .app-switcher-button-icon-background,
.companion-theme-light .companion-collapser-button.app-switcher-button-checked.app-switcher-button-focused .app-switcher-button-icon-background {
    background-color: #e8eaed
}
.companion-collapser-button.app-switcher-button-checked {
    right: -24px
}
.companion-collapser-button.app-switcher-button-checked .app-switcher-button-icon-container,
.companion-collapser-button.app-switcher-button-checked .app-switcher-button-icon-background {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0;
    height: 20px;
    left: 0;
    margin: 8px 0 8px 8px;
    padding: 10px 0 10px 10px;
    top: 0;
    width: calc(56px - 8px - 10px)
}
.companion-collapser-button.app-switcher-button-checked .app-switcher-button-icon-background {
    box-shadow: 0 1px 1px 0 rgba(60, 64, 67, .3), 0 1px 3px 1px rgba(60, 64, 67, .15)
}
.companion-collapser-button.app-switcher-button-checked.app-switcher-button-hover {
    right: 0
}
.companion-collapser-button .app-switcher-button-icon {
    left: 10px;
    position: absolute;
    top: 10px
}
html[dir="rtl"] .companion-collapser-button .app-switcher-button-icon,
body[dir="rtl"] .companion-collapser-button .app-switcher-button-icon {
    transform: rotate(180deg)
}
.companion-theme-dark .companion-collapser-button.app-switcher-button-checked.app-switcher-button-focused .app-switcher-button-icon-container,
.companion-theme-dark .companion-collapser-button.app-switcher-button-checked.app-switcher-button-hover .app-switcher-button-icon-container {
    background-color: #414141
}
.companion-collapser-button.app-switcher-button-checked .app-switcher-button-icon {
    margin-left: -6px;
    transform: rotate(180deg)
}
.companion-collapser-button.app-switcher-button-checked.app-switcher-button-hover .app-switcher-button-icon {
    margin-left: 0
}
html[dir="rtl"] .companion-collapser-button.app-switcher-button-checked .app-switcher-button-icon,
body[dir="rtl"] .companion-collapser-button.app-switcher-button-checked .app-switcher-button-icon {
    transform: rotate(0deg)
}
.acdd-draggable-shadow {
    background-color: white;
    background-repeat: no-repeat;
    border: transparent;
    border-radius: 8px;
    box-sizing: border-box;
    color: #666;
    height: 56px;
    outline: none;
    padding: 0 10px;
    pointer-events: none;
    position: fixed;
    z-index: 999
}
.acdd-draggable-shadow.acdd-draggable-shadow-detail-type {
    background-position: 20px center;
    background-size: 24px 24px;
    height: 56px;
    width: 200px
}
.acdd-draggable-shadow.acdd-draggable-shadow-image-type {
    background-position: center;
    background-size: 100% auto;
    height: 120px;
    width: 120px
}
.acdd-draggable-shadow.acdd-draggable-shadow-image-type.acdd-draggable-shadow-image-captioned {
    height: 156px
}
.acdd-draggable-shadow-text-wrap {
    box-sizing: border-box;
    display: table-cell;
    padding-left: 48px;
    max-width: 200px;
    vertical-align: middle
}
.acdd-draggable-shadow-text-wrap .acdd-draggable-shadow-title {
    font-size: 1.1em
}
.acdd-draggable-shadow-text-wrap .acdd-draggable-shadow-text {
    opacity: .75;
    padding-top: 2px
}
.acdd-draggable-shadow-image-type .acdd-draggable-shadow-text {
    background-color: rgba(32, 33, 36, .71);
    border-radius: 0 0 8px 8px;
    bottom: 0;
    color: white;
    height: 36px;
    left: 0;
    padding: 8px 10px;
    position: absolute;
    width: 100%
}
.acdd-draggable-shadow .acdd-draggable-shadow-title,
.acdd-draggable-shadow .acdd-draggable-shadow-text {
    box-sizing: border-box;
    margin: 0;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.acdd-draggable-shadow .acdd-draggable-shadow-count-bubble {
    background-color: #202124;
    border-radius: 20px;
    box-sizing: border-box;
    color: white;
    font-size: 16px;
    height: 40px;
    max-width: 75%;
    min-width: 40px;
    overflow: hidden;
    padding: 9px 8px;
    position: absolute;
    right: -15px;
    text-align: center;
    text-overflow: ellipsis;
    top: -15px
}
.acga-topLevelDiv {
    height: 100%;
    position: relative;
    width: 100%
}
.acga-content {
    height: 100%;
    left: 0;
    position: absolute;
    top: 0;
    width: 100%;
    z-index: 0
}
.agca-gab-unread-notifications::after {
    content: "";
    background-color: #db4437;
    border-radius: 50%;
    height: 8px;
    position: absolute;
    right: 17px;
    top: 17px;
    width: 8px
}
.companion-guest-app-switcher .app-switcher-button-icon-background-outer {
    border-color: #e8f0fe
}
.companion-theme-light .agca-gab-blue .app-switcher-button-icon-background-outer {
    border-color: rgba(66, 133, 244, .24)
}
.agca-gab-green .app-switcher-button-icon-background-outer {
    border-color: #e6f4ea
}
.companion-theme-light .agca-gab-green .app-switcher-button-icon-background-outer {
    border-color: rgba(52, 168, 83, .24)
}
.agca-gab-yellow .app-switcher-button-icon-background-outer {
    border-color: #fef7e0
}
.companion-theme-light .agca-gab-yellow .app-switcher-button-icon-background-outer {
    border-color: rgba(251, 188, 4, .24)
}
.companion-theme-dark .agca-gab-button .app-switcher-button-icon-background-outer {
    border-color: rgba(255, 255, 255, .24)
}
.companion-guest-app-switcher .app-switcher-button-inksplash .app-switcher-button-icon-background-inner,
.companion-guest-app-switcher .app-switcher-button-presence .app-switcher-button-icon-background-inner,
.companion-guest-app-switcher .app-switcher-button-selected .app-switcher-button-icon-background-inner,
.app-switcher-button-selected.agca-gab-blue.app-switcher-button-focused .app-switcher-button-icon-background-inner {
    background-color: #e8f0fe
}
.app-switcher-button-selected.agca-gab-blue.app-switcher-button-hover .app-switcher-button-icon-background-inner {
    background-color: #d2e3fc
}
.companion-theme-light .app-switcher-button-inksplash.agca-gab-blue .app-switcher-button-icon-background-inner,
.companion-theme-light .app-switcher-button-presence.agca-gab-blue .app-switcher-button-icon-background-inner,
.companion-theme-light .app-switcher-button-selected.agca-gab-blue .app-switcher-button-icon-background-inner,
.companion-theme-light .app-switcher-button-selected.agca-gab-blue.app-switcher-button-focused .app-switcher-button-icon-background-inner {
    background-color: rgba(66, 133, 244, .24)
}
.companion-theme-light .agca-gab-blue.app-switcher-button-hover .app-switcher-button-icon-background-inner,
.companion-theme-light .agca-gab-blue.app-switcher-button-focused .app-switcher-button-icon-background-inner {
    background-color: rgba(66, 133, 244, .12)
}
.app-switcher-button-inksplash.agca-gab-green .app-switcher-button-icon-background-inner,
.app-switcher-button-presence.agca-gab-green .app-switcher-button-icon-background-inner,
.app-switcher-button-selected.agca-gab-green .app-switcher-button-icon-background-inner,
.app-switcher-button-selected.agca-gab-green.app-switcher-button-focused .app-switcher-button-icon-background-inner {
    background-color: #e6f4ea
}
.app-switcher-button-selected.agca-gab-green.app-switcher-button-hover .app-switcher-button-icon-background-inner {
    background-color: #ceead6
}
.companion-theme-light .app-switcher-button-inksplash.agca-gab-green .app-switcher-button-icon-background-inner,
.companion-theme-light .app-switcher-button-presence.agca-gab-green .app-switcher-button-icon-background-inner,
.companion-theme-light .app-switcher-button-selected.agca-gab-green .app-switcher-button-icon-background-inner,
.companion-theme-light .app-switcher-button-selected.agca-gab-green.app-switcher-button-focused .app-switcher-button-icon-background-inner {
    background-color: rgba(52, 168, 83, .24)
}
.companion-theme-light .agca-gab-green.app-switcher-button-hover .app-switcher-button-icon-background-inner,
.companion-theme-light .agca-gab-green.app-switcher-button-focused .app-switcher-button-icon-background-inner {
    background-color: rgba(52, 168, 83, .12)
}
.app-switcher-button-inksplash.agca-gab-yellow .app-switcher-button-icon-background-inner,
.app-switcher-button-presence.agca-gab-yellow .app-switcher-button-icon-background-inner,
.app-switcher-button-selected.agca-gab-yellow .app-switcher-button-icon-background-inner,
.app-switcher-button-selected.agca-gab-yellow.app-switcher-button-focused .app-switcher-button-icon-background-inner {
    background-color: #fef7e0
}
.app-switcher-button-selected.agca-gab-yellow.app-switcher-button-hover .app-switcher-button-icon-background-inner {
    background-color: #feefc3
}
.companion-theme-light .app-switcher-button-inksplash.agca-gab-yellow .app-switcher-button-icon-background-inner,
.companion-theme-light .app-switcher-button-presence.agca-gab-yellow .app-switcher-button-icon-background-inner,
.companion-theme-light .app-switcher-button-selected.agca-gab-yellow .app-switcher-button-icon-background-inner,
.companion-theme-light .app-switcher-button-selected.agca-gab-yellow.app-switcher-button-focused .app-switcher-button-icon-background-inner {
    background-color: rgba(251, 188, 4, .24)
}
.companion-theme-light .agca-gab-yellow.app-switcher-button-hover .app-switcher-button-icon-background-inner,
.companion-theme-light .agca-gab-yellow.app-switcher-button-focused .app-switcher-button-icon-background-inner {
    background-color: rgba(251, 188, 4, .12)
}
.companion-theme-dark .agca-gab-button.app-switcher-button-inksplash .app-switcher-button-icon-background-inner,
.companion-theme-dark .agca-gab-button.app-switcher-button-presence .app-switcher-button-icon-background-inner,
.companion-theme-dark .agca-gab-button.app-switcher-button-selected .app-switcher-button-icon-background-inner,
.companion-theme-dark .agca-gab-button.app-switcher-button-selected.app-switcher-button-focused .app-switcher-button-icon-background-inner {
    background-color: rgba(255, 255, 255, .24)
}
.companion-theme-dark .agca-gab-button.app-switcher-button-hover .app-switcher-button-icon-background-inner,
.companion-theme-dark .agca-gab-button.app-switcher-button-focused .app-switcher-button-icon-background-inner {
    background-color: rgba(255, 255, 255, .12)
}
.agca-gab-icon-selection-indicator {
    background-color: #d704fb;
    border-radius: 3px 0 0 3px;
    display: none;
    height: 40px;
    position: absolute;
    right: 1px;
    top: 8px;
    width: 3px
}
.agca-gab-button.app-switcher-button-selected .agca-gab-icon-selection-indicator {
    display: inherit
}
.agca-gab-blue .agca-gab-icon-selection-indicator {
    background-color: #4285f4
}
.agca-gab-green .agca-gab-icon-selection-indicator {
    background-color: #34a853
}
.agca-gab-yellow .agca-gab-icon-selection-indicator {
    background-color: #fbbc04
}
.companion-theme-dark .companion-overflow-menu-button:not(.app-switcher-button-hover) .app-switcher-button-icon-background {
    opacity: .7
}
.companion-shell-content-component {
    background-color: white;
    box-sizing: border-box;
    height: 100%;
    left: 0;
    padding-top: 64px;
    position: absolute;
    top: 0;
    width: 100%
}
.companion-header-in-iframe .companion-shell-guest {
    padding-top: 0
}
.companion-shell-loading {
    overflow: hidden;
    position: absolute;
    text-align: center
}
.companion-shell-offline,
.companion-shell-permanent-failure,
.companion-shell-timed-out,
.companion-shell-unavailable {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-flex;
    display: flex;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-justify-content: center;
    justify-content: center;
    text-align: center
}
.companion-shell-offline-description,
.companion-shell-offline-title,
.companion-shell-unavailable-description,
.companion-shell-unavailable-title {
    color: #5f6368;
    margin: 0 70px
}
.companion-shell-offline-description,
.companion-shell-unavailable-description {
    font-size: 12px;
    line-height: 16px
}
.companion-shell-offline-title,
.companion-shell-unavailable-title {
    font-size: 16px;
    font-weight: 500;
    margin-bottom: 2px;
    margin-top: 34px
}
.companion-shell-permanent-failure-message,
.companion-shell-timed-out-message {
    margin: 10px;
    max-width: calc(100% - 20px)
}
.companion-shell-timed-out-retry {
    color: #4285f4;
    cursor: pointer;
    text-transform: uppercase
}
.companion-shell-iframe {
    border: 0;
    height: 100%;
    width: 100%
}
.companion-shell-header {
    align-items: center;
    background-color: #fff;
    border-bottom: solid 1px #f1f3f4;
    box-sizing: border-box;
    display: -webkit-flex;
    display: flex;
    -webkit-flex-direction: row;
    flex-direction: row;
    -moz-osx-font-smoothing: grayscale;
    -webkit-font-smoothing: antialiased;
    height: 64px;
    padding: 0 10px;
    position: relative;
    z-index: 1
}
.companion-shell-header-element {
    margin-left: 10px;
    margin-right: 10px
}
.companion-shell-title-container {
    display: -webkit-flex;
    display: flex;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    justify-content: center;
    width: 1px
}
.companion-shell-title-element {
    margin: 0
}
.companion-shell-title-text,
.companion-shell-subtitle-text,
.companion-shell-subtitle-text .goog-menu-button-caption {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.companion-shell-title-text,
.companion-shell-subtitle-text {
    outline: none
}
.companion-shell-title-text.companion-shell-title-big {
    font-size: 22px
}
.companion-shell-header-light-background .companion-shell-title-big {
    color: rgba(0, 0, 0, .54)
}
.companion-shell-header-dark-background .companion-shell-title-big {
    color: #fff
}
.companion-shell-title-text.companion-shell-title-small {
    color: #80868b;
    font-size: 10px;
    font-weight: 500;
    letter-spacing: 1.5px;
    text-transform: uppercase
}
.companion-shell-title-text.companion-shell-title-small.companion-shell-subview {
    left: 56px
}
.companion-shell-dropdown-container {
    font-size: 0
}
.companion-shell-subtitle-text {
    color: #5f6368;
    font-size: 16px;
    font-weight: 500;
    line-height: 20px
}
.companion-shell-subtitle-text.goog-menu-button-open {
    background-color: #f1f3f4
}
.companion-shell-subtitle-button {
    padding: 0 2px 0 4px
}
.companion-shell-subtitle-button .companion-shell-subtitle-text,
.companion-shell-subtitle-text .goog-menu-button-caption {
    padding: 0
}
.companion-shell-subtitle-call-out {
    color: #1a73e8
}
.companion-shell-dropdown-button {
    background: none;
    border-radius: 3px;
    border-width: 0;
    box-sizing: border-box;
    cursor: pointer;
    display: inline-block;
    margin-left: -4px;
    max-width: 100%;
    outline: none;
    padding: 0 2px 0 4px
}
.companion-shell-dropdown-button.companion-shell-dropdown-button-hover {
    background-color: #f1f3f4
}
.companion-shell-dropdown-button.companion-shell-dropdown-button-focused,
.companion-shell-dropdown-button.companion-shell-dropdown-button-open {
    background-color: #e8eaed
}
.companion-shell-dropdown-button.companion-shell-dropdown-button-disabled {
    opacity: .38
}
.companion-shell-dropdown-button .companion-shell-dropdown-button-outer-box {
    display: -webkit-flex;
    display: flex;
    -webkit-justify-content: flex-start;
    justify-content: flex-start
}
.companion-shell-dropdown-button .companion-shell-dropdown-button-inner-box {
    display: block;
    -webkit-flex-shrink: 1;
    flex-shrink: 1;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.companion-shell-dropdown-button-outer-box::after {
    content: '';
    display: block;
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0naHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmcnIHdpZHRoPScyNHB4JyBoZWlnaHQ9JzI0cHgnIHZpZXdCb3g9JzAgMCAyNCAyNCcgZmlsbD0nIzVmNjM2OCc+PHBhdGggZD0nTTcgMTBsNSA1IDUtNXonPjwvcGF0aD48cGF0aCBkPSdNMCAwaDI0djI0SDB6JyBmaWxsPSdub25lJz48L3BhdGg+PC9zdmc+") center no-repeat;
    -webkit-flex-shrink: 0;
    flex-shrink: 0;
    height: 20px;
    margin: 0 0 0 4px;
    padding: 0;
    width: 20px
}
.companion-shell-header-buttons {
    display: -webkit-flex;
    display: flex;
    height: 24px;
    -webkit-justify-content: flex-end;
    justify-content: flex-end;
    position: absolute;
    right: 8px;
    top: 18px
}
.companion-shell-header-button {
    background: no-repeat center center;
    background-size: 20px 20px;
    cursor: pointer;
    height: 24px;
    width: 24px
}
.companion-shell-header-light-background .companion-shell-header-svg-icon {
    fill: #000;
    opacity: .54
}
.companion-shell-header-dark-background .companion-shell-header-svg-icon {
    fill: #fff
}
html[dir="rtl"] .companion-shell-back-button,
body[dir="rtl"] .companion-shell-back-button,
html[dir="rtl"] .companion-shell-escape-hatch-button,
body[dir="rtl"] .companion-shell-escape-hatch-button {
    transform: scaleX(-1)
}
.companion-shell-header-button.companion-shell-title-element {
    margin: 0
}
.companion-shell-header-button:hover {
    opacity: .87
}
.companion-shell-subtitle-button[aria-disabled="true"],
.companion-shell-header-button[aria-disabled="true"] {
    cursor: not-allowed;
    opacity: .38
}
.companion-shell-back-button {
    margin-right: 2px
}
.goog-menu.companion-shell-drop-down-menu {
    background: #fff;
    border-width: 0;
    border-radius: 0 0 8px 8px;
    box-shadow: 0px -3px 6px -3px rgba(0, 0, 0, .12), 0 4px 8px -2px rgba(0, 0, 0, .14);
    box-sizing: border-box;
    max-height: 400px;
    overflow-x: hidden;
    overflow-y: auto;
    padding-bottom: 8px;
    position: absolute;
    width: 100%;
    z-index: 999
}
.goog-menuitem.companion-shell-drop-down-entry {
    border: none;
    height: 40px;
    padding: 0;
    width: 300px
}
.goog-menuitem-highlight.companion-shell-drop-down-entry {
    background: #f1f3f4
}
.goog-menu.companion-shell-drop-down-menu .goog-menuseparator {
    border-top: 1px solid rgba(32, 33, 36, 0.06);
    margin: 8px 0;
    padding: 0
}
.companion-shell-drop-down-check {
    display: none;
    height: 20px;
    padding: 10px 16px;
    position: absolute;
    right: 0;
    width: 20px
}
.goog-option-selected .companion-shell-drop-down-check {
    display: block
}
.companion-shell-drop-down-entry.goog-option-selected {
    background-image: none
}
.companion-shell-drop-down-entry .goog-menuitem-checkbox,
.companion-shell-drop-down-entry.goog-option-selected .goog-menuitem-checkbox {
    display: none
}
.companion-shell-drop-down-entry-text {
    box-sizing: border-box;
    font-size: 14px;
    color: #202124;
    padding: 10px 20px;
    letter-spacing: 0.2px;
    line-height: 20px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    width: 300px
}
.goog-option-selected .companion-shell-drop-down-entry-text {
    padding-right: 60px
}
.companion-shell-search-container {
    align-items: center;
    background-color: #fff;
    box-sizing: border-box;
    display: -webkit-flex;
    display: flex;
    -webkit-flex-direction: row;
    flex-direction: row;
    height: 100%;
    left: 0;
    padding: 0 10px;
    position: absolute;
    top: 0;
    width: 100%
}
.companion-shell-search-icon,
.companion-shell-search-close {
    margin-left: 10px;
    margin-right: 10px
}
.companion-shell-search-input {
    background-color: transparent;
    border: none;
    color: #5f6368;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    font-size: 16px;
    line-height: 24px;
    outline: none;
    width: 100px
}
.companion-shell-search-input::placeholder {
    color: #bdc1c6
}
.companion-shell-search-input::-webkit-input-placeholder {
    color: #bdc1c6
}
.companion-shell-search-input:-ms-input-placeholder {
    color: #bdc1c6
}
.companion-app-switcher-container .jfk-bubble {
    padding: 16px;
    border-radius: 8px
}
.app-switcher-notification-bubble {
    display: -webkit-flex;
    display: flex;
    -webkit-flex-direction: column;
    flex-direction: column
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-header {
    display: -webkit-flex;
    display: flex;
    -webkit-flex-direction: row;
    flex-direction: row;
    height: 32px
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-image-container {
    width: 32px;
    border-radius: 50%
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-image-container .app-switcher-notification-bubble-image {
    width: 32px;
    height: 32px;
    border-radius: 50%;
    margin-right: 8px
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-text {
    height: calc(14px*2);
    width: auto;
    display: -webkit-flex;
    display: flex;
    -webkit-flex-direction: column;
    flex-direction: column;
    margin-left: 8px;
    margin-bottom: 8px
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-text:focus {
    outline: none
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-title-text {
    height: 14px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    color: #5f6368
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-body-text {
    height: 14px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    color: #3c4043
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-footer {
    margin-top: 9px;
    height: 32px;
    display: -webkit-flex;
    display: flex;
    -webkit-flex-direction: row;
    flex-direction: row
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-footer .jfk-button {
    text-align: center;
    font-weight: 500;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    padding-left: 8px;
    padding-right: 16px;
    margin: 0;
    height: 30px;
    line-height: 30px;
    color: #ffffff;
    max-width: 300px;
    font-size: 16px;
    border-radius: 15px;
    -webkit-align-items: center;
    align-items: center;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-footer .app-switcher-notification-bubble-button-icon {
    width: 16px;
    height: 16px;
    padding-right: 8px;
    padding-top: calc((30px - 16px)/2 - 1px);
    padding-bottom: calc((30px - 16px)/2);
    vertical-align: middle
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-footer .app-switcher-notification-bubble-spacer {
    width: 8px
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-call-to-action-button {
    background-color: rgb(24, 128, 56)
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-call-to-action-button.jfk-button-hover {
    background-color: #2a8947;
    box-shadow: 0 1px 3px 1px rgba(24, 128, 56, 0.15)
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-call-to-action-button.jfk-button-focused {
    background-color: #4f9e67;
    box-shadow: 0 1px 3px 1px rgba(24, 128, 56, 0.15)
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-call-to-action-button.jfk-button-focused.jfk-button-hover {
    background-color: #62a877;
    box-shadow: 0 1px 3px 1px rgba(24, 128, 56, 0.15)
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-dismiss-button {
    background-color: rgb(217, 48, 37)
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-dismiss-button.jfk-button-hover {
    background-color: #d3443b;
    box-shadow: 0 1px 3px 1px rgba(217, 48, 37, 0.15)
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-dismiss-button.jfk-button-focused {
    background-color: #e06c64;
    box-shadow: 0 1px 3px 1px rgba(217, 48, 37, 0.15)
}
.app-switcher-notification-bubble .app-switcher-notification-bubble-dismiss-button.jfk-button-focused.jfk-button-hover {
    background-color: #e88a84;
    box-shadow: 0 1px 3px 1px rgba(217, 48, 37, 0.15)
}
.companion-overflow-menu-item {
    -webkit-align-items: center;
    align-items: center;
    cursor: pointer;
    display: -webkit-flex;
    display: flex;
    padding: 8px
}
.companion-overflow-menu-item-highlight {
    background-color: #f1f3f4
}
.companion-overflow-menu-item-icon {
    background: transparent no-repeat center;
    background-size: 20px 20px;
    border-radius: 50%;
    height: 40px;
    width: 40px
}
.companion-overflow-menu-item-content {
    padding: 0 6px;
    white-space: nowrap
}
.companion-server-render .acga-content {
    -webkit-animation: companion-server-render-guest-content-fadeout 333ms ease 0s 1 normal both paused;
    animation: companion-server-render-guest-content-fadeout 333ms ease 0s 1 normal both paused
}
.companion-server-render .companion-shell-splash-screen-ink-splash-color {
    display: none
}
.companion-server-render .companion-shell-splash-screen-app-logo {
    -webkit-animation: none;
    animation: none
}
.companion-server-render .companion-shell-splash-screen-beachball {
    display: none
}
@keyframes companion-server-render-guest-content-fadeout {
    from {
        opacity: .38
    }
    to {
        opacity: 0
    }
}
.companion-shell {
    background-color: white;
    box-sizing: border-box;
    height: 100%;
    width: 300px
}
.companion-shell-addon-content-container,
.companion-shell-guest-content-container {
    height: 100%
}
.companion-shell.companion-shell-overlay-content {
    border: 0;
    box-shadow: 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12), 0px 2px 4px -1px rgba(0, 0, 0, 0.2);
    opacity: 1
}
.companion-shell-app-switcher {
    bottom: 0px;
    left: 0px;
    position: absolute
}
.companion-shell-guest-container {
    height: 100%
}
.companion-shell-splash-screen-container {
    height: 680px;
    margin-left: 50%;
    position: relative;
    top: calc(50% - (340px + 64px));
    transform: translateX(-50%);
    width: 680px
}
html[dir="rtl"] .companion-shell-splash-screen-container,
body[dir="rtl"] .companion-shell-splash-screen-container {
    transform: translateX(50%)
}
.companion-shell-splash-screen-ink-splash-color {
    -webkit-animation: ink-splash-opacity 1s cubic-bezier(0.08, 0.8, 0.67, 1) 400ms 1 normal both, ink-splash-scale 1s cubic-bezier(0.05, 0.69, 0.67, 1) 400ms 1 normal both;
    animation: ink-splash-opacity 1s cubic-bezier(0.08, 0.8, 0.67, 1) 400ms 1 normal both, ink-splash-scale 1s cubic-bezier(0.05, 0.69, 0.67, 1) 400ms 1 normal both;
    border-radius: 50%;
    height: 100%;
    width: 100%
}
.companion-shell-splash-screen-calendar>.companion-shell-splash-screen-ink-splash-color {
    background: #aecbfa
}
.companion-shell-splash-screen-chat>.companion-shell-splash-screen-ink-splash-color {
    background: #a8dab5
}
.companion-shell-splash-screen-keep>.companion-shell-splash-screen-ink-splash-color {
    background: #fde293
}
.companion-shell-splash-screen-tasks>.companion-shell-splash-screen-ink-splash-color {
    background: #aecbfa
}
.companion-shell-splash-screen-homebase>.companion-shell-splash-screen-ink-splash-color {
    background: #aecbfa
}
.companion-shell-splash-screen-maps>.companion-shell-splash-screen-ink-splash-color {
    background: #3367d6
}
.companion-shell-splash-screen-voice>.companion-shell-splash-screen-ink-splash-color {
    background: #a8dab5
}
.companion-shell-splash-screen-demo>.companion-shell-splash-screen-ink-splash-color {
    background: #aecbfa
}
.companion-shell-splash-screen-drive>.companion-shell-splash-screen-ink-splash-color {
    background: #e8f0fe
}
.companion-shell-splash-screen-people>.companion-shell-splash-screen-ink-splash-color {
    background: #aecbfa
}
@keyframes ink-splash-opacity {
    from {
        opacity: 1
    }
    to {
        opacity: 0
    }
}
@keyframes ink-splash-scale {
    from {
        transform: scale(0)
    }
    to {
        transform: scale(1)
    }
}
.companion-shell-splash-screen-app-logo {
    -webkit-animation: app-logo-scale 330ms cubic-bezier(0.05, 0.62, 0.51, 1.26) 333ms 1 normal backwards, app-logo-scale-bounce 170ms cubic-bezier(0.29, 0, 0.73, 1) 667ms 1 normal forwards;
    animation: app-logo-scale 330ms cubic-bezier(0.05, 0.62, 0.51, 1.26) 333ms 1 normal backwards, app-logo-scale-bounce 170ms cubic-bezier(0.29, 0, 0.73, 1) 667ms 1 normal forwards;
    background-position: center;
    background-repeat: no-repeat;
    background-size: 128px 128px;
    bottom: 0;
    height: 128px;
    left: 0;
    margin: auto;
    position: absolute;
    right: 0;
    top: 0;
    width: 128px
}
@keyframes app-logo-scale {
    from {
        transform: scale(0)
    }
    to {
        transform: scale(1)
    }
}
@keyframes app-logo-scale-bounce {
    0%,
    100% {
        transform: scale(1)
    }
    20% {
        transform: scale(0.95)
    }
}
.companion-shell-splash-screen-beachball {
    -webkit-animation: beachball-opacity 330ms linear 1s 1 normal both;
    animation: beachball-opacity 330ms linear 1s 1 normal both;
    bottom: 0;
    height: 20px;
    left: 0;
    margin: auto;
    position: absolute;
    right: 0;
    top: 190px;
    width: 20px
}
@keyframes beachball-opacity {
    from {
        opacity: 0
    }
    to {
        opacity: 1
    }
}
.companion-tooltip {
    background-color: rgba(60, 64, 67, .9);
    border-radius: 4px;
    color: #fff;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 500;
    -moz-osx-font-smoothing: grayscale;
    -webkit-font-smoothing: antialiased;
    letter-spacing: .3px;
    line-height: 16px;
    padding: 4px 8px;
    white-space: nowrap;
    z-index: 9999
}
.docs-companion-sidebar {
    box-shadow: 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12), 0px 2px 4px -1px rgba(0, 0, 0, 0.2);
    height: 100%;
    outline: none;
    overflow: hidden;
    position: absolute;
    right: 0;
    top: 0;
    width: 300px;
    z-index: 901
}
.goog-custom-button {
    margin: 2px;
    border: 0;
    padding: 0;
    font-family: Arial, sans-serif;
    color: #000;
    background: #ddd url(//ssl.gstatic.com/editor/button-bg.png) repeat-x top left;
    text-decoration: none;
    list-style: none;
    vertical-align: middle;
    cursor: default;
    outline: none
}
.goog-custom-button-outer-box,
.goog-custom-button-inner-box {
    border-style: solid;
    border-color: #aaa;
    vertical-align: top
}
.goog-custom-button-outer-box {
    margin: 0;
    border-width: 1px 0;
    padding: 0
}
.goog-custom-button-inner-box {
    margin: 0 -1px;
    border-width: 0 1px;
    padding: 3px 4px;
    white-space: nowrap
}
* html .goog-custom-button-inner-box {
    left: -1px
}
* html .goog-custom-button-rtl .goog-custom-button-outer-box {
    left: -1px
}
* html .goog-custom-button-rtl .goog-custom-button-inner-box {
    right: auto
}
*:first-child+html .goog-custom-button-inner-box {
    left: -1px
}
*:first-child+html .goog-custom-button-rtl .goog-custom-button-inner-box {
    left: 1px
}
::root .goog-custom-button,
::root .goog-custom-button-outer-box {
    line-height: 0
}
::root .goog-custom-button-inner-box {
    line-height: normal
}
.goog-custom-button-disabled {
    background-image: none!important;
    opacity: 0.3;
    -moz-opacity: 0.3;
    filter: alpha(opacity=30)
}
.goog-custom-button-disabled .goog-custom-button-outer-box,
.goog-custom-button-disabled .goog-custom-button-inner-box {
    color: #333!important;
    border-color: #999!important
}
* html .goog-custom-button-disabled {
    margin: 2px 1px!important;
    padding: 0 1px!important
}
*:first-child+html .goog-custom-button-disabled {
    margin: 2px 1px!important;
    padding: 0 1px!important
}
.goog-custom-button-hover .goog-custom-button-outer-box,
.goog-custom-button-hover .goog-custom-button-inner-box {
    border-color: #9cf #69e #69e #7af!important
}
.goog-custom-button-active,
.goog-custom-button-checked {
    background-color: #bbb;
    background-position: bottom left
}
.goog-custom-button-focused .goog-custom-button-outer-box,
.goog-custom-button-focused .goog-custom-button-inner-box {
    border-color: orange
}
.goog-custom-button-collapse-right,
.goog-custom-button-collapse-right .goog-custom-button-outer-box,
.goog-custom-button-collapse-right .goog-custom-button-inner-box {
    margin-right: 0
}
.goog-custom-button-collapse-left,
.goog-custom-button-collapse-left .goog-custom-button-outer-box,
.goog-custom-button-collapse-left .goog-custom-button-inner-box {
    margin-left: 0
}
.goog-custom-button-collapse-left .goog-custom-button-inner-box {
    border-left: 1px solid #fff
}
.goog-custom-button-collapse-left.goog-custom-button-checked .goog-custom-button-inner-box {
    border-left: 1px solid #ddd
}
* html .goog-custom-button-collapse-left .goog-custom-button-inner-box {
    left: 0
}
*:first-child+html .goog-custom-button-collapse-left .goog-custom-button-inner-box {
    left: 0
}
.goog-flat-button {
    position: relative;
    margin: 2px;
    border: 1px solid #000;
    padding: 2px 6px;
    font: normal 13px "Trebuchet MS", Tahoma, Arial, sans-serif;
    color: #fff;
    background-color: #8c2425;
    cursor: pointer;
    outline: none
}
.goog-flat-button-disabled {
    border-color: #888;
    color: #888;
    background-color: #ccc;
    cursor: default
}
.goog-flat-button-hover {
    border-color: #8c2425;
    color: #8c2425;
    background-color: #eaa4a5
}
.goog-flat-button-active,
.goog-flat-button-selected,
.goog-flat-button-checked {
    border-color: #5b4169;
    color: #5b4169;
    background-color: #d1a8ea
}
.goog-flat-button-focused {
    border-color: #5b4169
}
.goog-flat-button-collapse-right {
    margin-right: 0
}
.goog-flat-button-collapse-left {
    margin-left: 0;
    border-left: none
}
.goog-button {
    color: #036;
    border-color: #036;
    background-color: #69c
}
.goog-button-disabled {
    border-color: #333;
    color: #333;
    background-color: #999
}
.goog-button-hover {
    color: #369;
    border-color: #369;
    background-color: #9cf
}
.goog-button-active {
    color: #69c;
    border-color: #69c
}
.goog-clipboard {
    width: 16px;
    height: 16px;
    background: url(//ssl.gstatic.com/docs/clipboard/icons3.png) no-repeat;
    vertical-align: middle
}
.goog-cbi1 {
    background-position: -16px
}
.goog-cbi2 {
    background-position: -32px
}
.goog-cbi3 {
    background-position: -48px
}
.goog-cbi4 {
    background-position: -64px
}
.goog-cbi5 {
    background-position: -80px
}
.goog-menu-button {
    background: #ddd url(//ssl.gstatic.com/editor/button-bg.png) repeat-x top left;
    border: 0;
    color: #000;
    cursor: pointer;
    list-style: none;
    margin: 2px;
    outline: none;
    padding: 0;
    text-decoration: none;
    vertical-align: middle
}
.goog-menu-button-outer-box,
.goog-menu-button-inner-box {
    border-style: solid;
    border-color: #aaa;
    vertical-align: top
}
.goog-menu-button-outer-box {
    margin: 0;
    border-width: 1px 0;
    padding: 0
}
.goog-menu-button-inner-box {
    margin: 0 -1px;
    border-width: 0 1px;
    padding: 3px 4px
}
* html .goog-menu-button-inner-box {
    left: -1px
}
* html .goog-menu-button-rtl .goog-menu-button-outer-box {
    left: -1px;
    right: auto
}
* html .goog-menu-button-rtl .goog-menu-button-inner-box {
    right: auto
}
*:first-child+html .goog-menu-button-inner-box {
    left: -1px
}
*:first-child+html .goog-menu-button-rtl .goog-menu-button-inner-box {
    left: 1px;
    right: auto
}
::root .goog-menu-button,
::root .goog-menu-button-outer-box,
::root .goog-menu-button-inner-box {
    line-height: 0
}
::root .goog-menu-button-caption,
::root .goog-menu-button-dropdown {
    line-height: normal
}
.goog-menu-button-disabled {
    background-image: none!important;
    opacity: 0.3;
    -moz-opacity: 0.3;
    filter: alpha(opacity=30)
}
.goog-menu-button-disabled .goog-menu-button-outer-box,
.goog-menu-button-disabled .goog-menu-button-inner-box,
.goog-menu-button-disabled .goog-menu-button-caption,
.goog-menu-button-disabled .goog-menu-button-dropdown {
    color: #333!important;
    border-color: #999!important
}
* html .goog-menu-button-disabled {
    margin: 2px 1px!important;
    padding: 0 1px!important
}
*:first-child+html .goog-menu-button-disabled {
    margin: 2px 1px!important;
    padding: 0 1px!important
}
.goog-menu-button-hover .goog-menu-button-outer-box,
.goog-menu-button-hover .goog-menu-button-inner-box {
    border-color: #9cf #69e #69e #7af!important
}
.goog-menu-button-active,
.goog-menu-button-open {
    background-color: #bbb;
    background-position: bottom left
}
.goog-menu-button-focused .goog-menu-button-outer-box,
.goog-menu-button-focused .goog-menu-button-inner-box {
    border-color: orange
}
.goog-menu-button-caption {
    padding: 0 4px 0 0;
    vertical-align: top
}
.goog-menu-button-dropdown {
    height: 15px;
    width: 7px;
    background: url(//ssl.gstatic.com/editor/editortoolbar.png) no-repeat -388px 0;
    vertical-align: top
}
.goog-menu-button-collapse-right,
.goog-menu-button-collapse-right .goog-menu-button-outer-box,
.goog-menu-button-collapse-right .goog-menu-button-inner-box {
    margin-right: 0
}
.goog-menu-button-collapse-left,
.goog-menu-button-collapse-left .goog-menu-button-outer-box,
.goog-menu-button-collapse-left .goog-menu-button-inner-box {
    margin-left: 0
}
.goog-menu-button-collapse-left .goog-menu-button-inner-box {
    border-left: 1px solid #fff
}
.goog-menu-button-collapse-left.goog-menu-button-checked .goog-menu-button-inner-box {
    border-left: 1px solid #ddd
}
.goog-submenu-arrow {
    color: #000;
    left: auto;
    padding-right: 6px;
    position: absolute;
    right: 0;
    text-align: right
}
.goog-menuitem-rtl .goog-submenu-arrow {
    text-align: left;
    left: 0;
    right: auto;
    padding-left: 6px
}
.goog-menuitem-disabled .goog-submenu-arrow {
    color: #ccc
}
.docs-a11y-ariascreenreader-speakable {
    position: absolute;
    left: -10000px
}
.a11y-settings-dialog {
    min-width: 464px
}
.a11y-settings-dialog ul,
.a11y-settings-dialog li {
    list-style: none;
    padding: 0;
    margin: 0
}
.a11y-settings-dialog .a11y-settings-dialog-indent-group {
    margin-left: 30px
}
.a11y-settings-dialog .a11y-settings-dialog-learn-more {
    margin-top: 8px
}
.a11y-settings-dialog .a11y-settings-dialog-description-text {
    margin-right: 2px
}
.a11y-settings-dialog a,
.a11y-settings-dialog a:hover,
.a11y-settings-dialog a:visited,
.a11y-settings-dialog a:focus,
.a11y-settings-dialog a:active {
    color: #1a73e8
}
.a11y-settings-dialog .docs-material-gm-labeled-checkbox-description a {
    padding: 3px 0
}
.a11y-settings-dialog a .docs-icon {
    pointer-events: none
}
.a11y-settings-dialog .docs-material-gm-dialog-buttons {
    padding-top: 0
}
.drive-viewer {
    color: #fff;
    font-family: arial, sans-serif;
    overflow: hidden;
    opacity: 0;
    visibility: hidden;
    -webkit-transition-property: opacity, visibility;
    -moz-transition-property: opacity, visibility;
    -o-transition-property: opacity, visibility;
    transition-property: opacity, visibility;
    -webkit-transition-duration: 0.1s, 0s;
    -moz-transition-duration: 0.1s, 0s;
    -o-transition-duration: 0.1s, 0s;
    transition-duration: 0.1s, 0s;
    -webkit-transition-timing-function: cubic-bezier(0.0, 0.0, 0.2, 1);
    -moz-transition-timing-function: cubic-bezier(0.0, 0.0, 0.2, 1);
    -o-transition-timing-function: cubic-bezier(0.0, 0.0, 0.2, 1);
    transition-timing-function: cubic-bezier(0.0, 0.0, 0.2, 1);
    -webkit-transition-delay: 0s, 0.1s;
    -moz-transition-delay: 0s, 0.1s;
    -o-transition-delay: 0s, 0.1s;
    transition-delay: 0s, 0.1s;
    position: fixed;
    top: 0;
    bottom: 0;
    left: 0;
    right: 0;
    z-index: 1001
}
.drive-viewer.drive-viewer-v3 {
    font-family: 'Google Sans', Roboto, arial, sans-serif
}
.drive-viewer-shown {
    opacity: 1;
    visibility: visible;
    -webkit-transition-timing-function: cubic-bezier(0.4, 0.0, 1, 1);
    -moz-transition-timing-function: cubic-bezier(0.4, 0.0, 1, 1);
    -o-transition-timing-function: cubic-bezier(0.4, 0.0, 1, 1);
    transition-timing-function: cubic-bezier(0.4, 0.0, 1, 1);
    -webkit-transition-delay: 0s, 0s;
    -moz-transition-delay: 0s, 0s;
    -o-transition-delay: 0s, 0s;
    transition-delay: 0s, 0s
}
.drive-viewer-shadow {
    background-color: #1e1e1e;
    position: fixed;
    top: 0;
    bottom: 0;
    left: 0;
    right: 0;
    filter: alpha(opacity=93);
    opacity: .93
}
.drive-viewer.drive-viewer-embed .drive-viewer-shadow {
    background-color: #d1d1d1;
    filter: alpha(opacity=100);
    opacity: 1
}
.drive-viewer-v3 .drive-viewer-shadow {
    background-color: rgba(0, 0, 0, 0.85);
    filter: alpha(opacity=100);
    opacity: 1
}
.drive-viewer-fixed-frame {
    margin: 0;
    height: 100%;
    width: 100%;
    overflow: hidden!important
}
.drive-viewer-focus-outlines-disabled *:focus {
    outline: none
}
.goog-menu {
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    border-radius: 0;
    -webkit-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
    box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
    -webkit-transition: opacity 0.218s;
    -moz-transition: opacity 0.218s;
    -o-transition: opacity 0.218s;
    transition: opacity 0.218s;
    background: #fff;
    border: 1px solid #ccc;
    border: 1px solid rgba(0, 0, 0, .2);
    cursor: default;
    font-size: 13px;
    margin: 0;
    outline: none;
    padding: 6px 0;
    position: absolute
}
.goog-menuitem,
.goog-tristatemenuitem,
.goog-filterobsmenuitem {
    position: relative;
    color: #333;
    cursor: pointer;
    list-style: none;
    margin: 0;
    padding: 6px 8em 6px 30px;
    white-space: nowrap
}
.goog-menu-nocheckbox .goog-menuitem,
.goog-menu-noicon .goog-menuitem {
    padding-left: 16px;
    vertical-align: middle
}
.goog-menu-noaccel .goog-menuitem {
    padding-right: 44px
}
.goog-menuitem-disabled {
    cursor: default
}
.goog-menuitem-disabled .goog-menuitem-accel,
.goog-menuitem-disabled .goog-menuitem-content {
    color: #ccc!important
}
.goog-menuitem-disabled .goog-menuitem-icon {
    filter: alpha(opacity=30);
    opacity: 0.3
}
.goog-menuitem-highlight,
.goog-menuitem-hover {
    background-color: #eee;
    border-color: #eee;
    border-style: dotted;
    border-width: 1px 0;
    padding-top: 5px;
    padding-bottom: 5px
}
.goog-menuitem-highlight .goog-menuitem-content,
.goog-menuitem-hover .goog-menuitem-content {
    color: #333
}
.goog-menuitem-checkbox,
.goog-menuitem-icon {
    background-repeat: no-repeat;
    height: 21px;
    left: 3px;
    position: absolute;
    right: auto;
    top: 3px;
    vertical-align: middle;
    width: 21px
}
.goog-option-selected {
    background-image: url(//ssl.gstatic.com/ui/v1/menu/checkmark.png);
    background-repeat: no-repeat;
    background-position: left center
}
.goog-option-selected .goog-menuitem-content {
    color: #333
}
.goog-menuitem-accel {
    color: #777;
    direction: ltr;
    left: auto;
    padding: 0 6px;
    position: absolute;
    right: 0;
    text-align: right
}
.goog-menuitem-mnemonic-hint {
    text-decoration: underline
}
.goog-menuitem-mnemonic-separator {
    color: #777;
    font-size: 12px;
    padding-left: 4px
}
::-webkit-scrollbar {
    height: 16px;
    overflow: visible;
    width: 16px
}
::-webkit-scrollbar-button {
    height: 0;
    width: 0
}
::-webkit-scrollbar-track {
    background-clip: padding-box;
    border: solid transparent;
    border-width: 0 0 0 4px
}
::-webkit-scrollbar-track:horizontal {
    border-width: 4px 0 0
}
::-webkit-scrollbar-track:hover {
    background-color: rgba(0, 0, 0, .05);
    box-shadow: inset 1px 0 0 rgba(0, 0, 0, .1)
}
::-webkit-scrollbar-track:horizontal:hover {
    box-shadow: inset 0 1px 0 rgba(0, 0, 0, .1)
}
::-webkit-scrollbar-track:active {
    background-color: rgba(0, 0, 0, .05);
    box-shadow: inset 1px 0 0 rgba(0, 0, 0, .14), inset -1px 0 0 rgba(0, 0, 0, .07)
}
::-webkit-scrollbar-track:horizontal:active {
    box-shadow: inset 0 1px 0 rgba(0, 0, 0, .14), inset 0 -1px 0 rgba(0, 0, 0, .07)
}
.jfk-scrollbar-dark::-webkit-scrollbar-track:hover {
    background-color: rgba(255, 255, 255, .1);
    box-shadow: inset 1px 0 0 rgba(255, 255, 255, .2)
}
.jfk-scrollbar-dark::-webkit-scrollbar-track:horizontal:hover {
    box-shadow: inset 0 1px 0 rgba(255, 255, 255, .2)
}
.jfk-scrollbar-dark::-webkit-scrollbar-track:active {
    background-color: rgba(255, 255, 255, .1);
    box-shadow: inset 1px 0 0 rgba(255, 255, 255, .25), inset -1px 0 0 rgba(255, 255, 255, .15)
}
.jfk-scrollbar-dark::-webkit-scrollbar-track:horizontal:active {
    box-shadow: inset 0 1px 0 rgba(255, 255, 255, .25), inset 0 -1px 0 rgba(255, 255, 255, .15)
}
::-webkit-scrollbar-thumb {
    background-color: rgba(0, 0, 0, .2);
    background-clip: padding-box;
    border: solid transparent;
    border-width: 1px 1px 1px 6px;
    min-height: 28px;
    padding: 100px 0 0;
    box-shadow: inset 1px 1px 0 rgba(0, 0, 0, .1), inset 0 -1px 0 rgba(0, 0, 0, .07)
}
::-webkit-scrollbar-thumb:horizontal {
    border-width: 6px 1px 1px;
    padding: 0 0 0 100px;
    box-shadow: inset 1px 1px 0 rgba(0, 0, 0, .1), inset -1px 0 0 rgba(0, 0, 0, .07)
}
::-webkit-scrollbar-thumb:hover {
    background-color: rgba(0, 0, 0, .4);
    box-shadow: inset 1px 1px 1px rgba(0, 0, 0, .25)
}
::-webkit-scrollbar-thumb:active {
    background-color: rgba(0, 0, 0, 0.5);
    box-shadow: inset 1px 1px 3px rgba(0, 0, 0, 0.35)
}
.jfk-scrollbar-dark::-webkit-scrollbar-thumb {
    background-color: rgba(255, 255, 255, .3);
    box-shadow: inset 1px 1px 0 rgba(255, 255, 255, .15), inset 0 -1px 0 rgba(255, 255, 255, .1)
}
.jfk-scrollbar-dark::-webkit-scrollbar-thumb:horizontal {
    box-shadow: inset 1px 1px 0 rgba(255, 255, 255, .15), inset -1px 0 0 rgba(255, 255, 255, .1)
}
.jfk-scrollbar-dark::-webkit-scrollbar-thumb:hover {
    background-color: rgba(255, 255, 255, .6);
    box-shadow: inset 1px 1px 1px rgba(255, 255, 255, .37)
}
.jfk-scrollbar-dark::-webkit-scrollbar-thumb:active {
    background-color: rgba(255, 255, 255, .75);
    box-shadow: inset 1px 1px 3px rgba(255, 255, 255, .5)
}
.jfk-scrollbar-borderless::-webkit-scrollbar-track {
    border-width: 0 1px 0 6px
}
.jfk-scrollbar-borderless::-webkit-scrollbar-track:horizontal {
    border-width: 6px 0 1px
}
.jfk-scrollbar-borderless::-webkit-scrollbar-track:hover {
    background-color: rgba(0, 0, 0, .035);
    box-shadow: inset 1px 1px 0 rgba(0, 0, 0, .14), inset -1px -1px 0 rgba(0, 0, 0, .07)
}
.jfk-scrollbar-borderless.jfk-scrollbar-dark::-webkit-scrollbar-track:hover {
    background-color: rgba(255, 255, 255, .07);
    box-shadow: inset 1px 1px 0 rgba(255, 255, 255, .25), inset -1px -1px 0 rgba(255, 255, 255, .15)
}
.jfk-scrollbar-borderless::-webkit-scrollbar-thumb {
    border-width: 0 1px 0 6px
}
.jfk-scrollbar-borderless::-webkit-scrollbar-thumb:horizontal {
    border-width: 6px 0 1px
}
::-webkit-scrollbar-corner {
    background: transparent
}
body::-webkit-scrollbar-track-piece {
    background-clip: padding-box;
    background-color: #f5f5f5;
    border: solid #fff;
    border-width: 0 0 0 3px;
    box-shadow: inset 1px 0 0 rgba(0, 0, 0, .14), inset -1px 0 0 rgba(0, 0, 0, .07)
}
body::-webkit-scrollbar-track-piece:horizontal {
    border-width: 3px 0 0;
    box-shadow: inset 0 1px 0 rgba(0, 0, 0, .14), inset 0 -1px 0 rgba(0, 0, 0, .07)
}
body::-webkit-scrollbar-thumb {
    border-width: 1px 1px 1px 5px
}
body::-webkit-scrollbar-thumb:horizontal {
    border-width: 5px 1px 1px
}
body::-webkit-scrollbar-corner {
    background-clip: padding-box;
    background-color: #f5f5f5;
    border: solid #fff;
    border-width: 3px 0 0 3px;
    box-shadow: inset 1px 1px 0 rgba(0, 0, 0, .14)
}
.jfk-bubble {
    -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, .2);
    -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, .2);
    box-shadow: 0 1px 3px rgba(0, 0, 0, .2);
    background-color: #fff;
    border: 1px solid;
    border-color: #bbb #bbb #a8a8a8;
    padding: 16px;
    position: absolute;
    z-index: 1201!important
}
.jfk-bubble-closebtn {
    background: url("//ssl.gstatic.com/ui/v1/icons/common/x_8px.png") no-repeat;
    border: 1px solid transparent;
    height: 21px;
    opacity: .4;
    outline: 0;
    position: absolute;
    right: 2px;
    top: 2px;
    width: 21px
}
.jfk-bubble-closebtn:focus {
    border: 1px solid #4d90fe;
    opacity: .8
}
.jfk-bubble-arrow {
    position: absolute
}
.jfk-bubble-arrow .jfk-bubble-arrowimplbefore,
.jfk-bubble-arrow .jfk-bubble-arrowimplafter {
    display: block;
    height: 0;
    position: absolute;
    width: 0
}
.jfk-bubble-arrow .jfk-bubble-arrowimplbefore {
    border: 9px solid
}
.jfk-bubble-arrow .jfk-bubble-arrowimplafter {
    border: 8px solid
}
.jfk-bubble-arrowdown {
    bottom: 0
}
.jfk-bubble-arrowup {
    top: -9px
}
.jfk-bubble-arrowleft {
    left: -9px
}
.jfk-bubble-arrowright {
    right: 0
}
.jfk-bubble-arrowdown .jfk-bubble-arrowimplbefore,
.jfk-bubble-arrowup .jfk-bubble-arrowimplbefore {
    border-color: #bbb transparent;
    left: -9px
}
.jfk-bubble-arrowdown .jfk-bubble-arrowimplbefore {
    border-color: #a8a8a8 transparent
}
.jfk-bubble-arrowdown .jfk-bubble-arrowimplafter,
.jfk-bubble-arrowup .jfk-bubble-arrowimplafter {
    border-color: #fff transparent;
    left: -8px
}
.jfk-bubble-arrowdown .jfk-bubble-arrowimplbefore {
    border-bottom-width: 0
}
.jfk-bubble-arrowdown .jfk-bubble-arrowimplafter {
    border-bottom-width: 0
}
.jfk-bubble-arrowup .jfk-bubble-arrowimplbefore {
    border-top-width: 0
}
.jfk-bubble-arrowup .jfk-bubble-arrowimplafter {
    border-top-width: 0;
    top: 1px
}
.jfk-bubble-arrowleft .jfk-bubble-arrowimplbefore,
.jfk-bubble-arrowright .jfk-bubble-arrowimplbefore {
    border-color: transparent #bbb;
    top: -9px
}
.jfk-bubble-arrowleft .jfk-bubble-arrowimplafter,
.jfk-bubble-arrowright .jfk-bubble-arrowimplafter {
    border-color: transparent #fff;
    top: -8px
}
.jfk-bubble-arrowleft .jfk-bubble-arrowimplbefore {
    border-left-width: 0
}
.jfk-bubble-arrowleft .jfk-bubble-arrowimplafter {
    border-left-width: 0;
    left: 1px
}
.jfk-bubble-arrowright .jfk-bubble-arrowimplbefore {
    border-right-width: 0
}
.jfk-bubble-arrowright .jfk-bubble-arrowimplafter {
    border-right-width: 0
}
.jfk-tooltip {
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    border-radius: 0;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    -webkit-transition: visibility 0, opacity .13s ease-in;
    -moz-transition: visibility 0, opacity .13s ease-in;
    -o-transition: visibility 0, opacity .13s ease-in;
    transition: visibility 0, opacity .13s ease-in;
    background-color: #2a2a2a;
    border: 1px solid #fff;
    color: #fff;
    cursor: default;
    display: block;
    font-size: 11px;
    font-weight: bold;
    margin-left: -1px;
    opacity: 1;
    padding: 7px 9px;
    position: absolute;
    visibility: visible;
    white-space: pre-wrap;
    word-break: break-all;
    word-break: break-word
}
.jfk-tooltip-hide {
    -webkit-transition: visibility .13s, opacity .13s ease-out, left 0 linear .13s, top 0 linear .13s;
    -moz-transition: visibility .13s, opacity .13s ease-out, left 0 linear .13s, top 0 linear .13s;
    -o-transition: visibility .13s, opacity .13s ease-out, left 0 linear .13s, top 0 linear .13s;
    transition: visibility .13s, opacity .13s ease-out, left 0 linear .13s, top 0 linear .13s;
    opacity: 0;
    left: 20px!important;
    top: 20px!important;
    visibility: hidden
}
.jfk-tooltip-data {
    display: none
}
.jfk-tooltip-arrow {
    pointer-events: none;
    position: absolute
}
.jfk-tooltip-arrow .jfk-tooltip-arrowimplbefore,
.jfk-tooltip-arrow .jfk-tooltip-arrowimplafter {
    content: '';
    display: block;
    height: 0;
    position: absolute;
    width: 0
}
.jfk-tooltip-arrow .jfk-tooltip-arrowimplbefore {
    border: 6px solid
}
.jfk-tooltip-arrow .jfk-tooltip-arrowimplafter {
    border: 5px solid
}
.jfk-tooltip-arrowdown {
    bottom: 0
}
.jfk-tooltip-arrowup {
    top: -6px
}
.jfk-tooltip-arrowleft {
    left: -6px
}
.jfk-tooltip-arrowright {
    right: 0
}
.jfk-tooltip-arrowdown .jfk-tooltip-arrowimplbefore,
.jfk-tooltip-arrowup .jfk-tooltip-arrowimplbefore {
    border-color: #fff transparent;
    left: -6px
}
.jfk-tooltip-arrowdown .jfk-tooltip-arrowimplafter,
.jfk-tooltip-arrowup .jfk-tooltip-arrowimplafter {
    border-color: #2a2a2a transparent;
    left: -5px
}
.jfk-tooltip-arrowdown .jfk-tooltip-arrowimplbefore {
    border-bottom-width: 0
}
.jfk-tooltip-arrowdown .jfk-tooltip-arrowimplafter {
    border-bottom-width: 0
}
.jfk-tooltip-arrowup .jfk-tooltip-arrowimplbefore {
    border-top-width: 0
}
.jfk-tooltip-arrowup .jfk-tooltip-arrowimplafter {
    border-top-width: 0;
    top: 1px
}
.jfk-tooltip-arrowleft .jfk-tooltip-arrowimplbefore,
.jfk-tooltip-arrowright .jfk-tooltip-arrowimplbefore {
    border-color: transparent #fff;
    top: -6px
}
.jfk-tooltip-arrowleft .jfk-tooltip-arrowimplafter,
.jfk-tooltip-arrowright .jfk-tooltip-arrowimplafter {
    border-color: transparent #2a2a2a;
    top: -5px
}
.jfk-tooltip-arrowleft .jfk-tooltip-arrowimplbefore {
    border-left-width: 0
}
.jfk-tooltip-arrowleft .jfk-tooltip-arrowimplafter {
    border-left-width: 0;
    left: 1px
}
.jfk-tooltip-arrowright .jfk-tooltip-arrowimplbefore {
    border-right-width: 0
}
.jfk-tooltip-arrowright .jfk-tooltip-arrowimplafter {
    border-right-width: 0
}
.activity-deck,
.activity-deck-events-view {
    height: 100%
}
.activity-list-container {
    background-color: #fff;
    font-family: Roboto, arial, sans-serif;
    font-size: 13px;
    height: 100%;
    position: relative
}
.activity-list {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    height: 100%;
    overflow-y: scroll;
    position: relative;
    z-index: 0
}
.activity-refresh-header {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    background-color: #eee;
    height: 0;
    overflow: hidden;
    padding-right: 16px;
    position: absolute;
    top: 0;
    width: 100%;
    z-index: 2
}
.activity-refresh-header .goog-inline-block.goog-flat-button {
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
    -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.1);
    -moz-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.1);
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.1);
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    background-color: white;
    color: #15c;
    cursor: pointer;
    height: 35px;
    line-height: 35px;
    text-align: center;
    width: 100%
}
.activity-list-static-header {
    box-sizing: border-box;
    left: 0;
    overflow: hidden;
    padding-bottom: 12px;
    position: absolute;
    right: 16px;
    top: 0;
    width: auto;
    z-index: 1
}
.activity-list-static-header .activity-event-section-title {
    box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2)
}
.drive-white-bg .activity-list-static-header .activity-event-section-title {
    box-shadow: none
}
.activity-list-loading {
    font-size: 14px;
    font-weight: normal;
    margin-top: 16px;
    text-align: center;
    width: 100%
}
.activity-list-loading .drive-white-circle {
    display: none
}
.activity-list-loading-more.activity-list-loading {
    font-size: 12px;
    font-weight: normal;
    margin-top: 0;
    padding-bottom: 8px
}
.activity-list-loading-more.activity-list-loading .activity-list-loading-icon,
.activity-list-loading-more.activity-list-loading .activity-list-loading-icon img,
.activity-list-loading-more.activity-list-loading .activity-list-loading-message {
    display: inline-block;
    vertical-align: middle
}
.activity-list-loading-more.activity-list-loading .activity-list-loading-message {
    margin-left: 8px;
    padding-left: 14px;
    padding-top: 6px
}
.activity-list-no-activity {
    font-size: 13px;
    margin-top: 16px;
    text-align: center;
    width: 100%
}
.activity-event.activity-event-new {
    background-color: #ffffd6
}
.activity-event.activity-event-background-transition {
    -webkit-transition: background-color 1000ms ease-in;
    -moz-transition: background-color 1000ms ease-in;
    -o-transition: background-color 1000ms ease-in;
    transition: background-color 1000ms ease-in
}
.activity-list-no-more-events-icon {
    display: inline-block;
    margin-bottom: 10px
}
.activity-event {
    background-color: #fff;
    border-bottom: 1px solid #dadce0;
    margin: 0 0 12px;
    padding: 0 0 12px;
    position: relative;
    width: 100%
}
.activity-event>div:first-child {
    line-height: 20px;
    padding: 16px 0
}
.activity-event-action-icon {
    height: 16px;
    padding: 8px 4px;
    position: absolute;
    width: 16px
}
.activity-event-available-action {
    border-top: 1px solid #efefef;
    margin-left: 24px;
    margin-top: 16px;
    padding-top: 16px
}
.activity-event-action-link-active {
    color: #4a4a4a;
    padding: 0;
    position: relative
}
.activity-event-action-link-active svg {
    fill: #4a4a4a
}
.activity-event-action-link-active:focus,
.activity-event-action-link-active:hover {
    color: #4285f4;
    cursor: pointer
}
.activity-event-action-link-active:focus svg,
.activity-event-action-link-active:hover svg {
    fill: #4285f4
}
.activity-event-action-link-used {
    color: #ccc
}
.activity-event-action-link-used svg {
    fill: #ccc
}
.activity-event-action-text {
    font-weight: 500;
    text-transform: uppercase
}
.activity-event-action-text-active {
    margin-left: 32px;
    padding: 8px 0
}
.activity-event-action-text-used {
    padding: 8px 4px
}
.activity-list-error,
.activity-list-no-more-events.activity-list-no-events {
    margin-bottom: 20px;
    margin-top: 10px;
    text-align: center
}
.activity-list-error-icon {
    display: inline-block;
    height: 24px;
    margin-bottom: -5px;
    margin-right: 20px;
    position: relative;
    width: 24px
}
.activity-list-error-icon svg {
    bottom: 0;
    position: absolute
}
.activity-list-events {
    -webkit-user-select: text;
    -moz-user-select: text;
    -ms-user-select: text
}
.activity-list-no-more-events {
    color: #5f6368;
    padding: 0 24px 0 16px;
    text-align: left
}
.activity-list-no-more-events-text {
    color: #5f6368;
    font-size: 13px;
    font-weight: normal;
    margin-bottom: 0
}
.activity-list-no-more-events-description,
.activity-list-no-more-events-learn-more {
    line-height: 20px;
    margin: 0;
    padding: 14px 0
}
.activity-decorated-link {
    color: #15c;
    cursor: pointer;
    outline: none;
    text-decoration: none
}
.activity-decorated-link:focus,
.activity-decorated-link:hover {
    text-decoration: underline
}
.activity-decorated-link:active {
    color: #d14836
}
.activity-list-error-try-again {
    color: #15c;
    cursor: pointer;
    outline: none;
    text-decoration: none
}
.activity-list-error-try-again:focus,
.activity-list-error-try-again:hover,
.activity-list-error-try-again .goog-flat-button-hover,
.activity-list-error-try-again .goog-flat-button-focus {
    text-decoration: underline
}
.activity-list-error-try-again:active {
    color: #d14836
}
.activity-list-show-more,
.activity-paging-footer-show-more .goog-flat-button {
    display: block;
    height: 0;
    margin: 0 5px;
    overflow: hidden
}
.activity-event-focus {
    outline: 1px solid #4d90fe
}
.activity-hideable-focus-hidden .activity-event.activity-event-focus {
    outline: none
}
.activity-event-person {
    height: 40px;
    left: 16px;
    position: absolute;
    width: 40px
}
.activity-event-person img {
    border-radius: 50%;
    height: 100%;
    width: 100%
}
.activity-event-background svg {
    border-radius: 50%;
    height: 40px;
    width: 40px
}
.activity-event-person-overlay {
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}
.activity-event-admin-icon svg {
    opacity: 0.5
}
.activity-event-person-icon svg {
    margin-top: 9px
}
.activity-event-admin-icon.activity-event-person-icon svg {
    margin-top: 7px
}
.activity-event-drive-icon svg {
    margin-top: 8px
}
.activity-event-person .activity-event-person-icon-container {
    border-radius: 50%;
    height: 40px;
    overflow: hidden;
    text-align: center;
    width: 40px
}
.activity-event-admin-icon-container {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    border: 2px solid rgba(0, 0, 0, 0.2)
}
.activity-event-person-icon-text {
    color: #fff;
    font-size: 16px;
    line-height: 40px;
    vertical-align: middle
}
.activity-event-header {
    margin-left: 56px;
    padding: 0 24px 0 16px
}
.activity-event-details-header {
    color: #5f6368;
    font-size: 13px;
    width: auto
}
.activity-event-details-container {
    color: #5f6368;
    font-size: 13px;
    font-weight: 500;
    margin-top: 4px
}
.activity-event-target-list {
    padding-left: 72px
}
.activity-event-file-approval,
.activity-event-people-names {
    color: #202124;
    font-weight: 500
}
.activity-event-approval-status {
    margin-top: 4px;
    font-weight: 500
}
.activity-event-approval-approved {
    color: #0f9d58
}
.activity-event-approval-rejected {
    color: #db4437
}
.activity-event-action {
    font-weight: normal
}
.activity-event-action::before {
    content: " "
}
.activity-event-target-number {
    font-weight: bold
}
.activity-event-copy-action {
    font-weight: bold
}
.activity-event-target-icon {
    height: 16px;
    position: absolute;
    width: 24px
}
.activity-event-target.activity-event-target-first {
    border-top: none
}
.activity-event-target {
    position: relative
}
.activity-event-parent {
    border-bottom: 1px solid #efefef;
    margin-left: 72px
}
.activity-event-target-details {
    margin-left: 32px
}
.activity-event-target-details.activity-event-locatable-target {
    margin-right: 24px
}
.activity-event-target-name {
    font-weight: 500;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.activity-list-hidden-text {
    height: 0;
    overflow: hidden;
    white-space: nowrap;
    width: 0
}
.activity-event-target:hover,
.activity-event-target:active,
.activity-event-target:focus {
    background-color: #fff
}
.activity-event-target-name.activity-event-openable-target:hover,
.activity-event-target-name.activity-event-openable-target:active,
.activity-event-target-name.activity-event-openable-target:focus,
.activity-event-target-name .activity-event-openable-target:hover,
.activity-event-target-name .activity-event-openable-target:active,
.activity-event-target-name .activity-event-openable-target:focus {
    color: #5f6368;
    cursor: pointer;
    outline: none;
    text-decoration: underline
}
.activity-event-scopes-show-more-button,
.activity-event-scopes-show-less-button {
    display: flex;
    margin-left: 24px
}
.activity-event-show-more-button,
.activity-event-show-less-button {
    display: flex;
    margin-left: 6px
}
.activity-event-toggle-button {
    border: 1px solid transparent;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    color: #4285f4;
    cursor: pointer;
    font-family: Google Sans, QUANTUM_FONT_FAMILY;
    font-size: 13px;
    font-weight: 500;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    outline: none;
    margin-top: 4px;
    padding: 9px 24px 11px 24px
}
.activity-event-toggle-button-hover {
    background-color: rgba(66, 133, 244, .04)
}
.activity-event-toggle-button-focused {
    background-color: #e8f0fe
}
.activity-event-toggle-button-hover.activity-event-toggle-button-focused {
    background-color: rgba(66, 133, 244, 0.16)
}
.activity-event-toggle-button-active {
    background-color: rgba(66, 133, 244, 0.16);
    box-shadow: 0 1px 2px 0 rgba(60, 64, 67, 0.30), 0 1px 3px 1px rgba(60, 64, 67, 0.15)
}
.activity-event-focus .activity-event-toggle-button .activity-event-toggle-button-icon,
.activity-event:hover .activity-event-toggle-button .activity-event-toggle-button-icon {
    visibility: visible
}
.activity-event:hover .activity-event-toggle-button {
    cursor: pointer
}
.activity-event-children {
    margin-left: 24px
}
.activity-event-target-icon,
.activity-event-target-details {
    padding: 7px 0 6px
}
.activity-event-target-icon-img {
    max-height: 16px;
    max-width: 16px;
    padding: 0 4px
}
.activity-event-section-title {
    background-color: #fff;
    color: #5f6368;
    font-size: 13px;
    font-weight: 500;
    line-height: 48px;
    margin: 0;
    padding: 0 24px 0 16px;
    position: relative;
    transition: box-shadow 267ms cubic-bezier(0.4, 0.0, 0.2, 1)
}
.drive-white-bg .activity-event-section-title {
    border-bottom: 1px solid #dadce0
}
.activity-event-annotation {
    color: #5f6368;
    display: inline;
    float: right;
    font-size: 12px;
    font-weight: normal;
    padding-right: 16px;
    padding-top: 0;
    position: relative
}
.activity-event-source {
    display: inline-block;
    max-width: 136px;
    overflow: hidden;
    text-overflow: ellipsis;
    vertical-align: top;
    white-space: nowrap
}
.activity-event-info {
    color: #5f6368;
    padding-bottom: 12px
}
.activity-event-timestamp {
    padding: 0 16px 0 16px;
    display: inline
}
.activity-event-target-parent {
    color: #bababa;
    font-size: 13px
}
.activity-event-target-parent.activity-event-openable-target:hover,
.activity-event-target-parent.activity-event-openable-target:active,
.activity-event-target-parent.activity-event-openable-target:focus {
    color: #00992c;
    cursor: pointer;
    outline: none
}
.activity-event-locate {
    height: 32px;
    outline: none;
    position: absolute;
    right: 3px;
    top: 0;
    width: 24px
}
.activity-event-locate svg {
    filter: alpha(opacity=0);
    opacity: 0;
    margin-left: 2px;
    margin-top: 5px
}
.activity-event-locate:hover,
.activity-event-locate:active,
.activity-event-locate:focus,
.activity-event-target:hover .activity-event-locate:hover,
.activity-event-target:active .activity-event-locate:active,
.activity-event-target:focus .activity-event-locate:focus {
    cursor: pointer
}
.activity-event-locate:hover svg,
.activity-event-locate:active svg,
.activity-event-locate:focus svg,
.activity-event-target:hover .activity-event-locate:hover svg,
.activity-event-target:active .activity-event-locate:active svg,
.activity-event-target:focus .activity-event-locate:focus svg {
    filter: alpha(opacity=72);
    opacity: .72;
    cursor: pointer
}
.activity-event-target:hover .activity-event-locate svg,
.activity-event-target:active .activity-event-locate svg,
.activity-event-target:focus .activity-event-locate svg {
    filter: alpha(opacity=55);
    opacity: .55
}
.activity-event-user-deletion-overlay svg {
    margin-top: 4px
}
.activity-list .drive-spinner {
    height: 40px
}
.activity-entry-empty-trash-targets .activity-event-target-name {
    text-decoration: line-through
}
.activity-event-rename-old-title {
    color: #ccc;
    margin-top: 8px;
    overflow: hidden;
    text-decoration: line-through;
    text-overflow: ellipsis;
    white-space: nowrap
}
.activity-event-scope-change-detail.activity-event-scope-change-detail-first {
    border-top: none
}
.activity-event-scope-change-detail {
    position: relative;
    padding: 2px 0
}
.activity-event-scope-icon {
    border-radius: 50%;
    display: inline-block;
    overflow: hidden;
    padding: 0;
    position: relative;
    vertical-align: middle;
    z-index: 1
}
.activity-event-scope-icon img {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    height: 24px;
    vertical-align: middle;
    width: 24px
}
.activity-event-scope-icon-container .activity-event-scope-svg-icon {
    left: 2px;
    position: absolute;
    top: 2px
}
.activity-event-scope-background svg {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    height: 24px;
    width: 24px
}
.activity-event-scope-icon .activity-event-scope-icon-container {
    height: 24px;
    text-align: center;
    width: 24px
}
.activity-event-scope-icon-text {
    color: #fff;
    height: 24px;
    left: 0;
    line-height: 24px;
    position: absolute;
    top: 0;
    width: 24px
}
.activity-event-scope-element {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    font-weight: lighter;
    padding-left: 48px;
    width: 100%
}
.activity-event-scope-element-access {
    color: #5f6368;
    font-size: 13px;
    float: right;
    padding-left: 8px
}
.activity-event-scope-element-text {
    color: #5f6368;
    font-weight: 500
}
.activity-event-scope-detail-unshared .activity-event-scope-element-text {
    text-decoration: line-through
}
.activity-event-scope-detail-icon-container {
    display: inline-block;
    line-height: normal;
    vertical-align: middle;
    width: 0
}
.activity-event-scope-detail-unshared {
    filter: alpha(opacity=50);
    opacity: 0.5
}
.activity-event-scope-detail-content-container {
    display: inline-block;
    line-height: normal;
    vertical-align: middle;
    width: 100%
}
.activity-event-scopes-list {
    margin-top: 12px;
    position: relative;
    padding: 0 24px
}
.activity-team-drive-setting-events {
    padding-top: 10px
}
.activity-team-drive-setting-detail {
    display: flex;
    padding-left: 35px
}
.activity-team-drive-setting-detail:not(:last-child) {
    padding-bottom: 10px
}
.activity-team-drive-setting-description {
    display: inline-block;
    font-weight: normal;
    padding-left: 20px
}
.docs-tabbar {
    clear: left;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    float: left;
    -webkit-justify-content: left;
    justify-content: left;
    outline: none
}
.docs-tabbar-tab {
    -ms-flex-align: center;
    -moz-box-align: center;
    -webkit-box-align: center;
    box-align: center;
    -webkit-align-items: center;
    align-items: center;
    border-bottom: 2px solid transparent;
    border-top: 2px solid transparent;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    cursor: pointer;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    height: 48px;
    box-pack: center;
    -ms-flex-pack: center;
    -webkit-box-pack: center;
    -webkit-justify-content: center;
    justify-content: center;
    max-width: 264px;
    min-width: 72px;
    padding: 0px 24px
}
.docs-tabbar-tab-selected {
    border-bottom: 2px solid #fff
}
.docs-hc-edge.docs-tabbar-tab.docs-tabbar-tab-selected .docs-tabbar-tablabel,
.docs-hc-gecko.docs-tabbar-tab.docs-tabbar-tab-selected .docs-tabbar-tablabel,
.docs-hc-ie.docs-tabbar-tab.docs-tabbar-tab-selected .docs-tabbar-tablabel {
    border-bottom: 2px solid #fff;
    padding-bottom: 0px
}
.docs-hc-edge.docs-tabbar-tab .docs-tabbar-tablabel,
.docs-hc-gecko.docs-tabbar-tab .docs-tabbar-tablabel,
.docs-hc-ie.docs-tabbar-tab .docs-tabbar-tablabel {
    padding-bottom: 2px
}
.docs-tabbar-focused .docs-tabbar-tab-selected {
    background: rgba(255, 255, 255, 0.12)
}
.docs-tabbar-mouseactive .docs-tabbar-tab {
    background: transparent
}
.docs-tabbar .docs-tabbar-tab-active {
    background: rgba(255, 255, 255, 0.25)
}
.docs-tabbar-tablabel {
    color: rgba(255, 255, 255, 0.7);
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    overflow: hidden;
    text-overflow: ellipsis;
    text-transform: uppercase;
    white-space: nowrap
}
.docs-tabbar-tab-selected .docs-tabbar-tablabel {
    color: #fff
}
.docs-material-checkbox {
    border: 2px solid rgba(0, 0, 0, 0.38);
    border-radius: 2px;
    cursor: pointer;
    float: left;
    height: 12px;
    margin: 1px;
    outline: none;
    top: 4px;
    vertical-align: middle;
    width: 12px
}
.docs-material-checkbox-checked {
    background: #4285f4 url("data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+CjxzdmcKICAgeG1sbnM6ZGM9Imh0dHA6Ly9wdXJsLm9yZy9kYy9lbGVtZW50cy8xLjEvIgogICB4bWxuczpjYz0iaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbnMjIgogICB4bWxuczpyZGY9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjItcmRmLXN5bnRheC1ucyMiCiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgdmVyc2lvbj0iMS4xIgogICB2aWV3Qm94PSIwIDAgMSAxIgogICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJ4TWluWU1pbiBtZWV0Ij4KICA8cGF0aAogICAgIGQ9Ik0gMC4wNDAzODA1OSwwLjYyNjc3NjcgMC4xNDY0NDY2MSwwLjUyMDcxMDY4IDAuNDI5Mjg5MzIsMC44MDM1NTMzOSAwLjMyMzIyMzMsMC45MDk2MTk0MSB6IE0gMC4yMTcxNTcyOSwwLjgwMzU1MzM5IDAuODUzNTUzMzksMC4xNjcxNTcyOSAwLjk1OTYxOTQxLDAuMjczMjIzMyAwLjMyMzIyMzMsMC45MDk2MTk0MSB6IgogICAgIGlkPSJyZWN0Mzc4MCIKICAgICBzdHlsZT0iZmlsbDojZmZmZmZmO2ZpbGwtb3BhY2l0eToxO3N0cm9rZTpub25lIiAvPgo8L3N2Zz4K");
    border: 2px solid #4285f4
}
.docs-material-checkbox-focused {
    border: 2px solid #4285f4
}
.docs-material-checkbox-disabled {
    border-color: rgba(0, 0, 0, 0.26);
    cursor: default
}
.docs-material-checkbox-disabled.docs-material-checkbox-checked {
    background-clip: padding-box;
    background-color: rgba(0, 0, 0, 0.26);
    border-color: rgba(0, 0, 0, 0.26)
}
.docs-material-labeledcheckbox>.docs-material-checkbox-disabled~label:first-of-type {
    color: rgba(0, 0, 0, 0.54)
}
.docs-material-checkbox-checked.docs-material-checkbox-focused {
    background-color: #2a56c6;
    border: 2px solid #2a56c6
}
.docs-material-labeledcheckbox>label {
    color: rgba(0, 0, 0, 0.87);
    display: block;
    font: 13px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    line-height: 20px;
    margin-left: 30px;
    overflow-wrap: break-word;
    padding: 4px 0;
    vertical-align: middle;
    width: auto;
    word-wrap: break-word
}
.docs-material-labeled-checkbox-checkbox {
    outline: none
}
.docs-material-labeled-checkbox .docs-material-labeled-checkbox-checkbox {
    border: 2px solid rgba(0, 0, 0, 0.38);
    border-radius: 2px;
    cursor: pointer;
    float: left;
    height: 12px;
    margin: 1px;
    position: relative;
    top: 4px;
    vertical-align: middle;
    width: 12px
}
.docs-material-labeled-checkbox-checkbox.docs-material-labeled-checkbox-checked:before {
    content: url("data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+CjxzdmcKICAgeG1sbnM6ZGM9Imh0dHA6Ly9wdXJsLm9yZy9kYy9lbGVtZW50cy8xLjEvIgogICB4bWxuczpjYz0iaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbnMjIgogICB4bWxuczpyZGY9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjItcmRmLXN5bnRheC1ucyMiCiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgdmVyc2lvbj0iMS4xIgogICB2aWV3Qm94PSIwIDAgMSAxIgogICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJ4TWluWU1pbiBtZWV0Ij4KICA8cGF0aAogICAgIGQ9Ik0gMC4wNDAzODA1OSwwLjYyNjc3NjcgMC4xNDY0NDY2MSwwLjUyMDcxMDY4IDAuNDI5Mjg5MzIsMC44MDM1NTMzOSAwLjMyMzIyMzMsMC45MDk2MTk0MSB6IE0gMC4yMTcxNTcyOSwwLjgwMzU1MzM5IDAuODUzNTUzMzksMC4xNjcxNTcyOSAwLjk1OTYxOTQxLDAuMjczMjIzMyAwLjMyMzIyMzMsMC45MDk2MTk0MSB6IgogICAgIGlkPSJyZWN0Mzc4MCIKICAgICBzdHlsZT0iZmlsbDojZmZmZmZmO2ZpbGwtb3BhY2l0eToxO3N0cm9rZTpub25lIiAvPgo8L3N2Zz4K");
    display: block;
    line-height: 12px
}
.docs-material-labeled-checkbox-checkbox.docs-material-labeled-checkbox-checked {
    background-color: #4285f4;
    border: 2px solid #4285f4
}
.docs-material-labeled-checkbox-focused .docs-material-labeled-checkbox-checkbox {
    border: 2px solid #4285f4
}
.docs-material-labeled-checkbox-disabled .docs-material-labeled-checkbox-checkbox {
    border-color: rgba(0, 0, 0, 0.26);
    cursor: default
}
.docs-material-labeled-checkbox-disabled .docs-material-labeled-checkbox-checkbox.docs-material-labeled-checkbox-checked {
    background-clip: padding-box;
    background-color: rgba(0, 0, 0, 0.26);
    border-color: rgba(0, 0, 0, 0.26)
}
.docs-material-labeled-checkbox-focused .docs-material-labeled-checkbox-checkbox.docs-material-labeled-checkbox-checked {
    background-color: #2a56c6;
    border: 2px solid #2a56c6
}
.docs-material-labeled-checkbox .docs-material-labeled-checkbox-label {
    color: rgba(0, 0, 0, 0.87);
    display: block;
    font: 13px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    line-height: 20px;
    margin-left: 30px;
    overflow-wrap: break-word;
    padding: 4px 0;
    vertical-align: middle;
    width: auto;
    word-wrap: break-word
}
.docs-material-labeled-checkbox.docs-material-labeled-checkbox-disabled .docs-material-labeled-checkbox-label {
    color: rgba(0, 0, 0, 0.54)
}
.docs-material-labeled-checkbox .docs-material-labeled-checkbox-description-hide {
    display: none
}
div.docs-material-gm-checkbox,
span.docs-material-gm-checkbox {
    border: 2px solid #5f6368;
    border-radius: 2px;
    box-sizing: border-box;
    cursor: pointer;
    height: 18px;
    margin: 1px;
    outline: none;
    top: 4px;
    vertical-align: middle;
    width: 18px;
    display: inline-block
}
div.docs-material-gm-checkbox-checked,
span.docs-material-gm-checkbox-checked,
div.docs-material-gm-checkbox-undetermined,
span.docs-material-gm-checkbox-undetermined {
    background-color: #188038;
    border: 2px solid #188038
}
div.docs-material-gm-checkbox-checked:before,
span.docs-material-gm-checkbox-checked:before {
    content: url("data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+CjxzdmcKICAgeG1sbnM6ZGM9Imh0dHA6Ly9wdXJsLm9yZy9kYy9lbGVtZW50cy8xLjEvIgogICB4bWxuczpjYz0iaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbnMjIgogICB4bWxuczpyZGY9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjItcmRmLXN5bnRheC1ucyMiCiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgdmVyc2lvbj0iMS4xIgogICB2aWV3Qm94PSIwIDAgMSAxIgogICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJ4TWluWU1pbiBtZWV0Ij4KICA8cGF0aAogICAgIGQ9Ik0gMC4wNDAzODA1OSwwLjYyNjc3NjcgMC4xNDY0NDY2MSwwLjUyMDcxMDY4IDAuNDI5Mjg5MzIsMC44MDM1NTMzOSAwLjMyMzIyMzMsMC45MDk2MTk0MSB6IE0gMC4yMTcxNTcyOSwwLjgwMzU1MzM5IDAuODUzNTUzMzksMC4xNjcxNTcyOSAwLjk1OTYxOTQxLDAuMjczMjIzMyAwLjMyMzIyMzMsMC45MDk2MTk0MSB6IgogICAgIGlkPSJyZWN0Mzc4MCIKICAgICBzdHlsZT0iZmlsbDojZmZmZmZmO2ZpbGwtb3BhY2l0eToxO3N0cm9rZTpub25lIiAvPgo8L3N2Zz4K");
    display: block;
    line-height: 15px
}
div.docs-material-gm-checkbox-undetermined:before,
span.docs-material-gm-checkbox-undetermined:before {
    border-top: 2px solid white;
    content: '';
    display: block;
    height: 0;
    margin-left: 3px;
    margin-top: 6px;
    width: 8px
}
div.docs-material-gm-checkbox-focused,
span.docs-material-gm-checkbox-focused {
    border: 2px solid #188038
}
div.docs-material-gm-checkbox-disabled,
span.docs-material-gm-checkbox-disabled {
    cursor: default;
    opacity: .38
}
div.docs-material-gm-checkbox-disabled.docs-material-gm-checkbox-checked,
span.docs-material-gm-checkbox-disabled.docs-material-gm-checkbox-checked {
    background-clip: padding-box;
    background-color: #5f6368;
    border-color: #5f6368;
    opacity: .38
}
div.docs-material-gm-checkbox-checked.docs-material-gm-checkbox-focused,
span.docs-material-gm-checkbox-checked.docs-material-gm-checkbox-focused {
    background-color: #188038;
    border: 2px solid #188038
}
div.docs-material-gm-checkbox-disabled.docs-material-gm-checkbox-undetermined,
span.docs-material-gm-checkbox-disabled.docs-material-gm-checkbox-undetermined {
    background-clip: padding-box;
    background-color: #5f6368;
    border-color: #5f6368;
    opacity: .38
}
div.docs-material-gm-checkbox-hover,
span.docs-material-gm-checkbox-hover,
div.docs-material-gm-checkbox-focused,
span.docs-material-gm-checkbox-focused {
    outline: 1px dotted transparent;
    outline-offset: 3px
}
div.docs-material-gm-checkbox-active,
span.docs-material-gm-checkbox-active {
    outline: 1px solid transparent;
    outline-offset: 3px
}
.docs-material-gm-labeled-checkbox {
    cursor: pointer;
    max-width: 672px;
    outline: none;
    padding: 8px 0px;
    width: 100%
}
.docs-material-gm-labeled-checkbox-content {
    display: inline-block
}
.docs-material-gm-labeled-checkbox-circle {
    width: 40px;
    height: 40px;
    border-radius: 50%;
    cursor: pointer;
    position: absolute;
    margin-left: -30px;
    margin-top: -9px
}
.docs-material-gm-labeled-checkbox-checkbox {
    border: 2px solid #5f6368;
    border-radius: 2px;
    box-sizing: border-box;
    cursor: pointer;
    height: 18px;
    margin: 1px;
    outline: none;
    top: 4px;
    vertical-align: middle;
    width: 18px;
    display: inline-block
}
.docs-material-gm-labeled-checkbox-checkbox.docs-material-gm-labeled-checkbox-checked,
.docs-material-gm-labeled-checkbox-checkbox.docs-material-gm-labeled-checkbox-undetermined {
    background-color: #188038;
    border: 2px solid #188038
}
.docs-material-gm-labeled-checkbox-checkbox.docs-material-gm-labeled-checkbox-checked:before {
    content: url("data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+CjxzdmcKICAgeG1sbnM6ZGM9Imh0dHA6Ly9wdXJsLm9yZy9kYy9lbGVtZW50cy8xLjEvIgogICB4bWxuczpjYz0iaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbnMjIgogICB4bWxuczpyZGY9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjItcmRmLXN5bnRheC1ucyMiCiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgdmVyc2lvbj0iMS4xIgogICB2aWV3Qm94PSIwIDAgMSAxIgogICBwcmVzZXJ2ZUFzcGVjdFJhdGlvPSJ4TWluWU1pbiBtZWV0Ij4KICA8cGF0aAogICAgIGQ9Ik0gMC4wNDAzODA1OSwwLjYyNjc3NjcgMC4xNDY0NDY2MSwwLjUyMDcxMDY4IDAuNDI5Mjg5MzIsMC44MDM1NTMzOSAwLjMyMzIyMzMsMC45MDk2MTk0MSB6IE0gMC4yMTcxNTcyOSwwLjgwMzU1MzM5IDAuODUzNTUzMzksMC4xNjcxNTcyOSAwLjk1OTYxOTQxLDAuMjczMjIzMyAwLjMyMzIyMzMsMC45MDk2MTk0MSB6IgogICAgIGlkPSJyZWN0Mzc4MCIKICAgICBzdHlsZT0iZmlsbDojZmZmZmZmO2ZpbGwtb3BhY2l0eToxO3N0cm9rZTpub25lIiAvPgo8L3N2Zz4K");
    display: block;
    line-height: 15px
}
.docs-material-gm-labeled-checkbox-checkbox.docs-material-gm-labeled-checkbox-undetermined:before {
    border-top: 2px solid white;
    content: '';
    display: block;
    height: 0;
    margin-left: 3px;
    margin-top: 6px;
    width: 8px
}
.docs-material-gm-labeled-checkbox-disabled .docs-material-gm-labeled-checkbox-checkbox {
    cursor: default;
    opacity: .38
}
.docs-material-gm-labeled-checkbox-hover .docs-material-gm-labeled-checkbox-checkbox,
.docs-material-gm-labeled-checkbox-focused .docs-material-gm-labeled-checkbox-checkbox {
    outline: 1px dotted transparent;
    outline-offset: 3px
}
.docs-material-gm-labeled-checkbox-active .docs-material-gm-labeled-checkbox-checkbox {
    outline: 1px solid transparent;
    outline-offset: 3px
}
.docs-material-gm-labeled-checkbox-hover .docs-material-gm-labeled-checkbox-circle {
    background-color: #5f6368;
    opacity: .04
}
.docs-material-gm-labeled-checkbox-focused .docs-material-gm-labeled-checkbox-circle {
    background-color: #5f6368;
    opacity: .06
}
.docs-material-gm-labeled-checkbox-active .docs-material-gm-labeled-checkbox-circle {
    background-color: #5f6368;
    opacity: .1
}
.docs-material-gm-labeled-checkbox-disabled .docs-material-gm-labeled-checkbox-checkbox.docs-material-gm-labeled-checkbox-checked {
    background-clip: padding-box;
    background-color: #5f6368;
    border-color: #5f6368;
    opacity: .38
}
.docs-material-gm-labeled-checkbox-disabled .docs-material-gm-labeled-checkbox-checkbox.docs-material-gm-labeled-checkbox-undetermined {
    background-clip: padding-box;
    background-color: #5f6368;
    border-color: #5f6368;
    opacity: .38
}
.docs-material-gm-labeled-checkbox-hover .docs-material-gm-labeled-checkbox-checked+.docs-material-gm-labeled-checkbox-circle {
    background-color: #188038;
    opacity: .04
}
.docs-material-gm-labeled-checkbox-focused .docs-material-gm-labeled-checkbox-checked+.docs-material-gm-labeled-checkbox-circle {
    background-color: #188038;
    opacity: .06
}
.docs-material-gm-labeled-checkbox-active .docs-material-gm-labeled-checkbox-checked+.docs-material-gm-labeled-checkbox-circle {
    background-color: #188038;
    opacity: .1
}
.docs-material-gm-labeled-checkbox .docs-material-gm-labeled-checkbox-label {
    color: #3c4043;
    cursor: pointer;
    display: inline-block;
    font: 14px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    line-height: 16px;
    margin-left: 12px;
    overflow-wrap: break-word;
    padding: 3px 0;
    vertical-align: middle;
    width: auto;
    word-wrap: break-word
}
.docs-material-gm-labeled-checkbox.docs-material-gm-labeled-checkbox-disabled .docs-material-gm-labeled-checkbox-label {
    opacity: .38
}
.docs-material-gm-labeled-checkbox .docs-material-gm-labeled-checkbox-description {
    color: #80868b;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    margin-left: 32px;
    padding: 1px 0;
    width: 100%
}
.docs-material-gm-labeled-checkbox.docs-material-gm-labeled-checkbox-disabled .docs-material-gm-labeled-checkbox-description {
    opacity: .38
}
.docs-material-gm-labeled-checkbox .docs-material-gm-labeled-checkbox-description-hide {
    display: none
}
.goog-flat-menu-button {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    background-color: #f5f5f5;
    background-image: -webkit-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -o-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: linear-gradient(top, #f5f5f5, #f1f1f1);
    border: 1px solid #dcdcdc;
    color: #333;
    cursor: default;
    font-size: 11px;
    font-weight: bold;
    line-height: 27px;
    list-style: none;
    margin: 0 2px;
    min-width: 46px;
    outline: none;
    padding: 0 18px 0 6px;
    text-align: center;
    text-decoration: none
}
.goog-flat-menu-button-disabled {
    background-color: #fff;
    border-color: #f3f3f3;
    color: #b8b8b8
}
.goog-flat-menu-button.goog-flat-menu-button-hover {
    background-color: #f8f8f8;
    background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -o-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
    -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, .1);
    -moz-box-shadow: 0 1px 1px rgba(0, 0, 0, .1);
    box-shadow: 0 1px 1px rgba(0, 0, 0, .1);
    border-color: #c6c6c6;
    color: #111
}
.goog-flat-menu-button.goog-flat-menu-button-focused {
    border-color: #4d90fe
}
.goog-flat-menu-button.goog-flat-menu-button-open,
.goog-flat-menu-button.goog-flat-menu-button-active {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    background-color: #eee;
    background-image: -webkit-linear-gradient(top, #eee, #e0e0e0);
    background-image: -moz-linear-gradient(top, #eee, #e0e0e0);
    background-image: -ms-linear-gradient(top, #eee, #e0e0e0);
    background-image: -o-linear-gradient(top, #eee, #e0e0e0);
    background-image: linear-gradient(top, #eee, #e0e0e0);
    border: 1px solid #ccc;
    color: #333;
    z-index: 2
}
.goog-flat-menu-button-caption {
    vertical-align: top;
    white-space: nowrap
}
.goog-flat-menu-button-dropdown {
    border-color: #777 transparent;
    border-style: solid;
    border-width: 4px 4px 0 4px;
    height: 0;
    width: 0;
    position: absolute;
    right: 5px;
    top: 12px
}
.goog-flat-menu-button .goog-flat-menu-button-img {
    margin-top: -3px;
    opacity: .70;
    vertical-align: middle
}
.goog-flat-menu-button-active .goog-flat-menu-button-img,
.goog-flat-menu-button-open .goog-flat-menu-button-img,
.goog-flat-menu-button-selected .goog-flat-menu-button-img,
.goog-flat-menu-button-hover .goog-flat-menu-button-img {
    opacity: 0.9
}
.goog-flat-menu-button-active .goog-flat-menu-button-dropdown,
.goog-flat-menu-button-open .goog-flat-menu-button-dropdown,
.goog-flat-menu-button-selected .goog-flat-menu-button-dropdown,
.goog-flat-menu-button-hover .goog-flat-menu-button-dropdown {
    border-color: #595959 transparent
}
.goog-flat-menu-button-left,
.goog-flat-menu-button-right {
    z-index: 1
}
.goog-flat-menu-button-left.goog-flat-menu-button-disabled {
    z-index: 0
}
.goog-flat-menu-button-right:focus,
.goog-flat-menu-button-hover.goog-flat-menu-button-collapse-right {
    z-index: 2
}
.goog-flat-menu-button-left:focus,
.goog-flat-menu-button-hover.goog-flat-menu-button-collapse-left {
    z-index: 2
}
.goog-flat-menu-button-collapse-left {
    margin-left: -1px;
    -moz-border-radius-bottomleft: 0;
    -moz-border-radius-topleft: 0;
    -webkit-border-bottom-left-radius: 0;
    -webkit-border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
    min-width: 0;
    padding-left: 0;
    vertical-align: top
}
.goog-flat-menu-button-collapse-right {
    margin-right: 0px;
    -moz-border-radius-topright: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-top-right-radius: 0;
    -webkit-border-bottom-right-radius: 0;
    border-top-right-radius: 0;
    border-bottom-right-radius: 0
}
.goog-menuseparator {
    border-top: 1px solid #ebebeb;
    margin-top: 6px;
    margin-bottom: 6px
}
.goog-submenu-arrow {
    -webkit-transition: all 0.218s;
    -moz-transition: all 0.218s;
    -o-transition: all 0.218s;
    transition: all 0.218s;
    font-size: 70%;
    left: auto;
    right: 10px;
    padding-top: 3px;
    padding-right: 0;
    position: absolute;
    text-align: right;
    opacity: .5;
    filter: alpha(opacity=50)
}
.goog-menuitem-highlight .goog-submenu-arrow,
.goog-menuitem-hover .goog-submenu-arrow {
    -webkit-transition: none;
    -moz-transition: none;
    -o-transition: none;
    transition: none;
    border-left-color: #999;
    opacity: 1.0
}
.goog-menuitem-disabled .goog-submenu-arrow {
    color: inherit;
    opacity: 1.0
}
.docs-material-labeled-select {
    outline: 0;
    width: 100%
}
.docs-material-labeled-select-outer-box {
    -webkit-transition: border-color 300ms ease;
    -moz-transition: border-color 300ms ease;
    -o-transition: border-color 300ms ease;
    transition: border-color 300ms ease;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    cursor: pointer;
    height: 26px;
    line-height: 26px;
    margin-bottom: 1px;
    width: 100%
}
.docs-material-labeled-select-hover .docs-material-labeled-select-outer-box {
    border-bottom-color: rgba(0, 0, 0, 0.38)
}
.docs-material-labeled-select-open .docs-material-labeled-select-outer-box,
.docs-material-labeled-select-focused .docs-material-labeled-select-outer-box {
    border-bottom-width: 2px;
    border-bottom-color: #4285f4;
    margin-bottom: 0px
}
.docs-material-labeled-select-disabled .docs-material-labeled-select-outer-box {
    border-bottom: 1px dotted rgba(0, 0, 0, 0.12);
    cursor: default
}
.docs-material-labeled-select-inner-box {
    display: flex;
    justify-content: space-between
}
.docs-material-labeled-select-caption {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    color: rgba(0, 0, 0, 0.87);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    height: 26px;
    line-height: 26px;
    max-width: 100%;
    overflow: hidden;
    padding-right: 24px;
    position: relative;
    text-overflow: ellipsis;
    white-space: nowrap
}
.docs-material-labeled-select-disabled .docs-material-labeled-select-caption {
    color: rgba(0, 0, 0, 0.12)
}
.docs-material-labeled-select-dropdown {
    align-items: center;
    display: flex;
    height: 24px;
    justify-content: center;
    width: 24px
}
.docs-material-labeled-select-dropdown-icon {
    background: no-repeat url(//ssl.gstatic.com/docs/common/material_common_sprite134_grey_medium.svg) 0 -1364px;
    height: 18px;
    width: 18px
}
.docs-material-labeled-select-hover .docs-material-labeled-select-dropdown-icon,
.docs-material-labeled-select-focused .docs-material-labeled-select-dropdown-icon {
    opacity: 0.54
}
.docs-material-labeled-select-disabled .docs-material-labeled-select-dropdown-icon {
    opacity: 0.12
}
.docs-material-labeled-select-label {
    color: #616161;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 11px;
    line-height: 16px
}
.docs-material-labeled-select-disabled .docs-material-labeled-select-label {
    opacity: 0.12
}
.docs-material-select {
    color: rgba(0, 0, 0, 0.87);
    cursor: pointer;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    height: 26px;
    line-height: 26px;
    outline: 0;
    width: 100%
}
.docs-material-select-disabled {
    color: rgba(0, 0, 0, 0.12);
    cursor: default
}
.docs-material-select-outer-box {
    -webkit-transition: border-color 300ms ease;
    -moz-transition: border-color 300ms ease;
    -o-transition: border-color 300ms ease;
    transition: border-color 300ms ease;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    height: 26px;
    line-height: 26px;
    margin-bottom: 1px;
    width: 100%
}
.docs-material-select-hover .docs-material-select-outer-box {
    border-bottom-color: rgba(0, 0, 0, 0.38)
}
.docs-material-select-focused .docs-material-select-outer-box,
.docs-material-select-open .docs-material-select-outer-box {
    border-bottom-width: 2px;
    border-bottom-color: #4285f4;
    margin-bottom: 0px
}
.docs-material-select-disabled .docs-material-select-outer-box {
    border-bottom: 1px dotted rgba(0, 0, 0, 0.12)
}
.docs-material-select-inner-box {
    position: relative;
    width: 100%
}
.docs-material-select-caption {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    height: 26px;
    line-height: 26px;
    max-width: 100%;
    overflow: hidden;
    padding-right: 24px;
    position: relative;
    text-overflow: ellipsis;
    white-space: nowrap
}
.docs-material-select-dropdown {
    position: absolute;
    right: 7px;
    top: 10.5px
}
.docs-material-select-dropdown-icon {
    -webkit-transition: opacity 0.3s ease;
    -moz-transition: opacity 0.3s ease;
    -o-transition: opacity 0.3s ease;
    transition: opacity 0.3s ease;
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI1IiBoZWlnaHQ9IjMiPjxwb2x5Z29uIHBvaW50cz0iMCwwIDUsMCAyLjUsMyIgZmlsbD0iIzAwMCIvPjwvc3ZnPg==") no-repeat;
    background-size: contain;
    height: 5px;
    opacity: 0.38;
    width: 9px
}
.docs-material-select-hover .docs-material-select-dropdown-icon,
.docs-material-select-focused .docs-material-select-dropdown-icon {
    opacity: 0.54
}
.docs-material-select-disabled .docs-material-select-dropdown-icon {
    opacity: 0.12
}
.docs-material-gm-labeled-select {
    color: #3c4043;
    outline: none;
    width: 100%
}
.docs-material-gm-labeled-select-outer-box {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    cursor: pointer;
    padding: 8px 6px 8px 8px;
    width: 100%
}
.docs-material-gm-labeled-select-hover .docs-material-gm-labeled-select-outer-box {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid #dadce0
}
.docs-material-gm-labeled-select-open .docs-material-gm-labeled-select-outer-box {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid transparent
}
.docs-material-gm-select-open.docs-material-gm-select-hover .docs-material-gm-labeled-select-outer-box {
    background-color: rgba(60, 64, 67, 0.06)
}
.docs-material-gm-select-open.docs-material-gm-select-focused .docs-material-gm-labeled-select-outer-box {
    background-color: rgba(60, 64, 67, 0.08)
}
.docs-material-gm-labeled-select-disabled .docs-material-gm-labeled-select-outer-box {
    border: 1px solid #dadce0;
    cursor: default
}
.docs-material-gm-labeled-select-inner-box {
    align-items: center;
    display: flex;
    justify-content: space-between;
    position: relative;
    width: 100%
}
.docs-material-gm-labeled-select-content {
    margin-bottom: 8px
}
.docs-material-gm-labeled-select-caption {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    height: 20px;
    line-height: 20px;
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.docs-material-gm-labeled-select-dropdown {
    align-items: center;
    display: flex;
    height: 24px;
    justify-content: center;
    width: 24px
}
.docs-material-gm-labeled-select-dropdown-icon {
    background: no-repeat url(//ssl.gstatic.com/docs/common/material_common_sprite134_grey_medium.svg) 0 -1364px;
    height: 18px;
    width: 18px
}
.docs-material-gm-labeled-select-open .docs-material-gm-labeled-select-dropdown-icon {
    -moz-transform: rotate(180deg);
    -webkit-transform: rotate(180deg);
    -ms-transform: rotate(180deg);
    transform: rotate(180deg)
}
.docs-material-gm-labeled-select-label {
    color: #5f6368;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px
}
.docs-material-gm-select {
    color: #3c4043;
    outline: none;
    width: 100%
}
.docs-material-gm-select-disabled {
    color: #5f6368;
    opacity: .38;
    cursor: default
}
.docs-material-gm-select-outer-box {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    cursor: pointer;
    padding: 8px 6px 8px 8px;
    width: 100%
}
.docs-material-gm-select-outer-box:active {
    background-color: #fff;
    border: 1px solid transparent;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.docs-material-gm-select-hover .docs-material-gm-select-outer-box {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid #dadce0
}
.docs-material-gm-select-focused .docs-material-gm-select-outer-box {
    background-color: rgba(60, 64, 67, 0.06);
    border: 1px solid #dadce0
}
.docs-material-gm-select-open .docs-material-gm-select-outer-box {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid transparent
}
.docs-material-gm-select-open.docs-material-gm-select-hover .docs-material-gm-select-outer-box {
    background-color: rgba(60, 64, 67, 0.06)
}
.docs-material-gm-select-open.docs-material-gm-select-focused .docs-material-gm-select-outer-box {
    background-color: rgba(60, 64, 67, 0.08)
}
.docs-material-gm-select-disabled .docs-material-gm-select-outer-box {
    border: 1px solid #dadce0;
    cursor: default
}
.docs-material-gm-select-inner-box {
    align-items: center;
    display: flex;
    justify-content: space-between;
    position: relative;
    width: 100%
}
.docs-material-gm-select-caption {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    height: 20px;
    line-height: 20px;
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.docs-material-gm-select-dropdown {
    align-items: center;
    display: flex;
    height: 24px;
    justify-content: center;
    width: 24px
}
.docs-material-gm-select-dropdown-icon {
    background: no-repeat url(//ssl.gstatic.com/docs/common/material_common_sprite134_grey_medium.svg) 0 -1364px;
    height: 18px;
    width: 18px
}
.docs-material-gm-select-open .docs-material-gm-select-dropdown-icon {
    -moz-transform: rotate(180deg);
    -webkit-transform: rotate(180deg);
    -ms-transform: rotate(180deg);
    transform: rotate(180deg)
}
.docs-material-labeled-text-field {
    height: 40px;
    line-height: 40px;
    padding-top: 5px;
    position: relative
}
.docs-material-labeled-text-field-input {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    -webkit-transition: border-color 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: border-color 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: border-color 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: border-color 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    background: none;
    border: none;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    color: rgba(0, 0, 0, 0.87);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    height: 26px;
    line-height: 26px;
    outline: none;
    overflow: hidden;
    text-overflow: ellipsis;
    width: 100%
}
.docs-material-labeled-text-field-hover .docs-material-labeled-text-field-input {
    border-bottom-color: rgba(0, 0, 0, 0.38)
}
.docs-material-labeled-text-field-focused .docs-material-labeled-text-field-input {
    border-bottom: 2px solid #4285f4
}
.docs-material-labeled-text-field-disabled .docs-material-labeled-text-field-input {
    border-bottom: 1px dotted rgba(0, 0, 0, 0.12);
    color: rgba(0, 0, 0, 0.12);
    cursor: default
}
.docs-material-labeled-text-field-label {
    -webkit-transition: transform 200ms cubic-bezier(0.4, 0.0, 1, 1);
    -moz-transition: transform 200ms cubic-bezier(0.4, 0.0, 1, 1);
    -o-transition: transform 200ms cubic-bezier(0.4, 0.0, 1, 1);
    transition: transform 200ms cubic-bezier(0.4, 0.0, 1, 1);
    color: #616161;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    line-height: 45px;
    position: absolute;
    transform-origin: left bottom
}
.docs-material-labeled-text-field-has-text .docs-material-labeled-text-field-label,
.docs-material-labeled-text-field-focused .docs-material-labeled-text-field-label {
    transform: translateY(-22px) scale(.846, .846)
}
.docs-material-labeled-text-field-focused .docs-material-labeled-text-field-label {
    color: #4285f4
}
.docs-material-labeled-text-field-disabled .docs-material-labeled-text-field-label {
    opacity: 0.12
}
.docs-material-text-area {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    -webkit-transition: border-color 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: border-color 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: border-color 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: border-color 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    background: none;
    border: none;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    color: rgba(0, 0, 0, 0.87);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    outline: none;
    resize: none;
    width: 100%
}
.docs-material-text-area:hover {
    border-bottom-color: rgba(0, 0, 0, 0.38)
}
.docs-material-text-area:focus {
    border-bottom: 2px solid #4285f4
}
.docs-material-text-area:disabled {
    border-bottom: 1px dotted rgba(0, 0, 0, 0.12);
    color: rgba(0, 0, 0, 0.12);
    cursor: default
}
.docs-material-text-field-input {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    -webkit-transition: border-color 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: border-color 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: border-color 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: border-color 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    background: none;
    border: none;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    color: rgba(0, 0, 0, 0.87);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    height: 26px;
    line-height: 26px;
    outline: none;
    overflow: hidden;
    text-overflow: ellipsis;
    width: 100%
}
.docs-material-text-field-hover .docs-material-text-field-input {
    border-bottom-color: rgba(0, 0, 0, 0.38)
}
.docs-material-text-field-focused .docs-material-text-field-input {
    border-bottom: 2px solid #4285f4
}
.docs-material-text-field-disabled .docs-material-text-field-input {
    border-bottom: 1px dotted rgba(0, 0, 0, 0.12);
    color: rgba(0, 0, 0, 0.12);
    cursor: default
}
.drive-spinner {
    height: 44px;
    overflow: hidden;
    position: relative
}
.drive-quantum-spinner {
    height: 28px;
    left: 50%;
    margin-left: -14px;
    position: absolute;
    top: 8px;
    width: 28px
}
.docs-analytics-icon {
    direction: ltr;
    text-align: left;
    overflow: hidden;
    position: relative;
    vertical-align: middle
}
.docs-analytics-img:before {
    content: url(//ssl.gstatic.com/docs/common/menu_feature_sprite7.svg)
}
.docs-analytics-img {
    height: 4332px;
    position: absolute;
    width: 72px
}
.docs-analytics-hc-edge .docs-analytics-icon,
.docs-analytics-hc-gecko .docs-analytics-icon {
    filter: invert(100%)
}
.docs-analytics-hc-ie .docs-analytics-icon {
    -ms-high-contrast-adjust: none;
    background-color: white
}
.docs-analytics-arrow-downward-18px {
    left: 0;
    top: -4296px
}
.docs-analytics-arrow-drop-down-black-18dp {
    left: -18px;
    top: -1944px
}
.docs-analytics-arrow-right-black-18dp {
    left: -18px;
    top: -3658px
}
.docs-analytics-arrow-upward-18px {
    left: 0;
    top: -640px
}
.docs-analytics-close-black-24px {
    left: -24px;
    top: -452px
}
.docs-analytics-close-white-24px {
    left: -48px;
    top: -452px
}
.docs-analytics-info-outline-black-24px {
    left: -42px;
    top: -1098px
}
.docs-analytics-group-in-circle-32px {
    left: -24px;
    top: -1748px
}
.docs-analytics-keyboard-arrow-down-18px {
    left: -50px;
    top: -1222px
}
.docs-analytics-keyboard-arrow-up-18px {
    left: 0;
    top: -2992px
}
.docs-analytics-document-icon-kix {
    left: 0;
    top: -2974px
}
.docs-analytics-document-icon-punch {
    left: -24px;
    top: -1098px
}
.docs-analytics-document-icon-sketchy {
    left: -50px;
    top: -3034px
}
.docs-analytics-document-icon-ritz {
    left: -36px;
    top: -4314px
}
.docs-analytics-email-icon {
    left: -24px;
    top: -4146px
}
.analytics-dialog {
    border-radius: 8px;
    height: 100%;
    max-height: 586px;
    max-width: 880px;
    min-width: 580px;
    width: 100%
}
.analytics-dialog.analytics-dialog-collapsed {
    max-width: 684px;
    width: calc(100% - (2*8px))
}
.analytics-dialog::before {
    border: 1px solid transparent;
    border-radius: 8px;
    bottom: -1px;
    content: '';
    left: -1px;
    position: absolute;
    right: -1px;
    top: -1px
}
.analytics-dialog-title {
    display: none
}
.analytics-vc-content .docs-material-gm-select-caption {
    padding-left: 8px;
    width: 100%
}
.analytics-vc-content .docs-material-gm-select-dropdown {
    padding-right: 8px
}
.analytics-vc-content .docs-material-gm-select-outer-box {
    padding: 0
}
.analytics-vc-content .goog-menu .goog-menuitem-highlight {
    border: none
}
.analytics-btn-fill.jfk-button {
    cursor: pointer;
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff
}
.analytics-btn-fill.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #2a8947;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.analytics-btn-fill.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #4f9e67;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.analytics-btn-fill.jfk-button-focused.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.analytics-btn-fill.jfk-button-focused.jfk-button-active {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 2px 6px 2px rgba(52, 168, 83, 0.15)
}
.analytics-btn-fill.jfk-button-disabled {
    cursor: default;
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #f1f3f4;
    color: #3c4043;
    opacity: 0.38
}
.analytics-btn-hairline.jfk-button {
    cursor: pointer;
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #dadce0!important;
    color: #188038
}
.analytics-btn-hairline.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #f8fcf9;
    border: 1px solid #c8e7d1!important
}
.analytics-btn-hairline.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #e7f5eb;
    border: 1px solid #bbe2c6!important
}
.analytics-btn-hairline.jfk-button-focused.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    border: 1px solid #b5e0c1!important
}
.analytics-btn-hairline.jfk-button-focused.jfk-button-active {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    border: 1px solid transparent!important;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.analytics-btn-hairline.jfk-button-disabled {
    cursor: default;
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #f1f3f4!important;
    color: #3c4043;
    opacity: 0.38
}
.analytics-btn-text.jfk-button {
    cursor: pointer;
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    color: #188038
}
.analytics-btn-text.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #f8fcf9;
    color: #188038
}
.analytics-btn-text.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #e7f5eb;
    color: #188038
}
.analytics-btn-text.jfk-button-focused.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    color: #188038
}
.analytics-btn-text.jfk-button-focused.jfk-button-active {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    color: #188038;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.analytics-btn-text.jfk-button-disabled {
    cursor: default;
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    color: #188038;
    color: #3c4043;
    opacity: 0.38
}
.analytics-cotc {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    overflow-x: hidden;
    overflow-y: auto
}
.analytics-cotc-header {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 0 0 auto;
    -webkit-flex: 0 0 auto;
    flex: 0 0 auto;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    justify-content: space-between;
    margin: 18px 24px 0 24px;
    overflow: hidden
}
.analytics-cotc-legend {
    -webkit-align-items: center;
    align-items: center;
    color: #202124;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 0 0;
    -webkit-flex: 0 0;
    flex: 0 0;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    font-size: 12px;
    margin: 40px 24px 40px 45px;
    text-align: center
}
.analytics-cotc-legend-box {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    margin-right: 8px
}
.analytics-cotc-legend span {
    margin-right: 24px
}
.analytics-ct-table {
    -webkit-align-items: flex-start;
    align-items: flex-start;
    border-collapse: collapse;
    display: flex;
    flex-direction: column;
    padding: 20px;
    white-space: nowrap
}
.analytics-ct-table-header {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1
}
.analytics-ct-table-header-container {
    display: flex;
    height: 11px;
    width: 100%
}
.analytics-ct-table-date-container {
    margin: 0;
    position: absolute
}
.analytics-ct-table-date {
    font-size: 9px;
    margin-left: -50%
}
.analytics-ct-table-date-light {
    opacity: 0.6
}
.analytics-ct-table-container {
    display: flex;
    flex: 1 1 auto;
    overflow-y: auto;
    width: 100%
}
.analytics-ct-table-contributors {
    border-collapse: collapse;
    max-height: 100%;
    overflow-y: auto;
    table-layout: fixed;
    width: 100%
}
.analytics-ct-contributor-row {
    align-items: center;
    border-right: 1px solid #e3e3e3
}
.analytics-ct-contributor-row:last-child .analytics-ct-table-profile {
    border-bottom: 0
}
.analytics-ct-contributor-row:last-child .analytics-ct-table-activity-cell-div {
    border-bottom: 0
}
.analytics-ct-table-profile-container {
    background-color: #f9f9f9;
    height: 38px;
    padding: 0;
    width: 170px
}
.analytics-ct-table-profile {
    -webkit-align-items: center;
    align-items: center;
    border-bottom: 2px solid #fff;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    height: 100%;
    padding: 3px 5px
}
.analytics-ct-table-profile .analytics-profile-image {
    max-height: 24px;
    max-width: 24px
}
.analytics-ct-table-name {
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    padding-left: 12px
}
.analytics-ct-table-activity-cell {
    flex-grow: 1;
    height: 38px;
    padding: 0;
    position: relative
}
.analytics-ct-table-activity-cell-light-border::before,
.analytics-ct-table-activity-cell-dark-border::before,
.analytics-ct-table-activity-cell-light-border-disabled::before,
.analytics-ct-table-activity-cell-dark-border-disabled::before {
    content: '';
    height: 100%;
    position: absolute;
    left: 0;
    top: 0
}
.analytics-ct-table-activity-cell-light-border::before {
    border-left: 1px solid #eeeeee
}
.analytics-ct-table-activity-cell-dark-border::before {
    border-left: 1px solid #e0e0e0
}
.analytics-ct-table-activity-cell-light-border-disabled::before {
    border-left: 1px solid #e0e0e0
}
.analytics-ct-table-activity-cell-dark-border-disabled::before {
    border-left: 1px solid #dbdbdb
}
.analytics-ct-table-activity-cell-div {
    background-color: #f9f9f9;
    border-bottom: 2px solid #fff;
    height: 100%
}
.analytics-ct-table-activity-cell-div-disabled {
    background-color: #eeeeee;
    border-bottom: 2px solid #f5f5f5
}
.analytics-ct-activity-edit-small {
    background-color: #c4d9f2;
    height: 100%;
    position: relative
}
.analytics-ct-activity-comment-fg {
    background-color: #fff;
    border-radius: 50%;
    height: 4px;
    left: 50%;
    margin-left: -2px;
    position: absolute;
    top: 17px;
    width: 4px;
    z-index: 2
}
.analytics-ct-activity-comment-bg {
    background-color: #3c4043;
    border-radius: 50%;
    height: 8px;
    left: 50%;
    margin-left: -4px;
    position: absolute;
    top: 15px;
    width: 8px;
    z-index: 1
}
.analytics-ct {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    overflow-x: hidden;
    overflow-y: auto
}
.analytics-ct-header {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    justify-content: space-between;
    margin: 10px 19px 0
}
.analytics-ct-header-right {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    justify-content: space-around;
    width: 220px
}
.analytics-ct-header-right .analytics-selector {
    margin-top: 8px;
    min-width: 100px
}
.analytics-ct-legend {
    -webkit-align-items: center;
    align-items: center;
    -webkit-align-self: flex-end;
    align-self: flex-end;
    color: #5f6368;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 0 0;
    -webkit-flex: 0 0;
    flex: 0 0;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    font-size: 12px;
    margin: 0 20px 20px;
    text-align: center
}
.analytics-ct-legend-comment,
.analytics-ct-legend-edit {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center
}
.analytics-ct-legend-comment-circle {
    background-color: #fff;
    border-radius: 50%;
    border: 2px solid #3c4043;
    height: 4px;
    width: 4px
}
.analytics-ct-legend-label {
    margin-left: 4px
}
.analytics-ct-legend-box {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    margin-left: 12px
}
.analytics-ct-legend-edit-bar {
    height: 12px;
    width: 4px
}
.analytics-drp {
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    margin-left: 16px;
    max-width: 400px
}
.analytics-drp-left,
.analytics-drp-right {
    border-radius: 20px;
    cursor: pointer;
    height: auto;
    padding: 8px;
    right: 11px
}
.analytics-drp-left.jfk-button-hover,
.analytics-drp-right.jfk-button-hover {
    background-color: #f1f3f4
}
.analytics-drp-left.jfk-button-focused,
.analytics-drp-right.jfk-button-focused {
    background-color: #e8eaed
}
.analytics-drp-left.jfk-button-disabled,
.analytics-drp-right.jfk-button-disabled {
    opacity: 0.6;
    cursor: default
}
.analytics-drp-date-range {
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px
}
.analytics-drpd {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    height: 28px;
    margin: auto 3px;
    padding: 0px
}
.docs-analytics-hc-ie .analytics-drpd {
    -ms-high-contrast-adjust: none;
    background-color: white
}
.analytics-drpd-icon {
    border-radius: 100%;
    display: inline-block;
    height: 9px;
    margin-right: 8px;
    width: 9px
}
.analytics-drpd .docs-material-menu-button-flat-default-dropdown {
    margin: 0
}
.analytics-drpd.docs-material-menu-button-flat-default-hover {
    background-color: rgba(0, 0, 0, 0.06)
}
.analytics-drpd.docs-material-menu-button-flat-default-focused {
    background-color: rgba(0, 0, 0, 0.12);
    border-color: transparent
}
.analytics-drp .goog-menu .goog-menuitem {
    padding: 6px 25px 6px 18px
}
.analytics-dialog-bg,
.analytics-od-bg,
.analytics-npd-bg {
    background: rgba(0, 0, 0, 0.6);
    left: 0;
    position: absolute;
    top: 0
}
.analytics-dialog-bg,
.analytics-od-bg {
    z-index: 1002
}
.analytics-dialog,
.analytics-od,
.analytics-npd {
    background-color: #fff;
    border: 0px;
    border-radius: 8px;
    box-shadow: 0 16px 24px 2px rgba(0, 0, 0, 0.14), 0 6px 30px 5px rgba(0, 0, 0, 0.12), 0 8px 10px -5px rgba(0, 0, 0, 0.14);
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    outline: 0;
    position: absolute
}
.analytics-dialog,
.analytics-od {
    z-index: 1003
}
.analytics-dialog-content,
.analytics-od-content,
.analytics-npd-content {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    min-height: 0
}
.analytics-npd-bg {
    z-index: 1004
}
.analytics-npd {
    z-index: 1005
}
.analytics-ec-content {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    box-pack: center;
    -ms-flex-pack: center;
    -webkit-box-pack: center;
    -webkit-justify-content: center;
    justify-content: center;
    width: 100%
}
.analytics-ec-message-container {
    width: 100%
}
.analytics-ec-message {
    color: rgba(0, 0, 0, 0.6);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px;
    font-weight: 400;
    line-height: 24px;
    padding: 16px 128px;
    text-align: center
}
.analytics-ec-container {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    box-pack: center;
    -ms-flex-pack: center;
    -webkit-box-pack: center;
    -webkit-justify-content: center;
    justify-content: center;
    width: 100%;
    height: 100%
}
.analytics-vhc-feedbackcard {
    color: rgba(0, 0, 0, 0.87);
    font-size: 11px;
    font-style: italic;
    margin: 0
}
.analytics-vhc-feedbackcard-button,
.analytics-vhc-feedbackcard-button:link,
.analytics-vhc-feedbackcard-button:visited {
    color: #4285f4;
    cursor: pointer;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 11px;
    font-style: italic;
    height: 14px;
    line-height: 14px;
    margin: 0 0 0 2px;
    text-decoration: none
}
.analytics-vhfc-card {
    border-bottom-right-radius: 8px;
    border-top: 1px solid #e0e0e0;
    box-shadow: 0 2px 12px 2px rgba(60, 64, 67, .15);
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    margin-top: auto;
    z-index: 1
}
.analytics-vhfc-settings-container,
.analytics-vhfc-feedback-container,
.analytics-vhfc-nudge-container {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row
}
.analytics-vhfc-settings-container {
    height: 56px;
    box-pack: justify;
    -ms-flex-pack: justify;
    -webkit-box-pack: justify;
    -webkit-justify-content: space-between;
    justify-content: space-between;
    padding: 0px 24px
}
.analytics-vhfc-label {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-weight: 400;
    margin-right: 24px
}
.analytics-vhfc-label a:link,
.analytics-vhfc-label a:visited {
    color: #4285f4;
    text-decoration: none
}
.analytics-vhfc-feedback-container {
    background-color: #f5f5f5;
    border-bottom-right-radius: 8px;
    height: 32px;
    padding: 0px 24px
}
.analytics-vhfc-feedback-container .analytics-vhc-feedbackcard {
    color: rgba(0, 0, 0, 0.54);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-style: normal;
    font-weight: 400
}
.analytics-vhfc-feedback-container .analytics-vhc-feedbackcard-button {
    font-size: 12px;
    font-style: normal
}
.analytics-vhfc-nudge-container {
    background-color: #fff;
    border-bottom-right-radius: 8px;
    box-pack: justify;
    -ms-flex-pack: justify;
    -webkit-box-pack: justify;
    -webkit-justify-content: space-between;
    justify-content: space-between;
    height: 56px;
    padding: 0px 8px 0px 32px

}
.analytics-vhfc-nudge-buttons {
    align-items: center;
    display: flex;
    box-pack: justify;
    -ms-flex-pack: justify;
    -webkit-box-pack: justify;
    -webkit-justify-content: flex-end;
    justify-content: flex-end
}
.analytics-vhfc-nudge-cancel-button.jfk-button,
.analytics-vhfc-nudge-continue-button.jfk-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    color: #188038;
    cursor: pointer;
    margin: 0px 8px;
    padding-left: 8px;
    padding-right: 8px;
    white-space: normal;
    word-wrap: break-word
}
.analytics-vhfc-nudge-cancel-button {
    color: #80868b
}
.analytics-vhfc-nudge-cancel-button.jfk-button-hover,
.analytics-vhfc-nudge-continue-button.jfk-button-hover {
    background-color: #f8fcf9
}
.analytics-vhfc-nudge-cancel-button.jfk-button-focused,
.analytics-vhfc-nudge-continue-button.jfk-button-focused {
    background-color: #e7f5eb
}
.analytics-vhfc-nudge-cancel-button.jfk-button-focused.jfk-button-hover,
.analytics-vhfc-nudge-continue-button.jfk-button-focused.jfk-button-hover {
    background-color: #dff2e4
}
.analytics-vhfc-nudge-cancel-button.jfk-button-focused.jfk-button-active,
.analytics-vhfc-nudge-continue-button.jfk-button-focused.jfk-button-active {
    background-color: #dff2e4;
    box-shadow: 0 1px 3px 1px rgba(60, 64, 67, .15)
}
.analytics-vhfc-nudge-label {
    color: #3c4043;
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-style: normal;
    max-width: 300px
}
.analytics-vhc-groupcard-root {
    border-bottom: 0;
    position: relative
}
.analytics-vhc-groupcard-root::after {
    border-bottom: 1px solid #e0e0e0;
    bottom: 0;
    content: '';
    display: block;
    height: 0;
    left: 72px;
    position: absolute;
    width: calc(100% - 72px)
}
.analytics-vhc-groupcard-members .analytics-vhc-groupcard-root::after {
    left: 48px;
    width: calc(100% - 48px)
}
.analytics-vhc-rowcard-root:last-child::after {
    display: none
}
.analytics-vhc-groupcard-root>.analytics-vhc-rowcard-row {
    border-bottom: 1px solid transparent
}
.analytics-vhc-groupcard-root>.analytics-vhc-rowcard-row::after {
    border-bottom: 0
}
.analytics-vhc-groupcard-root>.analytics-vhc-rowcard-row>.jfk-button {
    cursor: pointer;
    height: calc(48px - 2px);
    width: calc(100% - 2px)
}
.analytics-vhc-groupcard-root>.analytics-vhc-rowcard-row>.jfk-button-disabled {
    cursor: default
}
.analytics-vhc-groupcard-groupimg {
    height: 32px;
    margin: 0 16px 0 23px;
    vertical-align: middle;
    width: 32px
}
.analytics-vhc-groupcard-message {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    padding: 0 0 12px 72px
}
.analytics-vhc-groupcard-message-warning {
    color: rgba(0, 0, 0, 0.6);
    font-style: italic
}
.analytics-vhc-groupcard-message-error {
    color: #dd4330
}
.analytics-vhc-groupcard-members {
    margin-left: 72px
}
.analytics-vhc-groupcard-members .analytics-vhc-groupcard-members {
    margin-left: 48px
}
.analytics-vhc-groupcard-members .analytics-vhc-groupcard-message {
    padding-left: 48px
}
.analytics-vhc-groupcard-members .analytics-vhc-viewcardlist {
    border-top: 0
}
.analytics-vhc-groupcard-members .analytics-vhc-viewcardlist>div:last-child,
.analytics-vhc-groupcard-members .analytics-vhc-viewcardlist>.analytics-vhc-viewercard-root:last-child>.analytics-vhc-rowcard-row {
    border-bottom: 0
}
.analytics-vhc-groupcard-members .analytics-vhc-rowcard-profile .analytics-profile-image,
.analytics-vhc-groupcard-members .analytics-vhc-rowcard-profile .analytics-vhc-groupcard-groupimg {
    margin-left: 0
}
.analytics-vhc-groupcard-root>.analytics-vhc-rowcard-row .analytics-vhc-rowcard-profile {
    border: 0;
    box-shadow: none;
    font-weight: 400;
    margin: 0px;
    min-width: 0;
    padding: 0
}
.analytics-vhc-groupcard-expand-icon {
    margin-top: -2px
}
.analytics-vhc-groupcard-contracted .analytics-vhc-groupcard-expand-icon {
    margin-left: -7px;
    margin-right: 6px
}
.analytics-vhc-groupcard-expanded .analytics-vhc-groupcard-expand-icon {
    margin-left: -4px;
    margin-right: 3px
}
.analytics-vhc-groupcard-expanded>.analytics-vhc-rowcard-row .analytics-vhc-rowcard-time {
    visibility: hidden
}
.analytics-vhc-groupcard-expanded>.analytics-vhc-rowcard-row .analytics-vhc-rowcard-tooltip-icon {
    visibility: hidden
}
.analytics-lmec-link,
.analytics-lmec-link:active,
.analytics-lmec-link:hover,
.analytics-lmec-link:link,
.analytics-lmec-link:visited {
    color: #4285f4;
    cursor: pointer;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px;
    font-weight: 400;
    text-decoration: none
}
.analytics-vhc-listsortbutton {
    -webkit-align-items: center;
    align-items: center;
    cursor: pointer;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    margin: auto 24px auto 24px
}
.analytics-vhc-listsortbutton-mouse-focus {
    outline: 0
}
.analytics-vhc-listsortbutton:last-child {
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    margin: auto -10px auto 0;
    width: 107px
}
.analytics-vhc-checkboxes-visible .analytics-vhc-listsortbutton:last-child {
    margin: auto 72px auto 0;
    width: 107px
}
.analytics-vhc-listsortbutton-name {
    color: #5f6368;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    margin: 0px 8px 0px 0px
}
.analytics-vhc-listsortbutton-arrow {
    height: 18px;
    width: 18px
}
.analytics-vhc-listsortbutton-uwsa .analytics-vhc-listsortbutton-arrow,
.analytics-vhc-listsortbutton-uwsd .analytics-vhc-listsortbutton-arrow {
    visibility: hidden
}
.analytics-vhc-listsortbutton-ascending .analytics-vhc-listsortbutton-arrow,
.analytics-vhc-listsortbutton-descending .analytics-vhc-listsortbutton-arrow {
    opacity: 0.87
}
.analytics-low-data-treatment-title {
    color: #25272b;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 28px;
    padding: 0 48px 8px 48px
}
.analytics-low-data-treatment-description {
    color: #414549;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px;
    line-height: 24px;
    padding: 0 48px 16px 48px
}
.analytics-low-data-treatment-sharebutton .docs-icon {
    margin-top: 0;
    margin-bottom: 0;
    margin-right: 8px
}
.analytics-low-data-treatment-sharebutton.jfk-button {
    align-items: center;
    align-self: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    box-pack: justify;
    -ms-flex-pack: justify;
    -webkit-box-pack: justify;
    -webkit-justify-content: center;
    justify-content: center;
    margin: 0;
    padding-bottom: 9px!important;
    padding-left: 12px!important;
    padding-right: 16px!important
}
.analytics-nc-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    min-height: 0
}
.analytics-nc-navigationarea {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    min-height: 0
}
.analytics-nc-tabbar {
    background-color: #fff;
    border-bottom-left-radius: 8px;
    border-right: 1px solid #e0e0e0;
    position: relative;
    width: 256px;
    z-index: 2
}
.analytics-nc-tabbar-collapsed {
    width: 64px
}
.analytics-nc-content {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    min-height: 0;
    overflow-x: hidden;
    width: 623px
}
.analytics-nc-navigationbar {
    background-color: #fff;
    border-bottom: 1px solid #e0e0e0;
    border-top-left-radius: 8px;
    border-top-right-radius: 8px;
    z-index: 2
}
.analytics-npd {
    border-radius: 8px;
    width: 490px
}
.analytics-npd::before {
    border: 1px solid transparent;
    border-radius: 8px;
    bottom: -1px;
    content: '';
    left: -1px;
    position: absolute;
    right: -1px;
    top: -1px
}
.analytics-npd-title {
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 22px;
    margin: 24px 24px 0px 24px
}
.analytics-npd-paragraph {
    color: rgba(0, 0, 0, 0.6);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px;
    line-height: 24px;
    margin: 24px 24px 0px 24px
}
.analytics-npd-buttons {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    box-pack: justify;
    -ms-flex-pack: justify;
    -webkit-box-pack: justify;
    -webkit-justify-content: flex-end;
    justify-content: flex-end;
    margin: 40px 0 24px 24px
}
.analytics-npd-cancelbutton {
    margin: 0 8px
}
.analytics-npd-continuebutton {
    margin: 0 24px 0 8px
}
.analytics-ntb-container .goog-tab-bar {
    background-color: #ffffff;
    margin-top: 20px;
    width: 100%
}
.analytics-ntb-container .goog-tab {
    -webkit-align-items: center;
    align-items: center;
    background-color: #ffffff!important;
    border: 0;
    border-top-right-radius: 20px;
    border-bottom-right-radius: 20px;
    color: #3c4043;
    cursor: pointer;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    height: 44px;
    margin: 0 10px 0 0!important;
    padding: 0!important;
    text-decoration: none
}
.analytics-nc-tabbar-collapsed .analytics-ntb-container .goog-tab {
    border-radius: 22px;
    margin: 0 10px!important
}
.analytics-ntb-container .goog-tab.goog-tab-hover {
    background-color: #f1f3f4!important
}
.analytics-ntb-container .goog-tab.goog-tab-selected {
    background-color: #e6f4ea!important;
    color: #188038;
    left: 0px
}
.analytics-ntb-container .goog-tab.goog-tab-selected::before,
.analytics-ntb-container .goog-tab-hover::before {
    border-bottom: 1px solid transparent;
    border-right: 1px solid transparent;
    border-top: 1px solid transparent;
    border-top-right-radius: 20px;
    border-bottom-right-radius: 20px;
    bottom: -1px;
    content: '';
    left: 0px;
    position: absolute;
    right: -1px;
    top: -1px;
    z-index: 1
}
.analytics-ntb-container .goog-tab.goog-tab-selected.goog-tab-hover {
    background-color: #ceead6!important
}
.analytics-ntb-tab-icon {
    height: 24px;
    margin: 0 16px 0 24px;
    width: 24px
}
.analytics-nc-tabbar-collapsed .analytics-ntb-tab-icon {
    margin: 0 10px
}
.analytics-ntb-tab-text {
    max-width: 180px
}
.analytics-ntb-tab-content {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1
}
.analytics-nsc,
.analytics-nsc-content {
    color: #202124;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    overflow-x: hidden;
    overflow-y: auto
}
.analytics-nsc-content {
    margin: 24px 32px 0 32px
}
.analytics-nsc-offline,
.analytics-nsc-save-failed {
    -webkit-align-items: center;
    align-items: center;
    background-color: #eeeeee;
    border-bottom: 1px solid #e0e0e0;
    color: #dd4330;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    font-size: 13px;
    height: 48px;
    padding: 0 24px 0 24px
}
.analytics-nsc-heading,
.analytics-nsc-subheading {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    line-height: 26px;
    margin: 0 0 16px 0
}
.analytics-nsc-heading {
    font-size: 18px
}
.analytics-nsc-subheading {
    font-size: 14px
}
.analytics-nsc-edit-digest-section {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    font-size: 14px;
    height: 48px;
    box-pack: justify;
    -ms-flex-pack: justify;
    -webkit-box-pack: justify;
    -webkit-justify-content: space-between;
    justify-content: space-between
}
.analytics-nsc-edit-digest-select {
    min-width: 240px;
    width: auto
}
.analytics-nsc-edit-section,
.analytics-nsc-form-section {
    margin-bottom: 16px
}
.analytics-nsc-switches {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row
}
.analytics-nsc-switches .docs-material-gm-labeled-checkbox,
.analytics-nsc-switches .docs-material-gm-labeled-checkbox-label {
    cursor: pointer
}
.analytics-nsc-switch {
    margin-right: 32px
}
.analytics-nsc-footer {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    height: 80px;
    box-pack: end;
    -ms-flex-pack: end;
    -webkit-box-pack: end;
    -webkit-justify-content: flex-end;
    justify-content: flex-end;
    margin: 0 32px
}
.analytics-nsc-cancel-button {
    margin-right: 16px
}
.analytics-nvtt-content {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    padding: 9px 7px
}
.analytics-nvtt-text {
    color: #fff
}
.analytics-nvtt-learnmore,
.analytics-nvtt-learnmore:visited,
.analytics-nvtt-learnmore:link,
.analytics-nvtt-learnmore:hover {
    color: #7baaf7;
    margin-left: 14px;
    text-decoration: none
}
.analytics-ndch {
    -webkit-align-items: center;
    align-items: center;
    background-color: #fff;
    border: 1px solid #dadce0;
    box-sizing: border-box;
    -webkit-border-radius: 16px;
    -moz-border-radius: 16px;
    border-radius: 16px;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    height: 24px;
    margin: 0px 8px 4px 0px
}
.analytics-ndch-viewer-icon,
.analytics-ndch-group-icon {
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    height: 20px;
    margin-left: 1px;
    overflow: hidden;
    width: 20px
}
.analytics-ndch-text {
    color: #5f6368;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-weight: 500;
    padding-left: 8px
}
.analytics-ndch-remove-button {
    -webkit-align-items: center;
    align-items: center;
    cursor: pointer;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    box-pack: center;
    -ms-flex-pack: center;
    -webkit-box-pack: center;
    -webkit-justify-content: center;
    justify-content: center;
    padding: 0 4px 0 3px
}
.analytics-ndch-remove-button .docs-analytics-icon {
    opacity: 0.87
}
.analytics-ndch:only-child .analytics-ndch-remove-button {
    display: none
}
.analytics-ndch:only-child .analytics-ndch-text {
    padding-right: 8px
}
.analytics-ndc,
.analytics-ndc-body {
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1
}
.analytics-ndc-body {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    overflow-y: auto;
    padding: 32px 32px 0px 32px
}
.analytics-ndc-send-email-title {
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 18px;
    margin-bottom: 16px
}
.analytics-ndc-chip-title {
    color: rgba(0, 0, 0, 0.54);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 400;
    margin-bottom: 8px
}
.analytics-ndc-chip-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -moz-flex-wrap: wrap;
    -ms-flex-wrap: wrap;
    -webkit-flex-wrap: wrap;
    flex-wrap: wrap;
    max-height: 71px;
    min-height: 28px;
    overflow-y: auto
}
.analytics-ndc-subject-container {
    height: 36px;
    margin-top: 20px
}
.analytics-ndc-subject-container input::-ms-clear {
    display: none
}
.analytics-ndc-subject-container .docs-material-labeled-text-field {
    background-color: #fff;
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    height: initial;
    line-height: initial;
    padding: 0px
}
.analytics-ndc-subject-container .docs-material-labeled-text-field-hover {
    border: 1px solid #bdc1c6;
    box-sizing: border-box
}
.analytics-ndc-subject-container .docs-material-labeled-text-field-focused {
    border: 2px solid #1a73e8;
    box-sizing: border-box;
    margin: -1px 0 0 -1px
}
.analytics-ndc-subject-container .docs-material-labeled-text-field-content {
    padding: 0px 7px
}
.analytics-ndc-subject-container .docs-material-labeled-text-field-input {
    padding: 0px 8px
}
.analytics-ndc-subject-container .docs-material-labeled-text-field-input {
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 400;
    height: 100%;
    line-height: normal;
    padding: 9px
}
.analytics-ndc-subject-container .docs-material-labeled-text-field-label {
    background-color: #fff;
    color: #5f6368;
    font-size: 12px;
    line-height: 13px;
    padding: 0 3px;
    transform: translateY(-7px) scale(1, 1)
}
.analytics-ndc-subject-container .docs-material-labeled-text-field:not(.docs-material-labeled-text-field-focused) .docs-material-labeled-text-field-input {
    border-bottom-color: transparent
}
.analytics-ndc-subject-container .docs-material-labeled-text-field-input {
    border-bottom: 0
}
.analytics-ndc-message-container {
    background-color: #fff;
    margin-top: 16px;
    max-height: 108px
}
.analytics-ndc-message-container .docs-material-text-area {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 400;
    max-height: 108px;
    min-height: 108px;
    overflow-y: auto!important;
    padding: 7px 9px
}
.analytics-ndc-message-container .docs-material-text-area:hover {
    border: 1px solid #bdc1c6;
    box-sizing: border-box
}
.analytics-ndc-message-container .docs-material-text-area:focus {
    border: 2px solid #1a73e8;
    box-sizing: border-box;
    margin: -1px 0 0 -1px
}
.analytics-ndc-document-info-container {
    -webkit-align-items: center;
    align-items: center;
    background-color: #fff;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 0 0 auto;
    -webkit-flex: 0 0 auto;
    flex: 0 0 auto;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    margin-top: 16px;
    max-width: 100%;
    outline: none
}
.analytics-ndc-document-info {
    -webkit-align-items: center;
    align-items: center;
    border-radius: 100px;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row
}
.analytics-ndc-document-icon-container {
    outline: none;
    margin: 0 0 0 4px
}
.analytics-ndc-document-title {
    color: rgb(60, 64, 67);
    display: block;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    line-height: 16px;
    overflow: hidden;
    padding: 0px 8px;
    text-overflow: ellipsis;
    overflow: hidden;
    text-overflow: ellipsis;
    -webkit-box-orient: vertical;
    -webkit-line-clamp: 3;
    display: -webkit-box;
    max-height: 45px
}
.analytics-ndc-document-title a {
    color: #4285f4!important
}
.analytics-ndc-send-to-myself-container {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    box-pack: justify;
    -ms-flex-pack: justify;
    -webkit-box-pack: justify;
    -webkit-justify-content: flex-start;
    justify-content: flex-start;
    margin-left: -1px;
    margin-top: 12px
}
.analytics-ndc-send-to-myself-container .docs-material-gm-labeled-checkbox {
    cursor: pointer
}
.analytics-ndc-send-to-myself-container .docs-material-gm-labeled-checkbox-label {
    color: #5f6368;
    cursor: pointer;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 400
}
.analytics-ndc-buttons {
    -webkit-align-items: start;
    align-items: start;
    bottom: 0;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    box-pack: justify;
    -ms-flex-pack: justify;
    -webkit-box-pack: justify;
    -webkit-justify-content: flex-end;
    justify-content: flex-end;
    min-height: 60px;
    width: 100%
}
.analytics-ndc-cancel-button {
    margin: 0px 8px
}
.analytics-ndc-send-email-button {
    margin: 0px 32px 0px 8px
}
.analytics-ndc-chip-button {
    -webkit-align-items: center;
    align-items: center;
    border: 1px solid #dadce0;
    border-radius: 100px;
    cursor: pointer;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    line-height: normal;
    margin-right: 0;
    padding: 8px
}
.analytics-ndc-chip-button.jfk-button-focused {
    background-color: rgba(60, 64, 67, 0.06);
    border: 1px solid #dadce0!important
}
.analytics-ndc-chip-button.jfk-button-hover {
    background-color: rgba(60, 64, 67, 0.04)
}
.analytics-ndc-chip-button.jfk-button-hover.jfk-button-focused {
    background-color: rgba(60, 64, 67, 0.06)
}
.analytics-ndc-chip-button.jfk-button-active {
    background-color: rgba(60, 64, 67, 0.06);
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.analytics-ndc-toast.docs-ui-toast {
    border: 1px inset;
    border-color: rgba(255, 255, 255, 0.2) rgba(255, 255, 255, 0.1) rgba(255, 255, 255, 0) rgba(255, 255, 255, 0);
    box-shadow: 0 6px 6px rgba(0, 0, 0, 0.15);
    padding: 14px 24px;
    z-index: 1003
}
.analytics-ndc-toast.docs-ui-toast .docs-ui-toast-content {
    color: #fff;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 400
}
.analytics-vhc-nudgeselectdropdown-container .analytics-ndsd {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    margin: auto 0px;
    padding-left: 2px;
    visibility: hidden
}
.analytics-vhc-nudgeselectdropdown-container .goog-menu {
    position: fixed
}
.analytics-vhc-checkboxes-visible .analytics-ndsd {
    visibility: visible
}
.docs-analytics-hc-ie .analytics-ndsd {
    -ms-high-contrast-adjust: none;
    background-color: white
}
.analytics-ndsd-icon-container {
    height: 24px;
    opacity: 0.56;
    width: 24px
}
.analytics-od {
    width: 384px
}
.analytics-od,
.analytics-od-content {
    border-radius: 8px
}
.analytics-od-title {
    display: none
}
.analytics-od-picture {
    border-top-left-radius: 8px;
    border-top-right-radius: 8px;
    height: 216px
}
.analytics-od-header {
    color: rgba(0, 0, 0, 0.87);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 18px;
    font-weight: 500;
    margin: 26px 24px 18px 24px
}
.analytics-od-body {
    color: rgba(0, 0, 0, 0.7);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 400;
    margin: 0px 24px 0px 24px
}
.analytics-od-paragraph {
    line-height: 20px;
    margin: 0px 0px 18px 0px
}
.analytics-od-learnmorebutton,
.analytics-od-learnmorebutton:active,
.analytics-od-learnmorebutton:hover,
.analytics-od-learnmorebutton:link,
.analytics-od-learnmorebutton:visited {
    align-self: left;
    color: #4285f4;
    cursor: pointer;
    text-decoration: none
}
.analytics-od-settingsbutton,
.analytics-od-settingsbutton:focus,
.analytics-od-settingsbutton:hover,
.analytics-od-okbutton,
.analytics-od-okbutton:focus,
.analytics-od-okbutton:hover {
    margin: 4px;
    white-space: normal
}
.analytics-od-buttons {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    -moz-flex-wrap: wrap;
    -ms-flex-wrap: wrap;
    -webkit-flex-wrap: wrap;
    flex-wrap: wrap;
    box-pack: justify;
    -ms-flex-pack: justify;
    -webkit-box-pack: justify;
    -webkit-justify-content: center;
    justify-content: center;
    margin: 18px 24px 24px 24px
}
.analytics-od-okbutton {
    min-width: 155px;
    width: auto;
    width: unset
}
.analytics-profile-image {
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    height: 32px;
    max-height: 36px;
    max-width: 36px;
    width: 32px
}
.analytics-rec-buttons {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    height: 48px
}
.analytics-vhc-rowcard-root {
    width: 100%
}

.analytics-vhc-rowcard-row,
.analytics-vhc-rowcard-row-button {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    height: 48px;
    text-align: left;
    width: 100%
}
.analytics-vhc-rowcard-row {
    position: relative
}
.analytics-vhc-rowcard-row::after {
    border-bottom: 1px solid #e0e0e0;
    bottom: 0;
    content: '';
    display: block;
    height: 0;
    left: 72px;
    position: absolute;
    width: calc(100% - 72px)
}
.analytics-vhc-groupcard-members .analytics-vhc-rowcard-row::after {
    left: 48px;
    width: calc(100% - 48px)
}
.analytics-vhc-rowcard-root:last-child>.analytics-vhc-rowcard-row::after {
    display: none
}
.analytics-vhc-rowcard-profile {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1
}
.analytics-vhc-rowcard-name {
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    margin-right: 24px;
    white-space: normal
}
.analytics-vhc-rowcard-time {
    color: #202124;
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    margin-right: 36px;
    width: 110px
}
.analytics-vhc-rowcard-row-button>.analytics-vhc-rowcard-time {
    width: 108px
}
.analytics-vhc-rowcard-time-container {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row
}
.analytics-vhc-rowcard-timenever .analytics-vhc-rowcard-time {
    font-style: italic
}
.analytics-vhc-rowcard-timeabsent .analytics-vhc-rowcard-time,
.analytics-vhc-rowcard-iconabsent .analytics-vhc-rowcard-tooltip-icon {
    visibility: hidden
}
.analytics-vhc-rowcard-tooltip-icon {
    opacity: 0.56;
    padding: 5px 0 5px 0
}
.analytics-vhc-rowcard-checkbox-container {
    display: none;
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0
}
.analytics-vhc-checkboxes-visible .analytics-vhc-rowcard-checkboxvisible .analytics-vhc-rowcard-checkbox-container,
.analytics-vhc-checkboxes-visible .analytics-vhc-rowcard-checkboxinvisible .analytics-vhc-rowcard-checkbox-container {
    display: inherit;
    margin: 7px 32px 7px 30px;
    padding: 1px
}
.analytics-vhc-rowcard-checkboxinvisible .analytics-vhc-rowcard-checkbox-container {
    visibility: hidden
}
.analytics-vhc-rowcard-spacing {
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0
}
.analytics-selector {
    height: 30px;
    min-width: 140px
}
.docs-analytics-hc-ie .analytics-selector .docs-material-select-dropdown {
    -ms-high-contrast-adjust: none;
    background-color: white
}
.analytics-selector-menu.goog-menu .goog-menuitem {
    font-size: 14px;
    padding-right: 30px
}
.analytics-sc,
.analytics-sc-settings {
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1
}
.analytics-sc-settings {
    overflow-y: auto
}
.analytics-sc-settings-loading {
    visibility: hidden
}
.analytics-sc-disabled-by-admin-explanation,
.analytics-sc-view-visibility-explanation {
    color: rgba(0, 0, 0, 0.87);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 400;
    line-height: 18px;
    margin: 24px 24px 0px 24px;
    padding: 0px 100px 0px 0px
}
.analytics-sc-view-visibility-explanation {
    border-bottom: 1px solid rgba(0, 0, 0, 0.4);
    padding-bottom: 24px
}
.analytics-sc-disabled-by-admin-explanation-link,
.analytics-sc-disabled-by-admin-explanation-link:active,
.analytics-sc-disabled-by-admin-explanation-link:hover,
.analytics-sc-disabled-by-admin-explanation-link:link,
.analytics-sc-disabled-by-admin-explanation-link:visited {
    color: #4285f4;
    cursor: pointer;
    text-decoration: none
}
.analytics-sc-account-setting,
.analytics-sc-document-setting {
    margin: 0 0 0 32px;
    padding: 24px 0px
}
.analytics-sc-document-setting {
    border-top: 1px solid #e0e0e0
}
.analytics-sc-account-itemlabel,
.analytics-sc-document-itemlabel {
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 18px;
    line-height: 24px
}
.analytics-sc-section-label {
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    line-height: 20px
}
.analytics-sc-section {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    justify-content: space-between;
    margin: 16px 32px 0px 0px
}
.analytics-sc .analytics-sc-account-show-setting-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    color: #188038;
    cursor: pointer;
    margin-right: 0;
    max-width: 200px;
    white-space: normal;
    word-wrap: break-word
}
.analytics-sc-account-show-setting-button.jfk-button-hover {
    background-color: #f8fcf9
}
.analytics-sc-account-show-setting-button.jfk-button-focused {
    background-color: #e7f5eb
}
.analytics-sc-account-show-setting-button.jfk-button-focused.jfk-button-hover {
    background-color: #dff2e4
}
.analytics-sc-account-show-setting-button.jfk-button-focused.jfk-button-active {
    background-color: #dff2e4;
    box-shadow: 0 1px 3px 1px rgba(60, 64, 67, .15)
}
.analytics-sc-account-switch,
.analytics-sc-document-switch {
    margin-left: 5px
}
.analytics-sc-account-explanation,
.analytics-sc-document-explanation {
    color: #25272b;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 400;
    line-height: 20px;
    margin: 11px 110px 0 0;
    width: auto
}
.analytics-sc-account-explanation a:link,
.analytics-sc-account-explanation a:visited {
    color: #4285f4;
    text-decoration: none
}
.analytics-sc-buttons {
    -webkit-align-items: center;
    align-items: center;
    bottom: 0;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    height: 84px;
    box-pack: justify;
    -ms-flex-pack: justify;
    -webkit-box-pack: justify;
    -webkit-justify-content: flex-end;
    justify-content: flex-end;
    width: 100%
}
.analytics-sc-cancel-button {
    margin: 0px 8px
}
.analytics-sc-done-button,
.analytics-sc-save-button {
    margin: 0px 32px 0px 8px
}
.analytics-sc-section .apps-ui-material-slide-toggle-container {
    cursor: pointer;
    margin-right: 2px
}
.analytics-sc-section .apps-ui-material-slide-toggle-container.apps-ui-material-slide-toggle-container-disabled {
    cursor: default
}
.analytics-sc-section .apps-ui-material-slide-toggle-container-checked .apps-ui-material-slide-toggle-track {
    background-color: #ceead6;
    opacity: 1
}
.analytics-sc-section .apps-ui-material-slide-toggle-container-checked .apps-ui-material-slide-toggle-thumb {
    background-color: #188038
}
.analytics-sc-section .apps-ui-material-slide-toggle-container-checked.apps-ui-material-slide-toggle-container-disabled .apps-ui-material-slide-toggle-track {
    opacity: 0.07
}
.analytics-sc-section .apps-ui-material-slide-toggle-container-checked.apps-ui-material-slide-toggle-container-disabled .apps-ui-material-slide-toggle-thumb {
    opacity: 0.26
}
.analytics-sc-section .apps-ui-material-slide-toggle-thumb {
    opacity: 1.0
}
.analytics-sc-section .apps-ui-material-slide-toggle-container-focused .apps-ui-material-slide-toggle-thumb {
    box-shadow: 0 0 6px rgba(0, 0, 0, .16), 0 6px 12px rgba(0, 0, 0, .32);
    opacity: 1.0
}
.analytics-sc-section .apps-ui-material-slide-toggle-container-hover .apps-ui-material-slide-toggle-thumb {
    opacity: 1.0
}
.analytics-sc .analytics-ec-container {
    margin-bottom: 72px;
    margin-top: 56px
}
.analytics-sfc-card {
    -webkit-align-items: center;
    align-items: center;
    background-color: #eeeeee;
    border-bottom: 1px solid #e0e0e0;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    height: 48px
}
.analytics-sfc-label {
    color: #dd4330;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 400;
    margin: 0 24px 0 24px
}
.analytics-sic {
    background-color: #fff;
    box-shadow: 0 1px 0 0 #dadce0;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1
}
.analytics-sic-content {
    -webkit-align-items: center;
    align-items: center;
    color: #414549;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    -webkit-flex-basis: auto;
    -ms-flex-basis: auto;
    flex-basis: auto;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    box-pack: justify;
    -ms-flex-pack: justify;
    -webkit-box-pack: justify;
    -webkit-justify-content: flex-start;
    justify-content: flex-start;
    line-height: 18px;
    margin: 10px 0;
    min-height: 38px
}
.analytics-sic-icon {
    height: 20px;
    margin: 0 10px 0 30px;
    min-width: 20px;
    width: 20px
}
.analytics-sic-text {
    margin-right: 32px
}
.analytics-shc {
    overflow: hidden
}
.analytics-shc .activity-deck {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    min-height: 0;
    position: relative
}
.analytics-shc .activity-deck-events-view,
.analytics-shc .activity-deck-empty-view {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    height: auto;
    min-height: 0;
    overflow: hidden;
    width: 100%
}
.analytics-shc .activity-deck-empty-view {
    -webkit-align-items: center;
    align-items: center;
    box-pack: center;
    -ms-flex-pack: center;
    -webkit-box-pack: center;
    -webkit-justify-content: center;
    justify-content: center
}
.analytics-shc .activity-list {
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    height: auto;
    width: 100%
}
.analytics-shc .activity-event-target-list {
    display: none
}
.analytics-shc .activity-event-header {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    height: 40px
}
.analytics-shc .activity-event-scopes-list {
    margin-top: 0;
    padding-left: 72px
}
.analytics-shc .activity-event>div:first-child {
    padding-bottom: 0
}
.analytics-shc .activity-event-scopes-container {
    padding: 8px 0
}
.analytics-shc .activity-event-scope-change-detail {
    padding-top: 8px
}
.analytics-shc .activity-event-scope-change-detail.activity-event-scope-change-detail-first {
    padding-top: 2px
}
.analytics-ssc {
    -webkit-align-items: center;
    align-items: center;
    border-bottom: 1px solid #e0e0e0;
    color: #5f6368;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    justify-content: space-between;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-weight: 500;
    overflow: hidden;
    padding: 8px 12px 8px 16px
}
.analytics-ssc-summary {
    margin-right: 12px
}
.analytics-ssc-manage-settings-button.analytics-btn-text.jfk-button {
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    font-size: 13px
}
.analytics-ssc-summary {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row
}
.analytics-ssc-icon {
    margin-right: 8px
}
.analytics-trc {
    -webkit-align-items: center;
    align-items: center;
    color: rgba(0, 0, 0, 0.87);
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: none;
    -webkit-flex: none;
    flex: none;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px;
    font-weight: 500;
    margin: 24px 24px 18px 24px
}
.analytics-tb-container {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    height: 72px;
    box-pack: justify;
    -ms-flex-pack: justify;
    -webkit-box-pack: justify;
    -webkit-justify-content: space-between;
    justify-content: space-between
}
.analytics-tb-title-text {
    color: rgba(0, 0, 0, 0.87);
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 22px;
    margin: 0 0 0 24px
}
.analytics-tb-close {
    border: 0!important;
    border-radius: 20px;
    cursor: pointer;
    display: inline-flex;
    height: auto;
    margin: 0px;
    opacity: 0.54;
    padding: 8px;
    position: absolute;
    right: 11px;
    top: 16px;
    z-index: 2
}
.analytics-tb-close.jfk-button-hover {
    background-color: #f1f3f4;
    border: 0
}
.analytics-tb-close.jfk-button-focused {
    background-color: #e8eaed;
    border: 0
}
.analytics-ttmw {
    line-height: 13px
}
.analytics-tt-content {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 11px;
    font-weight: 500
}
.analytics-appbar-tt-content {
    line-height: 15px;
    max-width: 320px;
    padding: 0;
    word-break: normal
}
.analytics-tpec-total-unique-viewers,
.analytics-tpec-explanation {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 400;
    padding: 0 128px
}
.analytics-tpec-total-unique-viewers {
    color: #212121;
    font-size: 16px;
    line-height: 24px;
    padding-bottom: 8px
}
.analytics-tpec-explanation {
    color: #757575;
    font-size: 13px
}
.analytics-tpec-container {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    min-height: 132px;
    text-align: center;
    width: 100%
}
.analytics-tpec-heading {
    color: #25272b;
    font-size: 28px;
    height: 36px
}
.analytics-tpec-paragraph {
    color: #414549;
    font-size: 16px;
    margin: 8px 0 16px 0;
    width: 400px
}
.analytics-tpec-viewer-trend-button.jfk-button {
    -webkit-align-items: center;
    align-items: center;
    font-weight: 500
}
.analytics-tc {
    -webkit-align-items: center;
    align-items: center;
    color: rgba(0, 0, 0, 0.87);
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1 1 auto;
    -webkit-flex: 1 1 auto;
    flex: 1 1 auto;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 400;
    min-height: 30px
}
.analytics-tc-message {
    display: inline
}
.analytics-tc-comments-count {
    display: inline;
    font-weight: 500
}
.analytics-tc-tooltip-icon {
    margin: 0 24px 0 6px;
    opacity: 0.56
}
.analytics-tuvc {
    -webkit-align-items: center;
    align-items: center;
    color: rgba(0, 0, 0, 0.87);
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1 1 auto;
    -webkit-flex: 1 1 auto;
    flex: 1 1 auto;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 400;
    min-height: 30px
}
.analytics-tuvc-message {
    display: inline
}
.analytics-tuvc-viewers-count {
    display: inline;
    font-weight: 500
}
.analytics-tuvc-tooltip-icon {
    margin: 0 24px 0 6px;
    opacity: 0.56
}
.analytics-tcc,
.analytics-tcc-chart-container,
.analytics-tcc-chart {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    min-height: 120px;
    overflow: hidden
}
.analytics-tcc-chart .google-visualization-tooltip {
    pointer-events: none
}
.analytics-tcc-data-table {
    position: absolute;
    overflow: hidden;
    height: 1px;
    left: -10000px;
    top: auto;
    width: 1px
}
.analytics-trend-sparkline-graph {
    -ms-flex: 0 0 auto;
    -webkit-flex: 0 0 auto;
    flex: 0 0 auto;
    height: 60px;
    position: relative
}
.analytics-trend-sparkline-chart {
    height: 32px;
    left: 24px;
    position: absolute;
    right: 24px;
    top: 8px;
    z-index: 3
}
.analytics-trend-sparkline-chart.analytics-trend-sparkline-dragging {
    cursor: col-resize
}
.analytics-trend-sparkline-slider {
    left: 14.5px;
    position: absolute;
    right: 14.5px;
    top: 8px;
    z-index: 4
}
.analytics-trend-sparkline-left-bg,
.analytics-trend-sparkline-right-bg {
    border-color: #979797;
    border-width: 1px;
    position: absolute;
    bottom: 20px;
    top: 8px;
    background-color: #efefef;
    z-index: 1
}
.analytics-trend-previous-active-bg {
    z-index: 2
}
.analytics-trend-bg-selected.analytics-trend-sparkline-left-bg,
.analytics-trend-bg-selected.analytics-trend-sparkline-right-bg {
    border-color: #185abc;
    border-width: 2px
}
.analytics-trend-sparkline-left-bg {
    border-style: none dashed none none;
    left: 24px
}
.analytics-trend-sparkline-right-bg {
    border-style: none none none dashed;
    right: 24px
}
.analytics-trend-bg-selected.analytics-trend-sparkline-left-bg {
    left: 23.5px
}
.analytics-trend-bg-selected.analytics-trend-sparkline-right-bg {
    right: 23.5px
}
.analytics-slider-thumbimpl {
    background-color: transparent;
    cursor: col-resize;
    height: 32px;
    width: 20px
}
.analytics-trend-sparkline-graph .analytics-twothumbslider {
    height: 32px
}
.analytics-twothumbslider:focus,
.analytics-twothumbslider .goog-twothumbslider-value-thumb:focus,
.analytics-twothumbslider .goog-twothumbslider-extent-thumb:focus {
    outline: none
}
.analytics-twothumbslider.goog-slider-dragging {
    cursor: col-resize
}
.analytics-trend-sparkline-graph .analytics-twothumbslider .goog-twothumbslider-rangehighlight {
    height: 0
}
.analytics-trend-sparkline-graph .analytics-twothumbslider .goog-twothumbslider-value-thumb,
.analytics-trend-sparkline-graph .analytics-twothumbslider .goog-twothumbslider-extent-thumb {
    height: 32px;
    position: absolute;
    width: 20px;
    z-index: 1
}
.analytics-trend-sparkline-graph .analytics-twothumbslider .analytics-previous-active-thumb {
    z-index: 2
}
.analytics-tst {
    background-color: #8f8f8f;
    border: 0px;
    border-radius: 2px;
    height: 10px;
    padding: 4px 5px;
    position: absolute
}
.analytics-tst-content {
    color: #fff;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 9px;
    font-weight: 400;
    white-space: nowrap
}
.analytics-tst-arrow {
    position: absolute
}
.analytics-tst-arrowup {
    top: -5px
}
.analytics-tst-arrowimplbefore,
.analytics-tst-arrowimplafter {
    display: block;
    height: 0;
    position: absolute;
    width: 0
}
.analytics-tst-arrowimplbefore {
    border: 5px solid;
    border-color: #8f8f8f transparent;
    border-top-width: 0;
    left: -5px
}
.analytics-tst-arrowimplafter {
    border: 4px solid;
    border-color: #8f8f8f transparent;
    border-top-width: 0;
    left: -4px;
    top: 1px
}
.analytics-vhc-viewcardlist {
    width: 100%
}
.analytics-vhc-viewcardlist-scrollable {
    overflow-y: auto
}
.analytics-vc-root,
.analytics-vc-content,
.analytics-vc-low-data-content {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    min-height: 1px;
    position: relative;
    z-index: 1
}
.analytics-vc-spinner .docs-quantum-spinner {
    left: 0;
    margin-left: 0px
}
.analytics-vc-spinner .docs-spinner {
    height: 28px
}
.analytics-vc-spinner {
    height: 28px;
    left: 50%;
    position: absolute;
    top: 50%;
    -webkit-transform: translate(-50%, -50%);
    -moz-transform: translate(-50%, -50%);
    -ms-transform: translate(-50%, -50%);
    -o-transform: translate(-50%, -50%);
    transform: translate(-50%, -50%);
    width: 28px
}
.analytics-lowdatatreatment {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    text-align: center;
    width: 100%
}
.analytics-vc-low-data-content {
    align-items: center;
    justify-content: center
}
.analytics-vhc-rowcard-root .analytics-profile-image {
    margin: 0 16px 0 24px;
    vertical-align: middle
}
.analytics-votc {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    margin-bottom: 24px;
    overflow-x: hidden;
    overflow-y: auto
}
.analytics-votc-header {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 0 0 auto;
    -webkit-flex: 0 0 auto;
    flex: 0 0 auto;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    justify-content: space-between;
    margin: 18px 24px 0 24px;
    overflow: hidden
}
.analytics-votc-threshold-legend {
    -webkit-align-items: center;
    align-items: center;
    color: #25272b;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    font-size: 12px;
    margin: 16px 24px 0 45px;
    text-align: center
}
.analytics-votc-threshold-legend-box {
    border-top: 1px solid #669df6;
    height: 1px;
    margin-right: 12px;
    width: 20px
}
.analytics-votc-threshold-tooltip-icon {
    margin-left: 8px;
    opacity: 0.56
}
.analytics-vhc-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    min-height: 0
}
.analytics-vhc-viewhistory {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    min-height: 0
}
.analytics-vhc-button-container {
    -webkit-align-items: flex-start;
    align-items: flex-start;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    height: 58px;
    box-pack: justify;
    -ms-flex-pack: justify;
    -webkit-box-pack: justify;
    -webkit-justify-content: space-between;
    justify-content: space-between
}
.analytics-vhc-listsortbutton-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    box-pack: justify;
    -ms-flex-pack: justify;
    -webkit-box-pack: justify;
    -webkit-justify-content: space-between;
    justify-content: space-between;
    margin-top: 28px
}
.analytics-vhc-nudgeselectdropdown-container {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    margin-right: 13px;
    margin-top: 22px;
    width: 60px
}
.analytics-vhc-nudgeselectdropdown-container .goog-menuitem {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.analytics-vhc-nudgeselectdropdown-container .goog-menuitem.goog-menuitem-highlight {
    padding-bottom: 6px;
    padding-top: 6px
}
.analytics-vhc-tabbarholder {
    border-bottom: 1px solid #e0e0e0;
    box-shadow: 0 2px 12px 2px rgba(60, 64, 67, .15)
}
.analytics-vhc-tabbarholder .docs-tabbar {
    background-color: #fff;
    max-width: 100%
}
.analytics-vhc-tabbarholder .docs-tabbar-tab {
    border-bottom: 4px solid transparent;
    border-top: 4px solid transparent
}
.analytics-vhc-tabbarholder .docs-tabbar-tab-selected {
    border-bottom: 4px solid #2196f3
}
.analytics-vhc-tabbarholder .docs-tabbar-focused .docs-tabbar-tab-selected {
    background: #ffffff
}
.analytics-vhc-tabbarholder .docs-tabbar-mouseactive .docs-tabbar-tab {
    background: transparent
}
.analytics-vhc-tabbarholder .docs-tabbar .docs-tabbar-tab-active {
    background: transparent
}
.analytics-vhc-tabbarholder .docs-tabbar-tablabel {
    color: rgba(0, 0, 0, 0.54);
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 500
}
.analytics-vhc-tabbarholder .docs-tabbar-tab-selected .docs-tabbar-tablabel {
    color: rgba(0, 0, 0, 0.87)
}
.analytics-vhc-tabbarholder .docs-tabbar .docs-tabbar-tab {
    align-items: flex-end;
    height: 48px;
    padding: 0 16px;
    position: relative;
    max-width: 300px;
    border: 0
}
.analytics-vhc-tabbarholder .docs-tabbar .docs-tabbar-tab:first-child {
    margin-left: 8px
}
.analytics-vhc-tabbarholder .docs-tabbar-tab .docs-tabbar-tablabel {
    color: #5f6368;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    text-transform: none;
    margin-bottom: 8px;
    text-transform: none
}
.analytics-vhc-tabbarholder .docs-tabbar-tab-hover .docs-tabbar-tablabel {
    color: #3c4043
}
.analytics-vhc-tabbarholder .docs-tabbar-focused .docs-tabbar-tab-hover .docs-tabbar-tablabel {
    color: #202124
}
.analytics-vhc-tabbarholder .docs-tabbar-mouseactive .docs-tabbar-tab-hover .docs-tabbar-tablabel {
    color: #188038
}
.analytics-vhc-tabbarholder .docs-tabbar-tab-selected .docs-tabbar-tablabel {
    color: #188038
}
.analytics-vhc-tabbarholder .docs-tabbar-tab-selected.docs-tabbar-tab-hover .docs-tabbar-tablabel {
    color: #188038
}
.analytics-vhc-tabbarholder .docs-tabbar-focused .docs-tabbar-tab-selected.docs-tabbar-tab-hover .docs-tabbar-tablabel {
    color: #137333
}
.analytics-vhc-tabbarholder .docs-tabbar-mouseactive .docs-tabbar-tab-selected.docs-tabbar-tab-hover .docs-tabbar-tablabel {
    color: #137333
}
.analytics-vhc-tabbarholder .docs-tabbar-tab-selected::before {
    border-bottom: 3px solid #188038;
    border-radius: 3px 3px 0 0;
    bottom: 0;
    content: '';
    display: block;
    height: 0;
    left: 12px;
    position: absolute;
    width: calc(100% + -24px)
}
.analytics-vhc-tabbarholder .docs-tabbar-tab-selected.docs-tabbar-tab-hover::before {
    border-bottom-color: #188038
}
.analytics-vhc-tabbarholder .docs-tabbar-focused .docs-tabbar-tab-selected.docs-tabbar-tab-hover::before {
    border-bottom-color: #137333
}
.analytics-vhc-tabbarholder .docs-tabbar .docs-tabbar-tab-active {
    background: transparent
}
.analytics-vhc-tabbarholder .analytics-vhc .analytics-vc-spinner {
    top: 325px
}
.analytics-vhc-tablabel-domain-name {
    font-weight: 400;
    text-transform: none
}
.drive-locking-dialog {
    border-radius: 8px;
    max-width: 500px
}
.driveLockingDialogbasedialog-title {
    align-items: center;
    display: inline-flex
}
.driveLockingDialogbasedialog-title-icon {
    background-color: #1976d2;
    border-radius: 50%;
    margin-right: 12px;
    padding: 8px 3px 3px 8px;
    width: 29px;
    height: 29px
}
.driveLockingDialogbasedialog-title-text {
    display: block;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 22px;
    line-height: 28px
}
.driveLockingDialogbaseitem-chip {
    border: 1px solid #bdbdbd;
    border-radius: 100px;
    display: inline-block;
    font-size: 14px;
    height: 32px;
    margin-top: 10px;
    max-width: calc(100% - 30px);
    padding-left: 15px;
    padding-right: 15px
}
.driveLockingDialogbaseitem-chip-content {
    align-items: center;
    display: flex;
    height: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.driveLockingDialogbaseitem-chip-icon {
    width: 20px
}
.driveLockingDialogbaseitem-chip-title {
    padding-left: 10px
}
.driveLockingDialogbasedrive-lock-dialog-cancel {
    color: #1976d2
}
.driveLockingDialogbasedrive-lock-dialog-confirm,
.driveLockingDialogbasedrive-lock-dialog-cancel {
    text-transform: initial
}
.driveLockingUnlockcontent-text {
    color: #616161;
    display: block;
    font-family: Roboto, Arial, sans-serif;
    font-size: 1rem;
    font-weight: 400;
    letter-spacing: 0.00625em;
    line-height: 1.5rem
}
.driveLockingUnlockdetails-link {
    margin-left: 4px
}
#docs-approvals-toast-unlock {
    cursor: pointer
}
#docs-approvals-toast-unlock.jfk-button-disabled {
    display: none
}
.docs-blameview {
    display: block;
    background: #ffffff;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    outline: none;
    overflow: hidden;
    width: 240px
}
.docs-blameview-title-container {
    align-items: center;
    background: #f8f8f8;
    display: flex;
    flex-direction: row;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    justify-content: space-between
}
.docs-blameview-title {
    display: block;
    background: #f8f8f8;
    color: #3c4043;
    font-weight: 500;
    font-size: 14px;
    padding: 16px;
    white-space: nowrap
}
.docs-blameview-nav-container {
    margin: 2px 8px 0 8px
}
.docs-blameview-previous-edit-button,
.docs-blameview-next-edit-button {
    cursor: pointer;
    background: transparent;
    border-radius: 2px;
    height: 24px;
    outline: none
}
.docs-blameview-nav-container .docs-blameview-previous-edit-button .docs-blameview-button-icon .docs-icon-img:before,
.docs-blameview-nav-container .docs-blameview-next-edit-button .docs-blameview-button-icon .docs-icon-img:before,
.docs-blameview-nav-container .docs-blameview-previous-edit-button .docs-blameview-button-icon .docs-icon-img,
.docs-blameview-nav-container .docs-blameview-next-edit-button .docs-blameview-button-icon .docs-icon-img {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_green.svg)
}
.docs-blameview-previous-edit-button.jfk-button-hover,
.docs-blameview-next-edit-button.jfk-button-hover,
.docs-blameview-previous-edit-button.jfk-button-focused,
.docs-blameview-next-edit-button.jfk-button-focused {
    cursor: pointer;
    background: #f1f3f4;
    border-color: transparent
}
.docs-blameview-previous-edit-button.jfk-button-active,
.docs-blameview-next-edit-button.jfk-button-active {
    cursor: pointer;
    background: #e6f4ea
}
.docs-blameview-previous-edit-button.jfk-button-disabled,
.docs-blameview-next-edit-button.jfk-button-disabled {
    cursor: default
}
.docs-blameview-nav-container .docs-blameview-previous-edit-button.jfk-button-disabled .docs-icon-img:before,
.docs-blameview-nav-container .docs-blameview-next-edit-button.jfk-button-disabled .docs-icon-img:before,
.docs-blameview-nav-container .docs-blameview-previous-edit-button.jfk-button-disabled .docs-icon-img,
.docs-blameview-nav-container .docs-blameview-next-edit-button.jfk-button-disabled .docs-icon-img {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_grey_dark.svg);
    opacity: .38
}
.docs-blameview-button-icon {
    overflow: hidden;
    position: relative
}
.docs-blameview-message {
    background: #fff;
    border-bottom-left-radius: 4px;
    border-bottom-right-radius: 4px;
    color: #3c4043;
    display: block;
    font-size: 14px;
    line-height: 20px;
    overflow: hidden;
    overflow-wrap: break-word;
    padding: 13px 16px 13px 16px;
    text-overflow: ellipsis;
    white-space: normal
}
.docs-blameview-header {
    background: #f8f8f8;
    display: flex;
    flex-direction: row;
    padding: 0 16px 10px 16px;
    white-space: nowrap
}
.docs-blameview-avatar-holder {
    display: inline-block;
    max-width: 32px
}
.docs-blameview-avatar {
    border-radius: 50%;
    height: 32px;
    width: 32px
}
.docs-blameview-authortimestamp {
    color: #3c4043;
    display: inline-block;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    overflow: hidden;
    padding: 0 10px;
    text-overflow: ellipsis;
    white-space: nowrap;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1
}
.docs-blameview-timestamp {
    display: block;
    font-size: 12px;
    margin: 0
}
.docs-blameview-author {
    display: block;
    font-size: 14px;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    height: 18px;
    margin-bottom: 1px;
    max-width: 167px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.docs-blameview-valuecontainer {
    background: #ffffff;
    display: flex;
    flex: 1 1 auto;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    justify-content: space-between;
    line-height: 20px;
    max-height: 160px;
    overflow: hidden;
    overflow-wrap: break-word;
    white-space: normal;
    width: 100%
}
.docs-blame-bold-text {
    font-style: normal;
    font-weight: 500
}
.docs-blameview-value-content {
    color: #3c4043;
    display: inline;
    font-style: italic;
    overflow-x: hidden;
    overflow-y: auto;
    overflow-wrap: break-word;
    padding: 10px 16px;
    word-wrap: break-word
}
.docs-blameview-value-content-indirect-edit {
    margin-right: 0
}
.overlay-container-rtl .docs-blameview-value-content-indirect-edit {
    margin-left: 0
}
.docs-blameview-spinner {
    background: #fff;
    overflow: hidden;
    padding: 30px 16px 13px 16px
}
.docs-blameview-spinner-holder {
    float: left;
    height: 32px;
    margin: 0 0 0 16px;
    position: relative
}
.overlay-container-rtl .docs-blameview-spinner-holder {
    float: right;
    margin: 0 16px 0 0
}
.docs-blameview-icon:before {
    content: url(//ssl.gstatic.com/docs/common/menu_feature_sprite7.svg)
}
.docs-blameview-icon {
    height: 4332px;
    position: absolute;
    width: 72px
}
.docs-blameview-footer {
    border-top: 1px solid #dadce0;
    display: flex;
    flex-direction: column;
    padding: 12px 16px 0 16px
}
.docs-blameview-warning,
.docs-blameview-indirect-edit {
    color: #3c4043;
    display: block;
    font-size: 12px;
    line-height: 16px;
    padding-bottom: 12px;
    white-space: normal
}
a.docs-blameview-warning-info,
.docs-blameview-indirect-edit-learnmore a {
    color: #1a73e8;
    text-decoration: underline
}
.docs-blameview-feedback {
    align-items: center;
    background: #ffffff;
    border-top: 1px solid #dadce0;
    display: block;
    padding-left: 16px;
    padding-right: 9px;
    padding-top: 10px;
    line-height: 20px
}
.docs-blameview-short-feedback {
    display: none
}
.docs-blameview-useful-text {
    color: #3c4043;
    float: left;
    font-size: 14px;
    font-style: italic
}
.docs-blameview-give-thumbs-up {
    float: right;
    padding-right: 12px
}
.docs-blameview-thumbs-up-button {
    float: left;
    opacity: 0.6;
    padding-right: 10px;
    width: 18px
}
.docs-blameview-thumbs-down-button {
    float: right;
    opacity: 0.6;
    width: 18px
}
.docs-blameview-thumbs-up-button:hover,
.docs-blameview-thumbs-down-button:hover {
    cursor: pointer;
    opacity: 1
}
.docs-blameview-long-feedback {
    display: none;
    font-size: 14px;
    font-style: italic
}
.docs-blameview-long-feedback a,
.docs-blameview-long-feedback a:link,
.docs-blameview-long-feedback a:visited {
    color: #1a73e8
}
.docs-blameview-long-feedback-text {
    color: #3c4043
}
.docs-blameview-nav-container .docs-hc-edge.docs-blameview-previous-edit-button .docs-icon-img,
.docs-blameview-nav-container .docs-hc-edge.docs-blameview-next-edit-button .docs-icon-img,
.docs-blameview-nav-container .docs-hc-gecko.docs-blameview-previous-edit-button .docs-icon-img,
.docs-blameview-nav-container .docs-hc-gecko.docs-blameview-next-edit-button .docs-icon-img {
    filter: brightness(1.5)
}
.docs-blameview-nav-container .docs-hc-edge.docs-blameview-previous-edit-button.jfk-button-disabled .docs-icon-img,
.docs-blameview-nav-container .docs-hc-edge.docs-blameview-next-edit-button.jfk-button-disabled .docs-icon-img,
.docs-blameview-nav-container .docs-hc-gecko.docs-blameview-previous-edit-button.jfk-button-disabled .docs-icon-img,
.docs-blameview-nav-container .docs-hc-gecko.docs-blameview-next-edit-button.jfk-button-disabled .docs-icon-img {
    filter: brightness(10);
    opacity: 1
}
.docs-blameview-nav-container .docs-hc-ie.docs-blameview-previous-edit-button .docs-icon-img,
.docs-blameview-nav-container .docs-hc-ie.docs-blameview-next-edit-button .docs-icon-img {
    -ms-high-contrast-adjust: none;
    background-color: white
}
.docs-gm-sidebars .docs-gm-sidebar-icon {
    margin-right: 12px;
    height: 24px;
    width: 24px
}
.docs-gm-sidebars .docs-gm-sidebar-icon .docs-gm-sidebar-icon-24 {
    height: 24px;
    margin: 0;
    width: 24px
}
.docs-gm-sidebars .docs-gm-sidebar-icon-path {
    fill: #188038
}
.docs-sidebar-titlebar-icon-button {
    cursor: pointer;
    position: absolute;
    right: 10px
}
.docs-sidebar-gm-titlebar-icon-button {
    background-color: transparent;
    border: none!important;
    border-radius: 50%;
    cursor: pointer;
    height: 26px;
    margin-left: auto;
    margin-right: 0;
    padding: 6px 0 0 0;
    position: relative;
    right: -5px;
    text-align: center;
    top: 0;
    width: 32px
}
.docs-sidebar-gm-titlebar-icon-button:hover {
    background-color: #f1f3f4
}
.docs-sidebar-gm-titlebar-icon-button:focus {
    background-color: #e8eaed;
    outline: none
}
.docs-clipboard-clearall {
    font-weight: 500
}
.docs-clipboard-preview {
    position: absolute;
    background-color: #fff;
    color: black;
    visibility: hidden;
    width: 260px;
    height: 195px;
    overflow: hidden;
    font-size: 80%;
    border: 1px solid #888;
    outline: 0;
    padding: 2px;
    top: 0;
    z-index: 9999
}
.docs-clipboard-preview iframe {
    border: 0;
    padding: 0;
    margin: 0;
    width: 100%;
    height: 100%;
    vertical-align: top
}
.docs-textcolormenubutton .goog-toolbar-menu-button-outer-box .goog-toolbar-menu-button-inner-box .goog-toolbar-menu-button-caption .goog-color-menu-button-indicator {
    height: 20px;
    width: 22px;
    bottom: 1px
}
.docs-textcolormenubutton .goog-toolbar-menu-button-outer-box .goog-toolbar-menu-button-inner-box .goog-toolbar-menu-button-caption .goog-color-menu-button-indicator .docs-textcolormenubutton-background-indicator {
    height: 14px;
    left: 4px;
    position: relative;
    top: 4px;
    width: 14px
}
.docs-textcolormenubutton .goog-toolbar-menu-button-outer-box .goog-toolbar-menu-button-inner-box .goog-toolbar-menu-button-caption .goog-color-menu-button-indicator .docs-textcolormenubutton-background-indicator .docs-textcolormenubutton-char {
    bottom: 4px;
    font-size: 14px;
    font-weight: normal;
    position: relative
}
.docs-text-color-state-change-button {
    margin-right: 0;
    padding: 0 18px
}
.jfk-button-standard.docs-c-u-colormenutogglebutton-base.docs-c-u-colormenutogglebutton-extra-visible-border.jfk-button-hover,
.jfk-button-standard.docs-c-u-colormenutogglebutton-base.docs-c-u-colormenutogglebutton-extra-visible-border.jfk-button-hover.jfk-button-checked {
    border: 1px solid #000
}
.docs-text-color-omnibox-icon {
    float: left;
    width: 16px;
    height: 16px;
    margin: 2px
}
.docs-docos-activitybox {
    background: #fff;
    border: solid 1px #cbcbcb;
    -moz-box-shadow: -1px 1px 1px rgba(0, 0, 0, .2);
    -webkit-box-shadow: 0 2px 4px rgba(0, 0, 0, .2);
    box-shadow: 0 2px 4px rgba(0, 0, 0, .2);
    height: 550px;
    padding: 12px 0;
    position: absolute;
    outline: none;
    right: 20px;
    top: 46px;
    width: 434px;
    z-index: 900
}
.docs-docos-activitybox-inner {
    height: 100%;
    overflow: auto
}
.docs-docos-activitybox.docos-enable-new-header {
    padding: 0!important;
    height: auto!important
}
.docs-docos-activitybox.docos-enable-new-header>.docs-docos-activitybox-inner {
    overflow: visible!important
}
.docs-docos-caret-inner,
.docs-docos-caret-outer {
    border: 9px solid;
    border-top-width: 0;
    display: block;
    height: 0;
    margin: 0 auto;
    position: relative;
    width: 0;
    z-index: 901
}
.docs-docos-caret-inner {
    border-color: #fff transparent;
    top: 1px
}
.docs-docos-caret-outer {
    border-color: #cbcbcb transparent;
    top: 9px
}
.docos-enable-new-header>.docs-docos-caret-inner {
    border-color: #f1f1f1 transparent!important
}
.docos-shelly-icon {
    background-image: url(//ssl.gstatic.com/docs/common/d-icons30.png);
    background-repeat: no-repeat;
    height: 14px;
    width: 14px
}
.docos-icon-close-pane {
    background-position: 0 -21px
}
.docos-icon-close-pane:hover {
    background-position: -38px -45px
}
.docos-icon-grippy {
    background-position: -38px -94px;
    width: 16px;
    height: 4px
}
.docos-icon-discussion-button {
    background-position: -22px -66px;
    width: 14px;
    height: 15px;
    vertical-align: text-bottom;
    margin-right: 5px
}
.office-editing-export-error-bubble-close-button {
    float: right
}
.office-editing-export-error-bubble {
    background-color: #fff;
    border: 1px solid transparent;
    border-radius: 8px;
    box-shadow: 0 4px 8px 3px rgba(60, 64, 67, .15);
    position: absolute;
    z-index: 1003;
    color: #5f6368;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    outline: none;
    padding: 24px;
    white-space: pre-line;
    width: 400px;
    z-index: 99!important
}
.office-editing-export-error-bubble-title {
    color: #202124;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 22px;
    font-weight: 400;
    line-height: 28px;
    font-size: 16px;
    line-height: 24px
}
.office-editing-export-error-bubble-description {
    line-height: 20px;
    margin-top: 16px
}
.office-editing-export-error-bubble-retry-text {
    font-size: 12px;
    line-height: 16px;
    margin-top: 12px
}
.office-editing-export-error-bubble-learn-more,
.office-editing-export-error-bubble-learn-more:visited {
    color: #1a73e8;
    margin-left: 8px
}
.office-editing-onboarding-promo-bubble-dotted-progressbar-dot {
    background: #ceead6;
    border-radius: 50%;
    display: inline-block;
    height: 8px;
    margin-right: 8px;
    width: 8px
}
.office-editing-onboarding-promo-bubble-dotted-progressbar-dot-highlighted {
    background: #188038
}
.office-editing-onboarding-dialog {
    width: 480px
}
.office-editing-onboarding-dialog-logo {
    height: 92px;
    width: 92px
}
.office-editing-onboarding-dialog-heading {
    color: #202124;
    font-size: 24px;
    line-height: 32px;
    padding: 16px 0
}
.office-editing-onboarding-dialog-description {
    color: #5f6368;
    font-size: 18px;
    line-height: 28px;
    text-align: center
}
.office-editing-onboarding-dialog-logo-container,
.office-editing-onboarding-dialog-heading,
.office-editing-onboarding-dialog-description,
.office-editing-onboarding-dialog .docs-material-gm-dialog-buttons {
    display: flex;
    justify-content: center
}
.office-editing-onboarding-dialog .docs-material-gm-dialog-title {
    padding: 18px
}
.office-editing-onboarding-dialog .docs-material-gm-dialog-title-close {
    cursor: pointer
}
.office-editing-onboarding-dialog .docs-material-gm-dialog-buttons {
    padding-bottom: 34px
}
.office-editing-onboarding-promo-bubble {
    padding: 16px 16px 16px 20px;
    width: 324px
}
.office-editing-onboarding-promo-bubble-title {
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 18px;
    line-height: 24px;
    padding-bottom: 8px
}
.office-editing-onboarding-promo-bubble-description {
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    line-height: 20px;
    padding-right: 24px
}
.office-editing-onboarding-promo-bubble .docs-material-promo-walkthrough-bubble-buttons {
    display: block;
    padding: 24px 0 0 0;
    justify-content: normal
}
.office-editing-onboarding-promo-bubble .docs-material-promo-walkthrough-bubble-buttons .docs-material-button-fill-primary.docs-material-button {
    display: inline-block;
    float: right;
    height: 24px;
    padding: 3px 18px 3px
}
.office-editing-onboarding-promo-bubble .office-editing-promo-bubble-dotted-progressbar {
    display: inline-block;
    float: left
}
.docs-material .docs-icon,
.docs-material .goog-color-menu-button-indicator .docs-icon,
.docs-material .sketchy-toolbar-color-menu-button .goog-toolbar-menu-button-caption .docs-icon {
    height: 18px;
    width: 18px;
    margin: 1px 2px 2px 1px
}
.docs-material .docs-icon-img:before {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134.svg)
}
.docs-gm .docs-material .docs-icon-img:before {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_grey_medium.svg)
}
.docs-material .docs-icon-img {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134.svg)
}
.docs-gm .docs-material .docs-icon-img {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_grey_medium.svg)
}
.docs-material .docs-icon-img-container {
    height: 4316px;
    position: absolute;
    width: 78px
}
.docs-material .goog-menuitem-icon .docs-icon-img-container {
    opacity: 0.54
}
.docs-gm .docs-material .goog-menuitem-icon .docs-icon-img-container {
    opacity: 1
}
.docs-material .goog-menuitem-icon .docs-icon-document,
.docs-material .goog-menuitem-icon .docs-icon-punch,
.docs-material .goog-menuitem-icon .docs-icon-presentation,
.docs-material .goog-menuitem-icon .docs-icon-spreadsheet,
.docs-material .goog-menuitem-icon .docs-icon-form,
.docs-material .goog-menuitem-icon .docs-icon-drawing,
.docs-material .goog-menuitem-icon .docs-icon-script,
.docs-material .goog-menuitem-icon .docs-icon-site {
    opacity: 1
}
.docs-material .goog-toolbar-button-inner-box .docs-icon,
.docs-material .goog-toolbar-menu-button-caption .docs-icon,
.docs-material .goog-toolbar-menu-button-caption .goog-color-menu-button-indicator .docs-icon {
    margin-top: 0px
}
.docs-gm .docs-material .goog-toolbar-button-active .docs-icon-img:before,
.docs-gm .docs-material .goog-toolbar-button-checked .docs-icon-img:before,
.docs-gm .docs-material .goog-toolbar-button-selected .docs-icon-img:before,
.docs-gm .docs-material .goog-toolbar-combo-button-open .docs-icon-img:before,
.docs-gm .docs-material .goog-toolbar-menu-button-open .docs-icon-img:before,
.docs-gm .docs-material .docs-toolbar-split-create-button.goog-toolbar-button-active .docs-icon-img:before,
.docs-gm .docs-material .docs-toolbar-split-create-button.goog-toolbar-menu-button-active .docs-icon-img:before,
.docs-gm .docs-material .docs-toolbar-split-create-button.goog-toolbar-menu-button-open .docs-icon-img:before,
.docs-gm .docs-material .docs-appbar-circle-button.jfk-button-active .docs-icon-img:before,
.docs-gm .docs-material .docs-appbar-circle-button.jfk-button-checked .docs-icon-img:before,
.docs-gm .docs-material .docs-analytics-sidebar-tab-selected .docs-icon-img:before,
.docs-gm .docs-material.docs-sheet-active-tab .docs-icon-img:before,
.docs-gm .docs-material .docs-sheet-button-active .docs-icon-img:before,
.docs-gm .docs-material .docs-sheet-button-open .docs-icon-img:before,
.docs-gm .docs-material .punch-start-presentation-container .docs-icon-img:before,
.docs-gm .docs-material .waffle-named-ranges-promo-title .docs-icon-img:before,
.docs-gm .docs-material.trix-palette .goog-palette-cell-selected .docs-icon-img:before,
.docs-bubble .docs-bubble-button.jfk-button:hover:active .docs-icon-img:before,
.docs-save-indicator:active .docs-icon-img:before,
.docs-save-indicator.docs-save-indicator-selected .docs-icon-img:before,
.docs-material .docs-save-indicator-popup-icon .docs-icon-img:before {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_green.svg)
}
.docs-gm .docs-material .goog-toolbar-button-active .docs-icon-img,
.docs-gm .docs-material .goog-toolbar-button-checked .docs-icon-img,
.docs-gm .docs-material .goog-toolbar-button-selected .docs-icon-img,
.docs-gm .docs-material .goog-toolbar-combo-button-open .docs-icon-img,
.docs-gm .docs-material .goog-toolbar-menu-button-open .docs-icon-img,
.docs-gm .docs-material .docs-toolbar-split-create-button.goog-toolbar-button-active .docs-icon-img,
.docs-gm .docs-material .docs-toolbar-split-create-button.goog-toolbar-menu-button-active .docs-icon-img,
.docs-gm .docs-material .docs-toolbar-split-create-button.goog-toolbar-menu-button-open .docs-icon-img,
.docs-gm .docs-material .docs-appbar-circle-button.jfk-button-active .docs-icon-img,
.docs-gm .docs-material .docs-appbar-circle-button.jfk-button-checked .docs-icon-img,
.docs-gm .docs-material .docs-analytics-sidebar-tab-selected .docs-icon-img,
.docs-gm .docs-material.docs-sheet-active-tab .docs-icon-img,
.docs-gm .docs-material .docs-sheet-button-active .docs-icon-img,
.docs-gm .docs-material .docs-sheet-button-open .docs-icon-img,
.docs-gm .docs-material .punch-start-presentation-container .docs-icon-img,
.docs-gm .docs-material .waffle-named-ranges-promo-title .docs-icon-img,
.docs-gm .docs-material.trix-palette .goog-palette-cell-selected .docs-icon-img,
.docs-bubble .docs-bubble-button.jfk-button:hover:active .docs-icon-img,
.docs-save-indicator:active .docs-icon-img,
.docs-save-indicator.docs-save-indicator-selected .docs-icon-img,
.docs-material .docs-save-indicator-popup-icon .docs-icon-img {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_green.svg)
}
.docs-material.clean-palette .docs-icon {
    margin: 4px
}
.docs-material .docs-omnibox-row-icon .shape-icon {
    margin: -1px 0 0 -1px
}
.docs-material .docs-icon-save {
    left: -40px;
    top: -4188px
}
.docs-material .docs-icon-print {
    left: -40px;
    top: -192px
}
.docs-material .docs-icon-undo,
.docs-material .docs-icon-redo-rtl {
    left: 0;
    top: -2480px
}
.docs-material .docs-icon-redo,
.docs-material .docs-icon-undo-rtl {
    left: -20px;
    top: -1456px
}
.docs-material .docs-icon-copy {
    left: -40px;
    top: -3970px
}
.docs-material .docs-icon-cut {
    left: -20px;
    top: -4196px
}
.docs-material .docs-icon-paste {
    left: 0;
    top: -2980px
}
.docs-material .docs-icon-document {
    left: 0;
    top: -3126px
}
.docs-material .docs-icon-presentation,
.docs-material .docs-icon-punch {
    left: 0;
    top: -2960px
}
.docs-material .docs-icon-presentation-grey900 {
    left: -20px;
    top: -4176px
}
.docs-material .docs-icon-spreadsheet {
    left: -20px;
    top: -1334px
}
.docs-material .docs-icon-form {
    left: 0;
    top: -232px
}
.docs-material .docs-icon-form-black {
    left: -52px;
    top: -3224px
}
.docs-material .docs-icon-drawing {
    left: 0;
    top: -2646px
}
.docs-material .docs-icon-site {
    left: 0;
    top: -4256px
}
.docs-material .docs-icon-drawing-black {
    left: -40px;
    top: -4268px
}
.docs-material .docs-icon-excel {
    left: 0;
    top: -1436px
}
.docs-material .docs-icon-powerpoint {
    left: -20px;
    top: -1808px
}
.docs-material .docs-icon-word {
    left: -40px;
    top: -2834px
}
.docs-material .docs-icon-script {
    left: -20px;
    top: -1196px
}
.docs-material .docs-icon-insert-script {
    left: 0;
    top: -3810px
}
.docs-material .docs-icon-gadget {
    left: -20px;
    top: -3290px
}
.docs-material .docs-icon-image {
    left: 0;
    top: -1136px
}
.docs-material .docs-icon-clipboard {
    left: 0;
    top: -3558px
}
.docs-material .docs-icon-bold {
    left: 0;
    top: -212px
}
.docs-material .docs-icon-italic {
    left: 0;
    top: -3910px
}
.docs-material .docs-icon-text-color {
    left: 0;
    top: -1788px
}
.docs-material .docs-icon-align-left {
    left: -20px;
    top: -1954px
}
.docs-material .docs-icon-align-center {
    left: -40px;
    top: -3810px
}
.docs-material .docs-icon-align-right {
    left: 0;
    top: -918px
}
.docs-material .docs-icon-align-justify {
    left: -20px;
    top: -598px
}
.docs-material .docs-icon-align-shapes-left {
    left: -40px;
    top: -1618px
}
.docs-material .docs-icon-align-shapes-center {
    left: -20px;
    top: -1828px
}
.docs-material .docs-icon-align-shapes-right {
    left: 0;
    top: -2060px
}
.docs-material .docs-icon-align-shapes-top {
    left: -20px;
    top: -1476px
}
.docs-material .docs-icon-align-shapes-middle {
    left: -58px;
    top: -2206px
}
.docs-material .docs-icon-align-shapes-bottom {
    left: -40px;
    top: -3598px
}
.docs-material .docs-icon-distribute-shapes-horizontally {
    left: -48px;
    top: -292px
}
.docs-material .docs-icon-distribute-shapes-vertically {
    left: 0;
    top: -3000px
}
.docs-material .docs-icon-valign-top {
    left: -40px;
    top: -1954px
}
.docs-material .docs-icon-valign-middle {
    left: 0;
    top: -2732px
}
.docs-material .docs-icon-valign-bottom {
    left: -26px;
    top: -444px
}
.docs-material .docs-icon-list-number {
    left: -46px;
    top: -2354px
}
.docs-material .docs-icon-list-bullet {
    left: 0;
    top: -3704px
}
.docs-material .docs-icon-indent {
    left: -40px;
    top: -4096px
}
.docs-material .docs-icon-outdent {
    left: -20px;
    top: -3810px
}
.docs-material .docs-icon-line-spacing {
    left: -20px;
    top: -2120px
}
.docs-material .docs-icon-columns {
    left: -20px;
    top: -384px
}
.docs-material .docs-icon-underline {
    left: -20px;
    top: -232px
}
.docs-material .docs-icon-text-bgcolor {
    left: 0;
    top: -1704px
}
.docs-material .docs-icon-textbox {
    left: -20px;
    top: -3390px
}
.docs-material .docs-icon-shapes {
    left: -40px;
    top: -598px
}
.docs-material .docs-icon-line-width {
    left: 0;
    top: -2440px
}
.docs-material .docs-icon-add-trendline {
    left: 0;
    top: -938px
}
.docs-material .docs-icon-data-label {
    left: 0;
    top: -4136px
}
.docs-material .docs-icon-next {
    left: 0;
    top: -2940px
}
.docs-material .docs-icon-previous {
    left: 0;
    top: -192px
}
.docs-material .docs-icon-no-color {
    left: 0;
    top: -444px
}
.docs-material .docs-icon-fill-color {
    left: -20px;
    top: -1664px
}
.docs-material .docs-icon-line-color {
    left: -20px;
    top: -404px
}
.docs-material .docs-icon-line-type {
    left: 0;
    top: -3578px
}
.docs-material .docs-icon-table {
    left: -20px;
    top: -3990px
}
.docs-material .docs-icon-comment {
    left: 0;
    top: -3390px
}
.docs-material .docs-icon-comment-blank {
    left: 0;
    top: -3950px
}
.docs-material .docs-icon-comment-blank-highlighted {
    left: 0;
    top: -978px
}
.docs-material .docs-icon-comment-blank-grey600 {
    left: -52px;
    top: -658px
}
.docs-material .docs-icon-insert-comment {
    left: -26px;
    top: -2266px
}
.docs-material .docs-icon-insert-comment-24 {
    left: -40px;
    top: -3336px
}
.docs-material .docs-icon-trending-up-24 {
    left: -40px;
    top: -66px
}
.docs-material .docs-icon-chart {
    left: 0;
    top: -806px
}
.docs-material .docs-icon-list-number-rtl {
    left: 0;
    top: -384px
}
.docs-material .docs-icon-list-bullet-rtl {
    left: -40px;
    top: -4228px
}
.docs-material .docs-icon-indent-rtl {
    left: 0;
    top: -2120px
}
.docs-material .docs-icon-outdent-rtl {
    left: 0;
    top: -2420px
}
.docs-material .docs-icon-line-spacing-rtl {
    left: 0;
    top: -2306px
}
.docs-material .docs-icon-text-ltr {
    left: 0;
    top: -3850px
}
.docs-material .docs-icon-text-rtl {
    left: 0;
    top: -66px
}
.docs-material .docs-icon-sheet-rtl {
    left: -40px;
    top: -3578px
}
.docs-material .docs-icon-share {
    left: 0;
    top: -2626px
}
.docs-material .docs-icon-subscript {
    left: 0;
    top: -1764px
}
.docs-material .docs-icon-superscript {
    left: -20px;
    top: -3106px
}
.docs-material .docs-icon-strikethrough {
    left: 0;
    top: -1416px
}
.docs-material .docs-icon-clear-formatting {
    left: -20px;
    top: -1994px
}
.docs-material .docs-icon-link {
    left: -20px;
    top: -1888px
}
.docs-material .docs-icon-special-character {
    left: 0;
    top: -2266px
}
.docs-material .docs-icon-close-white {
    left: -26px;
    top: -2354px
}
.docs-material .docs-icon-close-small {
    left: 0;
    top: -1556px
}
.docs-material .docs-icon-close-thin {
    left: -40px;
    top: -1868px
}
.docs-material .docs-icon-paint-format {
    left: -42px;
    top: -718px
}
.docs-material .docs-icon-video {
    left: -48px;
    top: -2266px
}
.docs-material .docs-icon-reload {
    left: -20px;
    top: -2400px
}
.docs-material .docs-icon-reload-rtl {
    left: 0;
    top: -786px
}
.docs-material .docs-icon-insert-page-break {
    left: -20px;
    top: -1156px
}
.docs-material .docs-icon-close {
    left: -52px;
    top: -3244px
}
.docs-material .docs-icon-check {
    left: -20px;
    top: -3558px
}
.docs-material .docs-icon-up {
    left: -40px;
    top: -2140px
}
.docs-material .docs-icon-down {
    left: 0;
    top: -404px
}
.docs-material .docs-icon-add-page {
    left: 0;
    top: -2920px
}
.docs-material .docs-icon-email {
    left: -40px;
    top: -1334px
}
.docs-material .docs-icon-insert-equation {
    left: -20px;
    top: -1788px
}
.docs-material .docs-icon-insert-horizontal-line {
    left: -40px;
    top: -2754px
}
.docs-material .docs-icon-tabstop-center {
    left: -40px;
    top: -4208px
}
.docs-material .docs-icon-tabstop-center-blue500 {
    left: 0;
    top: -3724px
}
.docs-material .docs-icon-tabstop-center-bottom {
    left: 0;
    top: -684px
}
.docs-material .docs-icon-tabstop-center-bottom-blue500 {
    left: -46px;
    top: -2986px
}
.docs-material .docs-icon-tabstop-left {
    left: -20px;
    top: -3370px
}
.docs-material .docs-icon-tabstop-left-blue500 {
    left: -20px;
    top: -3950px
}
.docs-material .docs-icon-tabstop-right {
    left: 0;
    top: -2034px
}
.docs-material .docs-icon-tabstop-right-blue500 {
    left: -40px;
    top: -1236px
}
.docs-material .docs-icon-ruler-first-indent-drag-blue {
    left: -20px;
    top: -1396px
}
.docs-material .docs-icon-ruler-first-indent-drag-blue500 {
    left: 0;
    top: -1354px
}
.docs-material .docs-icon-border-all {
    left: 0;
    top: -2140px
}
.docs-material .docs-icon-border-right {
    left: -20px;
    top: -1868px
}
.docs-material .docs-icon-border-left {
    left: -20px;
    top: -2754px
}
.docs-material .docs-icon-border-top {
    left: 0;
    top: -3310px
}
.docs-material .docs-icon-border-bottom {
    left: 0;
    top: -826px
}
.docs-material .docs-icon-border-outside {
    left: 0;
    top: -576px
}
.docs-material .docs-icon-border-inside {
    left: -40px;
    top: -2520px
}
.docs-material .docs-icon-border-none {
    left: -40px;
    top: -1096px
}
.docs-material .docs-icon-border-horizontal {
    left: 0;
    top: -3370px
}
.docs-material .docs-icon-border-vertical {
    left: 0;
    top: -1744px
}
.docs-material .docs-icon-merge {
    left: -20px;
    top: -3410px
}
.docs-material .docs-icon-wrap {
    left: 0;
    top: -1808px
}
.docs-material .docs-icon-autofilter {
    left: -24px;
    top: -1376px
}
.docs-material .docs-icon-autofilter-filled {
    left: -20px;
    top: -3910px
}
.docs-material .docs-icon-insert-function {
    left: -20px;
    top: -3724px
}
.docs-material .docs-icon-insert-formula {
    left: 0;
    top: -1638px
}
.docs-material .docs-icon-folder-shared {
    left: 0;
    top: -4176px
}
.docs-material .docs-icon-folder-outline {
    left: -20px;
    top: -3310px
}
.docs-material .docs-icon-folder-outline-hover {
    left: 0;
    top: -2500px
}
.docs-material .docs-icon-folder-outline-pressed {
    left: -40px;
    top: -3430px
}
.docs-material .docs-icon-folder-solid {
    left: -48px;
    top: -872px
}
.docs-material .docs-icon-drive {
    left: 0;
    top: -1236px
}
.docs-material .docs-icon-drive-hover {
    left: -38px;
    top: -2226px
}
.docs-material .docs-icon-drive-pressed {
    left: -40px;
    top: -1156px
}
.docs-material .docs-icon-drive-large {
    left: -40px;
    top: -918px
}
.docs-material .docs-icon-drive-large-wrapper {
    width: 36px;
    height: 36px
}
.docs-material .docs-icon-back {
    left: 0;
    top: -92px
}
.docs-material .docs-icon-back-rtl {
    left: 0;
    top: -3970px
}
.docs-material .docs-icon-arrow-more {
    left: -20px;
    top: -1096px
}
.docs-material .docs-icon-arrow-more-rtl {
    left: -40px;
    top: -1196px
}
.docs-material .docs-icon-search-this-document {
    left: 0;
    top: -3270px
}
.docs-material .docs-icon-arrow-dropdown {
    left: 0;
    top: -1364px
}
.docs-material .docs-icon-arrow-dropdown-grey600 {
    left: -40px;
    top: -3410px
}
.docs-material .docs-icon-expand-all {
    left: 0;
    top: -2794px
}
.docs-material .docs-icon-word-art {
    left: -52px;
    top: -1496px
}
.docs-material .docs-icon-delete-x {
    left: -40px;
    top: -1908px
}
.docs-material .docs-icon-settings {
    left: 0;
    top: -3870px
}
.docs-material .docs-icon-plus {
    left: -20px;
    top: -1848px
}
.docs-material .docs-icon-plus-white {
    left: -58px;
    top: -2920px
}
.docs-material .docs-icon-alert {
    left: -20px;
    top: -2080px
}
.docs-material .docs-icon-alert-error-24-orange600 {
    left: -40px;
    top: -3290px
}
.docs-material .docs-icon-trash {
    left: 0;
    top: -132px
}
.docs-material .docs-icon-locked {
    left: 0;
    top: -1216px
}
.docs-material .docs-icon-locked-grey600 {
    left: 0;
    top: -3830px
}
.docs-material .docs-icon-unlocked {
    left: -20px;
    top: -1136px
}
.docs-material .docs-icon-add-fonts {
    left: 0;
    top: -1658px
}
.docs-material .docs-icon-enter-compact {
    left: -20px;
    top: -2060px
}
.docs-material .docs-icon-exit-compact {
    left: 0;
    top: -424px
}
.docs-material .docs-icon-mode-edit {
    left: 0;
    top: -3598px
}
.docs-material .docs-icon-mode-review {
    left: -40px;
    top: -1888px
}
.docs-material .docs-icon-mode-review-white {
    left: 0;
    top: -1456px
}
.docs-material .docs-icon-mode-view {
    left: 0;
    top: -1954px
}
.docs-material .docs-icon-mode-view-white {
    left: 0;
    top: -2520px
}
.docs-material .docs-icon-chat {
    left: 0;
    top: -1156px
}
.docs-material .docs-icon-chat-bubble-grey900 {
    left: 0;
    top: 0
}
.docs-material .docs-icon-chat-bubble-white {
    left: -20px;
    top: -132px
}
.docs-material .docs-icon-chat-person-grey900 {
    left: 0;
    top: -1116px
}
.docs-material .docs-icon-chat-person-wide-grey900 {
    left: -40px;
    top: -4076px
}
.docs-material .docs-icon-person-add-white {
    left: 0;
    top: -2180px
}
.docs-material .docs-icon-star {
    left: -46px;
    top: -1354px
}
.docs-material .docs-icon-duplicate {
    left: -20px;
    top: -2460px
}
.docs-material .docs-icon-file {
    left: -20px;
    top: -2140px
}
.docs-material .docs-icon-opacity {
    left: 0;
    top: -46px
}
.docs-material .docs-icon-label-slant {
    left: -22px;
    top: -3450px
}
.docs-material .docs-icon-point-size {
    left: -20px;
    top: -3350px
}
.docs-material .docs-icon-question {
    left: -20px;
    top: -66px
}
.docs-material .docs-icon-quote {
    left: -40px;
    top: -3890px
}
.docs-material .docs-icon-vertical-gridlines {
    left: -20px;
    top: -786px
}
.docs-material .docs-icon-left-axis {
    left: 0;
    top: -4276px
}
.docs-material .docs-icon-right-axis {
    left: 0;
    top: -1396px
}
.docs-material .docs-icon-left-axis-gridlines {
    left: 0;
    top: -2352px
}
.docs-material .docs-icon-right-axis-gridlines {
    left: -20px;
    top: -3430px
}
.docs-material .docs-icon-reset {
    left: -40px;
    top: -1994px
}
.docs-material .docs-icon-drag-move {
    left: 0;
    top: -4096px
}
.docs-material .docs-icon-col-dragger {
    left: 0;
    top: -3106px
}
.docs-material .docs-icon-chrome-store {
    left: -20px;
    top: -1556px
}
.docs-material .docs-icon-fit-area {
    left: 0;
    top: -2460px
}
.docs-material .docs-icon-zoom-out {
    left: -20px;
    top: -4136px
}
.docs-material .docs-icon-zoom-tool {
    left: 0;
    top: -1828px
}
.docs-material .docs-icon-download {
    left: -40px;
    top: -2500px
}
.docs-material .docs-icon-fusion-table {
    left: -40px;
    top: -2814px
}
.docs-material .docs-icon-spreadsheet-sink {
    left: 0;
    top: -638px
}
.docs-material .docs-icon-send-responses {
    left: -20px;
    top: -1618px
}
.docs-material .docs-icon-liveform {
    left: 0;
    top: -846px
}
.docs-material .docs-icon-ellipsis {
    left: -40px;
    top: -3910px
}
.docs-material .docs-icon-html-preview {
    left: 0;
    top: -3330px
}
.docs-material .docs-icon-grid {
    left: -20px;
    top: -3850px
}
.docs-material .docs-icon-add-animation {
    left: -20px;
    top: -4296px
}
.docs-material .docs-icon-play-filled-24 {
    left: 0;
    top: -464px
}
.docs-material .docs-icon-play-filled-error-36 {
    left: -20px;
    top: -1750px
}
.docs-material .docs-icon-playhead {
    left: 0;
    top: -1476px
}
.docs-material .docs-icon-playhead-rtl {
    left: -20px;
    top: -2692px
}
.docs-material .docs-icon-unsupported {
    left: -26px;
    top: -1522px
}
.docs-material .docs-icon-calendar {
    left: 0;
    top: -2286px
}
.docs-material .docs-zippy-closed {
    left: -40px;
    top: -3370px
}
.docs-material .docs-zippy-open {
    left: -20px;
    top: -2480px
}
.docs-material .docs-icon-bookmark {
    left: -20px;
    top: -3618px
}
.docs-material .docs-icon-heading {
    left: 0;
    top: -3990px
}
.docs-material .docs-icon-file-blue {
    left: 0;
    top: -2400px
}
.docs-material .docs-icon-web-result {
    left: -20px;
    top: -2040px
}
.docs-material .docs-icon-mic {
    left: -40px;
    top: -1556px
}
.docs-material .docs-icon-mic-plus {
    left: 0;
    top: -598px
}
.docs-material .docs-icon-paragraph {
    left: 0;
    top: -1868px
}
.docs-material .docs-icon-bookmark-black {
    left: -40px;
    top: -3558px
}
.docs-material .docs-icon-web-result-blue {
    left: 0;
    top: -3790px
}
.docs-material .docs-icon-popout {
    left: -40px;
    top: -252px
}
.docs-material .docs-icon-checkbox {
    left: 0;
    top: -4196px
}
.docs-material .docs-icon-checkbox-type {
    left: -20px;
    top: -3830px
}
.docs-material .docs-icon-dropdown-type {
    left: -20px;
    top: -4116px
}
.docs-material .docs-icon-grid-type {
    left: -22px;
    top: -1928px
}
.docs-material .docs-icon-image-type {
    left: -20px;
    top: -1416px
}
.docs-material .docs-icon-radio-type {
    left: 0;
    top: -3290px
}
.docs-material .docs-icon-scale-type {
    left: 0;
    top: -4236px
}
.docs-material .docs-icon-text-type {
    left: -40px;
    top: -1216px
}
.docs-material .docs-icon-time-type {
    left: -20px;
    top: -3126px
}
.docs-material .docs-icon-insert-text-block {
    left: -40px;
    top: -1788px
}
.docs-material .docs-icon-accepting-responses-on {
    left: -40px;
    top: -1476px
}
.docs-material .docs-icon-accepting-responses-off {
    left: -20px;
    top: -152px
}
.docs-material .docs-icon-decimal-increase {
    left: -20px;
    top: -4076px
}
.docs-material .docs-icon-decimal-decrease {
    left: 0;
    top: -4296px
}
.docs-material .docs-icon-settings-white {
    left: -40px;
    top: -998px
}
.docs-material .docs-icon-no-symbol {
    left: -40px;
    top: -46px
}
.docs-material .docs-icon-crop {
    left: -20px;
    top: -1908px
}
.docs-material .docs-icon-green-check {
    left: 0;
    top: -2854px
}
.docs-material .docs-icon-font-size {
    left: -40px;
    top: -272px
}
.docs-material .docs-icon-reset-image {
    left: -20px;
    top: -3330px
}
.docs-material .docs-icon-r-squared {
    left: -40px;
    top: -3316px
}
.docs-material .docs-icon-graph-legend {
    left: -40px;
    top: -404px
}
.docs-material .docs-icon-cast {
    left: -20px;
    top: -746px
}
.docs-material .docs-icon-wrap-overflow {
    left: -20px;
    top: -4236px
}
.docs-material .docs-icon-wrap-wrap {
    left: -26px;
    top: -424px
}
.docs-material .docs-icon-wrap-clip {
    left: 0;
    top: -3350px
}
.docs-material .docs-icon-highlights {
    left: 0;
    top: -1848px
}
.docs-material .docs-icon-green-back {
    left: 0;
    top: -618px
}
.docs-material .docs-icon-arrow-back-white {
    left: 0;
    top: -2326px
}
.docs-material .docs-icon-arrow-back-white-rtl {
    left: -40px;
    top: -2060px
}
.docs-material .docs-icon-help {
    left: -20px;
    top: -4096px
}
.docs-material .docs-icon-highlight-green {
    left: -20px;
    top: -1436px
}
.docs-material .docs-icon-explore-24 {
    left: -42px;
    top: -1928px
}
.docs-material .docs-icon-explore-black {
    left: -20px;
    top: -2500px
}
.docs-material .docs-icon-explore-black-padded {
    left: -20px;
    top: -3598px
}
.docs-material .docs-icon-explore-green {
    left: -44px;
    top: -1396px
}
.docs-material .docs-icon-explore-white {
    left: 0;
    top: -1908px
}
.docs-material .docs-icon-insert-autovis-chart {
    left: -40px;
    top: -618px
}
.docs-material .docs-icon-insert-autovis-chart-white {
    left: 0;
    top: -958px
}
.docs-material .docs-icon-zoom-in {
    left: 0;
    top: -1618px
}
.docs-material .docs-icon-thumb-up {
    left: 0;
    top: -3410px
}
.docs-material .docs-icon-thumb-down {
    left: 0;
    top: -172px
}
.docs-material .docs-icon-dlp-warning {
    left: -40px;
    top: -1136px
}
.docs-material .docs-icon-dogfood {
    left: 0;
    top: -4116px
}
.docs-material .docs-icon-add-to-drive {
    left: -40px;
    top: -766px
}
.docs-material .docs-icon-add-shortcut-to-drive {
    left: -40px;
    top: -958px
}
.docs-material .docs-icon-paste-without-formatting {
    left: 0;
    top: -4076px
}
.docs-material .docs-icon-qanda {
    left: 0;
    top: -2160px
}
.docs-material .docs-icon-update-chart {
    left: -40px;
    top: -3850px
}
.docs-material .docs-icon-arrow-back-dark {
    left: -22px;
    top: -292px
}
.docs-material .docs-icon-arrow-back-dark-rtl {
    left: -46px;
    top: -484px
}
.docs-material .docs-icon-open-in-external {
    left: 0;
    top: -2754px
}
.docs-material .docs-icon-unlink {
    left: -20px;
    top: -4276px
}
.docs-material .docs-icon-bar-chart {
    left: 0;
    top: -3538px
}
.docs-material .docs-icon-column-chart {
    left: 0;
    top: -2834px
}
.docs-material .docs-icon-line-chart {
    left: 0;
    top: -556px
}
.docs-material .docs-icon-pie-chart {
    left: -20px;
    top: -3970px
}
.docs-material .docs-icon-pie-chart-outline {
    height: 18px;
    left: -20px;
    top: -3000px;
    width: 18px
}
.docs-material .docs-icon-named-range {
    left: -46px;
    top: -2180px
}
.docs-material .docs-icon-clock {
    left: -20px;
    top: -272px
}
.docs-material .docs-icon-cancel {
    left: -40px;
    top: -786px
}
.docs-material .docs-icon-cancel-24 {
    left: 0;
    top: -872px
}
.docs-material .docs-icon-arrow-line-tool {
    left: -40px;
    top: -2160px
}
.docs-material .docs-icon-arrow-tilted {
    left: 0;
    top: -3638px
}
.docs-material .docs-icon-unsupported-black {
    left: -46px;
    top: -444px
}
.docs-material .docs-icon-text-rotation-up {
    left: -20px;
    top: -3790px
}
.docs-material .docs-icon-text-rotation-down {
    left: -20px;
    top: -3020px
}
.docs-material .docs-icon-text-rotation-angleup {
    left: 0;
    top: -3430px
}
.docs-material .docs-icon-text-rotation-angledown {
    left: 0;
    top: -2712px
}
.docs-material .docs-icon-text-rotation-vertical {
    left: -20px;
    top: -4256px
}
.docs-material .docs-icon-text-rotation-none {
    left: 0;
    top: -1334px
}
.docs-material .docs-icon-keep-lightbulb {
    left: -40px;
    top: -3790px
}
.docs-material .docs-icon-update-table {
    left: -20px;
    top: -1116px
}
.docs-material .docs-icon-update-slide {
    left: -26px;
    top: -464px
}
.docs-material .docs-icon-overflow-three-dots {
    left: -26px;
    top: -504px
}
.docs-material .docs-icon-restore {
    left: -20px;
    top: -4010px
}
.docs-material .docs-icon-paragraph-border-between {
    left: -40px;
    top: -2120px
}
.docs-material .docs-icon-paragraph-border-bottom {
    left: -40px;
    top: -3724px
}
.docs-material .docs-icon-paragraph-border-left {
    left: 0;
    top: -2100px
}
.docs-material .docs-icon-paragraph-border-right {
    left: -38px;
    top: -2206px
}
.docs-material .docs-icon-paragraph-border-top {
    left: -20px;
    top: -252px
}
.docs-material .docs-icon-diagram-white {
    left: 0;
    top: -898px
}
.docs-material .docs-icon-drive-black {
    left: -40px;
    top: -232px
}
.docs-material .docs-icon-file-upload {
    left: -26px;
    top: -3770px
}
.docs-material .docs-icon-photos {
    left: -40px;
    top: -2040px
}
.docs-material .docs-icon-keyboard {
    left: 0;
    top: -2692px
}
.docs-material .docs-icon-dogfood-white {
    left: -40px;
    top: -3538px
}
.docs-material .docs-icon-hierarchy {
    left: 0;
    top: -2814px
}
.docs-material .docs-icon-transition {
    left: -40px;
    top: -978px
}
.docs-material .docs-icon-mask {
    left: -20px;
    top: -46px
}
.docs-material .docs-icon-visibility-off {
    left: -26px;
    top: -484px
}
.docs-material .docs-icon-volume-up {
    left: -20px;
    top: -958px
}
.docs-material .docs-icon-volume-up-filled-36 {
    left: 0;
    top: -2206px
}
.docs-material .docs-icon-camera {
    left: -20px;
    top: -638px
}
.docs-material .docs-icon-pivot-table {
    left: 0;
    top: -1724px
}
.docs-material .docs-icon-insert-pivot-table {
    left: -38px;
    top: -2246px
}
.docs-material .docs-icon-avatar-anonymous-white-32 {
    left: -42px;
    top: -684px
}
.docs-material .docs-icon-code {
    left: -40px;
    top: -746px
}
.docs-material .docs-icon-play {
    left: 0;
    top: -998px
}
.docs-material .docs-icon-record {
    left: -20px;
    top: -2100px
}
.docs-material .docs-icon-flip-horizontal {
    left: -52px;
    top: -3744px
}
.docs-material .docs-icon-flip-vertical {
    left: 0;
    top: -1522px
}
.docs-material .docs-icon-rotate-cw {
    left: -20px;
    top: 0
}
.docs-material .docs-icon-database {
    left: -40px;
    top: -1808px
}
.docs-material .docs-icon-database-grey600 {
    left: -20px;
    top: -172px
}
.docs-material .docs-icon-plx {
    left: 0;
    top: -766px
}
.docs-material .docs-icon-bigquery {
    left: 0;
    top: -3020px
}
.docs-material .docs-icon-insert-dashboard {
    left: -40px;
    top: -2400px
}
.docs-material .docs-icon-filter-control {
    left: -40px;
    top: -3990px
}
.docs-material .docs-icon-drag-handle-20 {
    left: -56px;
    top: -3472px
}
.docs-material .docs-icon-comment-outline-20 {
    left: -26px;
    top: -872px
}
.docs-material .docs-icon-comment-outline-24 {
    left: -20px;
    top: -2940px
}
.docs-material .docs-icon-edit-outline-20 {
    left: -24px;
    top: -1354px
}
.docs-material .docs-icon-edit-outline-24 {
    left: 0;
    top: -4050px
}
.docs-material .docs-icon-error-outline-20 {
    left: 0;
    top: -1928px
}
.docs-material .docs-icon-settings-outline-20 {
    left: -26px;
    top: -530px
}
.docs-material .docs-icon-settings-outline-24 {
    left: -48px;
    top: -530px
}
.docs-material .docs-icon-share-outline-20 {
    left: -48px;
    top: -892px
}
.docs-material .docs-icon-share-outline-24 {
    left: -46px;
    top: -2940px
}
.docs-material .docs-icon-time-outline-20 {
    left: 0;
    top: -2244px
}
.docs-material .docs-icon-trend-outline-20 {
    left: 0;
    top: -3450px
}
.docs-material .docs-icon-accessibility {
    left: 0;
    top: -1176px
}
.docs-material .docs-icon-people-24 {
    left: 0;
    top: -3244px
}
.docs-material .docs-icon-reload-white {
    left: 0;
    top: -1684px
}
.docs-material .docs-icon-present {
    left: 0;
    top: -1096px
}
.docs-material .docs-icon-chevron-left-24 {
    left: 0;
    top: -504px
}
.docs-material .docs-icon-chevron-right-24 {
    left: 0;
    top: -3744px
}
.docs-material .docs-icon-chevron-down-24 {
    left: -40px;
    top: -4116px
}
.docs-material .docs-icon-delete-grey600-24 {
    left: 0;
    top: -530px
}
.docs-material .docs-icon-palette {
    left: -20px;
    top: -3270px
}
.docs-material .docs-icon-sheets-table-24 {
    left: -26px;
    top: -1496px
}
.docs-material .docs-icon-notifications-24 {
    left: 0;
    top: -658px
}
.docs-material .docs-icon-notifications-20 {
    left: -26px;
    top: -2286px
}
.docs-material .docs-icon-spellcheck {
    left: -20px;
    top: -2980px
}
.docs-material .docs-icon-add-item {
    left: -40px;
    top: -112px
}
.docs-material .docs-icon-info-outline-grey {
    left: -40px;
    top: -2540px
}
.docs-material .docs-icon-datasheet-24-grey800 {
    left: -26px;
    top: -4050px
}
.docs-material .docs-icon-undo-autocorrect {
    left: -38px;
    top: -2920px
}
.docs-material .docs-icon-spellbubble-feedback-16 {
    left: -20px;
    top: -2920px
}
.docs-material .docs-icon-spellbubble-ignore-16 {
    left: 0;
    top: -2374px
}
.docs-material .docs-icon-spellbubble-overflow-three-dots-16 {
    left: -58px;
    top: -1750px
}
.docs-material .docs-icon-list-24 {
    left: -20px;
    top: -1638px
}
.docs-material .docs-icon-audio {
    left: -40px;
    top: -1974px
}
.docs-material .docs-icon-drive-folder {
    left: 0;
    top: -112px
}
.docs-material .docs-icon-loading-circle-grey200 {
    left: -56px;
    top: -3478px
}
.docs-material .docs-icon-pdf {
    left: -40px;
    top: -172px
}
.docs-material .docs-icon-web {
    left: 0;
    top: -4010px
}
.docs-material .docs-icon-offline-pin-20 {
    left: -42px;
    top: -3450px
}
.docs-material .docs-icon-sync-20 {
    left: -56px;
    top: -3040px
}
.docs-material .docs-icon-sync-problem-20 {
    left: 0;
    top: -292px
}
.docs-material .docs-icon-acl-view-only {
    left: 0;
    top: -3224px
}
.docs-material .docs-icon-acl-view-only-on-brand-color-background {
    left: 0;
    top: -252px
}
.docs-material .docs-icon-acl-comment-only {
    left: -20px;
    top: -618px
}
.docs-material .docs-icon-acl-comment-only-on-brand-color-background {
    left: 0;
    top: -4030px
}
.docs-material .docs-icon-approvals-lock {
    left: -40px;
    top: -3618px
}
.docs-material .docs-icon-approvals-lock-open {
    left: -20px;
    top: -998px
}
.docs-material .docs-icon-approvals-stamp {
    left: 0;
    top: -2080px
}
.docs-material .docs-icon-recall-24 {
    left: -48px;
    top: -2286px
}
.docs-material .docs-icon-feedback {
    left: -20px;
    top: -1216px
}
.docs-material .docs-icon-offline-cloud-24 {
    left: -46px;
    top: 0
}
.docs-material .docs-icon-arrow-down {
    left: -40px;
    top: -3126px
}
.docs-material .docs-icon-arrow-up {
    left: -20px;
    top: -2420px
}
.docs-material .docs-icon-avatar-grey600 {
    left: 0;
    top: -4156px
}
.docs-material .docs-icon-description-grey600 {
    left: 0;
    top: -4216px
}
.docs-material .docs-icon-popout-below {
    left: -46px;
    top: -2966px
}
.docs-material .docs-icon-group {
    left: 0;
    top: -746px
}
.docs-material .docs-icon-revisions-grey600 {
    left: -46px;
    top: -464px
}
.docs-material .docs-icon-popout-viewer-24-white {
    left: -40px;
    top: -4288px
}
.docs-material .docs-icon-maximize-viewer {
    left: -40px;
    top: -4142px
}
.docs-material .docs-icon-maximize-viewer-24-white {
    left: -18px;
    top: -2374px
}
.docs-material .docs-icon-open-in-external-24-white {
    left: -20px;
    top: -2180px
}
.docs-material .docs-icon-copy-24-white {
    left: 0;
    top: -1496px
}
.docs-material .docs-icon-sync {
    left: -40px;
    top: -384px
}
.docs-material .docs-icon-search-insights {
    left: 0;
    top: -2580px
}
.docs-material .docs-icon-logo-docs-40px {
    left: 0;
    top: -704px
}
.docs-material .docs-icon-logo-sheets-40px {
    left: -26px;
    top: -2312px
}
.docs-material .docs-icon-logo-slides-40px {
    left: -20px;
    top: -2712px
}
.docs-material .docs-icon-text-wrapping-wrap {
    left: -40px;
    top: -132px
}
.docs-material .docs-icon-text-wrapping-break {
    left: -20px;
    top: -2834px
}
.docs-material .docs-icon-text-wrapping-inline {
    left: -20px;
    top: -2440px
}
.docs-material .docs-icon-text-wrapping-wrap-76 {
    left: 0;
    top: -1018px
}
.docs-material .docs-icon-text-wrapping-break-76 {
    left: 0;
    top: -3146px
}
.docs-material .docs-icon-text-wrapping-inline-76 {
    left: 0;
    top: -1256px
}
.docs-material .docs-icon-quick-layout-top-left-54 {
    left: 0;
    top: -3472px
}
.docs-material .docs-icon-quick-layout-top-center-54 {
    left: 0;
    top: -318px
}
.docs-material .docs-icon-quick-layout-top-right-54 {
    left: -20px;
    top: -2560px
}
.docs-material .docs-icon-quick-layout-center-left-54 {
    left: -20px;
    top: -2626px
}
.docs-material .docs-icon-quick-layout-center-54 {
    left: -20px;
    top: -806px
}
.docs-material .docs-icon-quick-layout-center-right-54 {
    left: -20px;
    top: -3638px
}
.docs-material .docs-icon-quick-layout-bottom-left-54 {
    left: -20px;
    top: -2854px
}
.docs-material .docs-icon-quick-layout-bottom-center-54 {
    left: -20px;
    top: -1684px
}
.docs-material .docs-icon-quick-layout-bottom-right-54 {
    left: 0;
    top: -3040px
}
.docs-material .docs-icon-encryption-shield {
    left: -46px;
    top: -2014px
}
.docs-material .docs-icon-cloud-check {
    left: -46px;
    top: -26px
}
.docs-material .docs-icon-sync-no-connection {
    left: -20px;
    top: -2814px
}
.docs-material .docs-icon-sync-problem-red500 {
    left: 0;
    top: -1196px
}
.docs-material .docs-icon-sync-saved-locally {
    left: 0;
    top: -1994px
}
.docs-material .docs-icon-sync-disabled {
    left: -46px;
    top: -424px
}
.docs-material .docs-icon-sync-disabled-red600 {
    left: -40px;
    top: -4248px
}
.docs-material .docs-icon-cloud-check-24 {
    left: -40px;
    top: -4162px
}
.docs-material .docs-icon-sync-no-connection-24 {
    left: -20px;
    top: -2014px
}
.docs-material .docs-icon-sync-problem-24-red500 {
    left: -44px;
    top: -2374px
}
.docs-material .docs-icon-sync-saved-locally-24 {
    left: -26px;
    top: -658px
}
.docs-material .docs-icon-sync-disabled-24 {
    left: -26px;
    top: -3224px
}
.docs-material .docs-icon-sync-disabled-24-red600 {
    left: -52px;
    top: -4050px
}
.docs-gm .docs-circle-promo-base {
    height: 210px;
    width: 210px;
    background-color: #188038!important;
    border-color: #188038!important
}
.docs-circle-promo-base {
    border-style: solid;
    border-width: 400px;
    border-radius: 800px;
    font-size: 16px;
    height: 136px;
    position: absolute;
    width: 136px;
    z-index: 9000
}
.docs-gm .docs-circle-promo-content {
    color: white;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px;
    line-height: 22px;
    margin-left: 80px;
    position: relative;
    width: 350px
}
.docs-circle-promo-content {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    width: 280px
}
.docs-gm .docs-circle-promo-header {
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 20px;
    font-size: var(--docs-material-font-size-22, 20px)
}
.docs-circle-promo-header {
    font-size: 20px;
    line-height: 27px;
    margin-bottom: 16px
}
.docs-circle-promo-buttons {
    margin-top: 16px
}
.docs-circle-promo-button {
    cursor: pointer;
    font-size: 14px;
    font-weight: 500;
    text-transform: uppercase
}
.docs-circle-promo-button:hover,
.docs-circle-promo-button:focus {
    opacity: 0.87
}
.docs-circle-promo-continue-button {
    margin-right: 20px
}
.docs-material-promo-walkthrough-bubble {
    background-color: #fff;
    border: 1px solid transparent;
    border-radius: 8px;
    box-shadow: 0 4px 8px 3px rgba(60, 64, 67, .15);
    position: absolute;
    z-index: 1003
}
.docs-material-promo-walkthrough-bubble:focus {
    outline: none
}
.docs-material-promo-walkthrough-bubble .jfk-bubble-content {
    min-width: 312px;
    padding: 0px 24px 24px
}
.docs-material-promo-walkthrough-bubble-buttons {
    display: flex;
    justify-content: flex-end;
    padding: 24px
}
.docs-material-promo-walkthrough-bubble .docs-material-button-fill-primary.docs-material-button {
    margin-left: 12px;
    text-transform: none
}
.docs-material-promo-walkthrough-bubble-close-button {
    background-color: transparent;
    border: none;
    border-radius: 50%;
    cursor: pointer;
    margin: 0px;
    outline: 0;
    padding: 7px;
    position: absolute;
    right: 8px;
    top: 8px
}
.docs-material-promo-walkthrough-bubble-close-button.goog-flat-button-hover {
    background-color: #f1f3f4
}
.docs-material-promo-walkthrough-bubble-close-button.goog-flat-button-focused {
    background-color: #e8eaed;
    outline: none
}
.docs-material-promo-walkthrough-bubble .jfk-bubble-arrowdown .jfk-bubble-arrowimplbefore,
.docs-material-promo-walkthrough-bubble .jfk-bubble-arrowup .jfk-bubble-arrowimplbefore {
    border-color: rgba(60, 64, 67, 0.1) transparent
}
.docs-material-promo-walkthrough-bubble .jfk-bubble-arrowleft .jfk-bubble-arrowimplbefore,
.docs-material-promo-walkthrough-bubble .jfk-bubble-arrowright .jfk-bubble-arrowimplbefore {
    border-color: transparent rgba(60, 64, 67, 0.1)
}
.docs-binaryupsavewarning {
    width: 512px
}
.docs-binaryupsavewarning-content-text {
    color: #5f6368;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px
}
a.docs-binaryupsavewarning-learn-more,
a.docs-binaryupsavewarning-learn-more:visited {
    align-self: center;
    color: #188038;
    font-family: var(--docs-material-header-font-family, Roboto, RobotoDraft, Helvetica, Arial, sans-serif);
    font-size: 14px;
    font-weight: var(--docs-material-font-weight-bold, 700);
    margin-right: auto
}
.office-editing-feedback {
    background-color: #e0ffff;
    height: 24px;
    padding-left: 4px
}
.office-editing-feedback-editor-header {
    left: 0;
    margin: 0 auto;
    position: absolute;
    right: 0;
    top: 0;
    width: 252px
}
.office-editing-feedback-warning-dialogs {
    bottom: 0;
    margin-left: 20px;
    padding-right: 4px;
    position: absolute
}
.office-editing-feedback-title {
    float: left;
    height: 24px;
    line-height: 24px
}
.office-editing-feedback-title-separator {
    height: 24px;
    line-height: 24px;
    margin: 0 4px
}
.office-editing-feedback-close-button {
    float: right;
    cursor: pointer;
    margin: 0 0 0 8px
}
.office-editing-survey-feedback {
    background-color: #188038;
    border-radius: 4px;
    color: #fff;
    display: inline-block;
    height: 40px;
    left: 0;
    margin: 0 auto;
    position: absolute;
    right: 0;
    top: 16px;
    width: 348px;
    z-index: 1
}
.office-editing-survey-feedback-title {
    float: left;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    line-height: 40px;
    padding: 0 32px 0 24px
}
.office-editing-survey-feedback-take-survey-button {
    color: #fff;
    cursor: pointer;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 40px;
    line-height: 40px
}
.office-editing-survey-feedback-close-button {
    cursor: pointer;
    float: right;
    height: 40px;
    line-height: 40px;
    margin-right: 12px;
    opacity: 0.5
}
.docs-unsupportedofficefeatureswarning {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    width: 512px
}
.docs-unsupportedofficefeatureswarning-content-restorefiletext {
    border-bottom: 1px solid #bdc1c6;
    color: #5f6368;
    font-size: 16px;
    line-height: 24px;
    margin-bottom: 23px;
    margin-top: -8px;
    padding-bottom: 16px
}
.docs-unsupportedofficefeatureswarning-content-features-list {

    font-size: 14px;
    max-height: 128px;
    overflow-y: auto
}
.docs-unsupportedofficefeatureswarning-content-feature {
    color: #3c4043;
    margin-bottom: 12px
}
a.docs-unsupportedofficefeatureswarning-learn-more,
a.docs-unsupportedofficefeatureswarning-learn-more:visited {
    align-self: center;
    color: #188038;
    font-family: var(--docs-material-header-font-family, Roboto, RobotoDraft, Helvetica, Arial, sans-serif);
    font-size: 14px;
    font-weight: var(--docs-material-font-weight-bold, 700);
    margin-right: auto
}
.docs-image-picker-upload {
    font-family: Roboto, Arial, sans-serif
}
.docs-image-picker-upload.modal-dialog {
    padding: 0
}
.docs-image-picker-upload .modal-dialog-title {
    padding: 17px 20px 0
}
.docs-image-picker-upload .modal-dialog-title-text {
    font-size: 20px
}
.docs-image-picker-upload .modal-dialog-content {
    line-height: normal;
    padding: 0 20px
}
.docs-image-picker-upload .modal-dialog-buttons {
    border-top: 1px solid #e5e5e5;
    margin-top: 20px;
    padding: 17px 20px
}
.docs-image-picker-upload-container {
    min-height: 300px;
    min-width: 450px
}
.docs-image-picker-upload-msg-bar {
    color: #ccc;
    font-size: 16px;
    font-style: italic;
    padding: 0 0 10px
}
.docs-image-picker-upload-dropzone-parent {
    height: 100%;
    width: 100%
}
.docs-image-picker-upload-dropzone-cell {
    border: #ddd 4px dashed;
    border-radius: 2px;
    height: 100%
}
.docs-image-picker-upload-dropzone-cell .jfk-button {
    margin: 0
}
.docs-image-picker-upload-dropzone {
    height: 100%;
    text-align: center;
    width: 100%
}
.docs-image-picker-upload-drop-here {
    color: #ccc;
    font-size: 20pt;
    padding: 0 10px
}
.docs-image-picker-upload-drop-alt {
    color: #ccc;
    font-size: 13px;
    font-weight: 500;
    padding: 15px 0 5px
}
.docs-image-picker-upload-warning {
    color: #aaa;
    display: inline-block;
    font-size: 13px;
    padding: 0 20px 0 30px;
    vertical-align: middle
}
.pub-dialog-disabled-text {
    color: #afafaf
}
.pub-dialog-wrap {
    font-size: 13px;
    font-size: var(--docs-material-font-size-normal, 13px);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    width: 500px
}
.pub-dialog-content-div {
    padding: 0 0 10px 30px
}
.pub-dialog-input-div {
    padding-bottom: 15px
}
.pub-dialog-option-vspacer {
    height: 5px
}
.pub-dialog-info {
    color: #999;
    font-size: 11px;
    padding-bottom: 2px
}
.docs-gm-dialogs .pub-dialog-info {
    color: #80868b
}
.docs-gm-dialogs .pub-dialog-state-published.pub-dialog-info {
    color: #1a73e8
}
.pub-dialog-tab {
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.goog-tab-bar.pub-dialog-tab-bar {
    background: none;
    border-bottom-color: silver!important;
    margin-top: 20px;
    padding-left: 0!important
}
.docs-gm-dialogs .goog-tab-bar.pub-dialog-tab-bar {
    margin-top: 21px;
    padding-top: 0
}
.goog-tab-bar.pub-dialog-tab-bar .goog-tab.pub-dialog-tab {
    color: #bdbdbd;
    cursor: pointer;
    font-weight: 500;
    margin: 1px 15px 0 0;
    padding: 4px 8px;
    text-decoration: none;
    top: 1px
}
.docs-gm-dialogs .goog-tab-bar.pub-dialog-tab-bar .goog-tab.pub-dialog-tab {
    color: #5f6368;
    font-size: 14px;
    text-align: center;
    width: 120px
}
.goog-tab-bar.pub-dialog-tab-bar .goog-tab.pub-dialog-tab.goog-tab-selected,
.goog-tab-bar.pub-dialog-tab-bar .goog-tab.pub-dialog-tab.goog-tab-hover {
    background: none;
    border-bottom: 3px solid #4d90fe;
    border-left: none;
    border-right: none;
    border-top: none;
    color: black
}
.docs-gm-dialogs .goog-tab-bar.pub-dialog-tab-bar .goog-tab.pub-dialog-tab.goog-tab-selected,
.docs-gm-dialogs .goog-tab-bar.pub-dialog-tab-bar .goog-tab.pub-dialog-tab.goog-tab-hover {
    border-bottom: 2px solid #1a73e8
}
.pub-dialog-document-link,
.pub-dialog-embed-code {
    margin-top: 20px;
    width: 100%;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box
}
.pub-dialog-link-content-div {
    margin-top: 10px
}
.docs-gm-dialogs .pub-dialog-link-options-container {
    display: flex
}
.pub-dialog-embed-code {
    font-size: 13px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    height: 65px
}
.docs-gm-dialogs .pub-dialog-embed-code {
    height: 82px!important
}
.docs-gm-dialogs .pub-dialog-link-options-document-part-menu-button {
    margin-right: 15px
}
.pub-dialog-sep-div {
    padding: 20px 0
}
#pub-dialog-publish-link-button {
    margin-top: 20px
}
.pub-dialog-sep {
    border-top-color: #e1e1e1;
    border-top-style: solid;
    border-width: 1px 0 0 0;
    color: #bfbfbf;
    height: 0
}
.goog-zippy-header.pub-dialog-zippy-header {
    cursor: pointer;
    display: inline-block;
    margin: 0
}
.docs-gm-dialogs .goog-zippy-header.pub-dialog-zippy-header {
    color: #3c4043
}
.pub-dialog-zippy-content {
    margin-left: 22px
}
.docs-gm-dialogs #pub-dialog-publish-button {
    color: #5f6368
}
.goog-zippy-collapsed .pub-dialog-settings-zippy-icon {
    -webkit-transform: rotate(0);
    -moz-transform: rotate(0);
    -ms-transform: rotate(0);
    -o-transform: rotate(0);
    transform: rotate(0)
}
.goog-zippy-expanded .pub-dialog-settings-zippy-icon {
    -webkit-transform: rotate(90deg);
    -moz-transform: rotate(90deg);
    -ms-transform: rotate(90deg);
    -o-transform: rotate(90deg);
    transform: rotate(90deg)
}
#pub-dialog-publish-button {
    margin-top: 10px
}
.pub-dialog-checkbox-container {
    line-height: 22px;
    margin-top: 10px
}
.docs-link-infilelinksuggestiongroup-cb .docs-link-infilelinksuggestiongroup-cb-openarrow {
    display: none
}
.docs-link-infilelinksuggestiongroup-cb.docs-link-infilelinksuggestiongroup-cb-open .docs-link-infilelinksuggestiongroup-cb-openarrow {
    display: inline-block
}
.docs-link-infilelinksuggestiongroup-cb.docs-link-infilelinksuggestiongroup-cb-closearrow {
    display: inline-block
}
.docs-link-infilelinksuggestiongroup-cb.docs-link-infilelinksuggestiongroup-cb-open .docs-link-infilelinksuggestiongroup-cb-closearrow {
    display: none
}
.docs-link-infilelinksuggestiongroup-cb .docs-icon {
    margin: 0 6px
}
.docs-link-infilelinksuggestiongroup-cb-title {
    display: inline-block;
    padding: 8px 0
}
.docs-link-infilelinksuggestiongroup-cb {
    margin: 6px 0;
    outline: none
}
.docs-link-infilelinksuggestiongroup-cb:hover,
.docs-link-infilelinksuggestiongroup-cb-keyboardfocus {
    background-color: #eee;
    cursor: default;
    outline: none
}
.goog-zippy-content .docs-link-linksuggestion {
    padding-left: 27px
}
.docs-linkbubble-link-preview .docs-link-bubble-mime-icon .docs-icon {
    vertical-align: baseline;
    width: 18px;
    height: 18px;
    margin: 0px
}
.docs-linkbubble-link-preview #docs-linkbubble-link-text {
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    opacity: 1;
    padding-left: 6px;
    padding-right: 6px;
    text-decoration: none!important;
    transition: all .15s;
    vertical-align: baseline;
    width: 180px
}
.docs-linkbubble-link-preview .link-previews-broken-link#docs-linkbubble-link-text {
    color: #80868b!important;
    cursor: default;
    font-style: italic;
    pointer-events: none
}
.docs-linkbubble-link-preview .link-previews-before-transition#docs-linkbubble-link-text {
    opacity: .5
}
.docs-linkbubble-link-preview.docs-linkbubble-bubble {
    padding: 6px;
    border: 0px
}
.docs-linkbubble-link-preview .link-bubble-header {
    display: flex;
    align-items: center
}
.docs-gm-dialogs .docs-linkbubble-bubble {
    background-color: #fff;
    border-color: #dadce0;
    border-radius: 8px;
    box-shadow: 0 4px 8px 3px rgba(60, 64, 67, .15);
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px
}
.docs-linkbubble-link-preview .docs-link-bubble-mime-icon {
    height: 18px;
    padding: 6px;
    vertical-align: baseline;
    width: 18px;
    opacity: 1;
    transition: all .15s
}
.docs-linkbubble-link-preview .docs-link-bubble-mime-icon.link-previews-before-transition {
    opacity: .5
}
.docs-linkbubble-link-preview .docs-link-bubble-mime-icon.link-previews-animate-icon {
    animation: fade .15s
}
@keyframes fade {
    from {
        opacity: .5
    }
}
.docs-linkbubble-link-preview .docs-link-bubble-card-component .docs-link-bubble-mime-icon {
    padding: 0px
}
.docs-linkbubble-link-preview .docs-link-bubble-card-component {
    align-items: center;
    display: flex;
    padding: 6px
}
.linkbubble-card-collapsed .docs-link-bubble-card-component {
    display: none!important
}
.linkbubble-card-collapsed .docs-link-bubble-card-component.linkbubble-card-non-collapsible {
    display: flex
}
.docs-linkbubble-link-preview .docs-link-bubble-title-card-component a {
    color: #202124!important;
    flex-grow: 1;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    height: 18px;
    overflow: hidden;
    padding-left: 12px;
    text-overflow: ellipsis;
    white-space: nowrap;
    width: 0
}
.docs-linkbubble-link-preview .docs-link-bubble-title-card-component a:hover {
    text-decoration: none!important
}
.docs-linkbubble-link-preview .docs-link-bubble-text-card-component span {
    color: #80868b!important;
    cursor: text;
    flex-direction: column;
    flex-grow: 1;
    font-size: 12px;
    justify-content: center;
    line-height: 1.3;
    overflow-wrap: break-word;
    white-space: normal;
    width: 0;
    word-wrap: break-word
}
.docs-linkbubble-link-preview .docs-link-bubble-thumbnail-container {
    background-color: #e8eaed;
    border-radius: 4px;
    display: flex;
    flex-grow: 1;
    height: 141px;
    overflow: hidden;
    width: 0
}
.docs-linkbubble-link-preview .docs-link-bubble-thumbnail-container a {
    display: flex;
    flex-direction: column;
    flex-grow: 1;
    justify-content: center;
    align-items: center
}
.docs-linkbubble-link-preview .drive-image-thumbnail-component .docs-link-bubble-thumbnail-container a {
    display: block!important
}
.drive-image-thumbnail-component .docs-link-bubble-thumbnail-container {
    border: 1px solid #e8eaed
}
#link-bubble-thumbnail-image {
    background-position: center;
    background-repeat: no-repeat;
    height: 100%;
    width: 100%
}
.default-image-card-component #link-bubble-thumbnail-image,
.vertical-image-card-component #link-bubble-thumbnail-image {
    background-size: contain
}
.horizontal-image-card-component #link-bubble-thumbnail-image {
    background-size: cover
}
.vertical-image-card-component img.link-bubble-drive-thumbnail-image {
    display: block;
    height: 100%;
    margin: auto
}
.default-image-card-component img.link-bubble-drive-thumbnail-image,
.horizontal-image-card-component img.link-bubble-drive-thumbnail-image {
    width: 100%
}
.docs-link-bubble-high-contrast .docs-link-bubble-thumbnail-container a {
    height: 120%;
    transform: translateY(-10%)
}
#high-contrast-link-bubble-thumbnail-image {
    height: 100%
}
.framed-image-card-component img.link-bubble-drive-thumbnail-image {
    box-shadow: 0 0 6px 0 rgba(0, 0, 0, 0.12);
    margin: 6% 7% 0 7%;
    width: 86%
}
.docs-linkbubble-link-preview .docs-link-bubble-text-card-component .docs-link-bubble-text-with-icon {
    padding-left: 12px
}
.docs-linkbubble-link-preview .docs-link-bubble-text-card-component.indented-card-component .text-card-component-text {
    padding-left: 30px
}
.docs-linkbubble-link-preview .docs-link-bubble-card-component.shrink-vertical-padding-card-component {
    padding-top: 0px
}
.docs-linkbubble-link-preview .docs-link-bubble-text-card-component.single-line-text-card-component .text-card-component-text {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.docs-linkbubble-link-preview .docs-link-bubble-separator {
    background-color: #e8eaed;
    height: 1px;
    margin: 6px
}
.docs-linkbubble-link-preview.docs-hc-gecko,
.docs-linkbubble-link-preview.docs-hc-ie {
    border: 1px solid transparent
}
.docs-hc-gecko .docs-link-bubble-separator,
.docs-hc-ie .docs-link-bubble-separator {
    height: 0px;
    border: 1px solid transparent
}
.docs-link-bubble-action-container .goog-menuitem {
    white-space: nowrap
}
.docs-linkbubble-bubble .goog-menu .goog-option-selected {
    background-position: 8px 50%
}
.docs-link-bubble-request-access-card-component.docs-link-bubble-card-component {
    display: flex;
    flex-direction: column
}
.docs-link-bubble-request-access-card-component .request-access-button {
    display: flex;
    padding-top: 6px;
    width: 100%
}
.docs-link-bubble-request-access-card-component .request-access-button .request-access-button-container {
    align-items: center;
    display: flex;
    flex-grow: 1;
    justify-content: flex-end;
    white-space: normal;
    word-break: break-word;
    width: 0
}
.docs-link-bubble-request-access-card-component .request-access-button .request-access-info-icon {
    display: flex;
    padding: 4px
}
.docs-link-bubble-request-access-card-component .request-access-button .request-access-info-icon:hover {
    background-color: rgba(0, 0, 0, .06);
    border-radius: 50%
}
.docs-link-bubble-request-access-card-component .request-access-header {
    display: flex;
    justify-content: flex-start;
    width: 100%
}
.docs-link-bubble-request-access-card-component .request-access-header span {
    color: #80868b;
    display: flex;
    flex-grow: 1;
    font-size: 12px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    white-space: normal;
    width: 0
}
.docs-link-bubble-request-access-card-component .requested-access-text {
    display: flex;
    width: 100%
}
.docs-link-bubble-request-access-card-component .requested-access-text span {
    color: #80868b;
    display: flex;
    flex-grow: 1;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-style: italic;
    justify-content: flex-end;
    padding-top: 6px;
    white-space: normal;
    width: 0
}
.docs-link-bubble-request-access-card-component .request-access-button-text {
    color: #188038;
    cursor: pointer;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    margin-left: 4px;
    padding: 4px 8px
}
.docs-link-bubble-request-access-card-component .request-access-button-text:hover {
    background-color: #e6f4ea;
    border-radius: 4px
}
.jfk-bubble.docs-promo-bubble {
    background-color: #1a73e8;
    border-radius: 8px
}
.jfk-bubble.jfk-bubble-promo.docs-promo-bubble.docs-link-previews-details-promo .jfk-bubble-arrowleft .jfk-bubble-arrowimplafter,
.jfk-bubble.jfk-bubble-promo.docs-promo-bubble.docs-link-previews-details-promo .jfk-bubble-arrowright .jfk-bubble-arrowimplafter {
    border-color: transparent #1a73e8
}
.docs-link-previews-details-promo .docs-promo-text-container {
    width: auto
}
.docs-link-previews-details-promo .docs-promo-body {
    color: #f1f3f4;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 400;
    letter-spacing: .2px;
    padding: 4px 0
}
.docs-link-previews-details-promo .docs-promo-action-container {
    color: #fff;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    margin: 12px 0 0 20px;
    text-transform: none
}
.docs-link-previews-details-promo .docs-promo-header {
    color: #fff;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px;
    font-weight: 500;
    opacity: 1
}
.docs-link-previews-details-promo .docs-promo-action-row {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row-reverse;
    -webkit-flex-direction: row-reverse;
    flex-direction: row-reverse;
    padding: 0
}
.docs-link-previews-details-promo .docs-promo-container {
    padding: 16px
}
.docs-link-previews-details-promo.docs-promo-bubble {
    -webkit-box-shadow: 0px 2px 6px 2px rgba(26, 115, 232, 0.15);
    -moz-box-shadow: 0px 2px 6px 2px rgba(26, 115, 232, 0.15);
    box-shadow: 0px 2px 6px 2px rgba(26, 115, 232, 0.15);
    background-color: #1a73e8;
    border-radius: 8px;
    width: 251px
}
.docs-link-insertlinkbubble {
    margin: -1px;
    min-width: 306px;
    outline: none;
    padding: 1px
}
.docs-gm-dialogs .docs-link-insertlinkbubble ::selection {
    background: #d2e3fc
}
.docs-link-insertlinkbubble-url-label,
.docs-link-insertlinkbubble-text-label {
    display: block;
    height: 13px;
    padding: 8px 0
}
.docs-link-insertlinkbubble-text {
    display: block;
    width: 244px
}
.docs-gm-dialogs .docs-link-insertlinkbubble-text {
    border-color: #dadce0;
    border-radius: 4px;
    color: #5f6368;
    font-size: 14px;
    height: 32px;
    margin: 0;
    width: 294px
}
.docs-gm-dialogs .docs-link-insertlinkbubble-text:focus {
    border: 2px solid #1a73e8;
    box-shadow: none;
    color: #3c4043;
    padding: 0 7px
}
.docs-link-insertlinkbubble-text-label,
.docs-link-insertlinkbubble-text {
    margin-bottom: 5px
}
.docs-gm-dialogs .docs-link-insertlinkbubble-url-label,
.docs-gm-dialogs .docs-link-insertlinkbubble-text-label {
    background-color: white;
    box-shadow: 5px 0 0 white, -5px 0 0 white;
    color: #5f6368;
    display: inline;
    font-size: 12px;
    left: 12px;
    margin-bottom: 0;
    max-width: 300px;
    padding: 0;
    position: absolute;
    top: -8px;
    word-wrap: break-word
}
.docs-link-insertlinkbubble-urlholder {
    float: left;
    outline: none
}
.docs-link-insertlinkbubble-suggestionholder {
    background-color: white;
    border: 1px solid #e5e5e5;
    border-top: none;
    -webkit-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0 2px 4px rgba(0, 0, 0, .2);
    box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
    max-height: 207px;
    overflow-x: hidden;
    outline: none;
    position: absolute;
    width: 260px;
    z-index: 1
}
.docs-gm-dialogs .docs-link-insertlinkbubble-suggestionholder {
    border-radius: 4px;
    color: #3c4043;
    margin: 1px 0px;
    width: 310px
}
.docs-link-insertlinkbubble-linkchip {
    width: 312px
}
.docs-link-insertlinkbubble-buttonbar .jfk-button {
    margin-right: 0
}
.docs-gm-dialogs .docs-link-insertlinkbubble-buttonbar .jfk-button {
    margin-left: 12px;
    min-width: 87px;
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff
}
.docs-gm-dialogs .docs-link-insertlinkbubble-buttonbar .jfk-button-action.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #2a8947;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-dialogs .docs-link-insertlinkbubble-buttonbar .jfk-button-action.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #4f9e67;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-dialogs .docs-link-insertlinkbubble-buttonbar .jfk-button-action.jfk-button-hover.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-dialogs .docs-link-insertlinkbubble-buttonbar .jfk-button-action.jfk-button-disabled {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #f1f3f4;
    color: #3c4043;
    opacity: 0.38
}
.docs-link-insertlinkbubble-error {
    color: #c5221f;
    padding: 12px 0 0 0
}
@media print {
    .docs-link-insertlinkbubble {
        display: none!important
    }
}
.jfk-bubble.docs-calloutbubble-bubble.docs-linkbubble-bubble {
    z-index: 503!important
}
.docs-gm-dialogs .docs-link-insertlinkbubble-toppane,
.docs-gm-dialogs .docs-link-insertlinkbubble-bottompane {
    margin: 24px
}
.docs-gm-dialogs .docs-link-insertlinkbubble-bottompane {
    display: flex
}
.docs-gm-dialogs .docs-link-insertlinkbubble-toppane,
.docs-gm-dialogs .docs-link-insertlinkbubble-urlcomponent {
    position: relative
}
.docs-link-linksuggestion:last-child {
    margin-bottom: 6px
}
.docs-link-linksuggestion:first-child {
    margin-top: 6px
}
.docs-link-linksuggestion,
.docs-link-chipselectedlinksuggestion {
    border: none;
    border-collapse: separate;
    border-spacing: 0 6px;
    display: table;
    font-size: 90%;
    height: 26px;
    max-height: 26px;
    outline: none;
    width: 100%
}
.docs-link-linksuggestion:hover,
.docs-link-linksuggestion:focus {
    background-color: #eee
}
.docs-link-linksuggestion-icon {
    display: table-cell;
    height: 21px;
    padding: 0 6px;
    vertical-align: middle;
    width: 21px
}
.docs-link-linksuggestion-url,
.docs-link-linksuggestion-title {
    cursor: default;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    width: 190px
}
.docs-link-linksuggestion-title:last-child {
    margin-top: 2px
}
.docs-link-linksuggestion-url {
    color: #093;
    font-size: 11px
}
.docs-link-linksuggestiongroup {
    border-color: #efefef;
    border-style: solid;
    border-width: 0 0 1px
}
.docs-link-linksuggestion-testlink,
.docs-link-chipselectedlinksuggestion-hide {
    display: table-cell;
    height: 21px;
    vertical-align: middle;
    width: 21px
}
.docs-link-linksuggestion-testlink {
    opacity: 0
}
.docs-link-chipselectedlinksuggestion-hide {
    opacity: 0.7
}
.docs-link-chipselectedlinksuggestion-hide:hover {
    opacity: 1
}
.docs-link-linksuggestion:hover .docs-link-linksuggestion-testlink,
.docs-link-linksuggestion:focus .docs-link-linksuggestion-testlink,
.docs-link-linksuggestion-testlink:focus {
    opacity: 1
}
.docs-link-linksuggestion-text {
    display: table-cell
}
.docs-link-linksuggestion-link-text {
    font-size: 90%
}
.docs-link-linksuggestion-action-text {
    font-size: 100%
}
.docs-link-linksuggestion.docs-link-chipselectedlinksuggestion {
    background-color: #fff;
    border-spacing: 0 4px;
    margin: 0
}
.docs-link-linksuggestioncontentbox-statusmessage {
    color: #222;
    margin-left: 33px;
    padding: 5px 0
}
.docs-link-linksuggestioncontentbox-explore {
    color: #333;
    font-size: 90%;
    margin: 6px 0;
    padding: 6px
}
.docs-link-linksuggestioncontentbox-explore:hover,
.docs-link-linksuggestioncontentbox-explore:focus {
    background-color: #eee;
    cursor: default;
    outline: none
}
.docs-link-linksuggestioncontentbox-exploretext {
    display: inline-block;
    overflow: hidden;
    padding-left: 5px;
    text-overflow: ellipsis;
    vertical-align: middle;
    white-space: nowrap;
    width: 196px
}
.docs-link-linksuggestioncontentbox-statusbar {
    border-bottom: 1px solid #f5f5f5;
    padding: 10px 0;
    position: relative
}
.docs-link-linksuggestioncontentbox-statusindicator {
    bottom: 12px;
    float: left;
    left: 17px;
    position: relative
}
.docs-link-linksuggestioncontentbox-offlinenotice {
    font-style: italic;
    margin-left: 5px;
    padding: 5px 0
}
.docs-link-urlinput-url {
    background: transparent!important;
    border: none!important;
    box-sizing: border-box;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    display: inline-block;
    flex-grow: 1;
    height: 27px;
    margin: 0;
    outline: none!important;
    padding: 1px 8px!important
}
.docs-gm-dialogs .docs-link-urlinput-url {
    border-color: #dadce0;
    border-radius: 4px;
    color: #5f6368;
    display: block;
    font-size: 14px;
    height: 34px;
    width: 312px
}
.docs-gm-dialogs .docs-link-urlinput-url:focus {
    height: 32px;
    padding: 0px 7px!important
}
.docs-gm-dialogs .docs-link-urlinput-url::placeholder {
    color: #9aa0a6
}
.docs-link-urlinput-action-icon-container {
    float: right;
    overflow: hidden;
    padding: 0 0 0 8px;
    text-align: right;
    width: 21px
}
.docs-link-urlinput-action-icon {
    background: transparent!important;
    border: transparent!important;
    cursor: pointer;
    margin: 0 0 0 -13px;
    opacity: .70;
    white-space: nowrap
}
.docs-link-urlinput-action-icon:hover,
.docs-link-urlinput-action-icon:focus {
    opacity: 0.9
}
.docs-link-urlinput-url-container {
    background: #fff;
    border: 1px solid #d9d9d9;
    border-top: 1px solid #c0c0c0;
    min-width: 20px;
    width: 260px;
    display: flex
}
.docs-gm-dialogs .docs-link-urlinput-url-container {
    border-color: #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    width: 312px
}
.docs-link-urlinput-url-container-focus {
    border: 1px solid #4d90fe!important;
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    outline: none
}
.docs-gm-dialogs .docs-link-urlinput-url-container-focus {
    border: 2px solid #4d90fe!important;
    box-shadow: none;
    color: #3c4043;
    padding: 0
}
.docs-link-urlinput-url-error,
.docs-link-urlinput-url-error:focus {
    border-color: #dd4b39
}
.picker-frame {
    width: 100%;
    height: 100%;
    border: 0;
    overflow: hidden
}
.picker.modal-dialog-bg {
    position: absolute;
    top: 0;
    left: 0;
    background-color: #fff
}
.picker.modal-dialog {
    position: absolute;
    top: 0;
    left: 0;
    background-color: #fff;
    border: 1px solid #acacac;
    width: auto;
    padding: 0;
    z-index: 1001;
    overflow: auto;
    -moz-box-shadow: rgba(0, 0, 0, .2) 0 4px 16px;
    -webkit-box-shadow: rgba(0, 0, 0, .2) 0 4px 16px;
    box-shadow: rgba(0, 0, 0, .2) 0 4px 16px;
    -webkit-transition: top .5s ease-in-out;
    -moz-transition: top .5s ease-in-out;
    -o-transition: top .5s ease-in-out;
    transition: top .5s ease-in-out
}
.picker-min {
    position: absolute;
    z-index: 1002
}
.picker.modal-dialog-content {
    font-size: 0;
    padding: 0
}
.picker.modal-dialog-title {
    height: 0;
    margin: 0
}
.picker.modal-dialog-title-text {
    display: none
}
.picker.modal-dialog-buttons {
    display: none
}
.picker.modal-dialog {
    z-index: 1201
}
div.docs-spell-content-box {
    overflow: auto;
    width: 425px;
    height: 130px;
    background-color: #e6e6e6;
    border: none;
    padding: 5px;
    cursor: default
}
.docs-spell-content-message {
    color: #666
}
.docs-spell-error {
    border-bottom: 1px solid red;
    cursor: pointer
}
.docs-spell-error-fixed {
    border-bottom: 1px dotted green;
    cursor: pointer
}
.docs-spell-button-set {
    width: 435px;
    height: 30px;
    margin: 20px 0 0 0
}
div.docs-spell-buttons-left {
    float: left
}
div.docs-spell-buttons-right {
    float: right
}
div.docs-spell-right-button {
    margin-right: 0
}
.docs-spell-content-box::-webkit-scrollbar-thumb {
    border: solid #e6e6e6
}
#docs-spellcheckslidingdialog-button-change-menu {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: #4d90fe;
    background-image: -webkit-linear-gradient(top, #4d90fe, #4787ed);
    background-image: -moz-linear-gradient(top, #4d90fe, #4787ed);
    background-image: -ms-linear-gradient(top, #4d90fe, #4787ed);
    background-image: -o-linear-gradient(top, #4d90fe, #4787ed);
    background-image: linear-gradient(top, #4d90fe, #4787ed);
    border: 1px solid #3079ed;
    color: #fff
}
#docs-spellcheckslidingdialog-button-change-menu:hover {
    background-color: #357ae8;
    background-color: #357ae8;
    background-image: -webkit-linear-gradient(top, #4d90fe, #357ae8);
    background-image: -moz-linear-gradient(top, #4d90fe, #357ae8);
    background-image: -ms-linear-gradient(top, #4d90fe, #357ae8);
    background-image: -o-linear-gradient(top, #4d90fe, #357ae8);
    background-image: linear-gradient(top, #4d90fe, #357ae8);
    border: 1px solid #2f5bb7;
    border-bottom-color: #2f5bb7
}
#docs-spellcheckslidingdialog-button-change-menu.goog-flat-menu-button-focused {
    -webkit-box-shadow: inset 0 0 0 1px #fff;
    -moz-box-shadow: inset 0 0 0 1px #fff;
    box-shadow: inset 0 0 0 1px #fff;
    border: 1px solid #fff;
    border: rgba(0, 0, 0, 0) solid 1px;
    outline: 1px solid #4d90fe;
    outline: rgba(0, 0, 0, 0) 0
}
#docs-spellcheckslidingdialog-button-change-menu .goog-flat-menu-button-dropdown {
    border-color: white transparent;
    color: white
}
#docs-spellcheckslidingdialog-button-change-menu.goog-flat-menu-button-open {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    background: #357ae8;
    border: 1px solid #2f5bb7;
    border-top: 1px solid #2f5bb7
}
#docs-spellcheckslidingdialog-button-change-menu.goog-flat-menu-button-disabled {
    background: #4d90fe;
    filter: alpha(opacity=50);
    opacity: 0.5
}
#docs-spellcheckslidingdialog-button-ignore-all {
    margin-left: 10px
}
.docs-spellcheckslidingdialog-buttons-white-menu.goog-flat-menu-button-disabled,
.docs-spellcheckslidingdialog-buttons-white-menu.goog-flat-menu-button-disabled:hover {
    background: #fff;
    border: 1px solid #dcdcdc!important;
    filter: alpha(opacity=50);
    opacity: 0.5
}
.docs-spellcheckslidingdialog-buttons-white-menu.goog-flat-menu-button-focus,
.docs-spellcheckslidingdialog-buttons-white-menu:hover {
    border: 1px solid #c6c6c6
}
.docs-spellcheckslidingdialog-buttons-white-menu:focus {
    z-index: 2
}
#docs-spellcheckslidingdialog-button-ignore,
#docs-spellcheckslidingdialog-button-ignore-menu {
    margin-bottom: 1px
}
#docs-spellcheckslidingdialog-button-dictionary,
#docs-spellcheckslidingdialog-button-dictionary-menu {
    margin-top: 7px
}
.docs-spellcheckslidingdialog-buttons-action {
    margin-left: 9px;
    overflow: hidden;
    text-overflow: ellipsis;
    width: 110px
}
.docs-spellcheckslidingdialog-count {
    color: #6a6a6a;
    padding-left: 4px
}
.goog-menuitem-disabled .docs-spellcheckslidingdialog-count {
    color: #ccc
}
#docs-spellcheckslidingdialog-id .docs-slidingdialog-close-container {
    position: absolute;
    right: 14px;
    top: 10px
}
#docs-spellcheckslidingdialog-ignore-buttons {
    padding-top: 7px;
    vertical-align: top
}
.docs-spellcheckslidingdialog-replacement-input,
.docs-spellcheckslidingdialog-replacement-input:focus {
    background: transparent;
    border: none;
    box-shadow: none;
    font-size: 13px;
    height: 25px;
    margin: 0;
    outline: none;
    padding: 1px 0px;
    width: 100%
}
.docs-spellcheckslidingdialog-replacement-input-container {
    background: #fff;
    border: 1px solid #d9d9d9;
    border-top: 1px solid #c0c0c0;
    min-width: 20px;
    padding: 0 8px
}
.docs-spellcheckslidingdialog-replacement-input-container-focus {
    border: 1px solid #4d90fe;
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    outline: none
}
.docs-spellcheckslidingdialog-title-text {
    margin-top: 2px;
    margin-bottom: 10px;
    color: #222;
    cursor: default
}
#docs-spellcheckslidingdialog-original-word {
    font-weight: 500
}
.docs-spellcheckslidingdialog-title-text.docs-spellcheckslidingdialog-no-misspellings {
    margin-bottom: 0;
    padding-right: 33px
}
#docs-spellcheckslidingdialog-no-misspellings:focus {
    outline: none
}
#docs-spellcheckslidingdialog-suggestion-list {
    box-shadow: none;
    margin-left: -1px;
    margin-top: -1px;
    height: 91px;
    overflow-y: auto;
    position: relative;
    width: 100%
}
.docs-spellcheckslidingdialog-container .goog-flat-menu-button {
    margin: 0;
    height: 27px
}
.docs-spellcheckslidingdialog-container .goog-flat-menu-button-collapse-left {
    margin-left: -1px
}
.docs-spellcheckslidingdialog-container .goog-flat-menu-button-collapse-right {
    min-width: 0px;
    padding-left: 0;
    margin-left: 0px;
    border-radius: 0 2px 2px 0
}
#docs-spellcheckslidingdialog-suggestion-list .goog-menuitem {
    padding-left: 8px
}
#docs-spellcheckslidingdialog-suggestion-list .goog-menuitem-checkbox {
    position: inherit
}
.docs-spellcheckslidingdialog-container table {
    width: 100%
}
.docs-spellcheckslidingdialog .docs-slidingdialog-holder {
    min-width: 250px
}
.docs-spellcheckslidingdialog-loading-spinner,
.docs-spellcheckslidingdialog-loading-text {
    display: inline-block;
    position: relative;
    -webkit-transition: left 300ms ease-out;
    -moz-transition: left 300ms ease-out;
    -o-transition: left 300ms ease-out;
    transition: left 300ms ease-out;
    -webkit-transition: width 300ms ease-out;
    -moz-transition: width 300ms ease-out;
    -o-transition: width 300ms ease-out;
    transition: width 300ms ease-out;
    vertical-align: middle
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-id .docs-slidingdialog {
    padding: 16px
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-id td {
    padding: 0;
    vertical-align: top
}
.docs-gm-dialogs .docs-spellcheckslidingdialog-title-text {
    font-size: 14px;
    height: 24px;
    margin: 0 0 16px 0;
    line-height: 24px;
    vertical-align: middle
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change-menu {
    background: #188038;
    background-image: none;
    border: 1px solid transparent;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    color: #fff;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change.jfk-button-hover,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change-menu.goog-flat-menu-button-hover {
    background: #2a8947;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change.jfk-button-focused,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change-menu.goog-flat-menu-button-focused {
    background: #4f9e67;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change.jfk-button-focused.jfk-button-hover,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change-menu.goog-flat-menu-button-focused.goog-flat-menu-button-hover {
    background: #62a877;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change.jfk-button-active,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change-menu.goog-flat-menu-button-active {
    background: #62a877;
    box-shadow: 0 2px 6px 2px rgba(52, 168, 83, 0.15)
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change.jfk-button-disabled,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change-menu.goog-flat-menu-button-disabled {
    background: #f1f3f4;
    color: #3c4043;
    opacity: 0.38
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-ignore,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-ignore-menu,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-dictionary,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-dictionary-menu {
    background: #fff;
    background-image: none;
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    color: #188038;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    margin-bottom: 0;
    margin-top: 8px
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-ignore.jfk-button-hover,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-ignore-menu.goog-flat-menu-button-hover,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-dictionary.jfk-button-hover,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-dictionary-menu.goog-flat-menu-button-hover {
    background: #f8fcf9;
    border: 1px solid #c8e7d1
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-ignore.jfk-button-focused,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-ignore-menu.goog-flat-menu-button-focused,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-dictionary.jfk-button-focused,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-dictionary-menu.goog-flat-menu-button-focused {
    background: #e7f5eb;
    border: 1px solid #bbe2c6
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-ignore.jfk-button-focused.jfk-button-hover,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-ignore-menu.goog-flat-menu-button-focused.goog-flat-menu-button-hover,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-dictionary.jfk-button-focused.jfk-button-hover,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-dictionary-menu.goog-flat-menu-button-focused.goog-flat-menu-button-hover {
    background: #dff2e4;
    border: 1px solid #b5e0c1
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-ignore.jfk-button-active,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-ignore-menu.goog-flat-menu-button-active,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-dictionary.jfk-button-active,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-dictionary-menu.goog-flat-menu-button-active {
    background: #dff2e4;
    border: 1px solid transparent;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-ignore.jfk-button-disabled,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-ignore-menu.goog-flat-menu-button-disabled,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-dictionary.jfk-button-disabled,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-dictionary-menu.goog-flat-menu-button-disabled {
    background: #fff;
    border: 1px solid #f1f3f4;
    color: #3c4043;
    opacity: 0.38
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-ignore,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-dictionary {
    border-radius: 4px 0 0 4px;
    margin-left: 16px;
    padding: 9px 8px 11px 8px;
    width: 156px
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change.jfk-button-focused,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change.jfk-button-hover,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change.jfk-button-hover.jfk-button-focused,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change.jfk-button-active,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change.jfk-button-disabled {
    border-right: 1px solid #ceead6
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change-menu,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change-menu.goog-flat-menu-button-focused,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change-menu.goog-flat-menu-button-hover,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change-menu.goog-flat-menu-button-hover.goog-flat-menu-button-focused,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change-menu.goog-flat-menu-button-active,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change-menu.goog-flat-menu-button-disabled {
    border-left: 1px solid #ceead6
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change-menu,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-ignore-menu,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-dictionary-menu {
    border-radius: 0 4px 4px 0;
    padding: 8px;
    width: 41px
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-change-menu .goog-flat-menu-button-dropdown,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-ignore-menu .goog-flat-menu-button-dropdown,
.docs-gm-dialogs #docs-spellcheckslidingdialog-button-dictionary-menu .goog-flat-menu-button-dropdown {
    right: 15px;
    top: 15px
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-replacement-input {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    color: #3c4043;
    padding: 1px 8px;
    font-size: 14px;
    height: 36px;
    margin: 8px 0;
    margin: 0
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-replacement-input:focus {
    border: 2px solid #1a73e8;
    box-shadow: none;
    padding: 0px 7px
}
.docs-gm-dialogs .docs-spellcheckslidingdialog-replacement-input-container {
    background: transparent;
    border: none;
    padding: 0;
    width: 156px
}
.docs-gm-dialogs .docs-spellcheckslidingdialog-replacement-input-container-focus {
    border: none;
    box-shadow: none;
    outline: none
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-suggestion-list {
    box-shadow: 0 1px 3px 1px rgba(60, 64, 67, .15);
    height: auto;
    margin: 0;
    width: 156px
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-id .docs-slidingdialog-close-container {
    height: 24px;
    right: 16px;
    top: 16px;
    width: 24px
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-id .docs-slidingdialog-button-close {
    opacity: 0.54
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-id .docs-slidingdialog-button-close.goog-flat-button-hover,
.docs-gm-dialogs #docs-spellcheckslidingdialog-id .docs-slidingdialog-button-close.goog-flat-button-focused,
.docs-gm-dialogs #docs-spellcheckslidingdialog-id .docs-slidingdialog-button-close.goog-flat-button-active {
    opacity: 0.87
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-id .docs-slidingdialog-button-close.goog-flat-button-focused {
    outline: none
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-no-misspellings-footer .jfk-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-no-misspellings-footer .jfk-button:last-child {
    margin-right: 0
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-no-misspellings-footer .jfk-button.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #2a8947;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-no-misspellings-footer .jfk-button.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #4f9e67;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-no-misspellings-footer .jfk-button.jfk-button-focused.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-dialogs #docs-spellcheckslidingdialog-no-misspellings-footer .jfk-button.jfk-button-active,
.docs-gm-dialogs #docs-spellcheckslidingdialog-no-misspellings-footer .jfk-button.jfk-button-active.jfk-button-focused.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 2px 6px 2px rgba(52, 168, 83, 0.15)
}
.docs-userdictionary-butterbar-item {
    font-weight: normal
}
.docs-userdictionarydialog-button-add {
    margin-left: 0px;
    margin-right: 0px;
    padding: 0px;
    width: 100%
}
.docs-userdictionarydialog-list-container {
    background-color: #fff;
    border: 1px solid #ececec;
    height: 415px;
    margin-top: 16px;
    overflow-y: auto;
    position: relative;
    width: 315px
}
.docs-gm-dialogs .docs-userdictionarydialog-list-container {
    height: 232px;
    min-width: 464px;
    width: auto;
    width: unset
}
.docs-userdictionarydialog-list-container:focus {
    outline: none
}
.docs-userdictionarydialog-button-add-container {
    border-left: 30px solid white;
    max-width: 125px
}
.docs-gm-dialogs .docs-userdictionarydialog-button-add-container {
    border-left: 0;
    margin-left: 16px
}
.docs-userdictionarydialog-input {
    margin-left: 0px;
    vertical-align: middle;
    width: 100%
}
.docs-gm-dialogs .docs-userdictionarydialog-input {
    width: 364px
}
.docs-userdictionarydialog-row-container {
    border-bottom: 1px solid #ececec;
    padding: 10px;
    min-width: 275px
}
.docs-gm-dialogs .docs-userdictionarydialog-row-container {
    border-bottom: 1px solid #dadce0;
    padding: 10px 16px;
    width: 432px
}
.docs-gm-dialogs .docs-userdictionarydialog-list-container-ie .docs-userdictionarydialog-row-container {
    padding-left: 20px;
    padding-right: 20px;
    width: 424px
}
.docs-userdictionarydialog-row-container-hover {
    background-color: #eee
}
.docs-gm-dialogs .docs-userdictionarydialog-row-container-hover {
    background-color: #f1f3f4
}
.docs-userdictionarydialog-row-content {
    display: inline-block;
    width: 250px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    vertical-align: middle
}
.docs-gm-dialogs .docs-userdictionarydialog-row-content {
    color: #3c4043
}
.docs-userdictionarydialog-list-remove-button {
    background-color: transparent;
    border: none;
    margin: 0;
    padding: 0;
    position: absolute;
    right: 3px
}
.docs-gm-dialogs .docs-userdictionarydialog-list-remove-button {
    left: 424px
}
.docs-gm-dialogs .docs-userdictionarydialog-list-container-ie .docs-userdictionarydialog-list-remove-button {
    left: 420px
}
.docs-gm-dialogs .docs-material.docs-userdictionarydialog-list-remove-button .docs-icon {
    height: 24px;
    margin: 0;
    width: 24px
}
.docs-userdictionarydialog-top-container {
    border-collapse: separate;
    display: table;
    width: 100%
}
.docs-userdictionarydialog-top-container>div {
    display: table-cell
}
.docs-templatestoast.docs-ui-toast {
    z-index: 1003
}
.docs-calloutbubble-anchor {
    position: absolute
}
.docs-calloutbubble-bubble.jfk-bubble {
    padding: 0px;
    z-index: 99!important
}
@media print {
    .docs-calloutbubble-anchor {
        display: none!important
    }
}
.docs-dismissible-bar {
    margin-top: 0;
    position: absolute;
    width: 500px
}
.docs-dismissible-bar .docs-dismissible-bar-content {
    background: rgba(0, 0, 0, 0.8);
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
    color: #fff;
    left: -50%;
    overflow: hidden;
    position: relative;
    z-index: 1001
}
.docs-dismissible-bar .docs-dismissible-bar-header {
    border-bottom: 1px solid #000;
    float: left;
    width: 100%
}
.docs-dismissible-bar .docs-dismissible-bar-title {
    float: left;
    font-size: 15px;
    font-weight: 500;
    margin: 16px 15px
}
.docs-dismissible-bar .docs-dismissible-bar-description {
    border-top: 1px solid #444;
    box-sizing: border-box;
    color: #bbb;
    float: left;
    padding: 10px 15px 15px;
    text-align: left;
    width: 100%
}
.docs-dismissible-bar .docs-dismissible-bar-dismiss-button {
    float: right;
    margin: 10px 10px 10px 0
}
.docs-dismissible-bar .docs-dismissible-bar-black-button {
    background-color: #454545;
    background-repeat: repeat-x;
    border: solid 1px #111;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
    -webkit-box-shadow: 0px 1px 1px 0px rgba(0, 0, 0, 0.05), inset 0px 1px 0px 0px rgba(255, 255, 255, 0.2);
    -moz-box-shadow: 0px 1px 1px 0px rgba(0, 0, 0, 0.05), inset 0px 1px 0px 0px rgba(255, 255, 255, 0.2);
    box-shadow: 0px 1px 1px 0px rgba(0, 0, 0, 0.05), inset 0px 1px 0px 0px rgba(255, 255, 255, 0.2);
    color: #ddd;
    cursor: pointer;
    background-color: #4b4b4b;
    background-image: -webkit-linear-gradient(top, #4b4b4b, #3b3b3b);
    background-image: -moz-linear-gradient(top, #4b4b4b, #3b3b3b);
    background-image: -ms-linear-gradient(top, #4b4b4b, #3b3b3b);
    background-image: -o-linear-gradient(top, #4b4b4b, #3b3b3b);
    background-image: linear-gradient(top, #4b4b4b, #3b3b3b);
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.8)
}
.docs-dismissible-bar .docs-dismissible-bar-black-button.jfk-button-hover {
    background: rgba(255, 255, 255, 0.1);
    border: 1px solid #141414;
    -webkit-box-shadow: 0 0 0 transparent inset;
    -moz-box-shadow: 0 0 0 transparent inset;
    box-shadow: 0 0 0 transparent inset;
    color: #fff
}
.docs-dismissible-bar .docs-dismissible-bar-black-button.jfk-button-active,
.docs-dismissible-bar .docs-dismissible-bar-black-button.jfk-button-focused {
    border-color: #fff
}
.docs-indeterminate-loading-bar {
    background: #c6dafc;
    height: 100%;
    position: relative;
    width: 100%
}
.docs-indeterminate-loading-bar>div {
    -webkit-animation: docs-indeterminate-loading-animation 2s linear infinite;
    -moz-animation: docs-indeterminate-loading-animation 2s linear infinite;
    -o-animation: docs-indeterminate-loading-animation 2s linear infinite;
    animation: docs-indeterminate-loading-animation 2s linear infinite;
    background: #4285f4;
    height: 100%;
    position: absolute;
    transition: width .2s cubic-bezier(.4, 0, .2, 1)
}
@keyframes docs-indeterminate-loading-animation {
    0% {
        left: 0%;
        width: 0
    }
    50% {
        left: 25%;
        width: 75%
    }
    75% {
        left: 100%;
        width: 0%
    }
}
.docs-loading-indicator {
    height: 48px;
    left: 50%;
    margin: -24px 0 0 -24px;
    position: absolute;
    top: 50%;
    width: 48px
}
.docs-loading-indicator-small {
    height: 20px;
    left: 50%;
    margin: -10px 0 0 -10px;
    position: absolute;
    top: 50%;
    width: 20px
}
.docs-sidebar-toggle-tabs-jfk.docs-sidebar-toggle-tabs {
    background-color: #fafafa;
    border-bottom: 1px solid #bdbdbd;
    width: 100%
}
.docs-sidebar-toggle-tabs-jfk .jfk-button.docs-sidebar-toggle-tab {
    width: 50%;
    border: none;
    color: #646464;
    cursor: pointer;
    font-size: 13px;
    height: 40px;
    line-height: 42px;
    margin: 0;
    text-align: center
}
.docs-sidebar-toggle-tabs-jfk .jfk-button.docs-sidebar-toggle-tab-inactive {
    font-weight: normal
}
.docs-sidebar-toggle-tabs-jfk .jfk-button.docs-sidebar-toggle-tab-active {
    font-weight: 500;
    border-bottom: 3px solid #3367d6
}
.docs-sidebar-toggle-tabs-jfk .jfk-button-focused.docs-sidebar-toggle-tab-inactive {
    border-bottom: 3px solid #4d90fe
}
.docs-sidebar-toggle-tabs-material.docs-sidebar-toggle-tabs {
    background-color: #eeeeee;
    width: 100%
}
.docs-sidebar-toggle-tabs-material .jfk-button.docs-sidebar-toggle-tab {
    width: 50%;
    border: none;
    cursor: pointer;
    font-size: 13px;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    text-transform: uppercase;
    height: 41px;
    line-height: 43px;
    margin: 0;
    text-align: center
}
.docs-sidebar-toggle-tabs-material .jfk-button.docs-sidebar-toggle-tab-inactive {
    color: rgba(0, 0, 0, 0.54)
}
.docs-sidebar-toggle-tabs-material .jfk-button.docs-sidebar-toggle-tab-active {
    color: rgba(0, 0, 0, 0.87);
    border-bottom: 2px solid #4285f4
}
.docs-sidebar-toggle-tabs-material .jfk-button-focused.docs-sidebar-toggle-tab-inactive {
    border-bottom: 2px dotted #4285f4
}
.docs-sidebar-toggle-tabs-material .jfk-button-active.jfk-button-focused.docs-sidebar-toggle-tab-inactive {
    border-bottom: none
}
.docs-spinner {
    height: 44px;
    overflow: hidden;
    position: relative
}
.docs-quantum-spinner {
    height: 28px;
    left: 50%;
    margin-left: -14px;
    position: absolute;
    top: 0;
    width: 28px
}
.docs-loading-indicator-small .docs-quantum-spinner {
    height: 20px;
    margin-left: -10px;
    top: 0;
    width: 20px
}
.docs-white-circle {
    background: white;
    border-radius: 50%;
    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.4);
    -moz-box-shadow: 0 2px 6px rgba(0, 0, 0, 0.4);
    -webkit-box-shadow: 0 2px 6px rgba(0, 0, 0, 0.4);
    height: 44px;
    left: 50%;
    margin-left: -22px;
    position: absolute;
    width: 44px
}
.docs-quantum-spinner.active {
    -webkit-animation: container-rotate 1568ms linear infinite;
    animation: container-rotate 1568ms linear infinite
}
@-webkit-keyframes container-rotate {
    to {
        -webkit-transform: rotate(360deg)
    }
}
@keyframes container-rotate {
    to {
        transform: rotate(360deg)
    }
}
.spinner-layer {
    position: absolute;
    width: 100%;
    height: 100%;
    opacity: 0
}
.spinner-blue {
    border-color: #4285f4
}
.spinner-red {
    border-color: #db4437
}
.spinner-yellow {
    border-color: #f4b400
}
.spinner-green {
    border-color: #0f9d58
}
.active .spinner-layer.spinner-blue {
    -webkit-animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both, blue-fade-in-out 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both;
    animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both, blue-fade-in-out 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both
}
.active .spinner-layer.spinner-red {
    -webkit-animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both, red-fade-in-out 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both;
    animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both, red-fade-in-out 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both
}
.active .spinner-layer.spinner-yellow {
    -webkit-animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both, yellow-fade-in-out 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both;
    animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both, yellow-fade-in-out 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both
}
.active .spinner-layer.spinner-green {
    -webkit-animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both, green-fade-in-out 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both;
    animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both, green-fade-in-out 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both
}
@-webkit-keyframes fill-unfill-rotate {
    12.5% {
        -webkit-transform: rotate(135deg)
    }
    25% {
        -webkit-transform: rotate(270deg)
    }
    37.5% {
        -webkit-transform: rotate(405deg)
    }
    50% {
        -webkit-transform: rotate(540deg)
    }
    62.5% {
        -webkit-transform: rotate(675deg)
    }
    75% {
        -webkit-transform: rotate(810deg)
    }
    87.5% {
        -webkit-transform: rotate(945deg)
    }
    to {
        -webkit-transform: rotate(1080deg)
    }
}
@keyframes fill-unfill-rotate {
    12.5% {
        transform: rotate(135deg)
    }
    25% {
        transform: rotate(270deg)
    }
    37.5% {
        transform: rotate(405deg)
    }
    50% {
        transform: rotate(540deg)
    }
    62.5% {
        transform: rotate(675deg)
    }
    75% {
        transform: rotate(810deg)
    }
    87.5% {
        transform: rotate(945deg)
    }
    to {
        transform: rotate(1080deg)
    }
}
@-webkit-keyframes blue-fade-in-out {
    from {
        opacity: 1
    }
    25% {
        opacity: 1
    }
    26% {
        opacity: 0
    }
    89% {
        opacity: 0
    }
    90% {
        opacity: 1
    }
    100% {
        opacity: 1
    }
}
@keyframes blue-fade-in-out {
    from {
        opacity: 1
    }
    25% {
        opacity: 1
    }
    26% {
        opacity: 0
    }
    89% {
        opacity: 0
    }
    90% {
        opacity: 1
    }
    100% {
        opacity: 1
    }
}
@-webkit-keyframes red-fade-in-out {
    from {
        opacity: 0
    }
    15% {
        opacity: 0
    }
    25% {
        opacity: 1
    }
    50% {
        opacity: 1
    }
    51% {
        opacity: 0
    }
}
@keyframes red-fade-in-out {
    from {
        opacity: 0
    }
    15% {
        opacity: 0
    }
    25% {
        opacity: 1
    }
    50% {
        opacity: 1
    }
    51% {
        opacity: 0
    }
}
@-webkit-keyframes yellow-fade-in-out {
    from {
        opacity: 0
    }
    40% {
        opacity: 0
    }
    50% {
        opacity: 1
    }
    75% {
        opacity: 1
    }
    76% {
        opacity: 0
    }
}
@keyframes yellow-fade-in-out {
    from {
        opacity: 0
    }
    40% {
        opacity: 0
    }
    50% {
        opacity: 1
    }
    75% {
        opacity: 1
    }
    76% {
        opacity: 0
    }
}
@-webkit-keyframes green-fade-in-out {
    from {
        opacity: 0
    }
    65% {
        opacity: 0
    }
    75% {
        opacity: 1
    }
    90% {
        opacity: 1
    }
    100% {
        opacity: 0
    }
}
@keyframes green-fade-in-out {
    from {
        opacity: 0
    }
    65% {
        opacity: 0
    }
    75% {
        opacity: 1
    }
    90% {
        opacity: 1
    }
    100% {
        opacity: 0
    }
}
.spinner-gap-patch {
    position: absolute;
    box-sizing: border-box;
    top: 0;
    left: 45%;
    width: 10%;
    height: 100%;
    overflow: hidden;
    border-color: inherit
}
.spinner-gap-patch .spinner-circle {
    width: 1000%;
    left: -450%
}
.spinner-circle-clipper {
    display: inline-block;
    position: relative;
    width: 50%;
    height: 100%;
    overflow: hidden;
    border-color: inherit
}
.spinner-circle-clipper .spinner-circle {
    width: 200%
}
.spinner-circle {
    box-sizing: border-box;
    height: 100%;
    border-width: 3px;
    border-style: solid;
    border-color: inherit;
    border-bottom-color: transparent!important;
    border-radius: 50%;
    -webkit-animation: none;
    animation: none
}
.spinner-circle-clipper.spinner-left .spinner-circle {
    border-right-color: transparent!important;
    -webkit-transform: rotate(129deg);
    transform: rotate(129deg)
}
.spinner-circle-clipper.spinner-right .spinner-circle {
    left: -100%;
    border-left-color: transparent!important;
    -webkit-transform: rotate(-129deg);
    transform: rotate(-129deg)
}
.active .spinner-circle-clipper.spinner-left .spinner-circle {
    -webkit-animation: left-spin 1333ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both;
    animation: left-spin 1333ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both
}
.active .spinner-circle-clipper.spinner-right .spinner-circle {
    -webkit-animation: right-spin 1333ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both;
    animation: right-spin 1333ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both
}
@-webkit-keyframes left-spin {
    from {
        -webkit-transform: rotate(130deg)
    }
    50% {
        -webkit-transform: rotate(-5deg)
    }
    to {
        -webkit-transform: rotate(130deg)
    }
}
@keyframes left-spin {
    from {
        transform: rotate(130deg)
    }
    50% {
        transform: rotate(-5deg)
    }
    to {
        transform: rotate(130deg)
    }
}
@-webkit-keyframes right-spin {
    from {
        -webkit-transform: rotate(-130deg)
    }
    50% {
        -webkit-transform: rotate(5deg)
    }
    to {
        -webkit-transform: rotate(-130deg)
    }
}
@keyframes right-spin {
    from {
        transform: rotate(-130deg)
    }
    50% {
        transform: rotate(5deg)
    }
    to {
        transform: rotate(-130deg)
    }
}
.spinner-fit {
    position: absolute;
    top: 0;
    bottom: 0;
    right: 0;
    left: 0
}
.docs-working-bar {
    color: #222;
    display: none;
    font: 13px/1.4 arial, sans-serif;
    margin-top: 0;
    min-width: 124px;
    position: absolute;
    z-index: 1001;
    -webkit-transition: 218ms ease-in;
    -moz-transition: 218ms ease-in;
    -o-transition: 218ms ease-in;
    transition: 218ms ease-in
}
.docs-working-bar-slideup {
    -webkit-transform: translateY(-60px);
    -moz-transform: translateY(-60px);
    -ms-transform: translateY(-60px);
    -o-transform: translateY(-60px);
    transform: translateY(-60px)
}
.docs-working-bar-display {
    display: block
}
.docs-working-bar .message {
    background: rgba(0, 0, 0, .8);
    border-radius: 3px;
    color: #fff;
    left: -50%;
    padding: 16px;
    position: relative
}
.docs-working-bar .message * {
    vertical-align: middle
}
.docs-working-bar .message .icon {
    margin-right: 16px
}
.docs-working-bar .spinner {
    display: inline-block
}
.docs-working-bar .label {
    font-weight: normal
}
@keyframes script-working-bar-spin {
    from {
        transform: rotate(0deg);
        -ms-transform: rotate(0deg)
    }
    to {
        transform: rotate(360deg);
        -ms-transform: rotate(360deg)
    }
}
@-webkit-keyframes script-working-bar-spin {
    from {
        -webkit-transform: rotate(0deg)
    }
    to {
        -webkit-transform: rotate(360deg)
    }
}
.docs-working-bar .spinner .icon {
    animation: script-working-bar-spin 1.5s infinite linear;
    -webkit-animation: script-working-bar-spin 1.5s infinite linear
}
.docs-material-colorpalette {
    outline: none
}
.docs-material-colorpalette-cell {
    border-radius: 50%
}
.docs-material-colorpalette-colorswatch {
    border-radius: 50%;
    box-sizing: border-box;
    cursor: pointer;
    height: 20px;
    margin: 1px 1px 0 0;
    width: 20px
}
.docs-material-colorpalette-table {
    border-spacing: 1px;
    padding: 1px 0
}
.docs-material-colorpalette-cell.docs-material-colorpalette-cell-hover .docs-material-colorpalette-colorswatch {
    box-shadow: 0 0 3px 1px #bdc1c6
}
.docs-material-colorpalette-colorswatch.docs-material-colorpalette-colorswatch-border {
    border: 1px solid #dadce0
}
.docs-customcolorpalette-add-custom-color-button:hover {
    background-color: #e8eaed;
    border-radius: 4px;
    cursor: pointer
}
.docs-material-colorpalette-cell.docs-material-colorpalette-cell-selected .docs-material-colorpalette-colorswatch {
    background: url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNnB4IiBoZWlnaHQ9IjE2cHgiIHZpZXdCb3g9IjAgMCA0OCA0OCIgZmlsbD0iIzAwMDAwMCI+PGcgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMSwgMCwgMCwgMSkiPjxwYXRoIGQ9Ik0wIDBoNDh2NDhIMHoiIGZpbGw9Im5vbmUiLz48cGF0aCBkPSJNMTggMzIuMzRMOS42NiAyNGwtMi44MyAyLjgzTDE4IDM4bDI0LTI0LTIuODMtMi44M3oiLz48L2c+PC9zdmc+);
    background-position: center;
    background-repeat: no-repeat
}
.docs-material-colorpalette-cell.docs-material-colorpalette-cell-selected .docs-material-colorpalette-colorswatch.docs-material-colorpalette-colorswatch-dark {
    background: url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxNnB4IiBoZWlnaHQ9IjE2cHgiIHZpZXdCb3g9IjAgMCA0OCA0OCIgZmlsbD0iI0ZGRkZGRiI+PHBhdGggZD0iTTAgMGg0OHY0OEgweiIgZmlsbD0ibm9uZSIvPjxwYXRoIGQ9Ik0xOCAzMi4zNEw5LjY2IDI0bC0yLjgzIDIuODNMMTggMzhsMjQtMjQtMi44My0yLjgzeiIvPjwvc3ZnPg==);
    background-position: center;
    background-repeat: no-repeat
}
.docs-hc-gecko .docs-material-colorpalette-colorswatch,
.docs-hc-ie .docs-material-colorpalette-colorswatch {
    border: 1px solid #dadce0
}
.docs-material-color-picker-base {
    cursor: pointer;
    height: 26px;
    min-width: 40px;
    outline: none
}
.docs-material-color-picker-base-disabled,
.docs-material-color-picker-base-disabled .docs-material-color-picker-base {
    cursor: default
}
.docs-material-color-picker-base-outer-box {
    -webkit-transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    background: rgba(0, 0, 0, 0.04);
    border-radius: 2px;
    height: 100%;
    padding: 2px 4px;
    width: 100%
}
.docs-material-color-picker-base-open .docs-material-color-picker-base-outer-box {
    background: rgba(0, 0, 0, 0.12)
}
.docs-material-color-picker-base-inner-box {
    width: 100%
}
.docs-material-color-picker-base-indicator {
    border-bottom: 3px solid transparent;
    height: 18px;
    width: 22px
}
.docs-material-color-picker-base-disabled .docs-material-color-picker-base-indicator {
    opacity: 0.12
}
.docs-material-color-picker-base-indicator .docs-icon {
    -webkit-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -webkit-transform: scale(0.9);
    -moz-transform: scale(0.9);
    -ms-transform: scale(0.9);
    -o-transform: scale(0.9);
    transform: scale(0.9);
    height: 14px;
    left: 1px;
    opacity: 0.54;
    width: 18px
}
.docs-material-color-picker-base-focused .docs-material-color-picker-base-indicator .docs-icon,
.docs-material-color-picker-base-open .docs-material-color-picker-base-indicator .docs-icon {
    opacity: 0.87
}
.docs-material-color-picker-base-dropdown {
    float: right
}
.docs-material-color-picker-base-dropdown-icon {
    -webkit-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI1IiBoZWlnaHQ9IjMiPjxwb2x5Z29uIHBvaW50cz0iMCwwIDUsMCAyLjUsMyIgZmlsbD0iIzAwMCIvPjwvc3ZnPg==") no-repeat;
    background-size: contain;
    height: 8px;
    opacity: 0.54;
    position: relative;
    top: 9px;
    width: 8px
}
.docs-material-color-picker-base-focused .docs-material-color-picker-base-dropdown-icon,
.docs-material-color-picker-base-open .docs-material-color-picker-base-dropdown-icon {
    opacity: 0.87
}
.docs-material-color-picker-base-disabled .docs-material-color-picker-base-dropdown-icon {
    opacity: 0.12
}
.docs-material-color-picker-dragger {
    border: 2px solid white;
    border-radius: 50%;
    box-shadow: 0 0 3px 1px #bdc1c6;
    cursor: pointer;
    position: absolute;
    z-index: 3
}
.docs-material-color-swatch-wrapper {
    border-radius: 50%;
    display: inline-block;
    position: relative;
    vertical-align: middle
}
.docs-material-color-swatch-color {
    box-shadow: 0 0 0 1px transparent
}
.docs-material-color-swatch-element {
    border-radius: 50%;
    height: 100%;
    position: absolute;
    width: 100%
}
.docs-material-color-swatch-wrapper-hover {
    box-shadow: 0 0 0 1px #c8e7d1
}
.docs-material-color-swatch-wrapper-focused {
    box-shadow: 0 0 0 1px #bbe2c6;
    outline: none
}
.docs-material-color-swatch-border {
    box-shadow: 0 0 0 1px #e8eaed
}
.docs-material-color-swatch-checkbox-background {
    background-image: url(https://ssl.gstatic.com/docs/common/checkboard.png);
    background-size: 10px
}
.docs-hc-ie .docs-material-color-swatch-color,
.docs-hc-gecko .docs-material-color-swatch-color {
    border: 1px solid #dadce0
}
.docs-gm-color-picker {
    color: #3c4043;
    outline: none;
    width: 100%
}
.docs-gm-color-picker-outer-box {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    cursor: pointer;
    padding: 8px 6px 8px 8px;
    width: 100%
}
.docs-gm-color-picker .docs-gm-color-picker-outer-box {
    width: auto
}
.docs-gm-color-picker-hover .docs-gm-color-picker-outer-box {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid #dadce0
}
.docs-gm-color-picker-open .docs-gm-color-picker-outer-box {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid transparent
}
.docs-material-gm-select-open.docs-material-gm-select-hover .docs-gm-color-picker-outer-box {
    background-color: rgba(60, 64, 67, 0.06)
}
.docs-material-gm-select-open.docs-material-gm-select-focused .docs-gm-color-picker-outer-box {
    background-color: rgba(60, 64, 67, 0.08)
}
.docs-gm-color-picker-disabled {
    color: #5f6368;
    opacity: .38;
    cursor: default
}
.docs-gm-color-picker-disabled .docs-gm-color-picker-outer-box {
    border: 1px solid #dadce0;
    cursor: default
}
.docs-gm-color-picker-inner-box {
    align-items: center;
    display: flex;
    justify-content: space-between;
    position: relative;
    width: 100%
}
.docs-gm-color-picker-inner-box {
    align-items: center;
    display: flex;
    justify-content: space-between;
    position: relative;
    width: 100%
}
.docs-gm-color-picker-caption {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    height: 20px;
    line-height: 20px;
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    height: 22px;
    width: 22px;
    border-radius: 50%;
    border: 1px solid #dadce0;
    margin: 0;
    outline: none
}
.docs-gm-color-picker-dropdown {
    align-items: center;
    display: flex;
    height: 24px;
    justify-content: center;
    width: 24px
}
.docs-gm-color-picker-dropdown-icon {
    background: no-repeat url(//ssl.gstatic.com/docs/common/material_common_sprite134_grey_medium.svg) 0 -1364px;
    height: 18px;
    width: 18px
}
.docs-gm-color-picker-open .docs-gm-color-picker-dropdown-icon {
    -moz-transform: rotate(180deg);
    -webkit-transform: rotate(180deg);
    -ms-transform: rotate(180deg);
    transform: rotate(180deg)
}
.docs-gm-labeled-color-picker {
    color: #3c4043;
    outline: none;
    width: 100%
}
.docs-gm-labeled-color-picker-outer-box {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    cursor: pointer;
    padding: 8px 6px 8px 8px;
    width: 100%
}
.docs-gm-labeled-color-picker .docs-gm-labeled-color-picker-outer-box {
    width: auto
}
.docs-gm-labeled-color-picker-hover .docs-gm-labeled-color-picker-outer-box {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid #dadce0
}
.docs-gm-labeled-color-picker-open .docs-gm-labeled-color-picker-outer-box {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid transparent
}
.docs-material-gm-select-open.docs-material-gm-select-hover .docs-gm-labeled-color-picker-outer-box {
    background-color: rgba(60, 64, 67, 0.06)
}
.docs-material-gm-select-open.docs-material-gm-select-focused .docs-gm-labeled-color-picker-outer-box {
    background-color: rgba(60, 64, 67, 0.08)
}
.docs-gm-labeled-color-picker-disabled {
    color: #5f6368;
    opacity: .38;
    cursor: default
}
.docs-gm-labeled-color-picker-disabled .docs-gm-labeled-color-picker-outer-box {
    border: 1px solid #dadce0;
    cursor: default
}
.docs-gm-labeled-color-picker-inner-box {
    align-items: center;
    display: flex;
    justify-content: space-between;
    position: relative;
    width: 100%
}
.docs-gm-labeled-color-picker-inner-box {
    align-items: center;
    display: flex;
    justify-content: space-between;
    position: relative;
    width: 100%
}
.docs-gm-labeled-color-picker-caption {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    height: 20px;
    line-height: 20px;
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    height: 22px;
    width: 22px;
    border-radius: 50%;
    border: 1px solid #dadce0;
    margin: 0;
    outline: none
}
.docs-gm-labeled-color-picker-dropdown {
    align-items: center;
    display: flex;
    height: 24px;
    justify-content: center;
    width: 24px
}
.docs-gm-labeled-color-picker-dropdown-icon {
    background: no-repeat url(//ssl.gstatic.com/docs/common/material_common_sprite134_grey_medium.svg) 0 -1364px;
    height: 18px;
    width: 18px
}
.docs-gm-labeled-color-picker-open .docs-gm-labeled-color-picker-dropdown-icon {
    -moz-transform: rotate(180deg);
    -webkit-transform: rotate(180deg);
    -ms-transform: rotate(180deg);
    transform: rotate(180deg)
}
.docs-gm-labeled-color-picker-label {
    color: #5f6368;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    margin-bottom: 8px;
    display: inline-block
}
.docs-material-hsv-color-picker {
    padding-bottom: 15px
}
.docs-material-hsv-color-picker-information {
    padding: 0 0 15px 0;
    width: 100%
}
.docs-material-hsv-color-picker-input {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    color: #3c4043;
    padding: 1px 8px;
    font-size: 14px;
    height: 36px;
    margin: 8px 0;
    width: 90px
}
.docs-material-hsv-color-picker-input:focus {
    border: 2px solid #1a73e8;
    box-shadow: none;
    padding: 0px 7px
}
.docs-material-info-element {
    display: inline-block;
    margin-right: 15px
}
.docs-material-hsv-color-picker-title {
    text-transform: uppercase
}
.docs-material-hsv-color-picker-text {
    color: #5f6368;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 11px;
    font-weight: 500;
    padding: 10px 0 0 0
}
.docs-material-hue-slider-background {
    background: linear-gradient(to right, hsl(0, 100%, 50%), hsl(60, 100%, 50%), hsl(120, 100%, 50%), hsl(180, 100%, 50%), hsl(240, 100%, 50%), hsl(300, 100%, 50%), hsl(360, 100%, 50%))
}
.docs-material-opacity-slider-checkbox-background {
    background-image: url(https://ssl.gstatic.com/docs/common/checkboard.png);
    background-size: 10px
}
.docs-material-labeled-toolbar-color-picker {
    outline: none
}
.docs-material-labeled-toolbar-color-picker-label {
    color: #616161;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 11px;
    line-height: 16px
}
.docs-material-color-picker-base-disabled .docs-material-labeled-toolbar-color-picker-label {
    opacity: 0.12
}
.docs-material-color-picker-base-disabled .docs-material-labeled-toolbar-color-picker-outer- {
    opacity: 0.12
}
.docs-material-labeled-toolbar-color-picker-outer-box {
    -webkit-transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    background: rgba(0, 0, 0, 0.04);
    border-radius: 2px;
    height: 100%;
    padding: 2px 4px;
    width: 100%
}
.docs-material-color-picker-base-open .docs-material-labeled-toolbar-color-picker-outer-box {
    background: rgba(0, 0, 0, 0.12)
}
.docs-material-labeled-toolbar-color-picker-inner-box {
    width: 100%
}
.docs-material-color-picker-saturation-value-background {
    border: 1px solid white;
    box-sizing: border-box
}
.docs-material-color-picker-saturation-value {
    height: 150px;
    outline: none;
    position: relative;
    width: 100%
}
.docs-material-color-picker-overlay {
    border-radius: 4px;
    height: 100%;
    left: 0;
    position: absolute;
    top: 0px;
    width: 100%
}
.docs-material-color-picker-saturation-overlay {
    background: linear-gradient(to right, #fff 0%, rgba(255, 255, 255, 0) 100%);
    z-index: 1
}
.docs-material-color-picker-value-overlay {
    background: linear-gradient(to bottom, transparent 0%, #000 100%);
    z-index: 2
}
.docs-material-toolbar-color-picker-outer-box {
    -webkit-transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    background: rgba(0, 0, 0, 0.04);
    border-radius: 2px;
    height: 100%;
    padding: 2px 4px;
    width: 100%
}
.docs-material-color-picker-base-open .docs-material-toolbar-color-picker-outer-box {
    background: rgba(0, 0, 0, 0.12)
}
.docs-material-toolbar-color-picker-inner-box {
    width: 100%
}
.docs-material-color-slider {
    box-sizing: border-box;
    outline: 0;
    padding: 8px 0;
    position: relative
}
.docs-material-color-slider-background {
    border-radius: 4px;
    display: inline-block;
    height: 10px;
    position: absolute;
    width: 100%
}
.docs-material-color-slider-wrapper {
    position: relative;
    width: 100%
}
.docs-material-color-slider-thumb {
    height: 16px;
    pointer-events: inherit;
    top: -5px;
    width: 16px
}
.docs-material-color-slider-track {
    left: 0;
    position: absolute;
    top: 0
}
.docs-material-color-slider-checkbox-background {
    background-image: url(https://ssl.gstatic.com/docs/common/checkboard.png);
    background-size: 10px
}
.docs-material-slider {
    box-sizing: border-box;
    padding: 8px;
    position: relative;
    outline: 0
}
.docs-material-slider-horizontal {
    height: calc(30px + 2*8px);
    min-width: 128px
}
.docs-material-slider-vertical {
    width: calc(30px + 2*8px);
    min-height: 128px
}
.docs-material-slider-wrapper {
    position: absolute
}
.docs-material-slider-horizontal .docs-material-slider-wrapper {
    left: 8px;
    height: 2px;
    right: 8px;
    top: 23px
}
.docs-material-slider-vertical .docs-material-slider-wrapper {
    bottom: 8px;
    left: 23px;
    top: 8px;
    width: 2px
}
.docs-material-slider-thumb {
    pointer-events: inherit;
    position: absolute
}
.docs-material-slider-horizontal .docs-material-slider-thumb {
    top: 50%;
    width: calc(2*8px)
}
.docs-material-slider-vertical .docs-material-slider-thumb {
    left: 50%;
    height: calc(2*8px)
}
.docs-material-slider-focus-ring {
    background-color: rgba(66, 133, 244, 0.38);
    border-radius: 50%;
    left: calc(-0.5*30px);
    height: 30px;
    opacity: 0;
    pointer-events: inherit;
    position: absolute;
    top: calc(-0.5*30px);
    transform: scale(0);
    -webkit-transition: transform .4s cubic-bezier(.25, .8, .25, 1), opacity .4s cubic-bezier(.25, .8, .25, 1);
    -moz-transition: transform .4s cubic-bezier(.25, .8, .25, 1), opacity .4s cubic-bezier(.25, .8, .25, 1);
    -o-transition: transform .4s cubic-bezier(.25, .8, .25, 1), opacity .4s cubic-bezier(.25, .8, .25, 1);
    transition: transform .4s cubic-bezier(.25, .8, .25, 1), opacity .4s cubic-bezier(.25, .8, .25, 1);
    width: 30px
}
.docs-material-slider-rtl .docs-material-slider-focus-ring {
    left: inherit;
    right: calc(-0.5*30px)
}
.docs-material-slider-thumb-grabber {
    background-color: #4285f4;
    border-color: #4285f4;
    border-radius: 50%;
    border-style: solid;
    box-sizing: border-box;
    cursor: pointer;
    height: 20px;
    position: absolute;
    transform: scale(0.7);
    -webkit-transition: transform .4s cubic-bezier(.25, .8, .25, 1);
    -moz-transition: transform .4s cubic-bezier(.25, .8, .25, 1);
    -o-transition: transform .4s cubic-bezier(.25, .8, .25, 1);
    transition: transform .4s cubic-bezier(.25, .8, .25, 1);
    width: 20px
}
.docs-material-slider-horizontal.docs-material-slider-ltr .docs-material-slider-thumb-grabber {
    bottom: calc(-0.5*20px);
    left: calc(-0.5*20px)
}
.docs-material-slider-horizontal.docs-material-slider-rtl .docs-material-slider-thumb-grabber {
    bottom: calc(-0.5*20px);
    right: calc(-0.5*20px)
}
.docs-material-slider-vertical .docs-material-slider-thumb-grabber {
    left: calc(-0.5*20px);
    top: calc(-0.5*20px)
}
.docs-material-slider-track-wrapper {
    left: 0px;
    position: absolute;
    top: 0px
}
.docs-material-slider-horizontal .docs-material-slider-track-wrapper {
    height: 2px;
    width: 100%
}
.docs-material-slider-vertical .docs-material-slider-track-wrapper {
    height: 100%;
    width: 2px
}
.docs-material-slider-track {
    position: absolute
}
.docs-material-slider-horizontal .docs-material-slider-track {
    height: 2px
}
.docs-material-slider-vertical .docs-material-slider-track {
    width: 2px
}
.docs-material-slider.docs-material-slider-horizontal.docs-hc-edge .docs-material-slider-track,
.docs-material-slider.docs-material-slider-horizontal.docs-hc-ie .docs-material-slider-track,
.docs-material-slider.docs-material-slider-horizontal.docs-hc-gecko .docs-material-slider-track {
    height: 0;
    outline: solid 2px
}
.docs-material-slider.docs-material-slider-vertical.docs-hc-edge .docs-material-slider-track,
.docs-material-slider.docs-material-slider-vertical.docs-hc-ie .docs-material-slider-track,
.docs-material-slider.docs-material-slider-vertical.docs-hc-gecko .docs-material-slider-track {
    width: 0;
    outline: solid 2px
}
.docs-material-slider-track-on {
    background-color: #4285f4
}
.docs-material-slider-track-off {
    background-color: #bdbdbd
}
.docs-material-slider.goog-slider-disabled .docs-material-slider-thumb-grabber,
.docs-material-slider.goog-slider-disabled .docs-material-slider-track-on {
    background-color: #bdbdbd;
    border-color: #bdbdbd;
    cursor: default
}
.docs-material-slider:not(.docs-material-slider-mouse-focused):not(.goog-slider-disabled):focus .docs-material-slider-focus-ring {
    opacity: 1;
    transform: scale(1)
}
.docs-material-slider.docs-material-slider-mouse-focused:not(.goog-slider-disabled) .docs-material-slider-thumb-grabber {
    transform: scale(1)
}
.docs-material-slider-ltr.docs-material-slider-horizontal .docs-material-slider-track-on,
.docs-material-slider-rtl.docs-material-slider-horizontal .docs-material-slider-track-off {
    left: 0px
}
.docs-material-slider-ltr.docs-material-slider-horizontal .docs-material-slider-track-off,
.docs-material-slider-rtl.docs-material-slider-horizontal .docs-material-slider-track-on {
    right: 0px
}
.docs-material-slider-vertical .docs-material-slider-track-on {
    bottom: 0px
}
.docs-material-slider-vertical .docs-material-slider-track-off {
    top: 0px
}
.docs-material-menu-button-flat-primary,
.docs-material-menu-button-flat-default,
.docs-material-menu-button-raised-primary,
.docs-material-menu-button-raised-default {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    border-radius: 2px;
    border: 1px solid transparent;
    cursor: pointer;
    display: inline-block;
    font: 500 13px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    height: 32px;
    line-height: 30px;
    margin: 0 4px;
    text-transform: uppercase;
    vertical-align: middle
}
.docs-material-menu-button-raised-primary,
.docs-material-menu-button-raised-default {
    padding: 0 6px 0 16px
}
.docs-material-menu-button-flat-primary,
.docs-material-menu-button-flat-default {
    padding: 0 0 0 8px
}
.docs-material-menu-button-flat-primary {
    color: #4285f4
}
.docs-material-menu-button-flat-primary-hover {
    background-color: rgba(66, 133, 244, .12)
}
.docs-material-menu-button-flat-primary-active {
    background-color: rgba(66, 133, 244, .32);
    color: #3387d6
}
.docs-material-menu-button-flat-primary-focused {
    border: 1px inset #4285f4;
    outline: none
}
.docs-material-menu-button-flat-default {
    background-color: #fff;
    color: rgba(0, 0, 0, 0.54)
}
.docs-material-menu-button-flat-default-hover {
    background-color: rgba(102, 102, 102, .2)
}
.docs-material-menu-button-flat-default-active {
    background-color: rgba(0, 0, 0, .2);
    color: rgba(0, 0, 0, 0.87)
}
.docs-material-menu-button-flat-default-focused {
    border: 1px inset #4285f4;
    outline: none
}
.docs-material-menu-button-raised-primary {
    background-color: #4285f4;
    color: #fff
}
.docs-material-menu-button-raised-primary-hover,
.docs-material-menu-button-raised-default-hover {
    box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2)
}
.docs-material-menu-button-raised-primary-active,
.docs-material-menu-button-raised-default-active {
    box-shadow: 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12), 0px 2px 4px -1px rgba(0, 0, 0, 0.2)
}
.docs-material-menu-button-raised-primary-active {
    background-color: #3387d6
}
.docs-material-menu-button-raised-primary-focused {
    background-color: #4285f4;
    border: 1px inset rgba(0, 0, 0, 0.38);
    outline: none
}
.docs-material-menu-button-raised-default {
    background-color: rgba(0, 0, 0, .04);
    color: rgba(0, 0, 0, 0.54)
}
.docs-material-menu-button-raised-default-active {
    background-color: rgba(0, 0, 0, 0.12);
    color: rgba(0, 0, 0, 0.87)
}
.docs-material-menu-button-raised-default-focused {
    border: 1px inset #4285f4;
    color: rgba(0, 0, 0, 0.54);
    outline: none
}
.docs-material-menu-button-flat-primary-disabled,
.docs-material-menu-button-flat-default-disabled,
.docs-material-menu-button-raised-default-disabled {
    background-color: #fff;
    color: rgba(0, 0, 0, 0.26);
    cursor: auto
}
.docs-material-menu-button-raised-primary-disabled {
    background-color: rgba(0, 0, 0, 0.12);
    color: #fff;
    cursor: auto
}
.docs-material-menu-button-flat-primary-disabled,
.docs-material-menu-button-flat-default-disabled,
.docs-material-menu-button-raised-default-disabled,
.docs-material-menu-button-raised-primary-disabled {
    box-shadow: none
}
.docs-material-menu-button-flat-default-caption,
.docs-material-menu-button-flat-primary-caption,
.docs-material-menu-button-raised-default-caption,
.docs-material-menu-button-raised-primary-caption {
    float: left;
    vertical-align: middle
}
.docs-material-menu-button-flat-default-dropdown,
.docs-material-menu-button-flat-primary-dropdown {
    height: 24px;
    margin: 3px 0 3px 2px
}
.docs-material-menu-button-raised-default-dropdown,
.docs-material-menu-button-raised-primary-dropdown {
    height: 24px;
    margin: 3px 0 3px 8px
}
.docs-material-menu-button-raised-primary-dropdown-icon {
    fill: #fff
}
.docs-material-menu-button-flat-default-dropdown-icon,
.docs-material-menu-button-raised-default-dropdown-icon {
    fill: rgba(0, 0, 0, 0.54)
}
.docs-material-menu-button-flat-primary-dropdown-icon {
    fill: #4285f4;
    opacity: 0.54
}
.docs-material-menu-button-raised-default-disabled .docs-material-menu-button-raised-default-dropdown-icon,
.docs-material-menu-button-flat-default-disabled .docs-material-menu-button-flat-default-dropdown-icon,
.docs-material-menu-button-flat-primary-disabled .docs-material-menu-button-flat-primary-dropdown-icon {
    fill: rgba(0, 0, 0, 0.26);
    opacity: 1.0
}
.docs-material-button {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    -webkit-transition: box-shadow 0.28s cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: box-shadow 0.28s cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: box-shadow 0.28s cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: box-shadow 0.28s cubic-bezier(0.4, 0.0, 0.2, 1);
    border-radius: 2px;
    border: none;
    cursor: pointer;
    display: inline-block;
    font: 500 13px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    height: 32px;
    line-height: 32px;
    margin: 0 4px;
    overflow: hidden;
    outline: none;
    position: relative;
    text-align: center;
    text-transform: uppercase;
    vertical-align: middle
}
.docs-material-button-content {
    position: relative
}
.docs-material-button-ripple-element {
    border-radius: 50%;
    left: 50%;
    opacity: 0;
    padding-bottom: 200%;
    position: absolute;
    top: 50%;
    transition: transform 0s linear 0.2s, opacity 0.2s ease-in;
    width: 200%
}
.docs-material-button-ripple-effect>.docs-material-button-ripple-element {
    -webkit-transform: translate(-50%, -50%) scale(1);
    -moz-transform: translate(-50%, -50%) scale(1);
    -ms-transform: translate(-50%, -50%) scale(1);
    -o-transform: translate(-50%, -50%) scale(1);
    transform: translate(-50%, -50%) scale(1);
    opacity: 1;
    transition: transform 0.35s ease-out, opacity 0s linear;
    visibility: visible
}
.docs-material-button-disabled {
    box-shadow: none;
    cursor: default
}
.docs-material-button-flat-primary,
.docs-material-button-flat-default,
.docs-material-button-flat-dark {
    background-color: transparent;
    padding: 0 8px
}
.docs-material-button-raised-primary,
.docs-material-button-raised-default {
    padding: 0 16px
}
.docs-material-button-hover.docs-material-button-raised-primary,
.docs-material-button-hover.docs-material-button-raised-default {
    box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2)
}
.docs-material-button-active.docs-material-button-raised-primary,
.docs-material-button-active.docs-material-button-raised-default {
    box-shadow: 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12), 0px 2px 4px -1px rgba(0, 0, 0, 0.2)
}
.docs-material-button-raised-primary {
    background-color: #4285f4;
    color: #fff
}
.docs-material-button-flat-primary {
    color: #4285f4
}
.docs-material-button-flat-default {
    color: rgba(0, 0, 0, 0.54)
}
.docs-material-button-flat-dark {
    color: #fff
}
.docs-material-button-hover.docs-material-button-flat-primary {
    background-color: rgba(66, 133, 244, .12)
}
.docs-material-button-hover.docs-material-button-flat-dark {
    background-color: rgba(256, 256, 256, 0.1)
}
.docs-material-button-active.docs-material-button-flat-primary {
    color: #3367d6
}
.docs-material-button-raised-primary.docs-material-button-focused {
    border: 1px inset rgba(0, 0, 0, 0.38);
    background: #3b78e7;
    line-height: 30px;
    padding: 0 15px
}
.docs-material-button-raised-default.docs-material-button-focused {
    border: 1px inset #4285f4;
    line-height: 30px;
    padding: 0 15px
}
.docs-material-button-flat-primary.docs-material-button-focused,
.docs-material-button-flat-default.docs-material-button-focused {
    border: 1px inset #4285f4;
    line-height: 30px;
    padding: 0 7px
}
.docs-material-button-flat-dark.docs-material-button-focused {
    border: 1px solid #fff;
    line-height: 30px;
    padding: 0 7px
}
.docs-material-button.docs-material-button-focused.docs-material-button-no-focus-border {
    border: none;
    line-height: 32px
}
.docs-material-button-raised-primary.docs-material-button-focused.docs-material-button-no-focus-border,
.docs-material-button-raised-default.docs-material-button-focused.docs-material-button-no-focus-border {
    padding: 0 16px
}
.docs-material-button-flat-primary.docs-material-button-focused.docs-material-button-no-focus-border,
.docs-material-button-flat-default.docs-material-button-focused.docs-material-button-no-focus-border,
.docs-material-button-flat-dark.docs-material-button-focused.docs-material-button-no-focus-border {
    padding: 0 8px
}
.docs-material-button-focused {
    outline: 1px dotted transparent;
    outline-offset: -4px
}
.docs-material-button-hover.docs-material-button-flat-default {
    background-color: rgba(0, 0, 0, 0.12)
}
.docs-material-button-active.docs-material-button-flat-default {
    color: rgba(0, 0, 0, 0.87)
}
.docs-material-button-raised-default {
    background-color: rgba(0, 0, 0, .04);
    color: rgba(0, 0, 0, 0.54)
}
.docs-material-button-active.docs-material-button-raised-default {
    color: rgba(0, 0, 0, 0.87)
}
.docs-material-button-disabled.docs-material-button-flat-primary,
.docs-material-button-disabled.docs-material-button-flat-default,
.docs-material-button-disabled.docs-material-button-raised-default {
    background-color: #fff;
    color: rgba(0, 0, 0, 0.26)
}
.docs-material-button-disabled.docs-material-button-flat-dark {
    color: rgba(255, 255, 255, 0.30)
}
.docs-material-button-disabled.docs-material-button-raised-primary {
    background-color: rgba(0, 0, 0, 0.12);
    color: #fff
}
.docs-material-button-flat-primary>.docs-material-button-ripple-element {
    background-color: rgba(66, 133, 244, .32)
}
.docs-material-button-raised-primary>.docs-material-button-ripple-element {
    background-color: #3367d6
}
.docs-material-button-flat-default>.docs-material-button-ripple-element {
    background-color: rgba(0, 0, 0, .2)
}
.docs-material-button-flat-dark>.docs-material-button-ripple-element {
    background-color: rgba(256, 256, 256, 0.24)
}
.docs-material-button-raised-default>.docs-material-button-ripple-element {
    background-color: rgba(0, 0, 0, 0.12)
}
.docs-material-button-hairline-primary.docs-material-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #dadce0!important;
    color: #188038;
    text-transform: none
}
.docs-material-button-hairline-default.docs-material-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #dadce0!important;
    color: #188038;
    color: #5f6368;
    text-transform: none
}
.docs-material-button-hairline-default.docs-material-button-hover,
.docs-material-button-hairline-primary.docs-material-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #f8fcf9;
    border: 1px solid #c8e7d1!important
}
.docs-material-button-hairline-default.docs-material-button-focused,
.docs-material-button-hairline-primary.docs-material-button-focused,
.docs-material-button-hairline-default.docs-material-button-focused.docs-material-button-no-focus-border,
.docs-material-button-hairline-primary.docs-material-button-focused.docs-material-button-no-focus-border {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #e7f5eb;
    border: 1px solid #bbe2c6!important
}
.docs-material-button-hairline-default.docs-material-button-hover.docs-material-button-focused,
.docs-material-button-hairline-primary.docs-material-button-hover.docs-material-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    border: 1px solid #b5e0c1!important
}
.docs-material-button-hairline-default.docs-material-button-active,
.docs-material-button-hairline-primary.docs-material-button-active {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    border: 1px solid transparent!important;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.docs-material-button-hairline-default.docs-material-button-disabled,
.docs-material-button-hairline-primary.docs-material-button-disabled {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #f1f3f4!important;
    color: #3c4043;
    opacity: 0.38
}
.docs-material-button-fill-primary.docs-material-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff
}
.docs-material-button-fill-primary.docs-material-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #2a8947;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-material-button-fill-primary.docs-material-button-focused,
.docs-material-button-fill-primary.docs-material-button-focused.docs-material-button-no-focus-border {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #4f9e67;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-material-button-fill-primary.docs-material-button-hover.docs-material-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-material-button-fill-primary.docs-material-button-active {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 2px 6px 2px rgba(52, 168, 83, 0.15)
}
.docs-material-button-fill-primary.docs-material-button-disabled {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #f1f3f4;
    color: #3c4043;
    opacity: 0.38
}
.addon-sidebar-card {
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    border-bottom: 1px solid rgba(0, 0, 0, .12);
    outline: none;
    padding: 14px 16px 8px 16px
}
.addon-sidebar-card-header {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    padding-bottom: 8px
}
.addon-sidebar-card-header-content {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    width: 100%
}
.addon-sidebar-card-icon {
    height: 24px;
    padding-right: 16px;
    padding-top: 2px;
    width: 24px
}
.addon-sidebar-card-icon img {
    height: 24px;
    width: 24px
}
.addon-sidebar-card-title {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    width: 100%
}
.addon-sidebar-card-title-caption.goog-control-focused {
    outline: none;
    text-decoration: underline
}
.addon-sidebar-card-title-caption.goog-control-hover {
    text-decoration: underline
}
.addon-sidebar-card-title-caption {
    color: rgba(0, 0, 0, 0.87);
    cursor: pointer;
    font-size: 15px;
    font-weight: 500;
    line-height: 20px;
    margin-right: 9px;
    max-height: 38px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.addon-sidebar-card-two-line-title-caption {
    display: -webkit-box;
    visibility: visible;
    -webkit-line-clamp: 2;
    -webkit-box-orient: vertical;
    white-space: normal;
    word-break: break-word;
    word-wrap: break-word
}
.addon-sidebar-card-check {
    color: #455a64;
    height: 18px;
    margin: 1px 0 0 auto;
    width: 18px
}
.addon-sidebar-card-category {
    color: rgba(0, 0, 0, 0.54);
    font-size: 13px;
    font-weight: 400;
    line-height: 20px
}
.addon-sidebar-card-summary {
    color: rgba(0, 0, 0, 0.54);
    font-size: 13px;
    font-weight: 400;
    line-height: 20px;
    overflow: hidden;
    padding: 0 0 8px 40px;
    text-overflow: ellipsis
}
.addon-sidebar-with-banner .addon-sidebar-card {
    border-bottom: none;
    padding-top: 16px
}
.addon-sidebar-with-banner .addon-sidebar-card-header {
    padding-bottom: 16px
}
.addon-sidebar-with-banner .addon-sidebar-card-title-caption {
    max-width: 194px
}
.addon-sidebar-with-banner .addon-sidebar-card-icon {
    height: 40px;
    padding-top: 0px;
    width: 40px
}
.addon-sidebar-with-banner .addon-sidebar-card-icon img {
    height: 40px;
    width: 40px
}
.addon-sidebar-with-banner .addon-sidebar-card-title {
    font-size: 16px
}
.addon-sidebar-with-banner .addon-sidebar-card-summary {
    font-size: 14px;
    padding: 0 0 24px 0
}
.addon-sidebar-card-button.docs-material-button-flat-primary,
.addon-sidebar-card-menu-button.docs-material-menu-button-flat-primary {
    margin-left: 32px
}
.addon-sidebar-card-button.docs-material-button-raised-primary,
.addon-sidebar-card-menu-button.docs-material-menu-button-raised-primary {
    margin-left: 0px
}
.addon-sidebar-card-button.docs-material-button-flat-primary,
.addon-sidebar-card-button.docs-material-button-raised-primary {
    height: 32px;
    line-height: 32px
}
.addon-sidebar-card-button.docs-material-button-flat-primary {
    padding: 0 8px
}
.addon-sidebar-card-menu-button.docs-material-menu-button-flat-primary,
.addon-sidebar-card-menu-button.docs-material-menu-button-raised-primary {
    height: 32px;
    line-height: 32px
}
.addon-sidebar-card-menu-button.docs-material-menu-button-flat-primary {
    padding: 0 2px 0 8px
}
.addon-sidebar-card-menu-button .docs-material-menu-button-flat-primary-caption,
.addon-sidebar-card-menu-button .docs-material-menu-button-raised-primary-caption {
    line-height: 32px
}
.addon-sidebar-card-menu-button .docs-material-menu-button-flat-primary-dropdown,
.addon-sidebar-card-menu-button .docs-material-menu-button-raised-primary-dropdown {
    margin-top: 3px
}
.goog-menuitem.addon-sidebar-menu-item-with-flat,
.goog-menuitem.addon-sidebar-menu-item-with-raised {
    padding-right: 30px
}
.addon-sidebar-menu-item-with-flat .goog-menuitem-content {
    max-width: 174px;
    overflow: hidden;
    text-overflow: ellipsis
}
.addon-sidebar-menu-item-with-raised .goog-menuitem-content {
    max-width: 206px;
    overflow: hidden;
    text-overflow: ellipsis
}
.addon-sidebar {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    background: #fff;
    border-left: 1px solid #d9d9d9;
    color: #222;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    outline: none;
    position: absolute;
    right: 0;
    width: 300px
}
.addon-sidebar-header {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    background: #616161;
    color: #fff;
    font-size: 15px;
    font-weight: 500;
    padding: 10px 16px 9px 16px;
    position: relative
}
.addon-sidebar-close {
    cursor: pointer;
    height: 21px;
    position: absolute;
    right: 13px;
    top: 7px;
    width: 21px
}
.addon-sidebar-content {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    height: 100%;
    width: 300px;
    overflow-y: overlay
}
.addon-sidebar-introduction {
    border-bottom: 1px solid rgba(0, 0, 0, .12);
    color: rgba(0, 0, 0, .54);
    font-size: 11px;
    font-weight: 500;
    line-height: 15px;
    padding: 10px 16px 10px 16px
}
.addon-sidebar-banner {
    display: inline-grid;
    position: relative
}
.addon-sidebar-banner-image {
    display: block;
    height: auto;
    width: 300px
}
.addon-sidebar-banner-image-overlay {
    background-image: linear-gradient(-180deg, rgba(0, 0, 0, 0.00) 0%, rgba(0, 0, 0, 0.01) 30%, rgba(0, 0, 0, 0.03) 50%, rgba(0, 0, 0, 0.06) 70%, rgba(0, 0, 0, 0.09) 90%, rgba(0, 0, 0, 0.11) 96%, rgba(0, 0, 0, 0.13) 100%);
    bottom: 0;
    position: absolute;
    width: 300px;
    height: 80px
}
.addon-sidebar-spinner {
    position: fixed;
    top: 50%;
    width: 300px
}
.addon-sidebar-empty-caption {
    position: fixed;
    text-align: center;
    top: 50%;
    width: 300px
}
.addon-sidebar-empty-title {
    color: rgba(0, 0, 0, 0.87);
    font-size: 15px;
    font-weight: 700;
    line-height: 18px;
    padding-bottom: 8px
}
.addon-sidebar-empty-description {
    color: rgba(0, 0, 0, 0.50);
    font-size: 13px;
    font-weight: 500;
    line-height: 18px
}
.script-application-sidebar {
    background: #fff;
    border-left: 1px solid #d9d9d9;
    color: #222;
    position: absolute;
    right: 0;
    width: 300px
}
.script-application-sidebar-header {
    background: #616161;
    border: 1px solid #616161;
    color: #fff;
    font-size: 13px;
    font-weight: bold;
    height: 15px;
    padding: 10px 0 10px 12px;
    position: relative
}
.script-application-sidebar-close {
    cursor: pointer;
    position: absolute;
    right: 6px;
    top: 8px
}
.script-application-sidebar-content {
    bottom: 0;
    position: absolute;
    top: 37px;
    width: 100%
}
#docs-script-button-bar .jfk-button {
    margin-right: 9px
}
.docs-script-button-bar-text {
    color: #777;
    display: inline-block;
    margin-left: 10px;
    margin-right: 20px;
    max-width: 55px;
    outline: none;
    overflow: hidden;
    text-overflow: ellipsis;
    vertical-align: text-bottom;
    white-space: nowrap
}
.docs-script-button-bar-text:hover {
    cursor: pointer;
    text-decoration: underline
}
.docs-script-button-bar-bubble {
    width: 175px
}
.docs-script-button-bar-bubble-content {
    text-align: left;
    white-space: normal
}
.script-errorfield {
    border-color: #dd4b39!important
}
.script-errormsg {
    color: #dd4b39!important
}
.script-promo-menu-item {
    border: 0px;
    min-height: 90px;
    max-width: 354px;
    padding: 0px!important
}
.script-promo-menu-item-content {
    vertical-align: middle;
    padding: 10px 20px
}
.script-promo-menu-item-description {
    color: #4a4a4a;
    font-size: 13px
}
.script-promo-menu-item-icon {
    display: inline-block;
    height: 75px;
    vertical-align: middle;
    width: 75px
}
.script-promo-menu-item-text {
    display: inline-block;
    max-width: 170px;
    padding-left: 10px;
    vertical-align: middle;
    white-space: pre-line
}
.script-promo-menu-item-title {
    color: #222222;
    font-weight: bold;
    font-size: 18px
}
.func-entry {
    border-top: 1px solid #ffffff;
    border-left: 1px solid #ffffff;
    border-right: 1px solid #ffffff;
    border-bottom: 1px solid #e5e5e5;
    cursor: default;
    outline: none
}
.func-entry:focus {
    border: 1px solid #4d90fe!important
}
.func-entry-checked {
    border-top: 1px solid #ffc;
    border-left: 1px solid #ffc;
    border-right: 1px solid #ffc;
    border-bottom: 1px solid #e5e5e5;
    background-color: #ffc
}
.func-entry-func,
.func-entry-lib {
    width: 305px;
    margin-left: 5px;
    padding-top: 4px;
    padding-bottom: 4px;
    white-space: nowrap;
    text-overflow: ellipsis;
    overflow: hidden
}
.func-entry-rb {
    float: left;
    padding-left: 8px;
    width: 18px;
    height: 26px
}
.func-entry-rb {
    background-image: url(//ssl.gstatic.com/ui/v1/radiobutton/unchecked.png);
    background-position: center center;
    background-repeat: no-repeat
}
.func-entry-checked .func-entry-rb {
    background-image: url(//ssl.gstatic.com/ui/v1/radiobutton/checked.png)
}
.modal-dialog.docs-dialog.gsm-widget {
    border: 0;
    border-radius: 0;
    box-shadow: none;
    padding: 0
}
.modal-dialog.docs-dialog.gsm-widget .modal-dialog-title {
    display: none;
    height: 0;
    margin: 0
}
.gsm-widget .modal-dialog-buttons {
    display: none
}
.gsm-widget .modal-dialog-content {
    background-color: transparent
}
.script-help-dialog {
    min-width: 392px
}
.script-help-dialog-content-left {
    border: 1px solid #e5e5e5;
    height: 160px;
    overflow-y: auto;
    vertical-align: top;
    width: 254px
}
.script-help-dialog-content-section {
    padding: 16px
}
.script-help-dialog-content-left-gsm-onhold {
    background-color: #fad2cf
}
.script-help-dialog-content-title {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    font-weight: 700;
    padding-bottom: 8px
}
.script-help-dialog-content-title-caution-icon {
    padding-right: 4px
}
.script-help-dialog-buttons {
    min-width: 102px;
    max-width: 200px;
    padding-left: 16px;
    vertical-align: top
}
.script-help-dialog-buttons .jfk-button {
    display: block;
    margin-right: 0px;
    margin-bottom: 16px;
    padding: 0px 8px 0px 8px;
    width: 100%
}
.script-manager-box {
    border: none;
    height: 450px;
    width: 700px
}
.script-prompt-contents DIV {
    min-width: 300px;
    max-width: 700px;
    max-height: 350px;
    overflow: auto
}
.script-prompt-contents INPUT {
    width: 100%
}
.script-app-dialog {
    z-index: 1003
}
.script-app-contents {
    padding: 0px
}
.script-error-message {
    max-height: 1em;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    display: inline-block
}
.script-error-dialog-content {
    max-height: 400px;
    max-width: 600px;
    overflow: auto
}
.script-postinstallbubble-dialog {
    outline: none
}
.script-postinstallbubble-content {
    max-width: 293px
}
.script-postinstallbubble-dialog .jfk-bubble-closebtn {
    right: 8px;
    top: 8px
}
.script-postinstallbubble-title {
    font-size: 16px;
    margin-bottom: 13px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    width: 274px
}
.script-postinstallbubble-description {
    font: normal 13px/1.4 arial, sans-serif;
    margin-bottom: 13px
}
.script-reportissue-dialog-content {
    width: 456px
}
.script-reportissue-dialog-description {
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
    font-family: arial, sans-serif;
    height: 100px;
    resize: none;
    vertical-align: top;
    width: 100%
}
.script-reportissue-dialog-nonanonymous-control {
    vertical-align: top;
    width: 20px
}
.script-reportissue-dialog-nonanonymous-label {
    vertical-align: top;
    width: 436px
}
.script-reportissue-dialog-nonanonymous-optional-text {
    color: #777
}
.script-explorer-contents {
    height: 350px;
    width: 700px;
    overflow: hidden
}
.func-header {
    width: 100%;
    border-top: 1px solid #e5e5e5;
    color: #555;
    cursor: default;
    font-weight: bold;
    text-transform: uppercase
}
.func-actions {
    margin-bottom: 14px
}
#func-action-new {
    margin-right: 22px!important
}
#func-action-reload {
    position: absolute;
    right: 26px;
    width: 45px
}
#func-action-reload .docs-icon {
    opacity: 0.7
}
.func-header-func,
.func-header-lib {
    width: 307px;
    margin-left: 5px;
    padding-top: 4px;
    padding-bottom: 4px;
    white-space: nowrap;
    text-overflow: ellipsis;
    overflow: hidden
}
.func-header-rb {
    width: 26px
}
.func-entries {
    max-height: 272px;
    border-top: 1px solid #e5e5e5;
    overflow-x: hidden;
    overflow-y: auto
}
.func-entries:focus {
    outline: none
}
.func-none,
.func-loading {
    width: 640px;
    cursor: default;
    padding-top: 4px;
    padding-bottom: 4px
}
.func-none {
    margin-left: 30px
}
.func-loading {
    background: transparent url(//ssl.gstatic.com/docs/script/images/spin-wait.gif) no-repeat 0 4px;
    padding-left: 20px;
    margin-left: 12px
}
.webstore-widget {
    padding: 0
}
.webstore-widget .modal-dialog-title {
    border-bottom: 1px solid #acacac;
    margin: 0;
    padding: 16px 12px
}
.active-account-dialog-email {
    font-weight: 500;
    word-break: break-all
}
.active-account-dialog .modal-dialog-content {
    display: flex
}
.active-account-dialog-display-name {
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    line-height: 12px;
    padding: 8px;
    display: flex;
    align-items: center
}
.active-account-dialog-avatar {
    background-color: #9aa0a6;
    border-radius: 50%;
    object-fit: cover;
    height: 32px;
    width: 32px
}
.active-account-dialog .modal-dialog-buttons {
    margin-top: 32px
}
.modal-dialog.active-account-dialog {
    display: table;
    max-width: 464px;
    table-layout: fixed
}
.goog-checkbox {
    border: 1px solid #1c5180;
    display: -moz-inline-box;
    display: inline-block;
    font-size: 1px;
    height: 11px;
    margin: 0 4px 0 1px;
    vertical-align: text-bottom;
    width: 11px
}
.goog-checkbox-checked {
    background: #fff url(//ssl.gstatic.com/closure/check-sprite.gif) no-repeat 2px center
}
.goog-checkbox-undetermined {
    background: #bbb url(//ssl.gstatic.com/closure/check-sprite.gif) no-repeat 2px center
}
.goog-checkbox-unchecked {
    background: #fff
}
.goog-checkbox-disabled {
    border: 1px solid lightgray;
    background-position: -7px
}
.jfk-checkbox {
    -webkit-border-radius: 1px;
    -moz-border-radius: 1px;
    border-radius: 1px;
    background-color: rgba(255, 255, 255, .05);
    border: 1px solid #c6c6c6;
    border: 1px solid rgba(155, 155, 155, .57);
    font-size: 1px;
    height: 11px;
    margin: 0px 4px 0px 1px;
    outline: 0;
    vertical-align: text-bottom;
    width: 11px
}
.jfk-checkbox-undetermined {
    background-color: #fff;
    background-color: rgba(255, 255, 255, .65)
}
.jfk-checkbox-checked {
    background-color: #fff;
    background-color: rgba(255, 255, 255, .65)
}
.jfk-checkbox-hover {
    -webkit-box-shadow: inset 0px 1px 1px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0px 1px 1px rgba(0, 0, 0, .1);
    box-shadow: inset 0px 1px 1px rgba(0, 0, 0, .1);
    border: 1px solid #b2b2b2
}
.jfk-checkbox-active {
    background-color: #ebebeb
}
.jfk-checkbox-focused {
    border: 1px solid #4d90fe
}
.jfk-checkbox-clearOutline.jfk-checkbox-focused {
    border: 1px solid #c6c6c6;
    border: 1px solid rgba(155, 155, 155, .57)
}
.jfk-checkbox-disabled,
.jfk-checkbox-clearOutline.jfk-checkbox-disabled {
    background-color: #fff;
    border: 1px solid #f1f1f1;
    cursor: default
}
.jfk-checkbox-checkmark {
    height: 15px;
    outline: 0;
    width: 15px;
    left: 0;
    position: relative;
    top: -3px
}
.jfk-checkbox-undetermined .jfk-checkbox-checkmark {
    background: url(//ssl.gstatic.com/ui/v1/menu/checkmark-partial.png) no-repeat -5px -3px;
    background-image: -webkit-image-set(url(//ssl.gstatic.com/ui/v1/menu/checkmark-partial.png) 1x, url(//ssl.gstatic.com/ui/v1/menu/checkmark-partial_2x.png) 2x)
}
.jfk-checkbox-checked .jfk-checkbox-checkmark {
    background: url(//ssl.gstatic.com/ui/v1/menu/checkmark.png) no-repeat -5px -3px;
    background-image: -webkit-image-set(url(//ssl.gstatic.com/ui/v1/menu/checkmark.png) 1x, url(//ssl.gstatic.com/ui/v1/menu/checkmark_2x.png) 2x)
}
.jfk-colormenu.goog-menu {
    padding: 0
}
.jfk-palette {
    cursor: default;
    outline: none
}
.jfk-palette-table {
    empty-cells: show;
    margin: 16px
}
.jfk-palette-cell {
    border: 1px solid transparent;
    cursor: pointer;
    margin: 0;
    position: relative
}
.jfk-palette-cell-hover {
    border: 1px solid #000
}
.jfk-palette-cell-selected {
    outline: 1px solid #000
}
.jfk-palette-colorswatch {
    height: 16px;
    width: 16px
}
.jfk-palette-cell-selected>.jfk-palette-colorswatch {
    background: url(//ssl.gstatic.com/ui/v1/colorpicker/checkmark.png) no-repeat 50% 50%
}
.jfk-colorwell {
    border: 1px solid #d9d9d9
}
.jfk-butterBar {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    -webkit-box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.2);
    -webkit-transition: all 0s linear 1s, opacity 1s;
    -moz-transition: all 0s linear 1s, opacity 1s;
    -o-transition: all 0s linear 1s, opacity 1s;
    transition: all 0s linear 1s, opacity 1s;
    border-style: solid;
    border-width: 0;
    font-size: 11px;
    height: 0;
    opacity: 0;
    visibility: hidden;
    overflow: hidden;
    padding: 0;
    text-align: center
}
.jfk-butterBar-info {
    background-color: #f9edbe;
    border-color: #f0c36d;
    color: #333
}
.jfk-butterBar-error {
    background-color: #484848;
    border-color: #202020;
    color: #fff
}
.jfk-butterBar-promo {
    background-color: #d6e9f8;
    border-color: #4d90f0;
    color: #333
}
.jfk-butterBar-warning {
    background-color: #dd4b39;
    border-color: #602019;
    color: #fff
}
.jfk-butterBar-shown {
    -webkit-transition: opacity 0.218s;
    -moz-transition: opacity 0.218s;
    -o-transition: opacity 0.218s;
    transition: opacity 0.218s;
    border-width: 1px;
    min-height: 14px;
    height: auto;
    opacity: 1;
    visibility: visible;
    padding: 6px 16px
}
.jfk-butterBar-mini.jfk-butterBar-shown {
    padding: 2px 16px
}
.goog-link-button {
    position: relative;
    color: #15c;
    text-decoration: underline;
    cursor: pointer
}
.goog-link-button-disabled {
    color: #ccc;
    text-decoration: none;
    cursor: default
}
.goog-toolbar {
    background: #f5f5f5;
    border-top: 1px solid #e5e5e5;
    border-bottom: 1px solid #ebebeb;
    outline: 0;
    padding: 8px 0 4px 0;
    position: relative;
    zoom: 1
}
.jfk-freestanding-menu-button {
    -webkit-border-radius: 1px;
    -moz-border-radius: 1px;
    border-radius: 1px;
    background: url(//ssl.gstatic.com/ui/v1/disclosure/light-grey-disclosure-arrow-down.png) center no-repeat;
    border: 1px solid #e5e5e5;
    height: 11px;
    width: 11px;
    cursor: pointer
}
.jfk-freestanding-menu-button-hover,
.jfk-freestanding-menu-button-active,
.jfk-freestanding-menu-button-open {
    background: url(//ssl.gstatic.com/ui/v1/disclosure/dark-grey-disclosure-arrow-down.png) center no-repeat #eee;
    border-color: #c6c6c6
}
.jfk-select .goog-flat-menu-button-caption {
    overflow: hidden;
    width: 100%
}
.jfk-select .goog-flat-menu-button-dropdown {
    background: url(//ssl.gstatic.com/ui/v1/disclosure/grey-disclosure-arrow-up-down.png) center no-repeat;
    border: none;
    height: 11px;
    margin-top: -4px;
    width: 7px
}
.jfk-progressStatus {
    color: #202020
}
.jfk-progressText {
    color: #999
}
.jfk-progressStatus,
.jfk-progressText {
    line-height: 18px
}
.jfk-progressBar-blocking .progress-bar-horizontal,
.jfk-progressBar-nonBlocking .progress-bar-horizontal {
    border: 1px solid #999;
    padding: 1px;
    width: 320px
}
.jfk-progressBar-blocking .progress-bar-thumb {
    background-color: #6188f5;
    height: 5px
}
.jfk-progressBar-nonBlocking .progress-bar-thumb {
    background-color: #ccc;
    height: 5px
}
.jfk-progressBar-blocking.jfk-progressBar-tall .progress-bar-thumb,
.jfk-progressBar-nonBlocking.jfk-progressBar-tall .progress-bar-thumb {
    height: 8px
}
.jfk-progressBar-blocking .progress-bar-thumb {
    -webkit-animation: jfk-progressBar-bg 0.8s linear 0s infinite;
    -moz-animation: jfk-progressBar-bg 0.8s linear 0s infinite;
    -o-animation: jfk-progressBar-bg 0.8s linear 0s infinite;
    animation: jfk-progressBar-bg 0.8s linear 0s infinite;
    background-position: 0 0;
    background-repeat: repeat-x;
    background-size: 16px 8px;
    background-color: #6188f5;
    background-image: -webkit-linear-gradient(315deg, transparent, transparent 33%, rgba(0, 0, 0, .12) 33%, rgba(0, 0, 0, .12) 66%, transparent 66%, transparent);
    background-image: -moz-linear-gradient(315deg, transparent, transparent 33%, rgba(0, 0, 0, .12) 33%, rgba(0, 0, 0, .12) 66%, transparent 66%, transparent);
    background-image: -ms-linear-gradient(315deg, transparent, transparent 33%, rgba(0, 0, 0, .12) 33%, rgba(0, 0, 0, .12) 66%, transparent 66%, transparent);
    background-image: -o-linear-gradient(315deg, transparent, transparent 33%, rgba(0, 0, 0, .12) 33%, rgba(0, 0, 0, .12) 66%, transparent 66%, transparent);
    background-image: linear-gradient(315deg, transparent, transparent 33%, rgba(0, 0, 0, .12) 33%, rgba(0, 0, 0, .12) 66%, transparent 66%, transparent)
}
.jfk-progressBar-blocking.jfk-progressBar-tall .progress-bar-thumb {
    -webkit-animation: jfk-progressBar-bg-tall 0.8s linear 0s infinite;
    -moz-animation: jfk-progressBar-bg-tall 0.8s linear 0s infinite;
    -o-animation: jfk-progressBar-bg-tall 0.8s linear 0s infinite;
    animation: jfk-progressBar-bg-tall 0.8s linear 0s infinite;
    background-size: 20px 10px
}
@-webkit-keyframes jfk-progressBar-bg {
    0% {
        background-position: 0 0
    }
    100% {
        background-position: -16px 0
    }
}
@-moz-keyframes jfk-progressBar-bg {
    0% {
        background-position: 0 0
    }
    100% {
        background-position: -16px 0
    }
}
@-o-keyframes jfk-progressBar-bg {
    0% {
        background-position: 0 0
    }
    100% {
        background-position: -16px 0
    }
}
@keyframes jfk-progressBar-bg {
    0% {
        background-position: 0 0
    }
    100% {
        background-position: -16px 0
    }
}
@-webkit-keyframes jfk-progressBar-bg-tall {
    0% {
        background-position: 0 0
    }
    100% {
        background-position: -20px 0
    }
}
@-moz-keyframes jfk-progressBar-bg-tall {
    0% {
        background-position: 0 0
    }
    100% {
        background-position: -20px 0
    }
}
@-o-keyframes jfk-progressBar-bg-tall {
    0% {
        background-position: 0 0
    }
    100% {
        background-position: -20px 0
    }
}
@keyframes jfk-progressBar-bg-tall {
    0% {
        background-position: 0 0
    }
    100% {
        background-position: -20px 0
    }
}
.jfk-progressbar .progress-bar-horizontal,
.jfk-progressbar .progress-bar-vertical {
    border-color: #999
}
.jfk-progressbar .progress-bar-thumb {
    background-color: #ccc
}
.jfk-radiobutton {
    display: inline-block;
    outline: none;
    padding: 5px 7px;
    position: relative
}
.jfk-radiobutton-radio {
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    background: url(//ssl.gstatic.com/ui/v1/radiobutton/unchecked.png) -3px -3px;
    background: rgba(255, 255, 255, 0);
    border: 1px solid rgba(198, 198, 198, 1);
    height: 15px;
    left: 7px;
    margin: 0;
    outline: none;
    position: absolute;
    text-align: left;
    top: 6px;
    width: 15px
}
.jfk-radiobutton:active .jfk-radiobutton-radio {
    background: rgba(235, 235, 235, 1);
    border-color: rgba(182, 182, 182, 1)
}
.jfk-radiobutton:hover .jfk-radiobutton-radio {
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, .1);
    border-color: rgba(182, 182, 182, 1)
}
.jfk-radiobutton:focus .jfk-radiobutton-radio {
    border-color: rgba(77, 144, 254, 1)
}
.jfk-radiobutton-checked .jfk-radiobutton-radio {
    background: url(//ssl.gstatic.com/ui/v1/radiobutton/checked.png) -3px -3px;
    background: rgba(255, 255, 255, 0)
}
.jfk-radiobutton.jfk-radiobutton:focus .jfk-radiobutton-radio {
    background: url(//ssl.gstatic.com/ui/v1/radiobutton/unchecked_focused.png) -3px -3px;
    background: rgba(255, 255, 255, 0)
}
.jfk-radiobutton-checked.jfk-radiobutton:focus .jfk-radiobutton-radio {
    background: url(//ssl.gstatic.com/ui/v1/radiobutton/checked_focused.png) -3px -3px;
    background: rgba(255, 255, 255, 0)
}
.jfk-radiobutton-checked .jfk-radiobutton-radio::after {
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    background: rgba(96, 96, 96, 1);
    border: 2px solid #606060;
    box-sizing: border-box;
    content: '';
    display: block;
    height: 7px;
    left: 3px;
    position: relative;
    top: 3px;
    width: 7px
}
.jfk-radiobutton .jfk-radiobutton-label {
    display: block;
    cursor: default;
    margin-left: 22px
}
.jfk-radiobutton-disabled .jfk-radiobutton-radio {
    background: url(//ssl.gstatic.com/ui/v1/radiobutton/unchecked-disabled.png) -3px -3px;
    background: rgba(255, 255, 255, 0);
    border-color: rgba(241, 241, 241, 1)
}
.jfk-radiobutton-disabled.jfk-radiobutton-checked .jfk-radiobutton-radio {
    background: url(//ssl.gstatic.com/ui/v1/radiobutton/checked-disabled.png) -3px -3px;
    background: rgba(255, 255, 255, 0)
}
.jfk-radiobutton-disabled.jfk-radiobutton-checked .jfk-radiobutton-radio::after {
    background: rgba(184, 184, 184, 1)
}
.jfk-radiobutton-disabled .jfk-radiobutton-label {
    color: rgb(184, 184, 184)
}
.jfk-radiobutton-disabled:active .jfk-radiobutton-radio,
.jfk-radiobutton-disabled:hover .jfk-radiobutton-radio {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background: rgba(255, 255, 255, 1);
    border-color: rgba(241, 241, 241, 1)
}
.goog-slider {
    position: relative;
    outline: 0
}
.goog-slider-horizontal {
    height: 18px
}
.goog-slider-vertical {
    width: 18px
}
.goog-slider-thumb {
    background-color: #f5f5f5;
    background-image: -webkit-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -o-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: linear-gradient(top, #f5f5f5, #f1f1f1);
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    -webkit-transition: background-color 0.218s, border-color 0.218s, background-image 0.218s;
    -moz-transition: background-color 0.218s, border-color 0.218s, background-image 0.218s;
    -o-transition: background-color 0.218s, border-color 0.218s, background-image 0.218s;
    transition: background-color 0.218s, border-color 0.218s, background-image 0.218s;
    border: 1px solid #dcdcdc;
    height: 16px;
    position: absolute;
    width: 16px
}
.goog-slider-thumb:hover {
    background-color: #f8f8f8;
    background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -o-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
    border-color: #c6c6c6
}
.goog-slider-scale {
    position: absolute
}
.goog-slider-horizontal .goog-slider-scale {
    border-top: 1px solid #ccc;
    top: 8px;
    width: 100%
}
.goog-slider-vertical .goog-slider-scale {
    border-left: 1px solid #ccc;
    height: 100%;
    left: 8px
}
.jfk-twothumbslider {
    position: relative;
    outline: 0
}
.goog-twothumbslider-horizontal {
    height: 18px
}
.goog-twothumbslider-vertical {
    width: 18px
}
.goog-twothumbslider-horizontal .goog-twothumbslider-value-thumb,
.goog-twothumbslider-horizontal .goog-twothumbslider-extent-thumb {
    position: absolute;
    height: 0;
    width: 16px
}
.goog-twothumbslider-vertical .goog-twothumbslider-value-thumb,
.goog-twothumbslider-vertical .goog-twothumbslider-extent-thumb {
    position: absolute;
    height: 16px;
    width: 0
}
.jfk-slider-thumbimpl {
    background-color: #999;
    border: 1px solid #999;
    -webkit-transition: background-color 0.218s, border-color 0.218s, background-image 0.218s;
    -moz-transition: background-color 0.218s, border-color 0.218s, background-image 0.218s;
    -o-transition: background-color 0.218s, border-color 0.218s, background-image 0.218s;
    transition: background-color 0.218s, border-color 0.218s, background-image 0.218s
}
.jfk-twothumbslider:hover .jfk-slider-thumbimpl,
.jfk-twothumbslider.goog-slider-dragging .jfk-slider-thumbimpl {
    background-color: #fff
}
.jfk-twothumbslider.goog-slider-dragging .goog-slider-thumb-dragging .jfk-slider-thumbimpl {
    background-color: #535252;
    border-color: #535252
}
.goog-twothumbslider-horizontal .jfk-slider-thumbimpl {
    height: 16px;
    width: 8px
}
.goog-twothumbslider-horizontal .goog-twothumbslider-value-thumb .jfk-slider-thumbimpl {
    -webkit-border-radius: 8px 0 0 8px;
    -moz-border-radius: 8px 0 0 8px;
    border-radius: 8px 0 0 8px
}
.goog-twothumbslider-horizontal .goog-twothumbslider-extent-thumb .jfk-slider-thumbimpl {
    -webkit-border-radius: 0 8px 8px 0;
    -moz-border-radius: 0 8px 8px 0;
    border-radius: 0 8px 8px 0;
    margin-left: 8px
}
.goog-twothumbslider-vertical .jfk-slider-thumbimpl {
    height: 8px;
    width: 16px
}
.goog-twothumbslider-vertical .goog-twothumbslider-value-thumb .jfk-slider-thumbimpl {
    margin-top: 8px;

    -webkit-border-radius: 0 0 8px 8px;
    -moz-border-radius: 0 0 8px 8px;
    border-radius: 0 0 8px 8px
}
.goog-twothumbslider-vertical .goog-twothumbslider-extent-thumb .jfk-slider-thumbimpl {
    -webkit-border-radius: 8px 8px 0 0;
    -moz-border-radius: 8px 8px 0 0;
    border-radius: 8px 8px 0 0
}
.jfk-slider-scale {
    background-color: #e5e5e5;
    position: absolute;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px
}
.goog-twothumbslider-horizontal .jfk-slider-scale {
    height: 6px;
    top: 6px;
    width: 100%
}
.goog-twothumbslider-vertical .jfk-slider-scale {
    height: 100%;
    left: 6px;
    width: 6px
}
.goog-twothumbslider-rangehighlight {
    background-color: #c6c6c6;
    position: absolute;
    -webkit-transition: background-color 0.218s, border-color 0.218s, background-image 0.218s;
    -moz-transition: background-color 0.218s, border-color 0.218s, background-image 0.218s;
    -o-transition: background-color 0.218s, border-color 0.218s, background-image 0.218s;
    transition: background-color 0.218s, border-color 0.218s, background-image 0.218s
}
.jfk-twothumbslider:hover .goog-twothumbslider-rangehighlight,
.jfk-twothumbslider.goog-slider-dragging .goog-twothumbslider-rangehighlight {
    background-color: #535252
}
.jfk-twothumbslider.goog-slider-dragging .goog-twothumbslider-rangehighlight {
    background-image: url(//ssl.gstatic.com/ui/v1/slider/rangehighlight-active-gray.png)
}
.goog-twothumbslider-horizontal .goog-twothumbslider-rangehighlight {
    height: 6px;
    top: 6px
}
.goog-twothumbslider-vertical .goog-twothumbslider-rangehighlight {
    left: 6px;
    width: 6px
}
.docs-butterbar-container {
    font-weight: 500;
    height: 0;
    position: absolute;
    text-align: center;
    top: 23px;
    width: 100%;
    z-index: 999
}
.docs-gm-dialogs .docs-butterbar-container {
    font-weight: normal;
    font-weight: var(--docs-material-font-weight-normal, normal)
}
.docs-butterbar-container.docs-butterbar-container-compact {
    top: 20px
}
.docs-butterbar-wrap {
    display: inline-block;
    padding-bottom: 5px
}
.docs-gm-dialogs .jfk-butterBar {
    align-items: center;
    border-radius: 4px;
    border-style: none;
    display: flex;
    font-size: 13px;
    font-size: var(--docs-material-font-size-normal, 13px);
    height: 40px;
    padding: 0px 24px
}
.docs-gm-dialogs .jfk-butterBar-info {
    background-color: #e6f4ea;
    color: #202124;
    white-space: pre
}
.docs-gm-dialogs .jfk-butterBar-warning {
    background-color: #d93025
}
.docs-gm-dialogs .jfk-butterBar-error {
    background-color: #202124;
    color: #dadce0
}
.docs-butterbar-dismiss,
.docs-butterbar-link,
a.docs-butterbar-link:link,
a.docs-butterbar-link:visited,
.docs-butterbar-link-no-pad,
a.docs-butterbar-link-no-pad:link,
a.docs-butterbar-link-no-pad:visited {
    color: #666;
    cursor: pointer;
    text-decoration: underline
}
.docs-butterbar-dismiss,
.docs-butterbar-link,
a.docs-butterbar-link:link,
a.docs-butterbar-link:visited {
    padding-left: 6px
}
.docs-gm-dialogs .docs-butterbar-dismiss {
    font-size: 16px;
    margin-left: 80px;
    padding: 0;
    text-decoration: none
}
.jfk-butterBar-warning .docs-butterbar-dismiss,
.jfk-butterBar-warning .docs-butterbar-link,
.jfk-butterBar-warning a.docs-butterbar-link:link,
.jfk-butterBar-warning a.docs-butterbar-link:visited,
.jfk-butterBar-warning .docs-butterbar-link-no-pad,
.jfk-butterBar-warning a.docs-butterbar-link-no-pad:link,
.jfk-butterBar-warning a.docs-butterbar-link-no-pad:visited {
    color: #111
}
.jfk-butterBar-error .docs-butterbar-dismiss,
.jfk-butterBar-error .docs-butterbar-link,
.jfk-butterBar-error a.docs-butterbar-link:link,
.jfk-butterBar-error a.docs-butterbar-link:visited,
.jfk-butterBar-error .docs-butterbar-link-no-pad,
.jfk-butterBar-error a.docs-butterbar-link-no-pad:link,
.jfk-butterBar-error a.docs-butterbar-link-no-pad:visited {
    color: #add8e6
}
.docs-gm-dialogs .docs-butterbar-dismiss,
.docs-gm-dialogs .docs-butterbar-link,
.docs-gm-dialogs a.docs-butterbar-link:link,
.docs-gm-dialogs a.docs-butterbar-link:visited,
.docs-gm-dialogs .docs-butterbar-link-no-pad,
.docs-gm-dialogs a.docs-butterbar-link-no-pad:link,
.docs-gm-dialogs a.docs-butterbar-link-no-pad:visited {
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-family: var(--docs-material-header-font-family, "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif)
}
.docs-gm-dialogs .jfk-butterBar-info .docs-butterbar-dismiss,
.docs-gm-dialogs .jfk-butterBar-info .docs-butterbar-link,
.docs-gm-dialogs .jfk-butterBar-info a.docs-butterbar-link:link,
.docs-gm-dialogs .jfk-butterBar-info a.docs-butterbar-link:visited,
.docs-gm-dialogs .jfk-butterBar-info .docs-butterbar-link-no-pad,
.docs-gm-dialogs .jfk-butterBar-info a.docs-butterbar-link-no-pad:link,
.docs-gm-dialogs .jfk-butterBar-info a.docs-butterbar-link-no-pad:visited {
    color: #188038
}
.docs-gm-dialogs .jfk-butterBar-warning .docs-butterbar-dismiss,
.docs-gm-dialogs .jfk-butterBar-warning .docs-butterbar-link,
.docs-gm-dialogs .jfk-butterBar-warning a.docs-butterbar-link:link,
.docs-gm-dialogs .jfk-butterBar-warning a.docs-butterbar-link:visited,
.docs-gm-dialogs .jfk-butterBar-warning .docs-butterbar-link-no-pad,
.docs-gm-dialogs .jfk-butterBar-warning a.docs-butterbar-link-no-pad:link,
.docs-gm-dialogs .jfk-butterBar-warning a.docs-butterbar-link-no-pad:visited {
    color: #fff
}
.docs-gm-dialogs .jfk-butterBar-error .docs-butterbar-dismiss,
.docs-gm-dialogs .jfk-butterBar-error .docs-butterbar-link,
.docs-gm-dialogs .jfk-butterBar-error a.docs-butterbar-link:link,
.docs-gm-dialogs .jfk-butterBar-error a.docs-butterbar-link:visited,
.docs-gm-dialogs .jfk-butterBar-error .docs-butterbar-link-no-pad,
.docs-gm-dialogs .jfk-butterBar-error a.docs-butterbar-link-no-pad:link,
.docs-gm-dialogs .jfk-butterBar-error a.docs-butterbar-link-no-pad:visited {
    color: #34a853
}
.docs-gm-dialogs .jfk-butterBar-info .docs-butterbar-dismiss:hover,
.docs-gm-dialogs .jfk-butterBar-info .docs-butterbar-link:hover,
.docs-gm-dialogs .jfk-butterBar-info .docs-butterbar-link-no-pad:hover {
    color: #0d652d
}
.docs-gm-dialogs .jfk-butterBar-warning .docs-butterbar-dismiss:hover,
.docs-gm-dialogs .jfk-butterBar-warning .docs-butterbar-link:hover,
.docs-gm-dialogs .jfk-butterBar-warning .docs-butterbar-link-no-pad:hover {
    color: #fad2cf
}
.docs-gm-dialogs .jfk-butterBar-error .docs-butterbar-dismiss:hover,
.docs-gm-dialogs .jfk-butterBar-error .docs-butterbar-link:hover,
.docs-gm-dialogs .jfk-butterBar-error .docs-butterbar-link-no-pad:hover {
    color: #81c995
}
.docs-ml-noselect {
    -webkit-touch-callout: none;
    -webkit-user-drag: none;
    -webkit-user-select: none;
    -khtml-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none
}
#docs-chrome {
    background: white;
    outline: none
}
#docs-header {
    position: relative;
    -ms-flex: 1 1 auto;
    -webkit-flex: 1 1 auto;
    flex: 1 1 auto
}
#docs-header.docs-og-minibar {
    max-height: 31px
}
#docs-header-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-justify-content: flex-end;
    justify-content: flex-end
}
#docs-banner-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-justify-content: flex-end;
    justify-content: flex-end
}
.docs-incompatibility-banner {
    background-color: #e6f4ea;
    border: 0;
    color: #188038;
    display: flex;
    font-size: 13px;
    height: 32px;
    justify-content: center;
    white-space: nowrap;
    width: 100%;
    -ms-flex: 1 1;
    -webkit-flex: 1 1;
    flex: 1 1
}
.docs-hc-ie.docs-incompatibility-banner .docs-incompatibility-banner-view-details-button,
.docs-hc-edge.docs-incompatibility-banner .docs-incompatibility-banner-view-details-button,
.docs-hc-gecko.docs-incompatibility-banner .docs-incompatibility-banner-view-details-button {
    border: 1px solid transparent
}
.docs-incompatibility-banner-text {
    line-height: 32px;
    max-width: calc(100% - 140px);
    overflow: hidden;
    text-overflow: ellipsis
}
.docs-incompatibility-banner-view-details-button {
    align-self: center;
    background-color: inherit;
    border: none;
    color: #188038;
    cursor: pointer;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    line-height: 24px;
    margin-left: 32px;
    min-width: 42px;
    overflow: hidden
}
.docs-full-height-sidebar-placeholder {
    -ms-flex: 0 0 0px;
    -webkit-flex: 0 0 0px;
    flex: 0 0 0px
}
.docs-full-height-sidebar-placeholder.expanded {
    -webkit-flex-basis: 300px;
    -ms-flex-basis: 300px;
    flex-basis: 300px
}
.docs-sidebar-header-text {
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    left: 20px;
    position: absolute;
    font-size: 13px;
    font-size: var(--docs-material-font-size-normal, 13px)
}
#docs-bars {
    position: relative;
    overflow: hidden
}
#docs-titlebar-container {
    margin-left: 40px;
    position: relative
}
#docs-branding-container {
    height: 60px;
    margin-top: 26px;
    position: absolute;
    width: 40px;
    z-index: 1
}
#docs-branding-container a {
    display: inline-block;
    height: 60px;
    width: 40px
}
.docs-og-minibar #docs-branding-container {
    margin-top: 0
}
#docs-titlebar {
    clear: both;
    font-size: 18px;
    height: 24px;
    padding: 0;
    padding-top: 7px;
    width: 100%
}
#docs-header.docs-og-minibar #docs-titlebar {
    height: 24px;
    padding-top: 0
}
#docs-header.docs-og-minibar #docs-titlebar-container {
    top: -21px
}
#docs-header.docs-og-minibar .docs-titlebar-buttons {
    top: 19px
}
.docs-exp {
    border-radius: 6px;
    border: 1px solid #800;
    color: #800;
    float: left;
    font-size: 11px;
    margin-right: 8px;
    padding: 0 5px;
    text-align: center;
    white-space: nowrap
}
#docs-drive-logo {
    height: 60px;
    position: absolute;
    width: 40px;
    opacity: 0;
    -webkit-transition: all 125ms linear;
    -moz-transition: all 125ms linear;
    -o-transition: all 125ms linear;
    transition: all 125ms linear
}
#docs-branding-logo {
    height: 60px;
    position: absolute;
    width: 40px;
    -webkit-transition: all 125ms linear;
    -moz-transition: all 125ms linear;
    -o-transition: all 125ms linear;
    transition: all 125ms linear
}
#docs-branding-container.docs-branding-default {
    background-color: #d1d1d1
}
#docs-branding-container.docs-branding-documents {
    background-color: #4285f4
}
#docs-branding-container.docs-branding-spreadsheets {
    background-color: #0f9d58
}
#docs-branding-container.docs-branding-presentations {
    background-color: #f4b400
}
#docs-branding-container.docs-branding-drawings {
    background-color: #db4437
}
#docs-branding-container.docs-branding-forms {
    background-color: #673ab7
}
#docs-branding-container.docs-branding-scripts {
    background-color: #4285f4
}
#docs-branding-container:not(.docs-branding-crossfade-transition-disabled):hover #docs-drive-logo {
    opacity: 1
}
#docs-branding-container:not(.docs-branding-crossfade-transition-disabled):hover #docs-branding-logo {
    opacity: 0
}
#docs-branding-container.docs-branding-default:hover #docs-drive-logo {
    opacity: 0
}
#docs-branding-container.docs-branding-default:hover #docs-branding-logo {
    opacity: 1
}
.docs-butter {
    text-align: center
}
.docs-butter-inner {
    border-radius: 3px;
    font-size: 13px;
    font-weight: 500;
    margin: 0 auto 5px;
    padding: 5px 7px
}
.docs-butter-info {
    background: #f6bc5d;
    color: #222
}
.docs-butter-info-link {
    color: #0658b5
}
.docs-butter-warning {
    background: #c00;
    color: #fff
}
.docs-butter-warning-link {
    color: #c3d9ff
}
#docs-chrome-cover-container {
    width: 100%;
    z-index: 990
}
#docs-chrome-cover {
    height: 60px
}
#docs-transient-bar-container {
    left: 50%;
    position: absolute;
    top: 100%;
    width: 0
}
.docs-fading-toolbar-message {
    background-color: #fff;
    border: #999 solid;
    border-width: 0px 0px 1px 0px;
    color: #999;
    font-size: 28px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    position: absolute;
    text-align: center
}
.docs-title-outer {
    margin-left: 17px;
    white-space: nowrap
}
.docs-title-outer.docs-title-inline-rename {
    margin-left: 12px
}
.docs-title {
    display: inline-block;
    outline: none
}
.docs-title-input {
    border: 1px solid transparent;
    border-radius: 2px!important;
    color: #fff;
    font-size: 18px;
    font-variant-ligatures: no-contextual;
    height: 20px;
    line-height: 22px;
    margin: 0;
    min-width: 1px;
    padding: 2px 7px;
    visibility: hidden
}
.docs-title-input-label {
    font-size: 18px;
    font-variant-ligatures: no-contextual;
    line-height: 22px;
    margin: 0;
    overflow: hidden;
    padding: 2px 8px;
    pointer-events: none;
    position: absolute;
    text-overflow: ellipsis;
    white-space: pre;
    z-index: 1
}
.docs-title-input-label-inner {
    display: inline;
    line-height: 22px
}
.docs-title-input:hover {
    border-color: #e5e5e5
}
.docs-title-input:focus {
    -webkit-appearance: none;
    -moz-appearance: none;
    border: 1px solid #4d90fe!important;
    -webkit-box-shadow: inset 0px 1px 2px rgba(0, 0, 0, 0.1);
    -moz-box-shadow: inset 0px 1px 2px rgba(0, 0, 0, 0.1);
    box-shadow: inset 0px 1px 2px rgba(0, 0, 0, 0.1);
    color: #000;
    outline: none
}
.docs-title-input::-ms-clear {
    display: none
}
.docs-title-inner {
    color: #333;
    font-size: 18px;
    max-width: 600px;
    margin: 2px 4px 1px 3px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: pre
}
.docs-title .docs-title-untitled,
.docs-title-input-label.docs-title-untitled {
    color: #777;
    font-style: italic
}
.docs-title-widget {
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    height: 27px;
    width: auto
}
.docs-title-widget-enabled:hover .docs-title {
    background-color: #eee;
    cursor: pointer
}
.docs-title-widget .docs-back-container a {
    display: none
}
.docs-title-widget:hover .docs-back-container a {
    display: inline-block
}
.docs-back-container {
    height: 21px;
    opacity: 0.6;
    padding-right: 9px;
    margin-top: 1px;
    vertical-align: top;
    width: 21px
}
.docs-back-container:hover {
    opacity: 0.9
}
.docs-titlebar-badges {
    vertical-align: top
}
.docs-titlebar-badges.docs-badges-hidden-with-width {
    width: 0;
    overflow: hidden
}
.docs-parent-collections-container-outer {
    outline: none
}
.docs-dlp-container,
.docs-star-container,
.docs-folder-container,
.docs-activity-indicator-container {
    height: 29px;
    margin-top: 2px;
    vertical-align: top;
    padding-right: 2px
}
.office-editing-file-extension {
    background-color: #188038;
    border: 1px solid transparent;
    border-radius: 4px;
    box-sizing: border-box;
    color: #fff;
    cursor: default;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 13px;
    height: 21px;
    line-height: 21px;
    margin: 0 8px 0 0;
    padding: 0 5px 0 4px;
    text-transform: uppercase;
    -webkit-font-smoothing: antialiased
}
.docs-templates-badge-container {
    vertical-align: middle
}
.docs-templates-badge {
    background-color: #5a5a5a;
    border-radius: 16px;
    color: white;
    font-size: 13px;
    padding: 0 11px;
    height: 24px;
    line-height: 24px
}
#docs-encrypted-doc-indicator .docs-icon-encryption-shield {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_green.svg);
    left: -46px;
    top: -2014px
}
#docs-dlp,
#docs-star,
#docs-folder,
#docs-activity-indicator,
#docs-encrypted-doc-indicator,
.docs-title-save-label {
    margin-left: 4px;
    outline: none
}
#docs-star {
    padding-top: 1px
}
#docs-activity-indicator {
    padding-left: 4px;
    padding-top: 2px
}
#docs-dlp .docs-icon-img {
    opacity: 0.45
}
#docs-dlp:hover .docs-icon-img {
    opacity: 0.55
}
#docs-folder.goog-control-active .docs-icon-img {
    opacity: 0.65
}
#docs-folder .docs-icon-img {
    opacity: 0.60
}
#docs-folder.goog-control-hover .docs-icon-img {
    opacity: 0.70
}
#docs-folder.goog-control-open .docs-icon-img {
    opacity: 0.80
}
#docs-star.jfk-star-hover,
#docs-folder.goog-control-hover .docs-icon-img {
    cursor: pointer
}
#docs-dlp,
#docs-star,
#docs-folder .docs-icon {
    vertical-align: baseline
}
.docs-debug-info,
.docs-debug-info a {
    color: #777!important;
    font-size: 9px
}
.docs-debug-container {
    margin-right: 6px;
    vertical-align: top
}
.docs-titlebar-buttons {
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    padding: 0 44px 0 0;
    position: absolute;
    right: 0;
    text-align: right;
    top: 26px;
    vertical-align: middle;
    white-space: nowrap
}
.docs-titlebar-button,
.docs-debug-container {
    z-index: 1
}
#docs-docos-commentsbutton {
    margin-right: 9px
}
#docs-titlebar-save {
    text-align: center
}
#docs-docos-commentsbutton,
#docs-titlebar-share-client-button div {
    height: 24px;
    padding-bottom: 3px;
    vertical-align: middle
}
#docs-titlebar-share-client-button div.jfk-button {
    margin-right: 0
}
#docs-docos-commentsbutton {
    cursor: default
}
.docs-titlebar-buttons .goog-menu-button-dropdown {
    position: relative;
    top: 2px;
    vertical-align: baseline
}
.docs-menubar {
    cursor: default;
    display: inline-block;
    font-size: 13px;
    font-size: var(--docs-material-font-size-normal, 13px);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    height: 29px;
    margin-left: 52px;
    outline: none;
    position: relative;
    white-space: nowrap
}
.docs-menubar .goog-control {
    padding: 3px 7px 5px 7px;
    margin-top: 2px;
    border: 1px solid transparent;
    outline: none
}
.docs-menubar .goog-control-hover {
    background: #eee;
    border-color: #eee
}
.docs-menubar .goog-control-open {
    background: #fff;
    border: 1px solid #ccc;
    border: 1px solid rgba(0, 0, 0, .2);
    border-bottom: none;
    -moz-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
    -webkit-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
    box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
    color: black;
    z-index: 1003
}
.docs-menubar .goog-control-disabled {
    color: #ccc
}
#docs-menubars {
    white-space: nowrap
}
#docs-editor-container {
    background: #eee;
    padding: 0
}
#docs-editor {
    background: #eee;
    outline: none
}
#docs-editor.companion-enabled {
    width: calc(100% - 56px)
}
.docs-gaia-disabled {
    color: #999;
    cursor: text
}
.docs-hide-label {
    display: none
}
.docs-title-save-label {
    color: #777;
    display: inline-block;
    margin-left: 14px;
    max-width: 250px;
    overflow: hidden;
    vertical-align: text-bottom;
    white-space: nowrap
}
.docs-title-save-label-with-icon .docs-title-save-label-text {
    max-width: calc(100% - 24px)
}
.docs-title-save-label-text {
    display: inline-block;
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
    vertical-align: text-bottom;
    white-space: nowrap;
    font-size: 13px;
    font-size: var(--docs-material-font-size-normal, 13px)
}
.docs-title-save-label-text:hover,
.docs-title-save-label-text-focused {
    cursor: pointer;
    text-decoration: underline
}
.docs-title-save-label-disabled>.docs-title-save-label-text:hover {
    cursor: auto;
    text-decoration: none
}
:not(.docs-title-save-label-disabled)>.docs-title-save-label-text-link {
    text-decoration: underline
}
.docs-material.docs-title-save-label .docs-title-save-label-icon {
    cursor: pointer;
    margin: 0 0 -1px 7px;
    opacity: 0.54;
    vertical-align: text-bottom
}
.docs-title-save-label-text:empty+.docs-title-save-label-icon {
    display: none
}
.docs-title-save-label-unsaved-changes {
    background-color: #fce4e2;
    color: #da362c;
    border-radius: 4px;
    margin-bottom: -5px;
    margin-left: 9px;
    padding: 5px
}
.docs-title-save-label-unsaved-changes-button {
    cursor: pointer;
    display: none;
    font-weight: bold;
    margin-left: 10px;
    outline: none
}
.docs-title-save-label-unsaved-changes .docs-title-save-label-unsaved-changes-button {
    display: inline-block
}
.docs-title-save-label-unsaved-changes-button.goog-flat-button-disabled {
    cursor: default;
    color: rgba(0, 0, 0, 0.26)
}
#blob-notice-button {
    border: none;
    border-radius: 4px;
    background-color: #fce8e6;
    color: #c5221f;
    cursor: pointer;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    margin: 0 0 0 14px;
    outline: 0;
    padding: 4px 8px;
    white-space: nowrap
}
.docs-hc-ie#blob-notice-button,
.docs-hc-edge#blob-notice-button,
.docs-hc-gecko#blob-notice-button {
    border: 1px solid transparent
}
.docs-rename-dialog,
.docs-edit-description-dialog {
    width: 340px
}
.docs-rename-dialog .modal-dialog-userInput,
.docs-edit-description-dialog .modal-dialog-userInput {
    width: 300px
}
.docs-gm-dialogs .docs-rename-dialog,
.docs-gm-dialogs .docs-edit-description-dialog {
    min-width: 312px;
    width: auto;
    width: unset
}
.docs-gm-dialogs .docs-rename-dialog .modal-dialog-content {
    font-size: 12px
}
.docs-gm-dialogs .docs-rename-dialog .modal-dialog-userInput {
    width: 100%
}
#docs-help-anchor {
    left: 30%;
    position: absolute
}
#docs-help-anchor-right {
    right: 0;
    position: absolute
}
.docs-faux-link {
    color: #20c;
    cursor: pointer;
    text-decoration: underline
}
.docs-offscreen {
    position: absolute;
    left: -10000px;
    top: -10000px
}
.docs-offscreen-z-index {
    position: absolute;
    left: 0px;
    top: -1px;
    z-index: -2;
    opacity: 0
}
.modal-dialog-bg,
.goog-modalpopup-bg {
    z-index: 1002
}
.modal-dialog,
.goog-modalpopup {
    z-index: 1003
}
.goog-menu {
    z-index: 1003
}
#docs-menu-shield {
    background-color: #fff;
    position: absolute;
    z-index: 1004
}
.docs-menu-hide-mnemonics .goog-menuitem-mnemonic-hint {
    text-decoration: none
}
.docs-menu-hide-mnemonics .goog-menuitem-mnemonic-separator {
    display: none
}
.goog-menu.goog-menu-noaccel .apps-menuitem {
    padding-right: 10px
}
.goog-menu.goog-menu-noicon .goog-menuitem.apps-menuitem {
    padding-left: 16px
}
.goog-menuitem.apps-menuitem {
    padding: 6px 10px 6px 30px;
    white-space: normal
}
.goog-menuitem-highlight.apps-menuitem {
    border-style: none;
    padding-bottom: 6px;
    padding-top: 6px
}
.apps-menuitem .goog-menuitem-label {
    padding-right: 6px
}
.apps-menuitem .goog-menuitem-accel,
.docs-gm .goog-menuitem .goog-menuitem-accel {
    float: right;
    padding: 0px 0px 0px 24px;
    position: relative
}
.docs-halfhovermenuitem .goog-submenu-arrow,
.apps-menuitem .goog-submenu-arrow,
.docs-gm .goog-menuitem .goog-submenu-arrow {
    float: right;
    padding-left: 35px;
    position: relative;
    right: 0px
}
.apps-menuitem.goog-menuitem-ie {
    padding: 3px 10px 20px 30px
}
.apps-menuitem .goog-menuitem-icon-ie {
    float: left;
    top: 0em
}
.apps-menuitem .goog-menuitem-label-ie {
    float: left
}
.modal-dialog-content {
    font-size: 13px;
    font-size: var(--docs-material-font-size-normal, 13px)
}
input {
    font-family: inherit
}
body {
    background-color: white;
    color: black;
    font-weight: normal;
    font-size: 13px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    margin: 0
}
.jfk-activityIndicator {
    display: inline-block;
    position: relative;
    direction: ltr
}
.jfk-activityIndicator,
.jfk-activityIndicator-icon,
.jfk-activityIndicator-circle,
.jfk-activityIndicator-circle-transition {
    height: 19px;
    width: 19px
}
.jfk-activityIndicator-small.jfk-activityIndicator,
.jfk-activityIndicator-small .jfk-activityIndicator-icon,
.jfk-activityIndicator-small .jfk-activityIndicator-circle,
.jfk-activityIndicator-small .jfk-activityIndicator-circle-transition {
    height: 16px;
    width: 16px
}
.jfk-activityIndicator-icon {
    background: url(//ssl.gstatic.com/ui/v1/activityindicator/offline.png) center no-repeat
}
.jfk-activityIndicator-small .jfk-activityIndicator-icon {
    background: url(//ssl.gstatic.com/ui/v1/activityindicator/offline_16.png) center no-repeat
}
.jfk-activityIndicator-icon {
    -webkit-transition: opacity .218s linear .44s;
    -moz-transition: opacity .218s linear .44s;
    -o-transition: opacity .218s linear .44s;
    transition: opacity .218s linear .44s;
    top: 0;
    left: 0;
    position: absolute;
    opacity: 0
}
.jfk-activityIndicator-circle {
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    top: 0;
    left: 0;
    position: absolute
}
.jfk-activityIndicator-mask {
    overflow: hidden;
    position: absolute
}
.jfk-activityIndicator-circle-transition {
    position: relative
}
.jfk-activityIndicator-transition {
    -webkit-transition: all .22s ease-in;
    -moz-transition: all .22s ease-in;
    -o-transition: all .22s ease-in;
    transition: all .22s ease-in
}
.jfk-activityIndicator-transition-second {
    -webkit-transition: all .22s ease-out .22s;
    -moz-transition: all .22s ease-out .22s;
    -o-transition: all .22s ease-out .22s;
    transition: all .22s ease-out .22s
}
.jfk-bubble.jfk-bubble-promo {
    background-color: #f9edbe;
    border: 1px solid #f0c36d
}
.jfk-bubble-promo .jfk-bubble-arrowdown .jfk-bubble-arrowimplbefore,
.jfk-bubble-promo .jfk-bubble-arrowup .jfk-bubble-arrowimplbefore {
    border-color: #f0c36d transparent
}
.jfk-bubble-promo .jfk-bubble-arrowdown .jfk-bubble-arrowimplafter,
.jfk-bubble-promo .jfk-bubble-arrowup .jfk-bubble-arrowimplafter {
    border-color: #f9edbe transparent
}
.jfk-bubble-promo .jfk-bubble-arrowleft .jfk-bubble-arrowimplbefore,
.jfk-bubble-promo .jfk-bubble-arrowright .jfk-bubble-arrowimplbefore {
    border-color: transparent #f0c36d
}
.jfk-bubble-promo .jfk-bubble-arrowleft .jfk-bubble-arrowimplafter,
.jfk-bubble-promo .jfk-bubble-arrowright .jfk-bubble-arrowimplafter {
    border-color: transparent #f9edbe
}
.jfk-star {
    display: inline-block;
    height: 19px;
    text-align: center;
    width: 19px;
    padding: 2px
}
.jfk-star:before {
    content: url(//ssl.gstatic.com/ui/v1/star/star4.png);
    content: -webkit-image-set(url(//ssl.gstatic.com/ui/v1/star/star4.png) 1x, url(//ssl.gstatic.com/ui/v1/star/star4_2x.png) 2x)
}
.jfk-star-hover:before {
    content: url(//ssl.gstatic.com/ui/v1/star/star-hover4.png);
    content: -webkit-image-set(url(//ssl.gstatic.com/ui/v1/star/star-hover4.png) 1x, url(//ssl.gstatic.com/ui/v1/star/star-hover4_2x.png) 2x)
}
.jfk-star-active:before {
    content: url(//ssl.gstatic.com/ui/v1/star/star-active4.png);
    content: -webkit-image-set(url(//ssl.gstatic.com/ui/v1/star/star-active4.png) 1x, url(//ssl.gstatic.com/ui/v1/star/star-active4_2x.png) 2x)
}
.jfk-star-checked:before {
    content: url(//ssl.gstatic.com/ui/v1/star/star-lit4.png);
    content: -webkit-image-set(url(//ssl.gstatic.com/ui/v1/star/star-lit4.png) 1x, url(//ssl.gstatic.com/ui/v1/star/star-lit4_2x.png) 2x)
}
.jfk-star-checked.jfk-star-hover:before {
    content: url(//ssl.gstatic.com/ui/v1/star/star-lit-hover4.png);
    content: -webkit-image-set(url(//ssl.gstatic.com/ui/v1/star/star-lit-hover4.png) 1x, url(//ssl.gstatic.com/ui/v1/star/star-lit-hover4_2x.png) 2x)
}
.jfk-star-checked.jfk-star-active:before {
    content: url(//ssl.gstatic.com/ui/v1/star/star-lit-active4.png);
    content: -webkit-image-set(url(//ssl.gstatic.com/ui/v1/star/star-lit-active4.png) 1x, url(//ssl.gstatic.com/ui/v1/star/star-lit-active4_2x.png) 2x)
}
.apps-share-sprite {
    background-image: url(//ssl.gstatic.com/docs/documents/share/images/sprite-22.svg)
}
.sharing-aria-region {
    position: absolute;
    top: -1000px;
    height: 1px;
    overflow: hidden
}
.share-butterbar-container {
    font-family: Roboto, arial, sans-serif;
    font-size: 13px;
    font-weight: bold;
    position: fixed;
    display: inline-block;
    padding-bottom: 5px
}
.share-client-dialog .share-butterbar-container {
    font-family: arial, sans-serif
}
.share-butterbar-container .jfk-butterBar-shown {
    height: 21px
}
.share-butterbar-top {
    top: 23px
}
.share-butterbar-zindex {
    z-index: 3021
}
.share-butter-icon {
    opacity: .55;
    display: inline-block;
    width: 21px;
    height: 21px;
    margin-bottom: 1px;
    margin-top: 1px;
    margin-right: 1px;
    vertical-align: middle
}
.share-butter-message,
.share-butter-link {
    line-height: 21px
}
.share-butter-link,
.share-butter-link:visited {
    color: #15c;
    text-decoration: none;
    cursor: pointer
}
.share-butter-link:focus {
    outline: none
}
.share-butter-link:active {
    color: #d14836
}
.share-butter-link:disabled {
    color: #222;
    cursor: default
}
.share-butter-copy-icon {
    background-position: 0 -120px
}
.share-butter-specific-people-icon {
    background-position: 0 -72px
}
.share-butter-person-link-icon {
    background-position: 0 -294px
}
.share-client-dialog {
    max-height: 100%;
    overflow: auto;
    width: auto!important;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    box-sizing: border-box
}
* html .share-client-dialog {
    max-height: none!important;
    overflow: visible!important
}
*:first-child+html .share-client-dialog {
    max-height: none!important;
    overflow: visible!important
}
.share-client-dialog .modal-dialog-content {
    padding: 0
}
.share-client-dialog .modal-dialog-title {
    padding: 0
}
.share-client-dialog .share-client-dialog-hidden-title {
    height: 0;
    margin: 0;
    padding: 0
}
.share-client-dialog .modal-dialog-title {
    font-family: arial, sans-serif;
    font-weight: normal
}
.share-client-content-iframe {
    height: 100%;
    width: 100%;
    border: none
}
.share-client-dialog .modal-dialog-buttons {
    display: none
}
.share-client-error-dialog {
    font-family: arial, sans-serif;
    font-size: 12px;
    width: 400px
}
.share-client-loading-contents {
    height: 99px;
    text-align: center;
    width: 454px
}
.share-client-spinner {
    background-image: url(//ssl.gstatic.com/docs/documents/share/images/spinner-1.gif);
    display: inline-block;
    margin-top: 41px;
    width: 16px;
    height: 16px
}
.inline-share-ui-status {
    font-size: 12pt;
    font-weight: bold;
    height: 19px;
    padding: 5px 10px;
    background-color: #f1f4ff
}
.inline-share-ui-overlay {
    position: absolute;
    z-index: 150;
    background-color: #fff;
    opacity: 0;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)"
}
.share-client-panel-dialog-share {
    height: 100%;
    width: 100%
}
.share-client-panel-dialog-overlay {
    position: absolute;
    z-index: 150
}
.share-client-offscreen {
    position: absolute!important;
    left: -10000px!important;
    top: -10000px!important
}
.share-client-loading-dialog {
    font-family: arial, sans-serif
}
.share-client-debug {
    display: none;
    position: absolute;
    bottom: 0;
    right: 0;
    color: #777;
    font-size: 10px
}
.team-drive-share-client-dialog {
    border: none;
    border-radius: 2px;
    box-shadow: 0px 24px 38px 3px rgba(0, 0, 0, 0.14), 0px 9px 46px 8px rgba(0, 0, 0, 0.12), 0px 11px 15px -7px rgba(0, 0, 0, 0.2);
    overflow: hidden;
    padding: 0
}
.full-screen-share-client-dialog {
    background-color: transparent!important;
    border: none!important;
    height: 100vh;
    overflow: hidden;
    padding: 0!important;
    width: 100vw!important
}
.full-screen-share-client-dialog .modal-dialog-content {
    background: transparent;
    height: 100%;
    width: 100%
}
.modal-dialog.share-client-dialog.team-drive-share-client-dialog {
    padding: 0
}
.full-screen-share-client-dialog .modal-dialog-title,
.team-drive-share-client-dialog .modal-dialog-title {
    display: none
}
.jfk-tooltip {
    z-index: 30000
}
.scb-container,
.scb-icon {
    display: inline-block
}
.scb-button-icon {
    margin: -3px 2px 0px -5px;
    vertical-align: middle!important
}
.scb-tooltip-contents {
    color: #fff;
    font-size: 13px;
    max-width: 300px
}
.scb-tooltip-title {
    font-size: 14px;
    font-weight: bold
}
.scb-tooltip-text {
    font-weight: normal
}
.scb-tooltip-icon-container {
    width: 25px;
    vertical-align: top
}
.scb-tooltip-separator {
    border-top: 1px solid #555555;
    margin: 2px 0
}
.jfk-button-standard .scb-button-icon {
    opacity: .70
}
.jfk-button-standard.jfk-button-checked .scb-button-icon,
.jfk-button-standard.jfk-button-selected .scb-button-icon,
.jfk-button-standard.jfk-button-hover .scb-button-icon {
    opacity: 0.9
}
.jfk-button-standard.jfk-button-disabled .scb-button-icon {
    opacity: 0.333
}
.scb-public-icon-white,
.scb-unlisted-icon-white,
.scb-domain-public-icon-white,
.scb-domain-unlisted-icon-white,
.scb-privately-shared-icon-white,
.scb-private-icon-white,
.scb-invalid-icon-white,
.scb-dlp-icon {
    width: 21px;
    height: 21px;
    background-repeat: no-repeat;
    vertical-align: bottom
}
.scb-public-icon-white {
    background-position: 0 -802px
}
.scb-unlisted-icon-white {
    background-position: 0 -48px
}
.scb-domain-public-icon-white {
    background-position: 0 -243px
}
.scb-domain-unlisted-icon-white {
    background-position: 0 -599px
}
.scb-privately-shared-icon-white {
    background-position: 0 -318px
}
.scb-private-icon-white {
    background-position: 0 -219px
}
.scb-invalid-icon-white {
    background-position: 0 -623px
}
.scb-dlp-icon {
    background-position: 0 -898px
}
.docs-branding-presentations .scb-public-icon-white {
    background-position: 0 -671px
}
.docs-branding-presentations .scb-unlisted-icon-white {
    background-position: 0 -294px
}
.docs-branding-presentations .scb-domain-public-icon-white {
    background-position: 0 -850px
}
.docs-branding-presentations .scb-domain-unlisted-icon-white {
    background-position: 0 -551px
}
.docs-branding-presentations .scb-privately-shared-icon-white {
    background-position: 0 -72px
}
.docs-branding-presentations .scb-private-icon-white {
    background-position: 0 -575px
}
.docs-branding-presentations .scb-invalid-icon-white {
    background-position: 0 -826px
}
.docs-branding-icon {
    direction: ltr;
    text-align: left;
    height: 60px;
    overflow: hidden;
    vertical-align: middle;
    width: 40px
}
.docs-branding-icon-img:before {
    content: url(//ssl.gstatic.com/docs/common/branding_sprite1.svg)
}
.docs-branding-icon-img {
    position: absolute
}
.docs-branding-icon-drive,
.docs-branding-icon-default {
    left: 0;
    top: 0
}
.docs-branding-icon-documents {
    left: 0;
    top: -180px
}
.docs-branding-icon-spreadsheets {
    left: 0;
    top: -300px
}
.docs-branding-icon-presentations {
    left: 0;
    top: -360px
}
.docs-branding-icon-drawings {
    left: 0;
    top: -60px
}
.docs-branding-icon-forms {
    left: 0;
    top: -120px
}
.docs-branding-icon-scripts {
    left: 0;
    top: -240px
}
.docs-icon {
    direction: ltr;
    text-align: left;
    height: 21px;
    overflow: hidden;
    vertical-align: middle;
    width: 21px
}
.docs-icon-img:before {
    content: url(//ssl.gstatic.com/docs/common/jfk_sprite186.png)
}
.docs-icon-img {
    *background: url(//ssl.gstatic.com/docs/common/jfk_sprite186.png)
}
.docs-icon-img-legacy {
    background: url(//ssl.gstatic.com/docs/common/jfk_sprite186.png)
}
.docs-icon-img-container {
    height: 4167px;
    position: absolute;
    width: 42px
}
.goog-color-menu-button-indicator .docs-icon {
    height: 19px
}
.goog-menuitem-icon .docs-icon-img-container {
    opacity: .70
}
.goog-menuitem-icon .docs-icon-document,
.goog-menuitem-icon .docs-icon-punch,
.goog-menuitem-icon .docs-icon-presentation,
.goog-menuitem-icon .docs-icon-spreadsheet,
.goog-menuitem-icon .docs-icon-form,
.goog-menuitem-icon .docs-icon-drawing,
.goog-menuitem-icon .docs-icon-script,
.goog-menuitem-icon .docs-icon-site {
    opacity: 1
}
.docs-icon-save {
    left: 0;
    top: -1077px
}
.docs-icon-print {
    left: 0;
    top: -528px
}
.docs-icon-undo,
.docs-icon-redo-rtl {
    left: 0;
    top: -759px
}
.docs-icon-redo,
.docs-icon-undo-rtl {
    left: -21px;
    top: -1434px
}
.docs-icon-copy {
    left: 0;
    top: -2694px
}
.docs-icon-cut {
    left: 0;
    top: -2085px
}
.docs-icon-paste {
    left: -21px;
    top: -528px
}
.docs-icon-document {
    left: -21px;
    top: -1392px
}
.docs-icon-presentation {
    left: -21px;
    top: -444px
}
.docs-icon-punch {
    left: -21px;
    top: -444px
}
.docs-icon-spreadsheet {
    left: -21px;
    top: -1014px
}
.docs-icon-form {
    left: -21px;
    top: -1140px
}
.docs-icon-form-black {
    left: 0;
    top: -1203px
}
.docs-icon-drawing {
    left: 0;
    top: -4044px
}
.docs-icon-site {
    left: -21px;
    top: -2442px
}
.docs-icon-drawing-black {
    left: -21px;
    top: -2904px
}
.docs-icon-excel {
    left: -21px;
    top: -2253px
}
.docs-icon-powerpoint {
    left: -21px;
    top: -2043px
}
.docs-icon-word {
    left: 0;
    top: -2778px
}
.docs-icon-script {
    left: -21px;
    top: -3393px
}
.docs-icon-code {
    left: -21px;
    top: -3393px
}
.docs-icon-insert-script {
    left: -21px;
    top: -2673px
}
.docs-icon-gadget {
    left: 0;
    top: -2295px
}
.docs-icon-image {
    left: 0;
    top: -2442px
}
.docs-icon-clipboard {
    left: 0;
    top: -864px
}
.docs-icon-bold {
    left: 0;
    top: -1035px
}
.docs-icon-italic {
    left: 0;
    top: -3540px
}
.docs-icon-text-color {
    left: -21px;
    top: -2148px
}
.docs-icon-align-left {
    left: 0;
    top: -3750px
}
.docs-icon-align-center {
    left: -21px;
    top: -1623px
}
.docs-icon-align-right {
    left: -21px;
    top: -2274px
}
.docs-icon-align-justify {
    left: 0;
    top: -2253px
}
.docs-icon-align-shapes-left {
    left: -21px;
    top: -591px
}
.docs-icon-align-shapes-center {
    left: 0;
    top: -1140px
}
.docs-icon-align-shapes-right {
    left: 0;
    top: -4104px
}
.docs-icon-align-shapes-top {
    left: 0;
    top: -2463px
}
.docs-icon-align-shapes-middle {
    left: 0;
    top: -801px
}
.docs-icon-align-shapes-bottom {
    left: 0;
    top: -402px
}
.docs-icon-distribute-shapes-horizontally {
    left: -21px;
    top: -1371px
}
.docs-icon-distribute-shapes-vertically {
    left: -21px;
    top: -3687px
}
.docs-icon-valign-top {
    left: 0;
    top: -3771px
}
.docs-icon-valign-middle {
    left: 0;
    top: -297px
}
.docs-icon-valign-bottom {
    left: -21px;
    top: -3582px
}
.docs-icon-list-number {
    left: 0;
    top: -3624px
}
.docs-icon-list-bullet {
    left: 0;
    top: -2232px
}
.docs-icon-indent {
    left: 0;
    top: -3876px
}
.docs-icon-outdent {
    left: -21px;
    top: -864px
}
.docs-icon-line-spacing {
    left: -21px;
    top: -1497px
}
.docs-icon-columns {
    left: 0;
    top: -1056px
}
.docs-icon-underline {
    left: 0;
    top: -675px
}
.docs-icon-text-bgcolor {
    left: -21px;
    top: -192px
}
.docs-icon-textbox {
    left: -21px;
    top: -1329px
}
.docs-icon-shapes {
    left: -21px;
    top: -2127px
}
.docs-icon-line-width {
    left: -21px;
    top: -2358px
}
.docs-icon-add-trendline {
    left: -21px;
    top: -87px
}
.docs-icon-data-label {
    left: 0;
    top: -1602px
}
.docs-icon-next {
    left: -21px;
    top: -2988px
}
.docs-icon-previous {
    left: 0;
    top: -1434px
}
.docs-icon-no-color {
    left: -21px;
    top: -2106px
}
.docs-icon-fill-color {
    left: 0;
    top: -3645px
}
.docs-icon-line-color {
    left: -21px;
    top: -2694px
}
.docs-icon-line-type {
    left: 0;
    top: -2967px
}
.docs-icon-table {
    left: 0;
    top: -3351px
}
.docs-icon-comment {
    left: -21px;
    top: -66px
}
.docs-icon-comment-blank {
    left: 0;
    top: -3393px
}
.docs-icon-comment-blank-highlighted {
    left: 0;
    top: -1560px
}
.docs-icon-insert-comment {
    left: -21px;
    top: -66px
}
.docs-icon-chart {
    left: 0;
    top: -423px
}
.docs-icon-list-number-rtl {
    left: -21px;
    top: -2064px
}
.docs-icon-list-bullet-rtl {
    left: -21px;
    top: -3918px
}
.docs-icon-indent-rtl {
    left: 0;
    top: -1497px
}
.docs-icon-outdent-rtl {
    left: 0;
    top: -2820px
}
.docs-icon-line-spacing-rtl {
    left: -21px;
    top: -2085px
}
.docs-icon-text-ltr {
    left: 0;
    top: -192px
}
.docs-icon-text-rtl {
    left: -21px;
    top: -2421px
}
.docs-icon-sheet-rtl {
    left: -21px;
    top: -972px
}
.docs-icon-share {
    left: 0;
    top: -3201px
}
.docs-icon-subscript {
    left: 0;
    top: -3456px
}
.docs-icon-superscript {
    left: -21px;
    top: -3960px
}
.docs-icon-strikethrough {
    left: 0;
    top: -486px
}
.docs-icon-clear-formatting {
    left: 0;
    top: -1707px
}
.docs-icon-link {
    left: -21px;
    top: -4125px
}
.docs-icon-special-character {
    left: -21px;
    top: -696px
}
.docs-icon-close-white {
    left: -21px;
    top: -2463px
}
.docs-icon-close-small {
    left: -21px;
    top: -3309px
}
.docs-icon-close-thin {
    left: -21px;
    top: -2022px
}
.docs-icon-paint-format {
    left: 0;
    top: -591px
}
.docs-icon-video {
    left: 0;
    top: -3414px
}
.docs-icon-reload {
    left: -21px;
    top: -4146px
}
.docs-icon-reload-rtl {
    left: 0;
    top: -3960px
}
.docs-icon-insert-page-break {
    left: -21px;
    top: -3666px
}
.docs-icon-close {
    left: -21px;
    top: -654px
}
.docs-icon-check {
    left: -21px;
    top: -1791px
}
.docs-icon-up {
    left: -21px;
    top: -3159px
}
.docs-icon-down {
    left: -21px;
    top: -402px
}
.docs-icon-add-page {
    left: 0;
    top: -1959px
}
.docs-icon-email {
    left: -21px;
    top: -108px
}
.docs-icon-insert-equation {
    left: -21px;
    top: -2400px
}
.docs-icon-insert-horizontal-line {
    left: -21px;
    top: -3117px
}
.docs-icon-tabstop-center {
    left: 0;
    top: -3792px
}
.docs-icon-tabstop-center-bottom {
    left: 0;
    top: -339px
}
.docs-icon-tabstop-left {
    left: 0;
    top: -255px
}
.docs-icon-tabstop-right {
    left: -21px;
    top: -1707px
}
.docs-icon-border-all {
    left: 0;
    top: -1329px
}
.docs-icon-border-right {
    left: 0;
    top: -45px
}
.docs-icon-border-left {
    left: -21px;
    top: -1098px
}
.docs-icon-border-top {
    left: 0;
    top: -4083px
}
.docs-icon-border-bottom {
    left: -21px;
    top: -45px
}
.docs-icon-border-outside {
    left: -21px;
    top: -213px
}
.docs-icon-border-inside {
    left: -21px;
    top: -2001px
}
.docs-icon-border-none {
    left: 0;
    top: -885px
}
.docs-icon-border-horizontal {
    left: 0;
    top: -1245px
}
.docs-icon-border-vertical {
    left: 0;
    top: -1644px
}
.docs-icon-merge {
    left: 0;
    top: -2022px
}
.docs-icon-wrap {
    left: -21px;
    top: -1749px
}
.docs-icon-autofilter {
    left: 0;
    top: -4125px
}
.docs-icon-autofilter-filled {
    left: -21px;
    top: -381px
}
.docs-icon-insert-function {
    left: 0;
    top: -3477px
}
.docs-icon-insert-formula {
    left: 0;
    top: -738px
}
.docs-icon-folder-shared {
    left: 0;
    top: -3117px
}
.docs-icon-folder-outline {
    left: 0;
    top: -381px
}
.docs-icon-folder-outline-hover {
    left: 0;
    top: -2673px
}
.docs-icon-folder-outline-pressed {
    left: -21px;
    top: -171px
}
.docs-icon-folder-solid {
    left: 0;
    top: -2568px
}
.docs-icon-drive {
    left: -21px;
    top: -3624px
}
.docs-icon-drive-grey {
    left: -21px;
    top: -1077px
}
.docs-icon-drive-grey-hover {
    left: 0;
    top: -2526px
}
.docs-icon-drive-grey-pressed {
    left: 0;
    top: -2358px
}
.docs-icon-drive-hover {
    left: 0;
    top: -1665px
}
.docs-icon-drive-pressed {
    left: -21px;
    top: -150px
}
.docs-icon-drive-large {
    left: 0;
    top: -1266px
}
.docs-icon-back {
    left: 0;
    top: -822px
}
.docs-icon-back-rtl {
    left: -21px;
    top: -3834px
}
.docs-icon-arrow-more {
    left: 0;
    top: -276px
}
.docs-icon-arrow-more-rtl {
    left: 0;
    top: -993px
}
.docs-icon-search-this-document {
    left: 0;
    top: -24px
}
.docs-icon-arrow-dropdown {
    left: 0;
    top: -3981px
}
.docs-icon-word-art {
    left: -21px;
    top: -4083px
}
.docs-icon-delete-x {
    left: 0;
    top: -2904px
}
.docs-icon-settings {
    left: 0;
    top: -780px
}
.docs-icon-drive-large-wrapper {
    width: 42px;
    height: 42px
}
.docs-icon-plus {
    left: 0;
    top: -1392px
}
.docs-icon-plus-white {
    left: 0;
    top: -3096px
}
.docs-icon-alert {
    left: -21px;
    top: -3180px
}
.docs-icon-trash {
    left: 0;
    top: -507px
}
.docs-icon-locked {
    left: -21px;
    top: -3729px
}
.docs-icon-unlocked {
    left: 0;
    top: -2589px
}
.docs-icon-add-fonts {
    left: -21px;
    top: -507px
}
.docs-icon-enter-compact {
    left: 0;
    top: -2736px
}
.docs-icon-exit-compact {
    left: 0;
    top: -1539px
}
.docs-icon-mode-edit {
    left: 0;
    top: -213px
}
.docs-icon-mode-review {
    left: -21px;
    top: -318px
}
.docs-icon-mode-review-white {
    left: 0;
    top: -3372px
}
.docs-icon-mode-view {
    left: 0;
    top: -654px
}
.docs-icon-mode-view-white {
    left: 0;
    top: -3330px
}
.docs-icon-chat {
    left: -21px;
    top: -2946px
}
.docs-icon-star {
    left: 0;
    top: -1182px
}
.docs-icon-duplicate {
    left: -21px;
    top: -3855px
}
.docs-icon-file {
    left: 0;
    top: -2862px
}
.docs-icon-opacity {
    left: 0;
    top: -3561px
}
.docs-icon-label-slant {
    left: 0;
    top: -2106px
}
.docs-icon-point-size {
    left: -21px;
    top: -549px
}
.docs-icon-question {
    left: 0;
    top: -3687px
}
.docs-icon-vertical-gridlines {
    left: -21px;
    top: -2631px
}
.docs-icon-left-axis {
    left: -21px;
    top: -1686px
}
.docs-icon-right-axis {
    left: 0;
    top: -3897px
}
.docs-icon-left-axis-gridlines {
    left: -21px;
    top: -3561px
}
.docs-icon-right-axis-gridlines {
    left: 0;
    top: -3729px
}
.docs-icon-reset {
    left: 0;
    top: -2043px
}
.docs-icon-drag-move {
    left: 0;
    top: -3435px
}
.docs-icon-col-dragger {
    left: -21px;
    top: -927px
}
.docs-icon-chrome-store {
    left: -21px;
    top: -3051px
}
.docs-icon-fit-area {
    left: 0;
    top: -3603px
}
.docs-icon-zoom-out {
    left: -21px;
    top: -2526px
}
.docs-icon-zoom-tool {
    left: 0;
    top: -2610px
}
.docs-icon-download {
    left: 0;
    top: -2946px
}
.docs-icon-fusion-table {
    left: -21px;
    top: -2841px
}
.docs-icon-spreadsheet-sink {
    left: 0;
    top: -2064px
}
.docs-icon-send-responses {
    left: 0;
    top: -234px
}
.docs-icon-liveform {
    left: -21px;
    top: -423px
}
.docs-icon-ellipsis {
    left: 0;
    top: -1833px
}
.docs-icon-html-preview {
    left: -21px;
    top: -2505px
}
.docs-icon-grid {
    left: -21px;
    top: -3264px
}
.docs-icon-add-animation {
    left: 0;
    top: -150px
}
.docs-icon-playhead {
    left: 0;
    top: -444px
}
.docs-icon-playhead-rtl {
    left: 0;
    top: -3519px
}
.docs-icon-unsupported {
    left: 0;
    top: -906px
}
.docs-icon-calendar {
    left: 0;
    top: -2001px
}
.docs-zippy-closed {
    left: 0;
    top: -1728px
}
.docs-zippy-open {
    left: -21px;
    top: -2967px
}
.docs-icon-bookmark {
    left: -21px;
    top: -1182px
}
.docs-icon-heading {
    left: 0;
    top: -3030px
}
.docs-icon-file-blue {
    left: -21px;
    top: -1350px
}
.docs-icon-web-result {
    left: 0;
    top: -1518px
}
.docs-icon-mic {
    left: -21px;
    top: -1917px
}
.docs-icon-paragraph {
    left: 0;
    top: -2274px
}
.docs-icon-bookmark-black {
    left: 0;
    top: -1770px
}
.docs-icon-web-result-blue {
    left: 0;
    top: -465px
}
.docs-icon-popout {
    left: -21px;
    top: -570px
}
.docs-icon-checkbox {
    left: -21px;
    top: -3414px
}
.docs-icon-checkbox-type {
    left: -21px;
    top: -1308px
}
.docs-icon-dropdown-type {
    left: -21px;
    top: -1644px
}
.docs-icon-grid-type {
    left: 0;
    top: -3498px
}
.docs-icon-image-type {
    left: 0;
    top: -2925px
}
.docs-icon-radio-type {
    left: 0;
    top: -2505px
}
.docs-icon-scale-type {
    left: -21px;
    top: -2883px
}
.docs-icon-text-type {
    left: -21px;
    top: -3009px
}
.docs-icon-time-type {
    left: 0;
    top: -972px
}
.docs-icon-insert-text-block {
    left: 0;
    top: -3834px
}
.docs-icon-accepting-responses-on {
    left: -21px;
    top: -1119px
}
.docs-icon-accepting-responses-off {
    left: 0;
    top: -1371px
}
.docs-icon-decimal-increase {
    left: 0;
    top: -3918px
}
.docs-icon-decimal-decrease {
    left: 0;
    top: -1308px
}
.docs-icon-settings-white {
    left: -21px;
    top: -3498px
}
.docs-icon-no-symbol {
    left: 0;
    top: -2757px
}
.docs-icon-crop {
    left: 0;
    top: -3708px
}
.docs-icon-green-check {
    left: 0;
    top: -3051px
}
.docs-icon-font-size {
    left: 0;
    top: -1413px
}
.docs-icon-reset-image {
    left: 0;
    top: -2421px
}
.docs-icon-r-squared {
    left: 0;
    top: -2169px
}
.docs-icon-graph-legend {
    left: 0;
    top: -2883px
}
.docs-icon-cast {
    left: 0;
    top: -1917px
}
.docs-icon-wrap-overflow {
    left: -21px;
    top: -24px
}
.docs-icon-wrap-wrap {
    left: -21px;
    top: -1602px
}
.docs-icon-wrap-clip {
    left: 0;
    top: -3309px
}
.docs-icon-highlights {
    left: -21px;
    top: -3939px
}
.docs-icon-green-back {
    left: 0;
    top: -360px
}
.docs-icon-arrow-back-white {
    left: 0;
    top: -3072px
}
.docs-icon-arrow-back-white-rtl {
    left: 0;
    top: -630px
}
.docs-icon-help {
    left: 0;
    top: -1875px
}
.docs-icon-highlight-green {
    left: -21px;
    top: -3201px
}
.docs-icon-explore-black {
    left: -21px;
    top: -2799px
}
.docs-icon-explore-black-padded {
    left: 0;
    top: -3180px
}
.docs-icon-explore-green {
    left: 0;
    top: -3813px
}
.docs-icon-explore-white {
    left: 0;
    top: -1686px
}
.docs-icon-insert-autovis-chart {
    left: -21px;
    top: -738px
}
.docs-icon-insert-autovis-chart-white {
    left: 0;
    top: -1455px
}
.docs-icon-zoom-in {
    left: 0;
    top: -2316px
}
.docs-icon-thumb-up {
    left: 0;
    top: -1098px
}
.docs-icon-thumb-down {
    left: 0;
    top: -2547px
}
.docs-icon-dlp-warning {
    left: 0;
    top: -3582px
}
.docs-icon-dogfood {
    left: 0;
    top: -4065px
}
.docs-icon-add-to-drive {
    left: 0;
    top: -3939px
}
.docs-icon-paste-without-formatting {
    left: -21px;
    top: -1980px
}
.docs-icon-qanda {
    left: -21px;
    top: -2610px
}
.docs-icon-update-chart {
    left: 0;
    top: -1161px
}
.docs-icon-arrow-back-dark {
    left: 0;
    top: -3285px
}
.docs-icon-arrow-back-dark-rtl {
    left: 0;
    top: -948px
}
.docs-icon-open-in-external {
    left: -21px;
    top: -759px
}
.docs-icon-unlink {
    left: 0;
    top: -1350px
}
.docs-icon-bar-chart {
    left: -21px;
    top: -2337px
}
.docs-icon-column-chart {
    left: 0;
    top: -1014px
}
.docs-icon-line-chart {
    left: 0;
    top: -549px
}
.docs-icon-pie-chart {
    left: -21px;
    top: -1413px
}
.docs-icon-pie-chart-outline {
    height: 24px;
    left: 0;
    top: 0;
    width: 24px
}
.docs-icon-named-range {
    left: 0;
    top: -3243px
}
.docs-icon-clock {
    left: 0;
    top: -696px
}
.docs-icon-cancel {
    left: -21px;
    top: -255px
}
.docs-icon-arrow-line-tool {
    left: 0;
    top: -4002px
}
.docs-icon-arrow-tilted {
    left: -21px;
    top: -2190px
}
.docs-icon-unsupported-black {
    left: -21px;
    top: -3222px
}
.docs-icon-text-rotation {
    left: -21px;
    top: -2379px
}
.docs-icon-text-rotation-up {
    left: 0;
    top: -2148px
}
.docs-icon-text-rotation-down {
    left: 0;
    top: -3264px
}
.docs-icon-text-rotation-angleup {
    left: -21px;
    top: -3030px
}
.docs-icon-text-rotation-angledown {
    left: -21px;
    top: -3813px
}
.docs-icon-text-rotation-vertical {
    left: 0;
    top: -717px
}
.docs-icon-text-rotation-none {
    left: -21px;
    top: -2652px
}
.docs-icon-keep-lightbulb {
    left: -21px;
    top: -717px
}
.docs-icon-update-table {
    left: -21px;
    top: -3540px
}
.docs-icon-update-slide {
    left: -21px;
    top: -1560px
}
.docs-icon-overflow-three-dots {
    left: -21px;
    top: -2232px
}
.docs-icon-restore {
    left: -21px;
    top: -4002px
}
.docs-icon-paragraph-border-between {
    left: 0;
    top: -129px
}
.docs-icon-paragraph-border-bottom {
    left: 0;
    top: -1854px
}
.docs-icon-paragraph-border-left {
    left: -21px;
    top: -3876px
}
.docs-icon-paragraph-border-right {
    left: -21px;
    top: -2295px
}
.docs-icon-paragraph-border-top {
    left: 0;
    top: -3666px
}
.docs-icon-diagram-white {
    left: -21px;
    top: -1875px
}
.docs-icon-drive-black {
    left: -21px;
    top: -1812px
}
.docs-icon-file-upload {
    left: 0;
    top: -2379px
}
.docs-icon-photos {
    left: -21px;
    top: -906px
}
.docs-icon-keyboard {
    left: 0;
    top: -318px
}
.docs-icon-dogfood-white {
    left: 0;
    top: -2715px
}
.docs-icon-hierarchy {
    left: -21px;
    top: -843px
}
.docs-icon-timeline {
    left: 0;
    top: -3138px
}
.docs-icon-process {
    left: 0;
    top: -2841px
}
.docs-icon-transition {
    left: 0;
    top: -612px
}
.docs-icon-mask {
    left: 0;
    top: -1224px
}
.docs-icon-visibility-off {
    left: 0;
    top: -2337px
}
.docs-icon-volume-up {
    left: -21px;
    top: -3372px
}
.docs-icon-camera {
    left: -21px;
    top: -2484px
}
.docs-icon-pivot-table {
    left: 0;
    top: -1623px
}
.docs-icon-insert-pivot-table {
    left: 0;
    top: -3159px
}
@media screen and (-webkit-min-device-pixel-ratio:2) {
    .docs-icon-img {
        content: url(//ssl.gstatic.com/docs/common/jfk_sprite_hdpi124.png)
    }
    .docs-icon-img-container {
        height: 4380px;
        position: absolute;
        width: 42px
    }
    .docs-icon-save {
        left: 0;
        top: -3870px
    }
    .docs-icon-print {
        left: 0;
        top: -1578px
    }
    .docs-icon-undo,
    .docs-icon-redo-rtl {
        left: 0;
        top: -3282px
    }
    .docs-icon-redo,
    .docs-icon-undo-rtl {
        left: -21px;
        top: -1137px
    }
    .docs-icon-copy {
        left: -21px;
        top: -3282px
    }
    .docs-icon-cut {
        left: 0;
        top: -360px
    }
    .docs-icon-paste {
        left: -21px;
        top: -594px
    }
    .docs-icon-document {
        left: 0;
        top: -42px
    }
    .docs-icon-presentation {
        left: -21px;
        top: -2292px
    }
    .docs-icon-punch {
        left: -21px;
        top: -2292px
    }
    .docs-icon-spreadsheet {
        left: -21px;
        top: -510px
    }
    .docs-icon-form {
        left: -21px;
        top: -990px
    }
    .docs-icon-form-black {
        left: -21px;
        top: -3660px
    }
    .docs-icon-drawing {
        left: -21px;
        top: -3828px
    }
    .docs-icon-site {
        left: 0;
        top: -3177px
    }
    .docs-icon-drawing-black {
        left: 0;
        top: -3618px
    }
    .docs-icon-excel {
        left: 0;
        top: -84px
    }
    .docs-icon-powerpoint {
        left: -21px;
        top: -3492px
    }
    .docs-icon-word {
        left: -21px;
        top: -864px
    }
    .docs-icon-script {
        left: -21px;
        top: -2862px
    }
    .docs-icon-code {
        left: -21px;
        top: -2862px
    }
    .docs-icon-insert-script {
        left: -21px;
        top: -3261px
    }
    .docs-icon-gadget {
        left: 0;
        top: -2145px
    }
    .docs-icon-image {
        left: 0;
        top: -4146px
    }
    .docs-icon-clipboard {
        left: -21px;
        top: -1683px
    }
    .docs-icon-bold {
        left: -21px;
        top: -1200px
    }
    .docs-icon-italic {
        left: -21px;
        top: -759px
    }
    .docs-icon-text-color {
        left: 0;
        top: -738px
    }
    .docs-icon-align-left {
        left: 0;
        top: -510px
    }
    .docs-icon-align-center {
        left: 0;
        top: -4083px
    }
    .docs-icon-align-right {
        left: -21px;
        top: -3198px
    }
    .docs-icon-align-justify {
        left: 0;
        top: -2061px
    }
    .docs-icon-align-shapes-left {
        left: -21px;
        top: -1704px
    }
    .docs-icon-align-shapes-center {
        left: 0;
        top: -2799px
    }
    .docs-icon-align-shapes-right {
        left: 0;
        top: -615px
    }
    .docs-icon-align-shapes-top {
        left: 0;
        top: -1053px
    }
    .docs-icon-align-shapes-middle {
        left: -21px;
        top: -2355px
    }
    .docs-icon-align-shapes-bottom {
        left: 0;
        top: -3345px
    }
    .docs-icon-distribute-shapes-horizontally {
        left: -21px;
        top: -105px
    }
    .docs-icon-distribute-shapes-vertically {
        left: 0;
        top: -3093px
    }
    .docs-icon-valign-top {
        left: 0;
        top: -2967px
    }
    .docs-icon-valign-middle {
        left: 0;
        top: -318px
    }
    .docs-icon-valign-bottom {
        left: -21px;
        top: -2208px
    }
    .docs-icon-list-number {
        left: 0;
        top: -2757px
    }
    .docs-icon-list-bullet {
        left: -21px;
        top: -3870px
    }
    .docs-icon-indent {
        left: -21px;
        top: -1431px
    }
    .docs-icon-outdent {
        left: -21px;
        top: -4104px
    }
    .docs-icon-line-spacing {
        left: -21px;
        top: -4041px
    }
    .docs-icon-columns {
        left: 0;
        top: -2463px
    }
    .docs-icon-underline {
        left: -21px;
        top: -1494px
    }
    .docs-icon-text-bgcolor {
        left: -21px;
        top: -2187px
    }
    .docs-icon-textbox {
        left: 0;
        top: -1557px
    }
    .docs-icon-shapes {
        left: -21px;
        top: 0
    }
    .docs-icon-line-width {
        left: 0;
        top: -2862px
    }
    .docs-icon-add-trendline {
        left: 0;
        top: -3051px
    }
    .docs-icon-data-label {
        left: 0;
        top: -4314px
    }
    .docs-icon-next {
        left: -21px;
        top: -2271px
    }
    .docs-icon-previous {
        left: 0;
        top: -2208px
    }
    .docs-icon-no-color {
        left: 0;
        top: -1095px
    }
    .docs-icon-fill-color {
        left: 0;
        top: -2355px
    }
    .docs-icon-line-color {
        left: -21px;
        top: -381px
    }
    .docs-icon-line-type {
        left: 0;
        top: -1116px
    }
    .docs-icon-table {
        left: -21px;
        top: -1872px
    }
    .docs-icon-comment {
        left: 0;
        top: -1326px
    }
    .docs-icon-comment-blank {
        left: 0;
        top: -4167px
    }
    .docs-icon-comment-blank-highlighted {
        left: 0;
        top: -489px
    }
    .docs-icon-insert-comment {
        left: 0;
        top: -1326px
    }
    .docs-icon-chart {
        left: 0;
        top: -1431px
    }
    .docs-icon-list-number-rtl {
        left: -21px;
        top: -2988px
    }
    .docs-icon-list-bullet-rtl {
        left: 0;
        top: -1284px
    }
    .docs-icon-indent-rtl {
        left: 0;
        top: -1977px
    }
    .docs-icon-outdent-rtl {
        left: 0;
        top: -63px
    }
    .docs-icon-line-spacing-rtl {
        left: 0;
        top: -1221px
    }
    .docs-icon-text-ltr {
        left: -21px;
        top: -4188px
    }
    .docs-icon-text-rtl {
        left: 0;
        top: -678px
    }
    .docs-icon-sheet-rtl {
        left: -21px;
        top: -234px
    }
    .docs-icon-share {
        left: 0;
        top: -105px
    }
    .docs-icon-subscript {
        left: 0;
        top: -2103px
    }
    .docs-icon-superscript {
        left: 0;
        top: -4041px
    }
    .docs-icon-strikethrough {
        left: 0;
        top: -3135px
    }
    .docs-icon-clear-formatting {
        left: 0;
        top: -1389px
    }
    .docs-icon-link {
        left: 0;
        top: -4335px
    }
    .docs-icon-special-character {
        left: -21px;
        top: -2082px
    }
    .docs-icon-close-white {
        left: -21px;
        top: -1242px
    }
    .docs-icon-close-small {
        left: 0;
        top: -3996px
    }
    .docs-icon-close-thin {
        left: 0;
        top: -2988px
    }
    .docs-icon-paint-format {
        left: 0;
        top: -2694px
    }
    .docs-icon-video {
        left: -21px;
        top: -2019px
    }
    .docs-icon-reload {
        left: -21px;
        top: -3975px
    }
    .docs-icon-reload-rtl {
        left: -21px;
        top: -1620px
    }
    .docs-icon-insert-page-break {
        left: -21px;
        top: -3639px
    }
    .docs-icon-close {
        left: 0;
        top: -1137px
    }
    .docs-icon-check {
        left: 0;
        top: -1242px
    }
    .docs-icon-up {
        left: -21px;
        top: -531px
    }
    .docs-icon-down {
        left: -21px;
        top: -3723px
    }
    .docs-icon-add-page {
        left: -21px;
        top: -1788px
    }
    .docs-icon-email {
        left: -21px;
        top: -3156px
    }
    .docs-icon-insert-equation {
        left: -21px;
        top: -3072px
    }
    .docs-icon-insert-horizontal-line {
        left: -21px;
        top: -2418px
    }
    .docs-icon-tabstop-center {
        left: 0;
        top: -1872px
    }
    .docs-icon-tabstop-center-bottom {
        left: -21px;
        top: -780px
    }
    .docs-icon-tabstop-left {
        left: -21px;
        top: -2757px
    }
    .docs-icon-tabstop-right {
        left: 0;
        top: -1515px
    }
    .docs-icon-border-all {
        left: 0;
        top: -1179px
    }
    .docs-icon-border-right {
        left: 0;
        top: -1683px
    }
    .docs-icon-border-left {
        left: -21px;
        top: -678px
    }
    .docs-icon-border-top {
        left: 0;
        top: -2568px
    }
    .docs-icon-border-bottom {
        left: -21px;
        top: -822px
    }
    .docs-icon-border-outside {
        left: 0;
        top: -3387px
    }
    .docs-icon-border-inside {
        left: -21px;
        top: -3345px
    }
    .docs-icon-border-none {
        left: -21px;
        top: -189px
    }
    .docs-icon-border-horizontal {
        left: 0;
        top: -1305px
    }
    .docs-icon-border-vertical {
        left: -21px;
        top: -1662px
    }
    .docs-icon-merge {
        left: -21px;
        top: -3534px
    }
    .docs-icon-wrap {
        left: -21px;
        top: -4146px
    }
    .docs-icon-autofilter {
        left: 0;
        top: -4272px
    }
    .docs-icon-autofilter-filled {
        left: 0;
        top: -3660px
    }
    .docs-icon-insert-function {
        left: 0;
        top: -1368px
    }
    .docs-icon-insert-formula {
        left: 0;
        top: -3681px
    }
    .docs-icon-folder-shared {
        left: -21px;
        top: -3240px
    }
    .docs-icon-folder-outline {
        left: 0;
        top: -1200px
    }
    .docs-icon-folder-outline-hover {
        left: -21px;
        top: -1914px
    }
    .docs-icon-folder-outline-pressed {
        left: 0;
        top: -885px
    }
    .docs-icon-folder-solid {
        left: -21px;
        top: -573px
    }
    .docs-icon-drive {
        left: 0;
        top: -2334px
    }
    .docs-icon-drive-grey {
        left: 0;
        top: -4125px
    }
    .docs-icon-drive-grey-hover {
        left: -18px;
        top: -3786px
    }
    .docs-icon-drive-grey-pressed {
        left: 0;
        top: -573px
    }
    .docs-icon-drive-hover {
        left: -21px;
        top: -2334px
    }
    .docs-icon-drive-pressed {
        left: 0;
        top: -3450px
    }
    .docs-icon-drive-large {
        left: 0;
        top: -3576px
    }
    .docs-icon-back {
        left: 0;
        top: -4293px
    }
    .docs-icon-back-rtl {
        left: 0;
        top: -2547px
    }
    .docs-icon-arrow-more {
        left: -21px;
        top: -3891px
    }
    .docs-icon-arrow-more-rtl {
        left: 0;
        top: -531px
    }
    .docs-icon-search-this-document {
        left: 0;
        top: -423px
    }
    .docs-icon-arrow-dropdown {
        left: -21px;
        top: -969px
    }
    .docs-icon-word-art {
        left: -21px;
        top: -297px
    }
    .docs-icon-delete-x {
        left: 0;
        top: -3891px
    }
    .docs-icon-settings {
        left: -21px;
        top: -4335px
    }
    .docs-icon-drive-large-wrapper {
        width: 42px;
        height: 42px
    }
    .docs-icon-plus {
        left: 0;
        top: -1998px
    }
    .docs-icon-plus-white {
        left: 0;
        top: -2082px
    }
    .docs-icon-alert {
        left: -21px;
        top: -3408px
    }
    .docs-icon-trash {
        left: -21px;
        top: -3303px
    }
    .docs-icon-locked {
        left: 0;
        top: -1410px
    }
    .docs-icon-unlocked {
        left: 0;
        top: -1704px
    }
    .docs-icon-add-fonts {
        left: -21px;
        top: -318px
    }
    .docs-icon-enter-compact {
        left: 0;
        top: -126px
    }
    .docs-icon-exit-compact {
        left: -21px;
        top: -2967px
    }
    .docs-icon-mode-edit {
        left: -21px;
        top: -3030px
    }
    .docs-icon-mode-review {
        left: 0;
        top: -468px
    }
    .docs-icon-mode-review-white {
        left: 0;
        top: -255px
    }
    .docs-icon-mode-view {
        left: -21px;
        top: -1998px
    }
    .docs-icon-mode-view-white {
        left: 0;
        top: -1074px
    }
    .docs-icon-chat {
        left: -21px;
        top: -2040px
    }
    .docs-icon-star {
        left: 0;
        top: -4188px
    }
    .docs-icon-duplicate {
        left: -21px;
        top: -1452px
    }
    .docs-icon-file {
        left: 0;
        top: -1452px
    }
    .docs-icon-opacity {
        left: -21px;
        top: -2694px
    }
    .docs-icon-label-slant {
        left: -21px;
        top: -1116px
    }
    .docs-icon-point-size {
        left: 0;
        top: -2376px
    }
    .docs-icon-question {
        left: -21px;
        top: -657px
    }
    .docs-icon-vertical-gridlines {
        left: 0;
        top: -1788px
    }
    .docs-icon-left-axis {
        left: -21px;
        top: -3765px
    }
    .docs-icon-right-axis {
        left: 0;
        top: -1662px
    }
    .docs-icon-left-axis-gridlines {
        left: 0;
        top: -657px
    }
    .docs-icon-right-axis-gridlines {
        left: -21px;
        top: -4083px
    }
    .docs-icon-reset {
        left: -21px;
        top: -1032px
    }
    .docs-icon-drag-move {
        left: 0;
        top: -3555px
    }
    .docs-icon-col-dragger {
        left: -21px;
        top: -1767px
    }
    .docs-icon-chrome-store {
        left: 0;
        top: -3492px
    }
    .docs-icon-fit-area {
        left: 0;
        top: -3975px
    }
    .docs-icon-zoom-out {
        left: 0;
        top: -2589px
    }
    .docs-icon-zoom-tool {
        left: 0;
        top: -3828px
    }
    .docs-icon-download {
        left: -21px;
        top: -423px
    }
    .docs-icon-fusion-table {
        left: -21px;
        top: -3954px
    }
    .docs-icon-spreadsheet-sink {
        left: 0;
        top: -3030px
    }
    .docs-icon-send-responses {
        left: -21px;
        top: -2145px
    }
    .docs-icon-liveform {
        left: 0;
        top: -3912px
    }
    .docs-icon-ellipsis {
        left: 0;
        top: -3471px
    }
    .docs-icon-html-preview {
        left: -21px;
        top: -3807px
    }
    .docs-icon-grid {
        left: 0;
        top: -990px
    }
    .docs-icon-add-animation {
        left: 0;
        top: -2484px
    }
    .docs-icon-playhead {
        left: 0;
        top: -2229px
    }
    .docs-icon-playhead-rtl {
        left: 0;
        top: -843px
    }
    .docs-icon-unsupported {
        left: 0;
        top: -1011px
    }
    .docs-icon-calendar {
        left: -21px;
        top: -3912px
    }
    .docs-zippy-closed {
        left: -21px;
        top: -1347px
    }
    .docs-zippy-open {
        left: 0;
        top: -2673px
    }
    .docs-icon-bookmark {
        left: -21px;
        top: -2397px
    }
    .docs-icon-heading {
        left: 0;
        top: -3408px
    }
    .docs-icon-file-blue {
        left: 0;
        top: -2418px
    }
    .docs-icon-web-result {
        left: 0;
        top: -3072px
    }
    .docs-icon-mic {
        left: 0;
        top: -4251px
    }
    .docs-icon-paragraph {
        left: 0;
        top: -339px
    }
    .docs-icon-bookmark-black {
        left: 0;
        top: -147px
    }
    .docs-icon-web-result-blue {
        left: -21px;
        top: -1011px
    }
    .docs-icon-popout {
        left: 0;
        top: -906px
    }
    .docs-icon-checkbox {
        left: -21px;
        top: -4062px
    }
    .docs-icon-checkbox-type {
        left: 0;
        top: -3429px
    }
    .docs-icon-dropdown-type {
        left: 0;
        top: -189px
    }
    .docs-icon-grid-type {
        left: -21px;
        top: -2946px
    }
    .docs-icon-image-type {
        left: 0;
        top: -3240px
    }
    .docs-icon-radio-type {
        left: 0;
        top: -3303px
    }
    .docs-icon-scale-type {
        left: 0;
        top: -2715px
    }
    .docs-icon-text-type {
        left: -21px;
        top: -2736px
    }
    .docs-icon-time-type {
        left: -21px;
        top: -552px
    }
    .docs-icon-insert-text-block {
        left: -21px;
        top: -3681px
    }
    .docs-icon-accepting-responses-on {
        left: 0;
        top: -1347px
    }
    .docs-icon-accepting-responses-off {
        left: 0;
        top: -2505px
    }
    .docs-icon-decimal-increase {
        left: -21px;
        top: -1536px
    }
    .docs-icon-decimal-decrease {
        left: 0;
        top: -2271px
    }
    .docs-icon-settings-white {
        left: 0;
        top: -1893px
    }
    .docs-icon-no-symbol {
        left: 0;
        top: -1956px
    }
    .docs-icon-crop {
        left: 0;
        top: -2778px
    }
    .docs-icon-green-check {
        left: 0;
        top: -3513px
    }
    .docs-icon-font-size {
        left: 0;
        top: -1032px
    }
    .docs-icon-reset-image {
        left: -21px;
        top: -3366px
    }
    .docs-icon-r-squared {
        left: 0;
        top: -3933px
    }
    .docs-icon-graph-legend {
        left: 0;
        top: -3849px
    }
    .docs-icon-cast {
        left: 0;
        top: -2019px
    }
    .docs-icon-wrap-overflow {
        left: 0;
        top: -948px
    }
    .docs-icon-wrap-wrap {
        left: -21px;
        top: -2124px
    }
    .docs-icon-wrap-clip {
        left: 0;
        top: -3639px
    }
    .docs-icon-highlights {
        left: 0;
        top: -3744px
    }
    .docs-icon-green-back {
        left: -21px;
        top: -2715px
    }
    .docs-icon-arrow-back-white {
        left: 0;
        top: -4017px
    }
    .docs-icon-arrow-back-white-rtl {
        left: 0;
        top: -2439px
    }
    .docs-icon-help {
        left: 0;
        top: -1851px
    }
    .docs-icon-highlight-green {
        left: 0;
        top: -1536px
    }
    .docs-icon-explore-black {
        left: 0;
        top: -1473px
    }
    .docs-icon-explore-black-padded {
        left: 0;
        top: -3114px
    }
    .docs-icon-explore-green {
        left: 0;
        top: -381px
    }
    .docs-icon-explore-white {
        left: 0;
        top: -3534px
    }
    .docs-icon-insert-autovis-chart {
        left: 0;
        top: -2610px
    }
    .docs-icon-insert-autovis-chart-white {
        left: 0;
        top: -297px
    }
    .docs-icon-zoom-in {
        left: -21px;
        top: -1389px
    }
    .docs-icon-thumb-up {
        left: -21px;
        top: -339px
    }
    .docs-icon-thumb-down {
        left: -21px;
        top: -4251px
    }
    .docs-icon-dlp-warning {
        left: -21px;
        top: -255px
    }
    .docs-icon-dogfood {
        left: 0;
        top: -3786px
    }
    .docs-icon-add-to-drive {
        left: 0;
        top: -21px
    }
    .docs-icon-paste-without-formatting {
        left: 0;
        top: -1158px
    }
    .docs-icon-qanda {
        left: 0;
        top: -3198px
    }
    .docs-icon-update-chart {
        left: 0;
        top: -594px
    }
    .docs-icon-arrow-back-dark {
        left: 0;
        top: -210px
    }
    .docs-icon-arrow-back-dark-rtl {
        left: 0;
        top: -444px
    }
    .docs-icon-open-in-external {
        left: 0;
        top: -234px
    }
    .docs-icon-unlink {
        left: 0;
        top: -276px
    }
    .docs-icon-bar-chart {
        left: 0;
        top: 0
    }
    .docs-icon-column-chart {
        left: -21px;
        top: -2568px
    }
    .docs-icon-line-chart {
        left: -21px;
        top: -927px
    }
    .docs-icon-pie-chart {
        left: 0;
        top: -717px
    }
    .docs-icon-pie-chart-outline {
        height: 24px;
        left: 0;
        top: -4356px;
        width: 24px
    }
    .docs-icon-named-range {
        left: 0;
        top: -3765px
    }
    .docs-icon-clock {
        left: -21px;
        top: -843px
    }
    .docs-icon-cancel {
        left: 0;
        top: -1767px
    }
    .docs-icon-arrow-line-tool {
        left: 0;
        top: -168px
    }
    .docs-icon-arrow-tilted {
        left: 0;
        top: -864px
    }
    .docs-icon-unsupported-black {
        left: -21px;
        top: -3471px
    }
    .docs-icon-text-rotation {
        left: 0;
        top: -1830px
    }
    .docs-icon-text-rotation-up {
        left: 0;
        top: -3009px
    }
    .docs-icon-text-rotation-down {
        left: 0;
        top: -822px
    }
    .docs-icon-text-rotation-angleup {
        left: -21px;
        top: -1557px
    }
    .docs-icon-text-rotation-angledown {
        left: -21px;
        top: -1095px
    }
    .docs-icon-text-rotation-vertical {
        left: 0;
        top: -2946px
    }
    .docs-icon-text-rotation-none {
        left: 0;
        top: -2904px
    }
    .docs-icon-keep-lightbulb {
        left: -21px;
        top: -2610px
    }
    .docs-icon-update-table {
        left: -21px;
        top: -1179px
    }
    .docs-icon-update-slide {
        left: -21px;
        top: -2652px
    }
    .docs-icon-overflow-three-dots {
        left: 0;
        top: -969px
    }
    .docs-icon-restore {
        left: -21px;
        top: -2229px
    }
    .docs-icon-paragraph-border-between {
        left: -21px;
        top: -3429px
    }
    .docs-icon-paragraph-border-bottom {
        left: -21px;
        top: -1977px
    }
    .docs-icon-paragraph-border-left {
        left: -21px;
        top: -615px
    }
    .docs-icon-paragraph-border-right {
        left: -21px;
        top: -1893px
    }
    .docs-icon-paragraph-border-top {
        left: 0;
        top: -2250px
    }
    .docs-icon-diagram-white {
        left: 0;
        top: -2397px
    }
    .docs-icon-drive-black {
        left: 0;
        top: -3324px
    }
    .docs-icon-file-upload {
        left: -21px;
        top: -1221px
    }
    .docs-icon-photos {
        left: -21px;
        top: -4230px
    }
    .docs-icon-keyboard {
        left: -21px;
        top: -3135px
    }
    .docs-icon-dogfood-white {
        left: 0;
        top: -2040px
    }
    .docs-icon-hierarchy {
        left: 0;
        top: -1263px
    }
    .docs-icon-timeline {
        left: 0;
        top: -1809px
    }
    .docs-icon-process {
        left: -21px;
        top: -2166px
    }
    .docs-icon-transition {
        left: -21px;
        top: -699px
    }
    .docs-icon-mask {
        left: -21px;
        top: -21px
    }
    .docs-icon-visibility-off {
        left: 0;
        top: -2883px
    }
    .docs-icon-volume-up {
        left: 0;
        top: -2652px
    }
    .docs-icon-camera {
        left: -21px;
        top: -2925px
    }
    .docs-icon-pivot-table {
        left: -21px;
        top: -2841px
    }
    .docs-icon-insert-pivot-table {
        left: 0;
        top: -2313px
    }
}
#googlebar-coldstart {
    height: 28px;
    line-height: 28px;
    background-color: transparent;
    padding: 0 30px;
    z-index: 1003
}
.googlebar-coldstart-email-container {
    background-color: #fff;
    float: right;
    height: inherit
}
.googlebar-coldstart-email {
    color: #999;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 11px;
    padding: 0 15px
}
.modal-dialog a {
    color: #15c
}
.docs-material #docs-branding-container {
    margin-top: 0;
    width: 64px
}
.docs-material .docs-branding-icon,
.docs-material #docs-branding-container a,
.docs-material #docs-branding-logo,
.docs-material #docs-drive-logo {
    height: 40px;
    width: 40px
}
.docs-material #docs-branding-container a,
.docs-material #docs-branding-container .docs-branding-logo-no-link {
    border-radius: 50%;
    margin: 4px 0 4px 8px;
    padding: 8px
}
.docs-material #docs-branding-container a:focus {
    background-color: rgba(0, 0, 0, .06);
    outline: none
}
.docs-material #docs-menubar,
.docs-material #docs-titlebar-container {
    margin-left: 64px
}
.docs-material .docs-title-outer {
    margin-left: 0
}
.docs-material #docs-folder {
    margin-top: 1px
}
.docs-material #docs-branding-container {
    background-color: inherit
}
.docs-material .docs-branding-icon-img:before {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134.svg)
}
.docs-material .docs-branding-icon-documents {
    left: 0;
    top: -704px
}
.docs-material .docs-branding-icon-drawings {
    left: 0;
    top: -1576px
}
.docs-material .docs-branding-icon-default,
.docs-material .docs-branding-icon-forms,
.docs-material .docs-branding-icon-scripts,
.docs-material .docs-branding-icon-drive {
    left: -20px;
    top: -556px
}
.docs-material .docs-branding-icon-spreadsheets {
    left: -26px;
    top: -2312px
}
.docs-material .docs-branding-icon-presentations {
    left: -20px;
    top: -2712px
}
.docs-material #docs-branding-container:not(.docs-branding-crossfade-transition-disabled):hover #docs-drive-logo {
    opacity: 0
}
.docs-material #docs-branding-container:not(.docs-branding-crossfade-transition-disabled):hover #docs-branding-logo {
    opacity: 1
}
.docs-material #docs-activity-indicator {
    padding-top: 3px
}
.docs-material .docs-titlebar-badges .jfk-activityIndicator {
    vertical-align: top
}
.docs-material #docs-header #docs-titlebar {
    padding-top: 9px
}
.docs-material #docs-header #docs-titlebar-container {
    max-height: 33px
}
.docs-material .docs-menubar {
    height: 31px
}
.docs-material #docs-branding-container,
.docs-material #docs-chrome-cover {
    height: 64px
}
.docs-material .docs-appbar-circle-button.jfk-button {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: transparent;
    background-image: none;
    cursor: pointer;
    height: 40px;
    width: 40px;
    border-radius: 50%;
    border-width: 1px;
    border-style: solid;
    border-color: transparent;
    box-shadow: none;
    background-clip: padding-box;
    cursor: pointer;
    -webkit-tap-highlight-color: transparent;
    min-width: 0;
    padding: 0;
    margin: 0 9px 0 0
}
.docs-material .docs-appbar-circle-button.jfk-button .docs-icon {
    height: 24px;
    width: 24px;
    opacity: 0.54
}
.docs-gm .docs-material .docs-appbar-circle-button.jfk-button .docs-icon {
    opacity: 1
}
.docs-material .docs-appbar-circle-button.jfk-button-hover,
.docs-material .docs-appbar-circle-button.jfk-button:focus {
    background-color: rgba(0, 0, 0, .06)
}
.docs-material .docs-appbar-circle-button.jfk-button-active,
.docs-material .docs-appbar-circle-button.jfk-button-checked {
    background-color: rgba(0, 0, 0, 0.12)
}
.docs-gm .docs-material .docs-appbar-circle-button.jfk-button-active,
.docs-gm .docs-material .docs-appbar-circle-button.jfk-button-checked {
    background-color: #e6f4ea
}
.docs-material .docs-appbar-circle-button.jfk-button-active .docs-icon,
.docs-material .docs-appbar-circle-button.jfk-button-checked .docs-icon {
    opacity: 0.87
}
.docs-gm .docs-material .docs-appbar-circle-button.jfk-button-active .docs-icon,
.docs-gm .docs-material .docs-appbar-circle-button.jfk-button-checked .docs-icon {
    opacity: 1
}
.docs-material .docs-appbar-circle-button.jfk-button-disabled .docs-icon {
    opacity: .26
}
.docs-gm .docs-material .docs-appbar-circle-button.jfk-button-disabled .docs-icon {
    opacity: .38
}
.docs-material .docs-appbar-circle-button.jfk-button-disabled {
    cursor: inherit
}
.docs-material .docs-chat.jfk-button {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    -webkit-justify-content: center;
    justify-content: center;
    -webkit-transition: background 0.2s 0.1s;
    -moz-transition: background 0.2s 0.1s;
    -o-transition: background 0.2s 0.1s;
    transition: background 0.2s 0.1s;
    background-color: #e8eaed;
    background-image: none
}
.docs-gm .docs-material .docs-chat.jfk-button,
.docs-gm .docs-material .docs-chat.jfk-button.jfk-button-clear-outline,
.docs-gm .docs-material .docs-chat.jfk-button.jfk-button-active.jfk-button-focused {
    background-color: #fff;
    border: 2px solid #dadce0;
    box-shadow: 0 0 0 2px #fff
}
.docs-gm .docs-material .docs-chat.jfk-button.jfk-button-focused {
    background-color: #fff
}
.docs-material .docs-chat.jfk-button,
.docs-material .docs-chat.jfk-button.jfk-button-clear-outline,
.docs-material .docs-chat.jfk-button.jfk-button-active.jfk-button-focused {
    height: 32px;
    width: 32px;
    border-radius: 50%;
    border-width: 2px;
    border-style: solid;
    border-color: #fff;
    box-shadow: none;
    background-clip: padding-box;
    cursor: pointer;
    -webkit-tap-highlight-color: transparent;
    margin: 0 0 0 -8px
}
.docs-material .docs-chat.jfk-button.jfk-button-hover {
    background-color: #dadce0
}
.docs-gm .docs-material .docs-chat.jfk-button.jfk-button-hover,
.docs-gm .docs-material .docs-chat.jfk-button.jfk-button-hover.jfk-button-clear-outline,
.docs-gm .docs-material .docs-chat.jfk-button.jfk-button-hover.jfk-button-focused {
    background-color: #dadce0
}
.docs-gm .docs-material .docs-chat.jfk-button.jfk-button-hover.jfk-button-clear-outline.jfk-button-focused.jfk-button-active {
    margin: 0 0 0 -8px
}
.docs-material .docs-chat.jfk-button.jfk-button-active {
    background-color: #bdc1c6
}
.docs-material .docs-chat.jfk-button.jfk-button-focused {
    border: 4px solid rgba(0, 0, 0, 0.12);
    margin: -2px -2px -2px -10px
}
.docs-gm .docs-material .docs-chat.jfk-button.jfk-button-focused {
    border: 4px solid rgba(0, 0, 0, 0.12);
    margin: -2px -2px -2px -10px;
    box-shadow: none
}
.docs-material .docs-chat.jfk-button .docs-icon {
    -webkit-transition-duration: 200ms;
    -moz-transition-duration: 200ms;
    -o-transition-duration: 200ms;
    transition-duration: 200ms;
    -webkit-transition-property: opacity;
    -moz-transition-property: opacity;
    -o-transition-property: opacity;
    transition-property: opacity;
    -webkit-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    opacity: .71;
    margin: 0
}
.docs-material .docs-chat.jfk-button.jfk-button-active .docs-icon,
.docs-material .docs-chat.jfk-button.jfk-button-checked .docs-icon,
.docs-material .docs-chat.jfk-button.jfk-button-focused .docs-icon,
.docs-material .docs-chat.jfk-button.jfk-button-hover .docs-icon {
    opacity: .86
}
.docs-material .docs-chat.jfk-button.jfk-button-disabled .docs-icon {
    opacity: 0.50
}
.docs-material .docs-chat-badge {
    border-radius: 50%;
    border: 1px solid #fff;
    right: -3px;
    top: -3px
}
.docs-gm-sidebars .docs-explore-feedback-title,
.docs-gm-sidebars .docs-explore-feedback-button {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px
}
.docs-gm-sidebars .docs-explore-sidebar-title-heading,
.docs-gm-sidebars .docs-explore-sidebar-title-heading-button {
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px;
    font-weight: 500;
    line-height: 24px;
    position: relative;
    left: auto;
    height: auto;
    max-width: calc(100% - 64px);
    padding: 0;
    right: auto;
    top: auto
}
.docs-gm-sidebars .docs-explore-sidebar-title-heading-button {
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px
}
.docs-gm-sidebars .docs-explore-serp-webresultscard-header-text,
.docs-gm-sidebars .docs-explore-serp-webresultscard-allresults-text {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px
}
.docs-gm-sidebars .docs-explore-serp-enterpriseresultscard-allresults-text {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px
}
.docs-gm-sidebars .docs-explore-serp-enterpriseresult-embeddeditems-show-more-button {
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500
}
.docs-gm-sidebars .docs-explore-serp-enterpriseresult-snippet {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px
}
.docs-gm-sidebars .docs-explore-serp-enterpriseresult-title {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px
}
.docs-gm-sidebars .docs-explore-searchbar-labelinput {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px
}
.docs-gm-sidebars .docs-explore-card-title-heading {
    color: #3c4043;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    line-height: 24px;
    text-transform: none
}
.docs-gm-sidebars .docs-explore-card-more-button {
    color: #1a73e8;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    line-height: 20px
}
.docs-gm-sidebars .docs-explore-card-subtitle {
    color: #80868b;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    line-height: 16px
}
.docs-material.goog-menu.goog-menu-nocheckbox .goog-menuitem,
.docs-material.goog-menu.goog-menu-noicon .goog-menuitem {
    padding-left: 16px
}
.docs-material.goog-menu .goog-menuitem {
    padding-left: 36px
}
.docs-material.goog-menu .apps-menuitem .goog-menuitem-checkbox,
.docs-material.goog-menu .apps-menuitem .goog-menuitem-icon {
    left: 8px
}
.docs-material.goog-menu .apps-menuitem.goog-option-selected {
    background-position: left 5px center
}
.docs-gm .docs-material.goog-menu .apps-menuitem.goog-option-selected {
    background-image: none
}
.docs-gm .docs-material.goog-menu .apps-menuitem.goog-option-selected .goog-menuitem-checkbox {
    background: no-repeat url(//ssl.gstatic.com/docs/common/material_common_sprite134.svg) -20px -3558px;
    height: 18px;
    width: 18px;
    top: 50%;
    margin-top: -9px
}
.docs-gm .docs-menubar .goog-control {
    border: 1px solid transparent;
    border-radius: 4px;
    box-shadow: none;
    color: #202124;
    cursor: pointer;
    font-size: 14px;
    letter-spacing: .2px;
    padding: 4px 6px
}
.docs-gm .docs-menubar .goog-control-hover {
    background-color: #f1f3f4
}
.docs-gm .docs-menubar .goog-control-open {
    background-color: #e6f4ea
}
.docs-gm .docs-menubar .goog-control-active,
.docs-gm .docs-menubar .goog-control:hover:active {
    background-color: #ceead6
}
.docs-gm .docs-menubar .goog-control-disabled {
    color: #9aa0a6;
    background-color: white;
    cursor: default
}
.docs-gm .docs-menubar .docs-menu-button-open-below,
.docs-gm .docs-menubar .docs-menu-button-open-above {
    z-index: 1003
}
.docs-gm .docs-menubar .goog-control.docs-menu-button-open-below {
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0
}
.docs-gm .goog-menu.docs-menu-attached-button-above {
    border-top-left-radius: 0
}
.docs-gm .goog-menu.docs-menu-attached-button-below {
    border-bottom-left-radius: 0
}
.docs-gm .goog-menu {
    border: 1px solid transparent;
    border-radius: 4px;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    max-height: calc(100vh - 70px);
    overflow-y: auto
}
.docs-gm .goog-menu .goog-dimension-picker,
.docs-gm .goog-menu.docs-fontmenu {
    overflow: hidden
}
.docs-gm .goog-menu.docs-omnibox-parent,
.docs-gm .goog-menu.docs-ruler-context-menu {
    overflow: visible
}
.docs-gm .docs-fontmenu {
    max-height: none;
    max-height: unset
}
.docs-gm .goog-menuseparator {
    border-top: 1px solid #dadce0;
    margin: 8px 0 8px 36px
}
.docs-gm .docs-colormenuitems .goog-menuseparator,
.docs-gm .waffle-conditionalformat-default-menu .goog-menuseparator {
    margin-left: 0
}
.docs-gm .goog-menu-noicon .goog-menuseparator {
    margin-left: 13px
}
.docs-gm .goog-menuitem {
    color: #202124;
    font-size: 14px;
    letter-spacing: .2px;
    line-height: 20px;
    white-space: normal
}
.docs-gm .goog-menu .goog-menuitem {
    padding: 6px 15px 6px 38px
}
.docs-gm .goog-menu-noicon .goog-menuitem {
    padding-left: 15px
}
.docs-gm .goog-menu .apps-menuitem .goog-menuitem-checkbox,
.docs-gm .goog-menu .apps-menuitem .goog-menuitem-icon {
    margin: 7px 8px 7px 12px;
    left: 0;
    top: 0
}
.docs-gm .goog-menuitem .goog-menuitem-content {
    min-height: 20px
}
.docs-gm .goog-menuitem .goog-submenu-arrow {
    padding-top: 0
}
.docs-gm .goog-menuitem .docs-toolbar-mode-switcher-menu-description,
.docs-gm .goog-menuitem .docs-display-density-toolbar-menuitem-description,
.docs-gm .goog-menuitem .punch-qanda-presenter-view-menu-item-description {
    color: #80868b;
    font-size: 12px;
    line-height: 1
}
.docs-gm .goog-menuitem-highlight {
    background-color: #f1f3f4
}
.docs-gm .goog-menuitem.goog-menuitem-highlight {
    border-color: #f1f3f4;
    border-style: dotted;
    border-width: 1px 0;
    padding-top: 5px;
    padding-bottom: 5px
}
.docs-gm .apps-menuitem.goog-menuitem-highlight {
    border: none;
    padding-top: 6px;
    padding-bottom: 6px
}
.docs-gm .docs-submenuitem.goog-menuitem {
    padding-bottom: 0;
    padding-right: 10px;
    padding-top: 0
}
.docs-gm .docs-fontmenu .goog-menuitem {
    padding-bottom: 6px;
    padding-right: 48px;
    padding-top: 6px
}
.docs-gm .docs-submenuitem.goog-menuitem-highlight {
    border: none;
    border-bottom: 1px solid #e6e6e6
}
.docs-gm .docs-fontmenu .goog-menuitem-highlight {
    border: none
}
.docs-gm .goog-menuitem-disabled,
.docs-gm .goog-menuitem-disabled .goog-menuitem-content {
    color: #9aa0a6!important
}
.docs-gm .goog-menuitem-active:hover:active {
    background-color: #e8eaed
}
.docs-gm .goog-menuitem-accel,
.docs-gm .goog-menuitem-disabled .goog-menuitem-accel {
    color: #80868b;
    font-weight: 500
}
.docs-gm .docs-ruler-context-menu-arrow-before {
    border: 0
}
.docs-gm .docs-omnibox-autocomplete .goog-menuitem-icon {
    top: auto
}
.docs-material #docs-presence-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    height: 36px;
    margin: 0 8px 0 0
}
.docs-material .docs-presence-plus-widget {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    -webkit-justify-content: flex-end;
    justify-content: flex-end
}
.docs-material .docs-presence-plus-widget-open .docs-presence-plus-widget-status {
    display: none
}
.docs-material .docs-presence-plus-widget-collabs {
    height: 36px
}
.docs-material .docs-presence-plus-collab-widget-container {
    margin: 0 0 0 -8px;
    overflow: visible;
    height: auto;
    width: auto
}
.docs-material .docs-presence-plus-collab-widget {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.docs-material .docs-presence-plus-collab-widget-color-block,
.docs-material.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget-color-block {
    height: 32px;
    width: 32px;
    border-radius: 50%;
    border-width: 2px;
    border-style: solid;
    border-color: #fff;
    box-shadow: none;
    background-clip: padding-box;
    cursor: pointer;
    -webkit-tap-highlight-color: transparent;
    background-color: #fff;
    opacity: 1;
    overflow: visible
}
.docs-material .docs-presence-plus-collab-widget-image-container,
.docs-material.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget-image-container {
    height: 32px;
    width: 32px;
    border-radius: 50%;
    padding: 0;
    overflow: visible;
    display: inline-block;
    opacity: .5;
    box-shadow: 0 0 1px 0 white
}
.docs-material .docs-presence-plus-collab-widget-active .docs-presence-plus-collab-widget-image-container {
    opacity: 1
}
.docs-material .docs-presence-plus-collab-widget-image-border,
.docs-material.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget-image-border {
    height: 28px;
    width: 28px;
    border-radius: 50%;
    margin: 2px;
    border: none
}
.docs-material .docs-presence-plus-collab-widget-image,
.docs-material.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget-image {
    height: 28px;
    width: 28px;
    border-radius: 50%;
    padding: 0;
    left: 0
}
.docs-material .docs-presence-plus-collab-widget-focus:focus {
    outline: none
}
.docs-material .docs-presence-plus-collab-widget-focus:focus .docs-presence-plus-collab-widget-color-block {
    border: 4px solid rgba(0, 0, 0, 0.12);
    margin: -2px
}
.docs-material .docs-presence-plus-widget-overflow-button {
    height: 32px;
    width: 32px;
    border-radius: 50%;
    border-width: 2px;
    border-style: solid;
    border-color: #fff;
    box-shadow: none;
    background-clip: padding-box;
    cursor: pointer;
    -webkit-tap-highlight-color: transparent;
    margin: 0 0 0 -8px;
    background-color: #e8eaed;
    background-image: none;
    color: rgba(32, 33, 36, .71)
}
.docs-material .docs-presence-plus-widget-overflow-button.goog-flat-menu-button-focused {
    border: 4px solid rgba(0, 0, 0, 0.12);
    color: rgba(32, 33, 36, .86);
    margin: -2px -2px -2px -10px
}
.docs-material .docs-presence-plus-widget-overflow-button.goog-flat-menu-button-focused.goog-flat-menu-button-open {
    border: 2px solid rgba(255, 255, 255, 1);
    margin: 0 0 0 -8px
}
.docs-material .docs-presence-plus-widget-overflow-button.goog-flat-menu-button-open {
    background-color: #e8eaed;
    z-index: auto
}
.docs-material .docs-presence-plus-widget-overflow-button.goog-flat-menu-button-hover {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: #dadce0;
    color: rgba(32, 33, 36, .86)
}
.docs-material .docs-presence-plus-widget-overflow-button.goog-flat-menu-button-active {
    background-color: #bdc1c6;
    color: rgba(32, 33, 36, .86)
}
.docs-material .docs-presence-plus-widget-overflow-button.goog-flat-menu-button-open .goog-flat-menu-button-caption {
    -webkit-transition-duration: 200ms;
    -moz-transition-duration: 200ms;
    -o-transition-duration: 200ms;
    transition-duration: 200ms;
    -webkit-transition-property: opacity;
    -moz-transition-property: opacity;
    -o-transition-property: opacity;
    transition-property: opacity;
    -webkit-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -webkit-transition-delay: 100ms;
    -moz-transition-delay: 100ms;
    -o-transition-delay: 100ms;
    transition-delay: 100ms;
    opacity: 0
}
.docs-material .docs-presence-plus-widget-overflow-button.goog-flat-menu-button-open .goog-flat-menu-button-dropdown {
    -webkit-transition-duration: 200ms;
    -moz-transition-duration: 200ms;
    -o-transition-duration: 200ms;
    transition-duration: 200ms;
    -webkit-transition-property: opacity;
    -moz-transition-property: opacity;
    -o-transition-property: opacity;
    transition-property: opacity;
    -webkit-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -webkit-transition-delay: 100ms;
    -moz-transition-delay: 100ms;
    -o-transition-delay: 100ms;
    transition-delay: 100ms;
    opacity: 1
}
.docs-material .docs-presence-plus-widget-overflow-button .goog-flat-menu-button-caption {
    -webkit-transition-duration: 200ms;
    -moz-transition-duration: 200ms;
    -o-transition-duration: 200ms;
    transition-duration: 200ms;
    -webkit-transition-property: opacity;
    -moz-transition-property: opacity;
    -o-transition-property: opacity;
    transition-property: opacity;
    -webkit-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    left: -2px;
    line-height: 32px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-weight: 500
}
.docs-material .docs-presence-plus-widget-overflow-button .goog-flat-menu-button-dropdown {
    -webkit-transition-duration: 200ms;
    -moz-transition-duration: 200ms;
    -o-transition-duration: 200ms;
    transition-duration: 200ms;
    -webkit-transition-property: opacity;
    -moz-transition-property: opacity;
    -o-transition-property: opacity;
    transition-property: opacity;
    -webkit-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    right: 10px;
    opacity: 0;
    border-width: 0 6px 6px;
    border-color: rgba(32, 33, 36, .71) transparent
}
.docs-material .docs-presence-plus-widget-overflow-button.goog-flat-menu-button-active .goog-flat-menu-button-dropdown,
.docs-material .docs-presence-plus-widget-overflow-button.goog-flat-menu-button-focused .goog-flat-menu-button-dropdown,
.docs-material .docs-presence-plus-widget-overflow-button.goog-flat-menu-button-hover .goog-flat-menu-button-dropdown {
    border-color: rgba(32, 33, 36, .86) transparent
}
.docs-material.docs-presence-plus-widget-overflow-menu {
    max-height: 340px;
    width: 256px;
    padding: 4px 0 8px 0;
    border-radius: 2px;
    box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2)
}
.docs-material.docs-presence-plus-widget-overflow-menu .goog-menuheader {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    margin-left: 16px;
    height: 40px;
    color: rgba(0, 0, 0, 0.54);
    font-weight: 500
}
.docs-material.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget-container {
    margin: 0;
    height: 48px;
    width: 100%
}
.docs-material.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget-color-block {
    margin: 0 16px 0;
    border: none
}
.docs-material.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    height: 48px
}
.docs-material.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget-name {
    color: rgba(0, 0, 0, 0.87);
    margin: 0
}
.docs-material.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget-idle-text {
    color: rgba(0, 0, 0, 0.54);
    margin-left: 6px;
    font-size: 13px
}
@keyframes material-collab-join {
    from {
        opacity: 0
    }
    to {
        opacity: 1
    }
}
@-webkit-keyframes material-collab-join {
    from {
        opacity: 0
    }
    to {
        opacity: 1
    }
}
.docs-material .docs-presence-plus-collab-widget-enter-material {
    -webkit-animation-name: material-collab-join;
    -moz-animation-name: material-collab-join;
    -o-animation-name: material-collab-join;
    animation-name: material-collab-join;
    -webkit-animation-timing-function: cubic-bezier(0, 0, .2, 1);
    -moz-animation-timing-function: cubic-bezier(0, 0, .2, 1);
    -o-animation-timing-function: cubic-bezier(0, 0, .2, 1);
    animation-timing-function: cubic-bezier(0, 0, .2, 1);
    -webkit-animation-duration: 200ms;
    -moz-animation-duration: 200ms;
    -o-animation-duration: 200ms;
    animation-duration: 200ms;
    -webkit-animation-fill-mode: both;
    animation-fill-mode: both
}
.docs-material .docs-presence-plus-collab-widget-exit-material {
    -webkit-animation-name: material-collab-join;
    -moz-animation-name: material-collab-join;
    -o-animation-name: material-collab-join;
    animation-name: material-collab-join;
    -webkit-animation-direction: reverse;
    -moz-animation-direction: reverse;
    -o-animation-direction: reverse;
    animation-direction: reverse;
    -webkit-animation-timing-function: cubic-bezier(.4, 0, .2, 1);
    -moz-animation-timing-function: cubic-bezier(.4, 0, .2, 1);
    -o-animation-timing-function: cubic-bezier(.4, 0, .2, 1);
    animation-timing-function: cubic-bezier(.4, 0, .2, 1);
    -webkit-animation-duration: 200ms;
    -moz-animation-duration: 200ms;
    -o-animation-duration: 200ms;
    animation-duration: 200ms;
    -webkit-animation-fill-mode: both;
    animation-fill-mode: both
}
.docs-gm .docs-title-input:focus {
    border: 2px solid #1a73e8!important;
    margin: -1px;
    box-shadow: none;
    border-radius: 4px!important
}
.docs-material .docs-titlebar-button {
    display: inline-flex;
    align-items: center;
    justify-content: center
}
.docs-revisions-sidebar .docs-revisions-sidebar-title {
    height: 64px
}
.docs-material .docs-debug-container {
    margin-right: 16px
}
.docs-material #docs-docos-commentsbutton {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: transparent;
    background-image: none;
    cursor: pointer;
    height: 40px;
    width: 40px;
    border-radius: 50%;
    border-width: 1px;
    border-style: solid;
    border-color: transparent;
    box-shadow: none;
    background-clip: padding-box;
    cursor: pointer;
    -webkit-tap-highlight-color: transparent;
    min-width: 0;
    padding: 0;
    margin: 0 9px 0 0
}
.docs-material #docs-docos-commentsbutton.jfk-button.jfk-button-hover,
.docs-material #docs-docos-commentsbutton:focus {
    background-color: rgba(0, 0, 0, .06)
}
.docs-material #docs-docos-commentsbutton.jfk-button.jfk-button-active,
.docs-material #docs-docos-commentsbutton.jfk-button.jfk-button-checked {
    background-color: rgba(0, 0, 0, 0.12)
}
.docs-gm .docs-material #docs-docos-commentsbutton.jfk-button.jfk-button-active,
.docs-gm .docs-material #docs-docos-commentsbutton.jfk-button.jfk-button-checked {
    background-color: #e6f4ea
}
.docs-material #docs-docos-commentsbutton .docs-icon {
    height: 24px;
    width: 24px;
    opacity: 0.54
}
.docs-material #docs-docos-commentsbutton.jfk-button.jfk-button-active .docs-icon,
.docs-material #docs-docos-commentsbutton.jfk-button.jfk-button-checked .docs-icon {
    opacity: 0.87
}
.docs-material #docs-docos-commentsbutton.jfk-button.jfk-button-disabled .docs-icon {
    opacity: .26
}
.docs-gm .docs-material #docs-docos-commentsbutton .docs-icon {
    opacity: 1
}
.docs-gm .docs-material #docs-docos-commentsbutton.jfk-button.jfk-button-active .docs-icon,
.docs-gm .docs-material #docs-docos-commentsbutton.jfk-button.jfk-button-checked .docs-icon {
    opacity: 1
}
.docs-gm .docs-material #docs-docos-commentsbutton.jfk-button.jfk-button-disabled .docs-icon {
    opacity: .38
}
.docs-material #docs-docos-commentsbutton.jfk-button.jfk-button-disabled,
.docs-material #docs-titlebar-share-client-button .jfk-button.jfk-button-disabled,
.docs-material #docs-script-button-bar .jfk-button.jfk-button-disabled {
    cursor: inherit
}
.docs-material #docs-titlebar-share-client-button .jfk-button {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: #4285f4;
    background-image: none;
    cursor: pointer;
    border-color: transparent!important;
    border-radius: 2px;
    border-width: 1px;
    border-style: inset;
    color: #fff;
    font-size: 13px;
    height: 30px;
    padding: 0 14px;
    text-transform: uppercase;
    font-size: var(--docs-material-font-size-normal, 13px);
    margin-right: 12px;
    padding: 0 7px;
    min-width: 0
}
.docs-material #docs-titlebar-share-client-button .jfk-button-disabled {
    background-color: rgba(0, 0, 0, 0.12);
    opacity: 1
}
.docs-material #docs-titlebar-share-client-button .jfk-button .scb-button-icon {
    margin: 0 3px 0 -4px
}
.docs-material #docs-titlebar-share-client-button .jfk-button:focus {
    border-color: rgba(0, 0, 0, 0.38)!important
}
.docs-material #docs-titlebar-share-client-button .jfk-button.jfk-button-hover {
    box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2)
}
.docs-material #docs-titlebar-share-client-button .jfk-button.jfk-button-active,
.docs-material #docs-titlebar-share-client-button .jfk-button.jfk-button-checked {
    box-shadow: 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12), 0px 2px 4px -1px rgba(0, 0, 0, 0.2);
    background-color: #3367d6
}
.docs-material #docs-script-button-bar .jfk-button {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: rgba(0, 0, 0, .04);
    background-image: none;
    cursor: pointer;
    border-color: transparent!important;
    border-radius: 2px;
    border-width: 1px;
    border-style: inset;
    color: rgba(0, 0, 0, 0.54);
    font-size: 13px;
    height: 30px;
    padding: 0 14px;
    text-transform: uppercase;
    margin-right: 8px
}
.docs-material #docs-script-button-bar .jfk-button.jfk-button-disabled {
    background-color: #fff;
    color: rgba(0, 0, 0, 0.26)
}
.docs-material #docs-script-button-bar .jfk-button:focus {
    border-color: #4285f4!important;
    color: rgba(0, 0, 0, .60)
}
.docs-material #docs-script-button-bar .jfk-button.jfk-button-hover {
    box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    color: rgba(0, 0, 0, .60)
}
.docs-material #docs-script-button-bar .jfk-button.jfk-button-active,
.docs-material #docs-script-button-bar .jfk-button.jfk-button-checked {
    box-shadow: 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12), 0px 2px 4px -1px rgba(0, 0, 0, 0.2);
    background-color: rgba(0, 0, 0, 0.12);
    color: rgba(0, 0, 0, 0.87)
}
.docs-material #docs-titlebar-share-client-button .jfk-button.jfk-button-clear-outline,
.docs-material #docs-script-button-bar .jfk-button.jfk-button-clear-outline {
    border-color: transparent!important
}
#docs-docos-caret {
    display: none
}
.docs-material .docs-docos-activitybox {
    top: 60px
}
.docs-material #docs-header .docs-titlebar-buttons {
    align-items: center;
    background-color: #fff;
    display: flex;
    height: 64px;
    padding: 0 12px 0 16px;
    top: 0;
    z-index: 900
}
.docs-material #docs-header .docs-titlebar-buttons.docs-titlebar-occluding::before {
    background: linear-gradient(to right, transparent, rgba(60, 64, 67, .1) 70%, rgba(60, 64, 67, .2) 100%);
    content: '';
    height: 100%;
    left: -6px;
    position: absolute;
    width: 6px;
    top: 0
}
.docs-material #docs-header .docs-titlebar-buttons-rtl.docs-titlebar-occluding::before {
    background: linear-gradient(to left, transparent, rgba(60, 64, 67, .1) 70%, rgba(60, 64, 67, .2) 100%)
}
.docs-material .docs-titlebar-buttons .onegoogle-material-minibar {
    text-align: left
}
.docs-material #googlebar-coldstart {
    height: 32px;
    width: 32px;
    border-radius: 50%;
    background-color: #0f9d58;
    margin: 0 8px 0 0;
    padding: 0;
    z-index: auto
}
.docs-material #googlebar-coldstart .docs-icon-img {
    opacity: 0.54
}
.docs-gm .docs-title-untitled {
    font-style: normal
}
.docs-gm #docs-titlebar-share-client-button .jfk-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    padding: 9px 16px 10px 12px;
    text-transform: capitalize
}
.docs-gm #docs-titlebar-share-client-button .jfk-button-disabled {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #f1f3f4;
    color: #3c4043;
    opacity: 0.38;
    padding: 9px 16px 10px 12px
}
.docs-gm #docs-titlebar-share-client-button .jfk-button .scb-button-icon {
    margin: 0 3px 0 -4px
}
.docs-gm #docs-titlebar-share-client-button .jfk-button:focus {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #4f9e67;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15);
    padding: 9px 16px 10px 12px;
    border-color: transparent!important
}
.docs-gm #docs-titlebar-share-client-button .jfk-button.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #2a8947;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15);
    padding: 9px 16px 10px 12px
}
.docs-gm #docs-titlebar-share-client-button .jfk-button.jfk-button-hover:focus {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15);
    padding: 9px 16px 10px 12px
}
.docs-gm #docs-titlebar-share-client-button .jfk-button.jfk-button-active,
.docs-gm #docs-titlebar-share-client-button .jfk-button.jfk-button-checked {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 2px 6px 2px rgba(52, 168, 83, 0.15);
    padding: 9px 16px 10px 12px
}
.docs-gm #docs-titlebar-share-client-button .decoupled-docs-share-button.docs-titlebar-button.jfk-button {
    padding: 9px 16px 10px 16px
}
.goog-toolbar-button,
.goog-toolbar-menu-button {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    background: 0;
    border-color: transparent;
    border-style: solid;
    border-width: 1px;
    outline: none;
    padding: 0;
    height: 24px;
    color: #333;
    line-height: 24px;
    list-style: none;
    font-size: 11px;
    font-weight: bold;
    text-decoration: none;
    vertical-align: middle;
    cursor: default
}
.goog-toolbar-button-outer-box,
.goog-toolbar-button-inner-box .goog-toolbar-menu-button-outer-box,
.goog-toolbar-menu-button-inner-box {
    border: 0;
    vertical-align: top
}
.goog-toolbar-button-outer-box,
.goog-toolbar-menu-button-outer-box {
    margin: 0;
    padding: 0
}
.goog-toolbar-button-inner-box,
.goog-toolbar-menu-button-inner-box {
    padding: 0 2px
}
.goog-toolbar-button-hover,
.goog-toolbar-button-active,
.goog-toolbar-button-checked,
.goog-toolbar-button-selected {
    color: #222;
    padding: 0
}
.goog-toolbar-button-hover,
.goog-toolbar-menu-button-hover {
    border-color: #c6c6c6!important;
    color: #222
}
.goog-toolbar-menu-button-open {
    color: #222
}
.goog-toolbar-button-hover,
.goog-toolbar-menu-button-hover {
    -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, .1);
    -moz-box-shadow: 0 1px 1px rgba(0, 0, 0, .1);
    box-shadow: 0 1px 1px rgba(0, 0, 0, .1);
    background-color: #f8f8f8;
    background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -o-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: linear-gradient(top, #f8f8f8, #f1f1f1)
}
.goog-toolbar-button-active,
.goog-toolbar-menu-button-active {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    background-color: #f6f6f6;
    background-image: -webkit-linear-gradient(top, #f6f6f6, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f6f6f6, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f6f6f6, #f1f1f1);
    background-image: -o-linear-gradient(top, #f6f6f6, #f1f1f1);
    background-image: linear-gradient(top, #f6f6f6, #f1f1f1);
    border-color: #c6c6c6
}
.goog-toolbar-button-selected,
.goog-toolbar-button-checked,
.goog-toolbar-menu-button-open {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    background-color: #eee;
    background-image: -webkit-linear-gradient(top, #eee, #e0e0e0);
    background-image: -moz-linear-gradient(top, #eee, #e0e0e0);
    background-image: -ms-linear-gradient(top, #eee, #e0e0e0);
    background-image: -o-linear-gradient(top, #eee, #e0e0e0);
    background-image: linear-gradient(top, #eee, #e0e0e0);
    border-color: #ccc
}
.goog-toolbar-button-disabled,
.goog-toolbar-menu-button-disabled {
    color: #222!important;
    opacity: 0.3;
    filter: alpha(opacity=30)
}
.goog-toolbar-button-collapse-right,
.goog-toolbar-button-collapse-right .goog-toolbar-button-outer-box,
.goog-toolbar-button-collapse-right .goog-toolbar-button-inner-box {
    margin-right: 0
}
.goog-toolbar-button-collapse-left,
.goog-toolbar-button-collapse-left .goog-toolbar-button-outer-box,
.goog-toolbar-button-collapse-left .goog-toolbar-button-inner-box {
    margin-left: 0
}
.goog-toolbar-menu-button-dropdown {
    background: url(//ssl.gstatic.com/ui/v1/disclosure/small-grey-disclosure-arrow-down.png) center no-repeat;
    float: right;
    margin: 10px 2px 0 3px;
    padding: 0;
    opacity: .8;
    vertical-align: middle;
    width: 5px;
    height: 7px;
    *float: none;
    *position: relative;
    *top: -3px
}
.goog-toolbar-separator {
    border-left: 1px solid #ccc;
    height: 17px;
    line-height: normal;
    list-style: none;
    margin: 0 2px;
    outline: none;
    overflow: hidden;
    padding: 0;
    text-decoration: none;
    vertical-align: middle;
    width: 0
}
.goog-toolbar-select .goog-toolbar-menu-button-dropdown {
    background: url(//ssl.gstatic.com/ui/v1/disclosure/small-grey-disclosure-arrow-down.png) center no-repeat;
    height: 11px;
    margin-top: 7px;
    width: 7px;
    -webkit-transform: none;
    -moz-transform: none;
    transform: none;
    filter: none
}
.goog-toolbar-menu-button-caption {
    padding: 0;
    margin: 0
}
.docs-material #docs-toolbar-wrapper {
    border-top: 1px solid #e0e0e0;
    border-bottom: 1px solid #e0e0e0;
    background: #fff;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none
}
.docs-gm #docs-toolbar-wrapper {
    border-top: 1px solid #dadce0;
    border-bottom: 1px solid #dadce0
}
.docs-material #docs-side-toolbar {
    margin: 0 21px 0 0
}
.docs-material.companion-enabled #docs-side-toolbar {
    margin: 0 4px 0 0
}
.docs-material #docs-toolbar-wrapper,
.docs-material #docs-equationtoolbar,
.docs-material .docs-printpreview-toolbar {
    padding: 0 21px 0 22px
}
.docs-material #docs-equationtoolbar,
.docs-material .docs-printpreview-toolbar {
    background: #fff
}
.docs-material #docs-equationtoolbar {
    border-top-width: 0;
    border-bottom: 1px solid #e0e0e0
}
.docs-material.companion-enabled #docs-equationtoolbar {
    padding-right: 4px
}
.docs-gm #docs-equationtoolbar .goog-toolbar-menu-button-inner-box {
    padding-top: 0
}
.docs-gm #docs-equationtoolbar .goog-toolbar-menu-button-caption {
    padding-top: 2px
}
#hide-equation-toolbar-button {
    float: right
}
.docs-gm #docs-omnibox-toolbar .docs-omnibox-input {
    height: 26px
}
.docs-gm #docs-omnibox-toolbar .docs-omnibox-autocomplete {
    margin: 6px 4px 6px 1px
}
.docs-gm .goog-toolbar,
.docs-gm #docs-toolbar {
    min-height: 38px
}
.docs-material .goog-toolbar-button,
.docs-material .goog-toolbar-combo-button,
.docs-material .goog-toolbar-menu-button {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: #fff;
    background-image: none;
    cursor: pointer;
    border-color: transparent!important;
    border-radius: 2px;
    border-width: 1px
}
.docs-material .goog-toolbar-button-hover,
.docs-material .goog-toolbar-menu-button-hover,
.docs-material .goog-toolbar-combo-button-hover,
.docs-material .docs-toolbar-button-split-sympathy-hover,
.docs-material .docs-toolbar-split-create-button,
.docs-material .docs-toolbar-split-create-button.goog-toolbar-button-hover,
.docs-material .docs-toolbar-split-create-button.goog-toolbar-menu-button-hover,
.docs-gm .docs-material.trix-palette .goog-palette-cell-hover {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: rgba(0, 0, 0, .06);
    background-image: none;
    cursor: pointer;
    border-color: transparent!important;
    border-radius: 2px;
    border-width: 1px;
    cursor: pointer
}
.docs-gm .docs-material .goog-toolbar-button-hover,
.docs-gm .docs-material .goog-toolbar-menu-button-hover,
.docs-gm .docs-material .goog-toolbar-combo-button-hover,
.docs-gm .docs-material .docs-toolbar-button-split-sympathy-hover,
.docs-gm .docs-material .docs-toolbar-split-create-button,
.docs-gm .docs-material .docs-toolbar-split-create-button.goog-toolbar-button-hover,
.docs-gm .docs-material .docs-toolbar-split-create-button.goog-toolbar-menu-button-hover .docs-gm .docs-material.trix-palette .goog-palette-cell-hover {
    background-color: #f1f3f4
}
.docs-material .goog-toolbar-button-active,
.docs-material .goog-toolbar-button-checked,
.docs-material .goog-toolbar-button-selected,
.docs-material .goog-toolbar-combo-button-open,
.docs-material .goog-toolbar-menu-button-open,
.docs-material .docs-toolbar-split-create-button.goog-toolbar-button-active,
.docs-material .docs-toolbar-split-create-button.goog-toolbar-menu-button-active,
.docs-material .docs-toolbar-split-create-button.goog-toolbar-menu-button-open,
.docs-gm .docs-material.trix-palette .goog-palette-cell-selected {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: rgba(0, 0, 0, 0.12);
    background-image: none;
    cursor: pointer;
    border-color: transparent!important;
    border-radius: 2px;
    border-width: 1px
}
.docs-gm .docs-material .goog-toolbar-button-active,
.docs-gm .docs-material .goog-toolbar-button-checked,
.docs-gm .docs-material .goog-toolbar-button-selected,
.docs-gm .docs-material .goog-toolbar-combo-button-open,
.docs-gm .docs-material .goog-toolbar-menu-button-open,
.docs-gm .docs-material .docs-toolbar-split-create-button.goog-toolbar-button-active,
.docs-gm .docs-material .docs-toolbar-split-create-button.goog-toolbar-menu-button-active,
.docs-gm .docs-material .docs-toolbar-split-create-button.goog-toolbar-menu-button-open,
.docs-gm .docs-material.trix-palette .goog-palette-cell-selected {
    background-color: #e6f4ea;
    color: #188038
}
.docs-material .docs-access-level-indicator-view {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: #4d90fe;
    background-image: none;
    cursor: pointer;
    border-color: transparent!important;
    border-radius: 2px;
    border-width: 1px
}
.docs-material .docs-access-level-indicator-comment {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: #1aa863;
    background-image: none;
    cursor: pointer;
    border-color: transparent!important;
    border-radius: 2px;
    border-width: 1px
}
.docs-gm .docs-material .docs-access-level-indicator-view {
    background-color: #1a73e8;
    color: #fff!important
}
.docs-gm .docs-material .docs-access-level-indicator-comment {
    background-color: #1aa863;
    color: #fff!important
}
.docs-material .goog-toolbar-button,
.docs-material .goog-toolbar-menu-button {
    margin: 3px 1px 0;
    height: 26px;
    line-height: 26px;
    color: rgba(0, 0, 0, .7)
}
.docs-material .goog-toolbar-button-inner-box,
.docs-material .goog-toolbar-menu-button-inner-box {
    height: 26px;
    min-width: 26px
}
.docs-material .docs-toolbar-button-split-left .goog-toolbar-button-inner-box {
    min-width: 26px
}
.docs-material .goog-toolbar-toggle-button.goog-toolbar-button-checked+.goog-toolbar-toggle-button.goog-toolbar-button-checked {
    border-left-color: #ccc;
    border-left-style: solid;
    border-left-width: 1px;
    border-top-left-radius: 2px;
    border-bottom-left-radius: 2px;
    margin-left: 1px
}
.docs-material .goog-toolbar-toggle-button.goog-toolbar-button-checked+.goog-toolbar-toggle-button.goog-toolbar-button-checked .goog-toolbar-button-outer-box .goog-toolbar-button-inner-box,
.docs-material .goog-toolbar-toggle-button.goog-toolbar-button-checked+.goog-toolbar-toggle-button.goog-toolbar-button-checked.goog-toolbar-button-hover .goog-toolbar-button-outer-box .goog-toolbar-button-inner-box {
    margin-left: 0
}
.docs-material .goog-toolbar-button .docs-icon,
.docs-material .goog-toolbar-menu-button .docs-icon {
    opacity: 0.54
}
.docs-gm .docs-material .goog-toolbar-button .docs-icon,
.docs-gm .docs-material .goog-toolbar-menu-button .docs-icon,
.docs-gm .docs-material .goog-toolbar-combo-button-dropdown,
.docs-gm .docs-material .goog-toolbar-menu-button-dropdown {
    opacity: 1
}
.docs-material .goog-toolbar-button-hover .docs-icon,
.docs-material .goog-toolbar-button-selected .docs-icon,
.docs-material .goog-toolbar-button-checked .docs-icon,
.docs-material .goog-toolbar-button-active .docs-icon,
.docs-material .goog-toolbar-menu-button-hover .docs-icon,
.docs-material .goog-toolbar-menu-button-selected .docs-icon,
.docs-material .goog-toolbar-menu-button-checked .docs-icon,
.docs-material .goog-toolbar-menu-button-open .docs-icon,
.docs-material .docs-bgcolor-toolbar-menu-button .goog-toolbar-menu-button-icon {
    opacity: 0.87
}
.docs-gm .docs-material .goog-toolbar-button-hover .docs-icon,
.docs-gm .docs-material .goog-toolbar-button-selected .docs-icon,
.docs-gm .docs-material .goog-toolbar-button-checked .docs-icon,
.docs-gm .docs-material .goog-toolbar-button-active .docs-icon,
.docs-gm .docs-material .goog-toolbar-menu-button-hover .docs-icon,
.docs-gm .docs-material .goog-toolbar-menu-button-selected .docs-icon,
.docs-gm .docs-material .goog-toolbar-menu-button-checked .docs-icon,
.docs-gm .docs-material .goog-toolbar-menu-button-open .docs-icon,
.docs-gm .docs-material .docs-bgcolor-toolbar-menu-button .goog-toolbar-menu-button-icon {
    opacity: 1
}
.docs-gm .goog-toolbar-button-inner-box,
.docs-gm .goog-toolbar-menu-button-inner-box {
    height: 24px;
    min-width: 24px
}
.docs-gm .goog-toolbar-button .docs-icon {
    margin: 0 0 1px 0
}
.docs-gm .goog-toolbar-button.docs-icon-toolbar-button-with-text .docs-icon-toolbar-button-with-text-icon-container {
    margin-right: 4px
}
.docs-gm .goog-toolbar-menu-button.docs-textcolormenubutton .docs-icon {
    margin-top: 1px
}
.docs-material .goog-toolbar-separator.goog-inline-block {
    border-left: 1px solid #e0e0e0;
    margin: 0 3px
}
.docs-material .docs-toolbar-small-separator+div.goog-toolbar-button,
.docs-material .docs-toolbar-small-separator+div.goog-toolbar-menu-button {
    margin-left: 1px
}
.docs-gm .goog-toolbar-separator.goog-inline-block {
    border-left: 1px solid #dadce0;
    margin: 9px 4px;
    height: 20px
}
.docs-material .docs-toolbar-button-split-left,
.docs-material .docs-toolbar-button-split-left.goog-inline-block {
    margin-right: 0
}
.docs-material .docs-toolbar-button-split-right,
.docs-material .docs-toolbar-button-split-right.goog-inline-block {
    margin-left: 0
}
.docs-material .docs-toolbar-button-split-right.goog-toolbar-button-hover,
.docs-material .docs-toolbar-button-split-right.goog-toolbar-menu-button-hover,
.docs-material .docs-toolbar-button-split-right.docs-toolbar-button-split-sympathy-hover,
.docs-material .docs-toolbar-button-split-left+.docs-toolbar-button-split-right.goog-toolbar-menu-button-open,
.docs-material .docs-toolbar-split-create-button+.docs-toolbar-button-split-right {
    border-left-color: rgba(0, 0, 0, 0.12)!important
}
.docs-gm .docs-material .docs-toolbar-button-split-right.goog-toolbar-button-hover,
.docs-gm .docs-material .docs-toolbar-button-split-right.goog-toolbar-menu-button-hover,
.docs-gm .docs-material .docs-toolbar-button-split-right.docs-toolbar-button-split-sympathy-hover,
.docs-gm .docs-material .docs-toolbar-button-split-left+.docs-toolbar-button-split-right.goog-toolbar-menu-button-open,
.docs-gm .docs-material .docs-toolbar-split-create-button+.docs-toolbar-button-split-right {
    border-left-color: #f1f3f4!important
}
.docs-material .docs-toolbar-split-create-button.goog-toolbar-menu-button {
    margin-right: 3px
}
.docs-material .goog-toolbar-menu-button-dropdown,
.docs-material .docs-toolbar-split-create-button .goog-toolbar-menu-button-dropdown,
.docs-material .goog-toolbar-combo-button-dropdown {
    margin-top: 10px
}
.docs-gm .docs-gm-arrow .docs-icon {
    margin: 0
}
.docs-material .goog-toolbar-select .goog-toolbar-menu-button-dropdown {
    margin-top: 8px
}
.docs-gm .docs-gm-arrow.goog-toolbar-menu-button-dropdown,
.docs-gm .docs-toolbar-split-create-button .goog-toolbar-menu-button-dropdown,
.docs-gm .docs-gm-arrow.goog-toolbar-combo-button-dropdown {
    background: none;
    margin: 0 -1px 0 -3px;
    width: 13px
}
.docs-gm .goog-toolbar-select .goog-toolbar-menu-button-outer-box .goog-toolbar-menu-button-inner-box .goog-toolbar-menu-button-dropdown {
    margin-right: -1px
}
.docs-material .goog-toolbar-combo-button {
    height: 26px;
    line-height: 26px;
    vertical-align: inherit;
    margin: 0 1px
}
.docs-material .goog-toolbar-combo-button-input {
    color: rgba(0, 0, 0, .7)
}
.docs-material .goog-toolbar-combo-button-hover .goog-toolbar-combo-button-input {
    border-right-color: rgba(0, 0, 0, 0.12)!important
}
.docs-material .goog-toolbar-combo-button-input,
.docs-material .goog-toolbar-combo-button-input:focus {
    height: 22px!important
}
.docs-material .goog-toolbar-combo-button-input:focus {
    border: 1px solid #4d90fe!important
}
.docs-gm .goog-toolbar-button,
.docs-gm .goog-toolbar-menu-button,
.docs-gm .goog-toolbar-combo-button,
.docs-gm #docs-equationtoolbar .goog-toolbar-button,
.docs-gm #docs-equationtoolbar .goog-toolbar-menu-button,
.docs-gm .trix-palette .goog-palette-cell {
    height: 24px;
    line-height: 24px;
    margin: 6px 1px;
    top: 0
}
.docs-gm .goog-toolbar-button-disabled,
.docs-gm .goog-toolbar-menu-button-disabled,
.docs-gm .trix-palette .goog-palette-cell-disabled {
    color: #5f6368!important;
    cursor: inherit;
    opacity: .38
}
.docs-gm .goog-toolbar-combo-button-input {
    box-sizing: border-box;
    height: 20px!important;
    width: 48px!important
}
.docs-gm .goog-toolbar-combo-button-open {
    background-color: #f1f3f4
}
.docs-gm .goog-toolbar-combo-button-input::selection {
    background-color: #e6f4ea
}
.docs-gm .goog-toolbar-combo-button-input:focus {
    border: 2px solid #1a73e8!important;
    border-radius: 4px;
    padding: 0 7px
}
.docs-material .goog-color-menu-button-indicator {
    height: 20px;
    border-bottom-color: transparent
}
.docs-material .docs-textcolormenubutton .goog-toolbar-menu-button-outer-box .goog-toolbar-menu-button-inner-box .goog-toolbar-menu-button-caption .goog-color-menu-button-indicator {
    bottom: 0
}
.docs-material.docs-toolbar-more-bubble {
    border: 0;
    box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    border-radius: 2px
}
.docs-material.docs-toolbar-more-bubble .jfk-bubble-arrowup .jfk-bubble-arrowimplafter,
.docs-material.docs-toolbar-more-bubble .jfk-bubble-arrowup .jfk-bubble-arrowimplbefore {
    border-color: transparent
}
.docs-material.docs-toolbar-more-toolbar {
    background: #fff;
    border-radius: 2px;
    padding: 0 4px
}
.docs-gm .docs-toolbar-more-bubble {
    border-radius: 4px;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.docs-gm .docs-toolbar-more-toolbar {
    border-radius: 4px
}
.docs-material .docs-bgcolor-toolbar-menu-button:after,
.docs-material .docs-bgcolor-toolbar-menu-button.goog-toolbar-menu-button-hover:hover:after {
    background-image: none
}
.docs-material .docs-bgcolor-toolbar-menu-button.goog-toolbar-menu-button-hover:hover {
    border-color: transparent!important
}
.docs-gm .docs-bgcolor-toolbar-menu-button .docs-icon-arrow-dropdown {
    left: 0;
    top: -2540px
}
.docs-gm .jfk-tooltip {}
.jfk-button {
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500
}
.jfk-button-flat {
    font-weight: normal
}
.goog-toolbar-button,
.goog-toolbar-menu-button {
    font-weight: 500;
    font-size: 11px;
    font-size: var(--docs-material-font-size-12, 11px)
}
.docs-gm #docs-editor,
.docs-gm #docs-editor-container {
    background: #f8f9fa
}
.goog-tab {
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500
}
.goog-flat-menu-button-caption {
    font-weight: 500;
    font-weight: var(--docs-material-font-weight-normal, 500)
}
.modal-dialog-buttons {
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.modal-dialog-buttons button {
    font-weight: 500
}
.modal-dialog-title {
    font-size: 16px;
    font-size: var(--docs-material-font-size-22, 16px)
}
.goog-flat-menu-button {
    font-weight: 500
}
.jfk-countrypicker-countryCurrent,
.jfk-countrypicker-countryCurrent:hover {
    font-weight: 500
}
.jfk-accordion .goog-zippy-expanded {
    font-weight: 500
}
.jfk-titleLink {
    font-weight: 500
}
.jfk-countrypicker-countryCurrent,
.jfk-countrypicker-countryCurrent:hover {
    font-weight: 500
}
.jfk-slideToggle {
    font-weight: 500
}
.jfk-tooltip {
    font-weight: 500;
    font-size: 11px;
    font-size: var(--docs-material-font-size-12, 11px)
}
.jfk-bubble-arrowdown .jfk-bubble-arrowimplbefore,
.jfk-bubble-arrowup .jfk-bubble-arrowimplbefore {
    border-color: #dadce0 transparent
}
.apps-shortcutshelpcontentimpl-title-container {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-family: var(--docs-material-header-font-family, Roboto, RobotoDraft, Helvetica, Arial, sans-serif)
}
.apps-shortcutshelppopup-title-container {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-family: var(--docs-material-header-font-family, Roboto, RobotoDraft, Helvetica, Arial, sans-serif)
}
.docs-gm .docs-debug-container {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.docs-gm .docs-rotationhandle-circle,
.docs-gm .docs-rotationhandle-stick,
.docs-gm .docs-squarehandleselectionbox-handle,
.docs-gm .waffle-obj-drag-component {
    background-color: #1a73e8
}
.docs-gm .docs-rotationhandle-outline,
.docs-gm .docs-squarehandleselectionbox-border {
    border-color: #1a73e8
}
.docs-gm .docs-rotationhandle-stick {
    height: 24px
}
.docs-gm-sidebars .punch-animation-sidebar-play,
.docs-gm-sidebars .punch-animation-sidebar-stop,
.docs-gm-dialogs .waffle-filterbox-button-container .jfk-button-action,
.docs-gm-dialogs .docs-suggestiondialog-accept-container .jfk-button,
.docs-gm-dialogs .docs-suggestiondialog-accept-container .goog-flat-menu-button,
.docs-gm-dialogs .docs-offline-optinpromo-buttons .jfk-button-action {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    cursor: pointer
}
.docs-gm-sidebars .punch-animation-sidebar-play.jfk-button-hover,
.docs-gm-sidebars .punch-animation-sidebar-stop.jfk-button-hover,
.docs-gm-dialogs .waffle-filterbox-button-container .jfk-button-action.jfk-button-hover,
.docs-gm-dialogs .docs-suggestiondialog-accept-container .jfk-button-hover,
.docs-gm-dialogs .docs-suggestiondialog-accept-container .goog-flat-menu-button-hover,
.docs-gm-dialogs .docs-offline-optinpromo-buttons .jfk-button-action.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #2a8947;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-sidebars .punch-animation-sidebar-play.jfk-button-focused,
.docs-gm-sidebars .punch-animation-sidebar-stop.jfk-button-focused,
.docs-gm-dialogs .waffle-filterbox-button-container .jfk-button-action.jfk-button-focused,
.docs-gm-dialogs .docs-suggestiondialog-accept-container .jfk-button-focused,
.docs-gm-dialogs .docs-suggestiondialog-accept-container .goog-flat-menu-button-focused,
.docs-gm-dialogs .docs-offline-optinpromo-buttons .jfk-button-action.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #4f9e67;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-sidebars .punch-animation-sidebar-play.jfk-button-hover.jfk-button-focused,
.docs-gm-sidebars .punch-animation-sidebar-stop.jfk-button-hover.jfk-button-focused,
.docs-gm-dialogs .waffle-filterbox-button-container .jfk-button-action.jfk-button-hover.jfk-button-focused,
.docs-gm-dialogs .docs-suggestiondialog-accept-container .jfk-button-hover.jfk-button-focused,
.docs-gm-dialogs .docs-suggestiondialog-accept-container .goog-flat-menu-button-hover.goog-flat-menu-button-focused,
.docs-gm-dialogs .docs-offline-optinpromo-buttons .jfk-button-action.jfk-button-hover.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-sidebars .punch-animation-sidebar-play.jfk-button-pressed,
.docs-gm-sidebars .punch-animation-sidebar-stop.jfk-button-pressed,
.docs-gm-dialogs .waffle-filterbox-button-container .jfk-button-action.jfk-button-pressed,
.docs-gm-dialogs .docs-suggestiondialog-accept-container .jfk-button-pressed,
.docs-gm-dialogs .docs-suggestiondialog-accept-container .goog-flat-menu-button-pressed,
.docs-gm-dialogs .docs-offline-optinpromo-buttons .jfk-button-action.jfk-button-pressed {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 2px 6px 2px rgba(52, 168, 83, 0.15)
}
.docs-gm-sidebars .punch-animation-sidebar-play.jfk-button-disabled,
.docs-gm-sidebars .punch-animation-sidebar-stop.jfk-button-disabled,
.docs-gm-dialogs .waffle-filterbox-button-container .jfk-button-action.jfk-button-disabled,
.docs-gm-dialogs .docs-suggestiondialog-accept-container .jfk-button-disabled,
.docs-gm-dialogs .docs-suggestiondialog-accept-container .goog-flat-menu-button-disabled,
.docs-gm-dialogs .docs-offline-optinpromo-buttons .jfk-button-action.jfk-button-disabled {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #f1f3f4;
    color: #3c4043;
    opacity: 0.38;
    cursor: default
}
.docs-gm-sidebars .docs-image-effect-adjustment-reset-button,
.docs-gm-dialogs .waffle-filterbox-button-container .jfk-button-standard,
.docs-gm-dialogs .docs-suggestiondialog-reject-container .jfk-button,
.docs-gm-dialogs .docs-suggestiondialog-reject-container .goog-flat-menu-button,
.docs-gm-dialogs .docs-offline-optinpromo-buttons .jfk-button-standard {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #dadce0!important;
    color: #188038;
    cursor: pointer
}
.docs-gm-sidebars .docs-image-effect-adjustment-reset-button.jfk-button-hover,
.docs-gm-dialogs .waffle-filterbox-button-container .jfk-button-standard.jfk-button-hover,
.docs-gm-dialogs .docs-suggestiondialog-reject-container .jfk-button-hover,
.docs-gm-dialogs .docs-suggestiondialog-reject-container .goog-flat-menu-button-hover,
.docs-gm-dialogs .docs-offline-optinpromo-buttons .jfk-button-standard.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #f8fcf9;
    border: 1px solid #c8e7d1!important
}
.docs-gm-sidebars .docs-image-effect-adjustment-reset-button.jfk-button-focused,
.docs-gm-dialogs .waffle-filterbox-button-container .jfk-button-standard.jfk-button-focused,
.docs-gm-dialogs .docs-suggestiondialog-reject-container .jfk-button-focused,
.docs-gm-dialogs .docs-suggestiondialog-reject-container .goog-flat-menu-button-focused,
.docs-gm-dialogs .docs-offline-optinpromo-buttons .jfk-button-standard.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #e7f5eb;
    border: 1px solid #bbe2c6!important
}
.docs-gm-sidebars .docs-image-effect-adjustment-reset-button.jfk-button-hover.jfk-button-focused,
.docs-gm-dialogs .waffle-filterbox-button-container .jfk-button-standard.jfk-button-hover.jfk-button-focused,
.docs-gm-dialogs .docs-suggestiondialog-reject-container .jfk-button-hover.jfk-button-focused,
.docs-gm-dialogs .docs-suggestiondialog-reject-container .goog-flat-menu-button-hover.goog-flat-menu-button-focused,
.docs-gm-dialogs .docs-offline-optinpromo-buttons .jfk-button-standard.jfk-button-hover.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    border: 1px solid #b5e0c1!important
}
.docs-gm-sidebars .docs-image-effect-adjustment-reset-button.jfk-button-pressed,
.docs-gm-dialogs .waffle-filterbox-button-container .jfk-button-standard.jfk-button-pressed,
.docs-gm-dialogs .docs-suggestiondialog-reject-container .jfk-button-pressed,
.docs-gm-dialogs .docs-suggestiondialog-reject-container .goog-flat-menu-button-pressed,
.docs-gm-dialogs .docs-offline-optinpromo-buttons .jfk-button-standard.jfk-button-pressed {}
.docs-gm-sidebars .docs-image-effect-adjustment-reset-button.jfk-button-disabled,
.docs-gm-dialogs .waffle-filterbox-button-container .jfk-button-standard.jfk-button-disabled,
.docs-gm-dialogs .docs-suggestiondialog-reject-container .jfk-button-disabled,
.docs-gm-dialogs .docs-suggestiondialog-reject-container .goog-flat-menu-button-disabled,
.docs-gm-dialogs .docs-offline-optinpromo-buttons .jfk-button-standard.jfk-button-disabled {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #f1f3f4!important;
    color: #3c4043;
    opacity: 0.38;
    cursor: default
}
.docs-gm-dialogs .modal-dialog button,
.docs-gm-dialogs .modal-dialog .jfk-button-standard {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #dadce0!important;
    color: #188038
}
.docs-gm-dialogs .modal-dialog button:hover,
.docs-gm-dialogs .modal-dialog .jfk-button-standard.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #f8fcf9;
    border: 1px solid #c8e7d1!important
}
.docs-gm-dialogs .modal-dialog button:focus,
.docs-gm-dialogs .modal-dialog .jfk-button-standard.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #e7f5eb;
    border: 1px solid #bbe2c6!important
}
.docs-gm-dialogs .modal-dialog button:hover:focus,
.docs-gm-dialogs .modal-dialog .jfk-button-standard.jfk-button-hover.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    border: 1px solid #b5e0c1!important
}
.docs-gm-dialogs .modal-dialog button:active,
.docs-gm-dialogs .modal-dialog button:focus:active,
.docs-gm-dialogs .modal-dialog .jfk-button-standard.jfk-button-active,
.docs-gm-dialogs .modal-dialog .jfk-button-standard.jfk-button-focus.jfk-button-active {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    border: 1px solid transparent!important;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.docs-gm-dialogs .modal-dialog button[disabled],
.docs-gm-dialogs .modal-dialog .jfk-button-standard.jfk-button-disabled {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #f1f3f4!important;
    color: #3c4043;
    opacity: 0.38
}
.docs-gm-dialogs .modal-dialog .goog-buttonset-action,
.docs-gm-dialogs .modal-dialog .jfk-button-action {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff
}
.docs-gm-dialogs .modal-dialog .goog-buttonset-action:hover,
.docs-gm-dialogs .modal-dialog .jfk-button-action.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #2a8947;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-dialogs .modal-dialog .goog-buttonset-action:focus,
.docs-gm-dialogs .modal-dialog .jfk-button-action.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #4f9e67;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-dialogs .modal-dialog .goog-buttonset-action:hover:focus,
.docs-gm-dialogs .modal-dialog .jfk-button-action.jfk-button-hover.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-dialogs .modal-dialog .goog-buttonset-action:active,
.docs-gm-dialogs .modal-dialog .goog-buttonset-action:focus:active,
.docs-gm-dialogs .modal-dialog .jfk-button-action.jfk-button-active,
.docs-gm-dialogs .modal-dialog .jfk-button-action.jfk-button-focus.jfk-button-active {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 2px 6px 2px rgba(52, 168, 83, 0.15)
}
.docs-gm-dialogs .modal-dialog .goog-buttonset-action[disabled],
.docs-gm-dialogs .modal-dialog .jfk-button-action.jfk-button-disabled {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #f1f3f4;
    color: #3c4043;
    opacity: 0.38
}
.docs-gm-dialogs .modal-dialog .goog-flat-button,
.docs-gm-dialogs .modal-dialog button,
.docs-gm-dialogs .modal-dialog .goog-buttonset-action,
.docs-gm-dialogs .modal-dialog .jfk-button-standard,
.docs-gm-dialogs .modal-dialog .jfk-button-action {
    cursor: pointer
}
.docs-gm-dialogs .modal-dialog .goog-flat-button.goog-flat-button-disabled,
.docs-gm-dialogs .modal-dialog button[disabled],
.docs-gm-dialogs .modal-dialog .goog-buttonset-action[disabled],
.docs-gm-dialogs .modal-dialog .jfk-button-standard.jfk-button-disabled,
.docs-gm-dialogs .modal-dialog .jfk-button-action.jfk-button-disabled {
    cursor: default
}
.docs-gm-dialogs .modal-dialog .jfk-textinput {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    color: #3c4043;
    padding: 1px 8px;
    font-size: 14px;
    height: 36px;
    margin: 8px 0
}
.docs-gm-dialogs .modal-dialog textarea.jfk-textinput {
    min-height: 36px;
    height: auto;
    height: unset;
    padding: 7px 8px
}
.docs-gm-dialogs .modal-dialog .jfk-textinput.sketchy-guiderow-position {
    margin: 0
}
.docs-gm-dialogs .modal-dialog .jfk-textinput:focus {
    border: 2px solid #1a73e8;
    box-shadow: none;
    padding: 0px 7px
}
.docs-gm-dialogs .modal-dialog textarea.jfk-textinput:focus {
    padding: 6px 7px
}
.docs-gm-dialogs .modal-dialog,
.docs-gm-dialogs .docs-offline-optinpromo.jfk-bubble,
.docs-gm-dialogs .docs-sync-indicator-popup.jfk-bubble {
    background-color: #fff;
    border: 1px solid transparent;
    border-radius: 8px;
    box-shadow: 0 4px 8px 3px rgba(60, 64, 67, .15);
    position: absolute;
    z-index: 1003;
    padding: 24px
}
.docs-gm-dialogs .picker.modal-dialog {
    padding: 0;
    z-index: 1201
}
.docs-gm-dialogs .modal-dialog,
.docs-gm-dialogs .modal-dialog-content,
.docs-gm-dialogs #docs-offline-optinpromo-description,
.docs-gm-dialogs #docs-offline-optinpromo-learn-more-container {
    color: #3c4043
}
.docs-gm-dialogs #docs-offline-optinpromo-title {
    border-bottom: none;
    padding: 24px
}
.docs-gm-dialogs .modal-dialog-title-text,
.docs-gm-dialogs .docs-offline-optinpromo-title-text {
    color: #202124;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 22px;
    font-weight: 400;
    line-height: 28px
}
.docs-gm-dialogs .docs-offline-optinpromo-buttons {
    display: flex;
    flex-direction: row-reverse
}
.docs-gm-dialogs .docs-offline-optinpromo-confirm-buttons {
    margin-top: 24px
}
.docs-gm-dialogs .docs-offline-optinpromo-buttons .jfk-button {
    cursor: pointer;
    margin-left: 16px;
    margin-right: 0
}
.docs-gm-dialogs .modal-dialog-buttons,
.docs-gm-dialogs .docs-findandreplacedialog-buttons {
    display: flex;
    justify-content: flex-end;
    margin-top: 24px
}
.docs-gm-dialogs .modal-dialog-buttons button {
    margin: 0 0 0 12px
}
.docs-gm-dialogs .modal-dialog-buttons button:first-child {
    margin-left: 0
}
.docs-gm-dialogs .docs-dialog .modal-dialog-title {
    position: relative
}
.docs-gm-dialogs .docs-dialog .modal-dialog-title-text {
    display: inline-block;
    max-width: calc(100% - 32px);
    min-width: 200px
}
.docs-gm-dialogs .docs-dialog .modal-dialog-title-close {
    background-color: transparent;
    border-radius: 50%;
    cursor: pointer;
    height: 18px;
    line-height: 18px;
    padding: 7px;
    right: 0;
    text-align: center;
    top: -3px;
    width: 18px
}
.docs-gm-dialogs .docs-dialog .modal-dialog-title-close:hover {
    background-color: #f1f3f4
}
.docs-gm-dialogs .docs-dialog .modal-dialog-title-close:focus {
    background-color: #e8eaed;
    outline: none
}
.docs-gm-dialogs .docs-dialog .modal-dialog-title-close:after {
    position: relative;
    right: 0;
    top: 0
}
.docs-gm .modal-dialog .docs-flatcolormenubutton .goog-flat-menu-button-caption,
.docs-gm .sketchy-shape-effects-shadow-tile .docs-flatcolormenubutton .goog-flat-menu-button-caption {
    height: 22px;
    width: 22px;
    border-radius: 50%;
    border: 1px solid #dadce0;
    margin: 0;
    outline: none
}
.docs-gm .modal-dialog .docs-flatcolormenubutton.goog-flat-menu-button,
.docs-gm .sketchy-shape-effects-shadow-tile .docs-flatcolormenubutton.goog-flat-menu-button {
    padding: 6px 0 6px 6px
}
.docs-gm-dialogs div.goog-modalpopup-bg,
.docs-gm-dialogs div.modal-dialog-bg {
    background-color: #000;
    left: 0;
    position: absolute;
    top: 0;
    z-index: 1002;
    opacity: .6!important
}
.docs-gm-sidebars ::-webkit-scrollbar-track {
    box-shadow: none;
    margin: 0 4px
}
.docs-gm-sidebars ::-webkit-scrollbar-track:hover {
    box-shadow: none;
    background: none
}
.docs-gm-sidebars ::-webkit-scrollbar-thumb {
    border-style: solid;
    border-color: transparent;
    border-width: 4px;
    background-color: #dadce0;
    border-radius: 8px;
    box-shadow: none
}
.docs-gm-sidebars ::-webkit-scrollbar-thumb:hover {
    background-color: #80868b
}
.docs-gm-sidebars ::-webkit-scrollbar-thumb:active {
    background-color: #5f6368
}
.docs-gm .modal-dialog .goog-flat-menu-button,
.docs-gm .sketchy-shape-effects-shadow-tile .goog-flat-menu-button {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    cursor: pointer;
    padding: 8px 6px 8px 8px;
    width: 100%;
    align-items: center;
    background: none;
    color: #3c4043;
    display: inline-flex;
    justify-content: space-between;
    outline: none;
    position: relative;
    width: auto;
    width: unset
}
.docs-gm .modal-dialog .goog-flat-menu-button-disabled,
.docs-gm .sketchy-shape-effects-shadow-tile .goog-flat-menu-button-disabled {
    color: #5f6368;
    opacity: .38;
    cursor: default
}
.docs-gm .modal-dialog .goog-flat-menu-button:active,
.docs-gm .sketchy-shape-effects-shadow-tile .goog-flat-menu-button:active {
    background-color: #fff;
    border: 1px solid transparent;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.docs-gm .modal-dialog .goog-flat-menu-button-hover,
.docs-gm .sketchy-shape-effects-shadow-tile .goog-flat-menu-button-hover {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid #dadce0;
    box-shadow: none
}
.docs-gm .modal-dialog .goog-flat-menu-button-focused,
.docs-gm .sketchy-shape-effects-shadow-tile .goog-flat-menu-button-focused {
    background-color: rgba(60, 64, 67, 0.06);
    border: 1px solid #dadce0
}
.docs-gm .modal-dialog .goog-flat-menu-button-open,
.docs-gm .sketchy-shape-effects-shadow-tile .goog-flat-menu-button-open {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid transparent
}
.docs-gm .modal-dialog .goog-flat-menu-button-hover.goog-flat-menu-button-open,
.docs-gm .sketchy-shape-effects-shadow-tile .goog-flat-menu-button-hover.goog-flat-menu-button-open {
    background-color: rgba(60, 64, 67, 0.06)
}
.docs-gm .modal-dialog .goog-flat-menu-button-focused.goog-flat-menu-button-open,
.docs-gm .sketchy-shape-effects-shadow-tile .goog-flat-menu-button-focused.goog-flat-menu-button-open {
    background-color: rgba(60, 64, 67, 0.08)
}
.docs-gm .modal-dialog .goog-flat-menu-button-disabled,
.docs-gm .sketchy-shape-effects-shadow-tile .goog-flat-menu-button-disabled {
    border: 1px solid #dadce0;
    cursor: default
}
.docs-gm .modal-dialog .goog-flat-menu-button-caption,
.docs-gm .sketchy-shape-effects-shadow-tile .goog-flat-menu-button-caption {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    height: 20px;
    line-height: 20px;
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.docs-gm .modal-dialog .goog-flat-menu-button-disabled .goog-flat-menu-button-caption,
.docs-gm .sketchy-shape-effects-shadow-tile .goog-flat-menu-button-disabled .goog-flat-menu-button-caption {
    color: #5f6368;
    opacity: .38;
    cursor: default
}
.docs-gm .modal-dialog .goog-flat-menu-button-dropdown,
.docs-gm .sketchy-shape-effects-shadow-tile .goog-flat-menu-button-dropdown {
    background: no-repeat url(//ssl.gstatic.com/docs/common/material_common_sprite134_grey_medium.svg) 0 -1364px;
    height: 18px;
    width: 18px;
    border: none;
    margin-top: 0;
    position: relative;
    right: 0;
    top: 0
}
.docs-gm .modal-dialog .goog-flat-menu-button-disabled .goog-flat-menu-button-dropdown,
.docs-gm .sketchy-shape-effects-shadow-tile .goog-flat-menu-button-disabled .goog-flat-menu-button-dropdown {
    opacity: .38
}
.docs-gm .modal-dialog .goog-flat-menu-button-disabled.goog-flat-menu-button:active,
.docs-gm .sketchy-shape-effects-shadow-tile .goog-flat-menu-button-disabled.goog-flat-menu-button:active {
    border: 1px solid #dadce0;
    cursor: default;
    box-shadow: none
}
.docs-gm .modal-dialog .goog-flat-menu-button-open .goog-flat-menu-button-dropdown,
.docs-gm .sketchy-shape-effects-shadow-tile .goog-flat-menu-button-open .goog-flat-menu-button-dropdown {
    -moz-transform: rotate(180deg);
    -webkit-transform: rotate(180deg);
    -ms-transform: rotate(180deg);
    transform: rotate(180deg)
}
.docs-gm .modal-dialog .jfk-radiobutton-disabled .jfk-radiobutton-label {
    color: #5f6368;
    opacity: .38;
    cursor: default
}
.docs-gm-dialogs .share-butterbar-container {
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-family: var(--docs-material-header-font-family, "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif);
    font-size: 13px;
    font-size: var(--docs-material-font-size-normal, 13px);
    font-weight: normal;
    font-weight: var(--docs-material-font-weight-normal, normal)
}
.docs-gm-dialogs .share-client-dialog .share-butterbar-container {
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-family: var(--docs-material-header-font-family, "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif)
}
.docs-gm-dialogs .share-butterbar-container .jfk-butterBar-shown {
    height: 40px;
    padding: 0 16px
}
.docs-gm-dialogs .share-butterbar-container .jfk-butterBar-shown>span {
    display: flex;
    padding-top: 4px
}
.docs-gm-dialogs .share-butter-icon {
    margin-right: 8px
}
.docs-gm-dialogs .share-butter-link,
.docs-gm-dialogs .share-butter-link:visited {
    color: #188038;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-family: var(--docs-material-header-font-family, "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif);
    font-size: 16px;
    margin-left: 80px
}
.docs-gm-dialogs .share-butter-link:hover,
.docs-gm-dialogs .share-butter-link:active {
    color: #0d652d
}
.docs-gm-dialogs .share-butter-link:disabled {
    color: #188038
}
.docs-display-density-comfortable.goog-menu .goog-menuitem:not(.docs-submenuitem) {
    padding-top: 10px;
    padding-bottom: 10px
}
.docs-display-density-comfortable .waffle-function-category-row-description {
    display: block
}
.docs-display-density-comfortable.waffle-function-category-row.waffle-function-category-active {
    padding: 5px 10px
}
.docs-display-density-comfortable.goog-menu:not(.docs-fontmenu) .goog-menuitem:not(.waffle-colormenuitems-scheme-header-edit-button):not(.docs-submenuitem):not(.apps-menuitem):not(.docs-menuitem-add-fonts).goog-menuitem-highlight {
    padding-top: calc(10px - 1px);
    padding-bottom: calc(10px - 1px);
    border-width: 1px 0
}
.docs-display-density-comfortable.goog-menu .goog-menuitem-icon {
    top: calc(10px - 1px)
}
.docs-display-density-comfortable.goog-menu .goog-menuitem-highlight:not(.apps-menuitem):not(.docs-menuitem-add-fonts) .goog-menuitem-icon {
    top: calc(calc(10px - 1px) - 1px)
}
.docs-gm .docs-display-density-comfortable.goog-menu .apps-menuitem .goog-menuitem-icon {
    top: 0;
    margin-top: 11px;
    margin-bottom: 11px
}
.docs-gm .docs-display-density-comfortable.goog-menu .goog-menuitem-highlight:not(.apps-menuitem) .goog-menuitem-icon {
    top: 0;
    margin-top: 10px;
    margin-bottom: 10px
}
#t-border-palette.docs-display-density-comfortable .goog-palette-cell {
    padding: 4px 6px 4px 4px
}
#t-border-palette.docs-display-density-comfortable #t-border-style-menu-button {
    margin-top: 6px
}
#t-border-palette.docs-display-density-comfortable .goog-toolbar-color-menu-button {
    padding-top: 3px;
    padding-bottom: 3px
}
.docs-display-density-comfortable.trix-palette .goog-palette-cell {
    display: inline-block;
    margin: 2px;
    padding: 4px 6px 4px 4px
}
.docs-display-density-comfortable.trix-palette .goog-palette-table {
    margin: 0
}
#t-text-rotation-palette td:not(.goog-palette-cell),
.docs-display-density-comfortable.trix-palette {
    padding: 0
}
.docs-display-density-comfortable .goog-inline-block.goog-toolbar-combo-button.waffle-text-rotation-combobox {
    padding-top: 3px;
    padding-bottom: 3px;
    margin: 4px
}
.docs-display-density-comfortable.goog-menu .docs-omnibox-input {
    padding-top: 5px;
    padding-bottom: 5px;
    height: 33px
}
.docs-display-density-comfortable .docs-material-colorpalette-cell {
    padding: 2px
}
.docs-display-density-comfortable .docs-material-colorpalette-colorswatch {
    height: 24px;
    width: 24px
}
.docs-gm .docs-display-density-comfortable.docs-colormenuitems .goog-menuitem.colormenuitems-custom-header-add-button {
    padding: 10px 0
}
.docs-gm .goog-menu.docs-display-density-comfortable .goog-menuitem.colormenuitems-no-color {
    padding-top: 9px;
    padding-bottom: 9px;
    border-width: 1px 0
}
.docs-display-density-comfortable.docs-colormenuitems .goog-menuitem.goog-inline-block.waffle-colormenuitems-scheme-header-edit-button {
    padding: 5px
}
.docs-display-density-comfortable.docs-colormenuitems .goog-menuitem-highlight.waffle-colormenuitems-scheme-header-edit-button {
    padding-top: 4px;
    padding-bottom: 4px;
    border-width: 1px 0
}
.docs-display-density-comfortable.docs-colormenuitems .goog-menuseparator {
    margin: 10px 0
}
.docs-display-density-comfortable.goog-menu .docs-omnibox-autocomplete {
    padding-top: 6px;
    padding-bottom: 6px
}
.docs-display-density-comfortable.goog-menu .docs-omnibox-autocomplete.goog-menuitem-highlight {
    padding-top: calc(6px - 1px);
    padding-bottom: calc(6px - 1px)
}
.docs-display-density-comfortable .goog-toolbar .goog-toolbar-button,
.docs-display-density-comfortable .goog-toolbar .goog-toolbar-combo-button,
.docs-display-density-comfortable .goog-toolbar .goog-toolbar-menu-button {
    padding: 2px;
    margin-left: 2px;
    margin-right: 2px
}
.docs-display-density-comfortable .docs-toolbar-more-toolbar {
    min-height: calc(35px + 2*2px)
}
.docs-display-density-comfortable .goog-toolbar .goog-toolbar-separator.goog-inline-block {
    height: calc(35px + 2*2px)
}
.docs-gm .docs-display-density-comfortable .goog-toolbar .goog-toolbar-separator.goog-inline-block {
    height: 24px
}
.docs-display-density-comfortable .goog-toolbar .docs-toolbar-button-split-left {
    margin-right: 0
}
.docs-display-density-comfortable .goog-toolbar .docs-toolbar-button-split-right {
    margin-left: 0
}
.docs-display-density-comfortable .goog-toolbar .docs-omnibox-input {
    height: 29px
}
.docs-display-density-comfortable .goog-toolbar .docs-omnibox-autocomplete {
    margin-right: 2px
}
.docs-display-density-comfortable.docs-colormenuitems .docs-c-u-colormenutogglebutton-base {
    padding: 4px 33px
}
.docs-display-density-comfortable.docs-colormenuitems .jfk-palette-table {
    width: 100%
}
.docs-display-density-comfortable.docs-colormenuitems .jfk-palette-row {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-justify-content: space-between;
    justify-content: space-between
}
.docs-display-density-comfortable.docs-colormenuitems .jfk-palette-colorswatch,
.docs-display-density-comfortable.docs-colormenuitems .docs-colormenuitems-custom-palette .jfk-palette-cell {
    height: 22px;
    width: 22px
}
.docs-display-density-comfortable.goog-menu.docs-fontmenu .docs-menuitem-add-fonts {
    border-color: #eee
}
.docs-display-density-comfortable.goog-menu.docs-fontmenu .goog-menuitem.docs-submenuitem {
    padding-top: 10px;
    padding-bottom: 10px;
    border: 0
}
.docs-display-density-comfortable.goog-menu.docs-fontmenu .goog-menuitem.docs-submenuitem::before {
    line-height: 38px
}
.docs-display-density-comfortable.goog-menu.docs-fontmenu .docs-submenuitem-splitbutton {
    height: calc(38px - 2px);
    line-height: calc(38px - 2px)
}
body:not(.docs-gm) .docs-display-density-comfortable.goog-menu .goog-menuitem-ie {
    padding-top: 7px;
    padding-bottom: 24px
}
body:not(.docs-gm) .docs-display-density-comfortable.goog-menu .goog-menuitem-icon-ie {
    top: 4px
}
.docs-display-density-toolbar-menuitem-label {
    font-weight: 500;
    padding-bottom: 4px
}
.docs-display-density-toolbar-menuitem-description {
    font-size: 11px;
    color: #777
}
.docs-chat.jfk-button {
    border-radius: 0;
    height: 28px;
    margin-left: 2px;
    margin-right: 0px;
    min-width: 24px;
    vertical-align: top
}
.docs-chat.jfk-button .docs-icon {
    opacity: .70
}
.docs-chat.jfk-button.jfk-button-checked .docs-icon {
    opacity: 0.9
}
.docs-chat.jfk-button.jfk-button-disabled .docs-icon {
    opacity: 0.333
}
.docs-chat-badge {
    background: #db4437;
    border-radius: 6px;
    display: none;
    height: 12px;
    pointer-events: none;
    position: absolute;
    right: -4px;
    top: -4px;
    width: 12px
}
.docs-chat-badge-visible {
    display: block
}
.docs-chat-badge.docs-chat-hc-gecko {
    filter: url("data:image/svg+xml;utf8,\00003csvg%20xmlns=\000027http://www.w3.org/2000/svg\000027\00003e\00003cfilter%20id=\000027invertColor\000027\00003e\00003cfeColorMatrix%20type=\000027matrix\000027%20values=\000027-1 0 0 0 1 0 -1 0 0 1 0 0 -1 0 1 0 0 0 1 0\000027/\00003e\00003c/filter\00003e\00003c/svg\00003e#invertColor")
}
.docs-chat-badge.docs-chat-hc-ie {
    -ms-high-contrast-adjust: none;
    background-color: white
}
.docs-chat-message-tooltip-container {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    -webkit-box-shadow: 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 2px 1px -1px rgba(0, 0, 0, 0.12), 0 1px 3px 0 rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 2px 1px -1px rgba(0, 0, 0, 0.12), 0 1px 3px 0 rgba(0, 0, 0, 0.2);
    box-shadow: 0 1px 1px 0 rgba(0, 0, 0, 0.14), 0 2px 1px -1px rgba(0, 0, 0, 0.12), 0 1px 3px 0 rgba(0, 0, 0, 0.2);
    background-color: #fafafa;
    padding: 12px;
    z-index: 501
}
.docs-chat-message-tooltip-container .jfk-bubble-arrowup .jfk-bubble-arrowimplafter {
    border-color: #fafafa transparent
}
.docs-chat-message-tooltip-container .jfk-bubble-arrowup .jfk-bubble-arrowimplbefore {
    border-color: rgba(0, 0, 0, 0.3) transparent
}
.docs-chat-message-tooltip {
    font-size: 13px;
    height: 32px;
    line-height: 18px;
    position: relative;
    text-align: left;
    width: 192px
}
.docs-chat-message-tooltip-subject {
    opacity: .87;
    font-weight: 500
}
.docs-chat-message-tooltip-content {
    opacity: .54;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    word-break: break-all;
    word-wrap: break-word
}
.docs-chat-pane-container {
    border-left: 1px solid #d9d9d9;
    outline: none;
    position: absolute;
    right: 0;
    top: 0;
    width: 300px
}
.docs-gm-sidebars .docs-chat-pane-container {
    overflow: hidden;
    box-shadow: -3px 0px 6px -3px rgba(60, 64, 67, .15), 3px 0px 6px -3px rgba(60, 64, 67, .15);
    border-left: 0
}
.docs-chat-pane {
    background-color: #fff;
    font-size: 13px;
    height: 100%;
    overflow: hidden;
    position: relative;
    z-index: 801
}
.docs-gm-sidebars .docs-chat-pane {
    font-size: 14px
}
.docs-chat-users {
    background: #f5f5f5;
    color: #000;
    margin: 0;
    max-height: 33%;
    outline-style: none;
    overflow: auto;
    padding: 8px 0 3px 0;
    text-align: left;
    vertical-align: top
}
.docs-chat-users-empty {
    display: none
}
.docs-chat-messages {
    background-color: #fff;
    box-sizing: border-box;
    color: rgba(0, 0, 0, .87);
    outline-style: none;
    overflow: auto;
    padding: 16px 24px 0px 16px;
    position: relative;
    vertical-align: middle
}
.docs-gm-sidebars .docs-chat-messages {
    color: #3c4043;
    letter-spacing: .25px;
    padding: 16px 16px 0px 16px
}
.docs-chat-edit-container {
    background: #eee;
    bottom: 0;
    height: 96px;
    margin: 0;
    outline: 0;
    position: absolute;
    width: 100%
}
.docs-gm-sidebars .docs-chat-edit-container {
    background-color: #fff
}
.docs-chat-edit-box {
    border: 1px solid #5ea0e3;
    box-sizing: border-box;
    font-size: 100%;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    height: 64px;
    left: 16px;
    outline: 0;
    overflow: auto;
    padding: 8px;
    position: relative;
    top: 16px;
    width: 268px;
    resize: none
}
.docs-gm-sidebars .docs-chat-edit-box {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    color: #3c4043;
    padding: 1px 8px;
    font-size: 14px;
    height: 36px;
    margin: 8px 0
}
.docs-gm-sidebars .docs-chat-edit-box {
    height: 64px;
    margin: 0;
    padding: 8px
}
.docs-chat-edit-box::-webkit-input-placeholder,
.docs-chat-edit-box::-moz-placeholder,
.docs-chat-edit-box:-ms-input-placeholder {
    color: #5f6368
}
.docs-chat-edit-box-focus {
    outline: 1px solid #5ea0e3
}
.docs-gm-sidebars .docs-chat-edit-box-focus {
    border: 2px solid #1a73e8;
    box-shadow: none;
    padding: 0px 7px
}
.docs-gm-sidebars .docs-chat-edit-box-focus {
    padding: 7px
}
.docs-chat-roster {
    width: 250px;
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
    word-break: break-all;
    word-wrap: break-word
}
.docs-gm-sidebars .docs-chat-roster {
    width: 240px
}
.label-input-label {
    color: #a9a9a9
}
.docs-chat-status {
    color: gray;
    line-height: 12px
}
.docs-chat-name {
    font-weight: 500
}
.docs-gm-sidebars .docs-chat-name {
    font-weight: 500
}
.docs-chat-message.docs-chat-status-message {
    margin-bottom: 0px
}
.docs-chat-message {
    line-height: 18px;
    margin-bottom: 2px;
    outline-style: none;
    word-wrap: break-word;
    white-space: pre-wrap
}
.docs-chat-first-series-message {
    margin-top: 10px
}
.docs-user-roster {
    margin: 0;
    outline-style: none;
    padding: 0 0 10px 1em;
    position: relative
}
.docs-user-roster-name {
    color: #666;
    left: 2.7em;
    position: absolute;
    top: 0
}
.docs-user-roster-bubble {
    height: 13px;
    margin-right: 1px;
    top: 1px;
    vertical-align: text-bottom;
    width: 13px
}
.docs-user-roster-bubble-clickable {
    cursor: pointer
}
.docs-chat-anon {
    color: gray;
    font-size: 11px;
    padding: 6px 24px 3px 16px
}
.docs-chat-title-bar {
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    background-color: #616161;
    border-bottom: 1px solid #616161;
    border-top: 1px solid #616161;
    color: #fff;
    height: 15px;
    padding: 10px 0 10px 12px;
    position: relative
}
.docs-gm-sidebars .docs-chat-title-bar {
    display: flex;
    align-items: center;
    color: #202124;
    background-color: #fff;
    height: 56px;
    padding: 0 16px;
    border-bottom: 1px solid #dadce0;
    border-top: 1px solid #dadce0;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px;
    z-index: 1;
    padding-right: 56px;
    letter-spacing: .1px
}
.docs-chat-title-bar-highlight {
    background-color: #4285f4;
    border-bottom-color: #4285f4;
    border-top-color: #4285f4;
    color: #fff
}
.docs-chat-title {
    font-weight: 500
}
.docs-gm-sidebars .docs-chat-title-bar.docs-chat-shadow {
    -webkit-box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    -moz-box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.docs-gm-sidebars .docs-chat-edit-container.docs-chat-shadow {
    -webkit-box-shadow: 0 -2px 6px 2px rgba(60, 64, 67, .15);
    -moz-box-shadow: 0 -2px 6px 2px rgba(60, 64, 67, .15);
    box-shadow: 0 -2px 6px 2px rgba(60, 64, 67, .15)
}
.docs-sidebar-close-button.docs-chat-close-button {
    float: right;
    top: 8px
}
.docs-sidebar-gm-close-button.docs-chat-close-button {
    position: absolute;
    right: 11px;
    top: 12px
}
.docs-presence-widget {
    cursor: pointer;
    height: 19px;
    margin: 0 0 5px 0;
    outline: 0;
    position: absolute;
    right: 44px;
    top: 11px;
    width: 207px
}
#docs-presence-menubar .docs-presence-widget {
    top: 5px
}
#docs-presence .docs-presence-widget {
    display: inline-block;
    position: relative;
    right: auto;
    text-align: left;
    width: auto
}
.docs-presence-widget-inner {
    border: 1px solid transparent;
    height: 17px;
    margin-bottom: 8px
}
#docs-presence .docs-presence-widget-inner {
    display: inline-block;
    max-width: 190px
}
.docs-presence-widget-normal .docs-presence-widget-inner {
    background: #fff;
    border-color: #fff;
    color: #666
}
.docs-presence-widget-hover .docs-presence-widget-inner,
.docs-presence-widget-focused .docs-presence-widget-inner {
    background: #f3f3f3;
    border-color: #f3f3f3;
    color: #222!important
}
.docs-presence-widget-open .docs-presence-widget-inner {
    background: #f3f3f3;
    border-color: #e5e5e5;
    color: #666
}
.docs-presence-widget-notify .docs-presence-widget-inner {
    color: #fff
}
.docs-presence-widget-arrow {
    position: absolute!important;
    top: 0
}
.docs-presence-widget-content {
    font-size: 11px;
    line-height: 18px;
    max-width: 98px;
    overflow: hidden;
    padding: 0 4px;
    text-overflow: ellipsis;
    white-space: nowrap
}
#docs-presence .docs-presence-widget-content {
    max-width: 90px;
    position: relative;
    vertical-align: top
}
.docs-presence-widget-collab {
    max-width: 90px;
    overflow: hidden;
    position: absolute;
    right: 4px;
    top: 1px
}
#docs-presence .docs-presence-widget-collab {
    display: inline-block;
    margin-right: 4px;
    position: relative;
    right: auto;
    top: auto
}
.docs-presence-widget-collab .docs-user-roster-bubble {
    margin: 1px;
    vertical-align: baseline
}
#docs-presence-container {
    height: 29px;
    margin-right: 10px;
    vertical-align: middle
}
#docs-presence {
    vertical-align: top
}
.docs-presence-plus-widget {
    max-width: 250px;
    outline: 0;
    text-align: left
}
#docs-bars .docs-presence-plus-widget {
    position: absolute;
    overflow: hidden;
    right: 0;
    top: 2px
}
.docs-presence-plus-widget-inner {
    vertical-align: top
}
.docs-presence-plus-widget-status {
    color: #222;
    display: none;
    text-align: right;
    margin: 8px 10px 0 0
}
.docs-presence-plus-widget-open .docs-presence-plus-widget-status {
    display: block
}
.docs-presence-plus-widget-collabs {
    height: 30px
}
.docs-presence-plus-widget-open .docs-presence-plus-widget-collabs {
    display: none
}
.docs-presence-plus-widget-overflow-button {
    border-radius: 0;
    height: 28px;
    margin: 0 2px 0 -1px;
    min-width: 0;
    padding: 0;
    width: 13px
}
.docs-presence-plus-widget-overflow-button .goog-flat-menu-button-dropdown {
    right: 3px
}
.docs-presence-plus-widget-overflow-menu {
    max-height: 300px;
    outline: none;
    overflow: auto;
    padding: 7px;
    text-align: left;
    white-space: nowrap
}
.docs-presence-plus-widget-overflow,
.docs-presence-plus-collab-widget-container {
    height: 30px;
    overflow: hidden;
    vertical-align: top
}
.docs-presence-plus-collab-widget-color-block {
    height: 30px;
    overflow: hidden;
    width: 25px
}
.docs-presence-plus-collab-widget-menuitem,
.docs-gm-sidebars.docs-gm .goog-menu .docs-presence-plus-collab-widget-menuitem.goog-menuitem,
.docs-gm-sidebars.docs-gm .goog-menu .docs-presence-plus-collab-widget-menuitem.goog-menuitem-highlight {
    border-style: none;
    padding: 0
}
.docs-presence-plus-collab-widget-container {
    margin: 0 2px;
    width: 25px
}
.docs-presence-plus-collab-widget-color-block {
    opacity: .5;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)"
}
.docs-presence-plus-collab-widget-active .docs-presence-plus-collab-widget-color-block {
    opacity: 1;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=100)"
}
.docs-presence-plus-collab-widget-exit .docs-presence-plus-collab-widget-color-block {
    height: 0;
    width: 0
}
.docs-presence-plus-collab-widget-image,
.docs-presence-plus-collab-widget-image-container {
    height: 25px;
    padding-bottom: 5px;
    width: 25px
}
.docs-presence-plus-collab-widget-image-container {
    overflow: hidden
}
.docs-presence-plus-collab-widget-image-border {
    border-bottom: 1px solid #fff;
    height: 24px
}
.docs-presence-plus-collab-widget-idle-text {
    color: #777;
    font-size: 11px
}
.docs-presence-plus-collab-widget-active .docs-presence-plus-collab-widget-idle-text {
    display: none
}
.docs-presence-plus-widget-overflow-button-collabs {
    margin: 0
}
@-webkit-keyframes color-join {
    from {
        margin-top: 25px
    }
    to {
        margin-top: 0
    }
}
@-moz-keyframes color-join {
    from {
        margin-top: 25px
    }
    to {
        margin-top: 0
    }
}
@-ms-keyframes color-join {
    from {
        margin-top: 25px
    }
    to {
        margin-top: 0
    }
}
.docs-presence-plus-collab-widget-enter .docs-presence-plus-collab-widget-color-block {
    -webkit-animation-name: color-join;
    -moz-animation-name: color-join;
    -ms-animation-name: color-join;
    -webkit-animation-duration: .5s;
    -moz-animation-duration: .5s;
    -ms-animation-duration: .5s
}
@-webkit-keyframes image-join {
    0% {
        height: 0;
        padding-bottom: 0
    }
    33% {
        height: 0;
        padding-bottom: 0
    }
    100% {
        height: 25px;
        padding-bottom: 5px
    }
}
@-moz-keyframes image-join {
    0% {
        height: 0;
        padding-bottom: 0
    }
    33% {
        height: 0;
        padding-bottom: 0
    }
    100% {
        height: 25px;
        padding-bottom: 5px
    }
}
@-ms-keyframes image-join {
    0% {
        height: 0;
        padding-bottom: 0
    }
    33% {
        height: 0;
        padding-bottom: 0
    }
    100% {
        height: 25px;
        padding-bottom: 5px
    }
}
.docs-presence-plus-collab-widget-enter .docs-presence-plus-collab-widget-image-container {
    -webkit-animation-name: image-join;
    -moz-animation-name: image-join;
    -ms-animation-name: image-join;
    -webkit-animation-duration: 1.5s;
    -moz-animation-duration: 1.5s;
    -ms-animation-duration: 1.5s;
    -webkit-animation-timing-function: ease-in;
    -moz-animation-timing-function: ease-in;
    -ms-animation-timing-function: ease-in
}
@-webkit-keyframes collab-exit {
    0% {
        height: 30px;
        width: 25px;
        margin: 0;
        opacity: .5
    }
    25% {
        height: 30px;
        width: 25px;
        margin: 0;
        opacity: .5
    }
    99% {
        height: 0;
        width: 0;
        margin: 15px 12px
    }
    100% {
        height: 0;
        width: 0;
        margin: 0
    }
}
@-moz-keyframes collab-exit {
    0% {
        height: 30px;
        width: 25px;
        margin: 0;
        opacity: .5
    }
    25% {
        height: 30px;
        width: 25px;
        margin: 0;
        opacity: .5
    }
    99% {
        height: 0;
        width: 0;
        margin: 15px 12px
    }
    100% {
        height: 0;
        width: 0;
        margin: 0
    }
}
@-ms-keyframes collab-exit {
    0% {
        height: 30px;
        width: 25px;
        margin: 0;
        opacity: .5
    }
    25% {
        height: 30px;
        width: 25px;
        margin: 0;
        opacity: .5
    }
    99% {
        height: 0;
        width: 0;
        margin: 15px 12px
    }
    100% {
        height: 0;
        width: 0;
        margin: 0
    }
}
.docs-presence-plus-collab-widget-exit .docs-presence-plus-collab-widget-color-block {
    -webkit-animation-name: collab-exit;
    -moz-animation-name: collab-exit;
    -ms-animation-name: collab-exit;
    -webkit-animation-duration: 1s;
    -moz-animation-duration: 1s;
    -ms-animation-duration: 1s
}
@-webkit-keyframes collab-image-exit {
    0% {
        margin: 0;
        padding-bottom: 5px
    }
    25% {
        margin: 0;
        padding-bottom: 5px
    }
    100% {
        margin-top: -15px;
        margin-left: -12px
    }
}
@-moz-keyframes collab-image-exit {
    0% {
        margin: 0;
        padding-bottom: 5px
    }
    25% {
        margin: 0;
        padding-bottom: 5px
    }
    100% {
        margin-top: -15px;
        margin-left: -12px
    }
}
@-ms-keyframes collab-image-exit {
    0% {
        margin: 0;
        padding-bottom: 5px
    }
    25% {
        margin: 0;
        padding-bottom: 5px
    }
    100% {
        margin-top: -15px;
        margin-left: -12px
    }
}
.docs-presence-plus-collab-widget-exit .docs-presence-plus-collab-widget-image {
    -webkit-animation-name: collab-image-exit;
    -moz-animation-name: collab-image-exit;
    -ms-animation-name: collab-image-exit;
    -webkit-animation-duration: 1s;
    -moz-animation-duration: 1s;
    -ms-animation-duration: 1s
}
.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget-container {
    display: block;
    height: 25px;
    margin: 0 0 5px;
    width: auto
}
.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget-color-block {
    width: 30px
}
.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget {
    height: 25px;
    padding-right: 20px
}
.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget-image {
    position: relative;
    left: -1px
}
.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget-image,
.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget-image-container {
    padding-bottom: 0
}
.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget-image-container {
    padding-left: 5px
}
.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget-image-border {
    border-bottom: none;
    border-left: 1px solid #fff;
    height: 25px
}
.docs-presence-plus-widget-overflow-menu .docs-presence-plus-collab-widget-name {
    color: #222;
    font-size: 13px;
    margin: 4px 0 0 5px;
    vertical-align: top
}
.talk_roster {
    display: none
}
.docs-chat-mole-hidden>div {
    top: -10000px!important;
    left: -10000px!important
}
.talk_chat_widget {
    z-index: 900!important
}
.docs-copydocdialog {
    width: 360px
}
.docs-copydocdialog-filenameinput {
    width: 250px
}
.docs-copydocdialog-warning,
.docs-copydocdialog-destination-sharewarning {
    color: #999;
    font-size: 11px
}
.docs-copydocdialog-checkbox {
    font-size: 14px;
    letter-spacing: 0.2px;
    padding-top: 5px;
    vertical-align: top
}
.docs-gm-dialogs .docs-copydocdialog-checkbox {
    cursor: pointer;
    padding-top: 8px
}
.docs-gm-dialogs .docs-copydocdialog-checkbox .jfk-checkbox {
    margin-top: -8px;
    margin-right: 8px
}
.docs-copydocdialog-checkbox.docs-copydocdialog-collaboratorcheckbox {
    padding-top: 0
}
.docs-gm-dialogs .docs-copydocdialog {
    min-width: 312px;
    width: auto;
    width: unset
}
.docs-gm-dialogs .docs-copydocdialog .docs-copydocdialog-filenameinput {
    width: 100%
}
.docs-gm-dialogs .docs-copydocdialog .docs-copydocdialog-destination-button {
    height: 34px;
    width: 294px
}
.docs-gm-dialogs .docs-copydocdialog-destination-img {
    top: 3px
}
.docs-gm-dialogs .docs-copydocdialog-destination-name {
    vertical-align: sub
}
.docs-copydocdialog-includeresolvedscommentcheckbox {
    margin-left: 26px
}
.docs-copydocdialog-destination-button,
.docs-copydocdialog-filenameinput {
    margin-top: 4px
}
.docs-copydocdialog-destination-button {
    border: 1px solid #ddd;
    margin-right: 0;
    overflow: hidden;
    position: relative;
    text-align: left;
    text-overflow: ellipsis;
    width: 250px
}
.docs-copydocdialog-destination-button.jfk-button-focused {
    border: 1px solid #4d90fe
}
.docs-copydocdialog-destination-section {
    margin-top: 16px
}
.docs-copydocdialog-destination-img {
    height: 10px;
    margin-right: 5px;
    position: relative;
    top: 2px;
    width: 13px
}
.docs-copydocdialog-description {
    font-size: 16px;
    height: 72px;
    letter-spacing: 0.15px;
    line-height: 24px;
    vertical-align: top;
    width: 312px
}
.docs-gm-dialogs .docs-copydocdialog-description {
    height: auto;
    height: unset;
    color: #5f6368;
    max-width: 464px;
    width: 100%
}
.goog-menu.picker-min.docs-copydocdialog-destination-picker {
    z-index: 1003
}
.modal-dialog.docs-dialog.docs-copy-endangered-dialog {
    z-index: 1007;
    width: 376px
}
.modal-dialog-bg.docs-copy-endangered-dialog-bg {
    z-index: 1006
}
.docs-gm-dialogs .modal-dialog.docs-dialog.docs-copy-endangered-dialog {
    min-width: 464px;
    width: auto;
    width: unset
}
.docs-dialog.docs-hc-gecko .modal-dialog-title-close:after {
    filter: invert(100%)
}
.docs-dialog.docs-hc-ie .modal-dialog-title-close:after {
    -ms-high-contrast-adjust: none;
    background-color: white
}
.docs-dialog .modal-dialog-title-close {
    opacity: 0.54
}
.docs-dialog .modal-dialog-title-close:hover {
    opacity: 0.87
}
.modal-dialog-title-text {
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: normal
}
.docs-dialog .modal-dialog-title-close:after {
    background: none;
    right: 13px;
    top: 14px;
    content: url(//ssl.gstatic.com/images/icons/material/system/svg/close_18px.svg);
    height: 18px;
    width: 18px
}
.docs-details-dialog {
    min-width: 200px
}
.docs-details-error {
    margin-left: 10px;
    margin-top: 40px
}
.docs-details-loading {
    background-image: url(//ssl.gstatic.com/docs/common/loading_animation.gif);
    height: 50px;
    margin: auto;
    width: 50px
}
.docs-details-table {
    border-collapse: collapse
}
.docs-details-field {
    font-size: 13px;
    font-weight: 500;
    height: 27px;
    width: 100px
}
#docs-details-folder {
    margin-right: 6px;
    opacity: 0.45;
    outline: none;
    vertical-align: bottom
}
.docs-details-value {
    height: 27px;
    max-width: 200px
}
.docs-gm-dialogs .docs-details-dialog {
    min-width: 312px;
    padding: 24px
}
.docs-gm-dialogs .docs-details-dialog .modal-dialog-title-text {
    color: #3c4043;
    font-size: 22px;
    font-weight: normal;
    height: 28px
}
.docs-gm-dialogs .docs-details-field,
.docs-gm-dialogs .docs-details-value {
    font-size: 14px;
    height: 20px;
    padding: 8px 0
}
.docs-gm-dialogs .docs-details-field {
    color: #3c4043;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    min-width: 100px;
    padding-right: 20px
}
.docs-gm-dialogs .docs-details-value {
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.picker-iframe.picker-min {
    -moz-box-shadow: rgba(0, 0, 0, .2) 0 4px 16px;
    -webkit-box-shadow: rgba(0, 0, 0, .2) 0 4px 16px;
    box-shadow: rgba(0, 0, 0, .2) 0 4px 16px;
    color: #000;
    padding: 0;
    position: absolute;
    z-index: 1002
}
.picker-iframe.picker-minew .picker-min-frame-up {
    background-color: #f1f1f1
}
.picker-iframe.picker-white-callout.picker-minew .picker-min-frame-up {
    background-color: #fff
}
.picker-iframe.picker-min.goog-menu {
    border-color: #ccc;
    line-height: 0;
    max-height: none;
    overflow: visible
}
.picker-iframe.picker-min-top {
    margin-top: 15px
}
.picker-iframe.picker-minew.picker-min-top {
    margin-top: 9px
}
.picker-iframe.picker-min-bottom {
    margin-top: -15px
}
.picker-iframe.picker-minew.picker-min-bottom {
    margin-top: -9px
}
.picker-iframe .picker-min-arrow-up,
.picker-iframe .picker-min-arrow-down {
    position: absolute;
    width: 32px;
    z-index: 0
}
.picker-iframe .picker-min-arrow-up {
    top: -15px
}
.picker-iframe.picker-minew .picker-min-arrow-up {
    top: -10px;
    width: 20px
}
.picker-iframe .picker-min-arrow-down {
    bottom: -16px
}
.picker-iframe.picker-minew .picker-min-arrow-down {
    bottom: -10px;
    width: 20px
}
.picker-iframe .picker-min-arrow-inner,
.picker-iframe .picker-min-arrow-border {
    border: 16px solid;
    height: 0;
    position: absolute;
    width: 0
}
.picker-iframe.picker-minew .picker-min-arrow-inner,
.picker-iframe.picker-minew .picker-min-arrow-border {
    border: 10px solid
}
.picker-iframe.picker-minew .picker-min-arrow-up .picker-min-arrow-inner {
    border-color: #f1f1f1 transparent
}
.picker-iframe.picker-white-callout.picker-minew .picker-min-arrow-up .picker-min-arrow-inner {
    border-color: #fff transparent
}
.picker-iframe .picker-min-arrow-up .picker-min-arrow-inner {
    border-color: #fff transparent;
    top: 1px;
    z-index: 1
}
.picker-iframe .picker-min-arrow-down .picker-min-arrow-inner {
    border-color: #fff transparent;
    bottom: 1px;
    z-index: 1
}
.picker-iframe .picker-min-arrow-up .picker-min-arrow-border,
.picker-iframe .picker-min-arrow-down .picker-min-arrow-border {
    border-color: rgba(0, 0, 0, 0.2) transparent
}
.picker-iframe .picker-min-arrow-down .picker-min-arrow-border {
    bottom: 0
}
.picker-iframe .picker-min-arrow-up .picker-min-arrow-inner,
.picker-iframe .picker-min-arrow-up .picker-min-arrow-border {
    border-top-width: 0
}
.picker-iframe .picker-min-arrow-down .picker-min-arrow-inner,
.picker-iframe .picker-min-arrow-down .picker-min-arrow-border {
    border-bottom-width: 0
}
.drive-organize-atd-popup {
    display: inline-block;
    vertical-align: middle
}
.drive-organize-atd-popup-undo-btn {
    float: right
}
.drive-organize-popup {
    position: absolute;
    z-index: 1002;
    -webkit-box-shadow: rgba(0, 0, 0, 0.2) 0 4px 16px;
    -moz-box-shadow: rgba(0, 0, 0, 0.2) 0 4px 16px;
    box-shadow: rgba(0, 0, 0, 0.2) 0 4px 16px;
    background-color: #f1f1f1;
    border: 1px solid rgba(0, 0, 0, 0.2);
    color: #6e6e6e;
    font-size: 13px;
    font-weight: normal;
    text-align: left;
    white-space: nowrap
}
.drive-organize-popup-outline-hidden *:focus {
    outline: none
}
.drive-organize-popup-content {
    padding: 10px
}
.drive-organize-popup-message {
    display: inline-block;
    max-width: 160px;
    padding-right: 10px
}
.drive-organize-button {
    display: inline-block;
    vertical-align: middle
}
.drive-organize-popup-link-btn {
    color: #15c;
    cursor: pointer;
    padding: 0 7px
}
.drive-organize-popup-close-btn {
    cursor: pointer;
    height: 15px;
    padding: 3px;
    vertical-align: middle
}
.drive-organize-popup-link-btn.drive-organize-button-hover {
    text-decoration: underline
}
.drive-organize-popup-arrow {
    position: absolute;
    width: 20px
}
.drive-organize-popup-arrow .drive-organize-popup-triangle-before,
.drive-organize-popup-arrow .drive-organize-popup-triangle-after {
    content: '';
    display: block;
    height: 0;
    position: absolute;
    width: 0
}
.drive-organize-popup-arrow .drive-organize-popup-triangle-before {
    border: 10px solid
}
.drive-organize-popup-arrow .drive-organize-popup-triangle-after {
    border: 9px solid
}
.drive-organize-popup-arrowdown {
    bottom: 0
}
.drive-organize-popup-arrowup {
    top: -10px
}
.drive-organize-popup-arrowdown .drive-organize-popup-triangle-before,
.drive-organize-popup-arrowup .drive-organize-popup-triangle-before {
    border-color: rgba(0, 0, 0, 0.2) transparent;
    left: 0
}
.drive-organize-popup-arrowdown .drive-organize-popup-triangle-after,
.drive-organize-popup-arrowup .drive-organize-popup-triangle-after {
    border-color: #f1f1f1 transparent;
    left: 1px
}
.drive-organize-popup-arrowdown .drive-organize-popup-triangle-before {
    border-bottom-width: 0
}
.drive-organize-popup-arrowdown .drive-organize-popup-triangle-after {
    border-bottom-width: 0
}
.drive-organize-popup-arrowup .drive-organize-popup-triangle-before {
    border-top-width: 0
}
.drive-organize-popup-arrowup .drive-organize-popup-triangle-after {
    border-top-width: 0;
    top: 2px
}
.drive-organize-dialog {
    -webkit-box-shadow: 0 4px 16px rgba(0, 0, 0, .2);
    -moz-box-shadow: 0 4px 16px rgba(0, 0, 0, .2);
    box-shadow: 0 4px 16px rgba(0, 0, 0, .2);
    background: #fff;
    background-clip: padding-box;
    color: #000;
    font-family: inherit;
    outline: 0;
    padding: 24px;
    position: absolute;
    width: 560px;
    z-index: 2204
}
.drive-organize-dialog-bg {
    background: #000;
    left: 0;
    position: absolute;
    top: 0;
    z-index: 2203
}
div.drive-organize-dialog-bg {
    filter: alpha(opacity=50);
    opacity: .50
}
.drive-organize-dialog-title {
    background-color: #fff;
    color: #000;
    cursor: default;
    font-size: 20px;
    font-weight: normal;
    line-height: 24px
}
.drive-organize-dialog-title-close {
    height: 11px;
    margin: 24px;
    opacity: 0.7;
    padding: 6px;
    position: absolute;
    right: 0;
    top: 0;
    width: 11px
}
.drive-organize-dialog-title-close:after {
    background: url(//ssl.gstatic.com/ui/v1/dialog/close-x.png);
    content: '';
    height: 11px;
    position: absolute;
    width: 11px
}
.drive-organize-dialog-title-close:hover {
    opacity: 1
}
.drive-organize-dialog-content {
    background-color: #fff;
    font-size: 16px;
    line-height: 1.4em;
    padding-top: 24px;
    padding-bottom: 24px;
    word-wrap: break-word
}
.drive-organize-dialog-buttons {
    text-align: right
}
.drive-organize-dialog-buttons .drive-organize-button {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    background-color: #f5f5f5;
    background-image: -webkit-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -o-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: linear-gradient(top, #f5f5f5, #f1f1f1);
    border: 1px solid #dcdcdc;
    border: 1px solid rgba(0, 0, 0, 0.1);
    color: #444;
    cursor: default;
    font-family: inherit;
    font-size: 11px;
    font-weight: bold;
    height: 29px;
    line-height: 27px;
    margin: 0 0 0 16px;
    min-width: 72px;
    outline: 0;
    padding: 0 8px
}
.drive-organize-dialog-buttons .drive-organize-button:hover,
.drive-organize-dialog-buttons .drive-organize-button:active {
    -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.1);
    -moz-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.1);
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.1);
    background-color: #f8f8f8;
    background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -o-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
    border: 1px solid #c6c6c6;
    color: #333
}
.drive-organize-dialog-buttons .drive-organize-button:active {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1)
}
.drive-organize-dialog-buttons .drive-organize-button:focus {
    border: 1px solid #4d90fe
}
.drive-organize-dialog-buttons .drive-organize-button[disabled] {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background: #fff;
    background-image: none;
    border: 1px solid #f3f3f3;
    border: 1px solid rgba(0, 0, 0, 0.5);
    color: rgba(0, 0, 0, .26)
}
.drive-organize-dialog-buttons .goog-buttonset-action {
    background-color: #4d90fe;
    background-image: -webkit-linear-gradient(top, #4d90fe, #4787ed);
    background-image: -moz-linear-gradient(top, #4d90fe, #4787ed);
    background-image: -ms-linear-gradient(top, #4d90fe, #4787ed);
    background-image: -o-linear-gradient(top, #4d90fe, #4787ed);
    background-image: linear-gradient(top, #4d90fe, #4787ed);
    border: 1px solid #3079ed;
    color: #fff
}
.drive-organize-dialog-buttons .goog-buttonset-action:hover,
.drive-organize-dialog-buttons .goog-buttonset-action:active {
    background-color: #357ae8;
    background-image: -webkit-linear-gradient(top, #4d90fe, #357ae8);
    background-image: -moz-linear-gradient(top, #4d90fe, #357ae8);
    background-image: -ms-linear-gradient(top, #4d90fe, #357ae8);
    background-image: -o-linear-gradient(top, #4d90fe, #357ae8);
    background-image: linear-gradient(top, #4d90fe, #357ae8);
    border: 1px solid #2f5bb7;
    color: #fff
}
.drive-organize-dialog-buttons .goog-buttonset-action:active {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3)
}
.drive-organize-dialog-buttons .goog-buttonset-action:focus {
    -webkit-box-shadow: inset 0 0 0 1px #fff;
    -moz-box-shadow: inset 0 0 0 1px #fff;
    box-shadow: inset 0 0 0 1px #fff;
    border: 1px solid #fff;
    border: rgba(0, 0, 0, 0) solid 1px;
    outline: 1px solid #4d90fe;
    outline: rgba(0, 0, 0, 0) 0
}
.drive-organize-dialog-buttons .goog-buttonset-action[disabled] {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background: #4d90fe;
    color: #fff;
    filter: alpha(opacity=50);
    opacity: 0.5
}
.drive-organize-dialog .goog-menu {
    box-shadow: none;
    margin-bottom: -24px;
    padding: 0;
    position: relative;
    z-index: inherit
}
.drive-organize-dialog .goog-menuitem {
    color: #000;
    font-size: 13px;
    height: 16px;
    margin: 0;
    opacity: .87;
    padding: 0 0 24px 16px
}
.drive-organize-dialog-parent-name {
    font-weight: bold
}
.drive-organize-dialog-list-item {
    display: block;
    overflow: hidden;
    text-overflow: ellipsis
}
.drive-organize-dialog .goog-menuitem-highlight {
    border-left: 0;
    background-color: inherit
}
.drive-organize-dialog .goog-menuitem-content {
    margin: 0
}
.drive-organize-dialog .goog-menuitem-highlight .goog-menuitem-content,
.drive-organize-dialog .goog-option-selected .goog-menuitem-content {
    color: inherit
}
.drive-organize-dialog .goog-menuitem-checkbox {
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    background: rgba(255, 255, 255, 0);
    border: 1px solid rgba(198, 198, 198, 1);
    height: 15px;
    left: 0;
    margin: 0;
    outline: none;
    position: absolute;
    text-align: left;
    top: 2px;
    width: 15px
}
.drive-organize-dialog .goog-menuitem-active .goog-menuitem-checkbox {
    background: rgba(235, 235, 235, 1);
    border-color: rgba(182, 182, 182, 1)
}
.drive-organize-dialog .goog-menuitem-highlight .goog-menuitem-checkbox {
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, .1);
    border-color: rgba(182, 182, 182, 1)
}
.drive-organize-dialog .goog-menuitem-focus .goog-menuitem-checkbox {
    border-color: rgba(77, 144, 254, 1)
}
.drive-organize-dialog .goog-option-selected {
    background: rgba(255, 255, 255, 0)
}
.drive-organize-dialog .goog-option-selected .goog-menuitem-checkbox::after {
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    background: rgba(96, 96, 96, 1);
    content: '';
    display: block;
    height: 7px;
    left: 3px;
    position: relative;
    top: 3px;
    width: 7px
}
.modal-dialog.docs-endangered-doc-warning-dialog {
    z-index: 1007
}
.modal-dialog-bg.docs-endangered-doc-warning-dialog-bg {
    z-index: 1006
}
.docs-gm-dialogs .modal-dialog.docs-endangered-doc-warning-dialog {
    min-width: 464px;
    width: auto;
    width: unset
}
.fatal-error-dialog-container {
    display: table;
    width: 374px
}
.fatal-error-dialog-contents {
    display: table-row;
    min-height: 100px
}
.fatal-error-dialog-contents a:hover {
    cursor: pointer
}
.fatal-error-message {
    display: table-cell;
    vertical-align: middle;
    width: 320px
}
.fatal-error-debug-text {
    font-size: 85%;
    height: 200px;
    width: 90%
}
.docs-invite-favicon {
    height: 16px;
    margin-right: 5px;
    vertical-align: sub;
    width: 16px
}
.docs-invite-header {
    height: 77px;
    max-height: 77px;
    width: 100%;
    overflow-x: hidden;
    overflow-y: hidden;
    background: #f5f5f5;
    font-size: 12.5px;
    color: #444;
    border-bottom: 1px solid #d9d9d9
}
.docs-invite-header>div {
    display: table;
    width: 100%;
    height: 100%;
    max-height: inherit
}
.docs-invite-button {
    margin-right: 25px
}
.docs-invite-fixedcol {
    display: table-cell;
    vertical-align: middle;
    white-space: nowrap
}
.docs-invite-flexcol {
    display: table-cell;
    width: 100%;
    vertical-align: middle;
    max-height: inherit
}
.docs-invite-inviter-img {
    height: 60px;
    border: 1px solid #ccc;
    margin-left: 25px
}
.docs-invite-heavy {
    font-weight: 500;
    color: #222
}
.docs-invite-business-icon {
    margin-left: 40px
}
.docs-invite-msg {
    margin: 0px 10px 0px 25px;
    max-height: inherit;
    line-height: 2.0
}
.docs-invite-business-header {
    position: absolute;
    z-index: 1
}
.docs-parent-collections-container-prefix,
.docs-parent-collections-container-text {
    color: rgba(0, 0, 0, .54);
    padding-left: 4px
}
.docs-parent-collections-container-folder-name {
    color: rgba(0, 0, 0, .87);
    font-size: 14px;
    padding-left: 4px;
    bottom: 1px
}
.docs-parent-collections-container {
    padding: 2px 4px 0px 2px
}
.docs-parent-collections-container:hover,
.docs-parent-collections-container:focus {
    background-color: #eeeeee;
    border-radius: 2px
}
.docs-parent-collections-container-icon {
    bottom: 2px;
    opacity: .54
}
.request-comment-access-toast-link {
    text-transform: uppercase;
    font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif;
    font-weight: 500!important
}
.modal-dialog.docs-dialog.docs-restore-dialog {
    z-index: 1007
}
.modal-dialog-bg.docs-restore-dialog-bg {
    z-index: 1006
}
.docs-gm-dialogs .modal-dialog.docs-dialog.docs-restore-dialog {
    min-width: 464px;
    width: auto;
    width: unset
}
#docs-toolbar-iterator-label {
    color: rgba(0, 0, 0, 0.87);
    font-size: 13px;
    line-height: 24px;
    margin-right: 10px;
    margin-top: 4px;
    vertical-align: middle
}
#docs-toolbar-iterator-previous,
#docs-toolbar-iterator-next {
    margin-left: 3px;
    margin-right: 3px
}
.docs-in-editor-sync-state-icon {
    float: right;
    margin: 0 0 0 24px;
    vertical-align: middle
}
.docs-in-editor-sync-state-icon .docs-icon {
    height: 20px;
    margin: 0;
    opacity: 1;
    width: 20px
}
.docs-in-editor-animated-sync {
    -webkit-animation-duration: 2s;
    -moz-animation-duration: 2s;
    -o-animation-duration: 2s;
    animation-duration: 2s;
    -webkit-animation-iteration-count: infinite;
    -moz-animation-iteration-count: infinite;
    -o-animation-iteration-count: infinite;
    animation-iteration-count: infinite;
    -webkit-animation-name: spin;
    -moz-animation-name: spin;
    -o-animation-name: spin;
    animation-name: spin;
    -webkit-animation-timing-function: linear;
    -moz-animation-timing-function: linear;
    -o-animation-timing-function: linear;
    animation-timing-function: linear;
    -webkit-transform-origin: center;
    -moz-transform-origin: center;
    -ms-transform-origin: center;
    -o-transform-origin: center;
    transform-origin: center
}
@keyframes spin {
    0% {
        -webkit-transform: rotate(360deg);
        -moz-transform: rotate(360deg);
        -ms-transform: rotate(360deg);
        -o-transform: rotate(360deg);
        transform: rotate(360deg)
    }
    100% {
        -webkit-transform: rotate(0deg);
        -moz-transform: rotate(0deg);
        -ms-transform: rotate(0deg);
        -o-transform: rotate(0deg);
        transform: rotate(0deg)
    }
}
@-webkit-keyframes spin {
    0% {
        -webkit-transform: rotate(360deg);

        -moz-transform: rotate(360deg);
        -ms-transform: rotate(360deg);
        -o-transform: rotate(360deg);
        transform: rotate(360deg)
    }
    100% {
        -webkit-transform: rotate(0deg);
        -moz-transform: rotate(0deg);
        -ms-transform: rotate(0deg);
        -o-transform: rotate(0deg);
        transform: rotate(0deg)
    }
}
.docs-offline-optindialog-short-disclaimer {
    margin-top: 20px
}
.docs-offline-optindialog-disclaimer-link {
    cursor: pointer
}
#docs-offline-optindialog-disclaimer-link.docs-offline-optindialog-disclaimer-link-disabled {
    color: #ccc;
    pointer-events: none;
    text-decoration: none
}
.docs-offline-optindialog-disclaimer {
    margin-top: 20px;
    max-width: 400px
}
.docs-offline-optinpromo.jfk-bubble {
    font-size: 13px;
    max-width: 500px;
    outline: none;
    padding-left: 24px;
    padding-top: 11px;
    position: fixed;
    right: 15px;
    top: 113px
}
.docs-offline-optinpromo .jfk-bubble-arrow {
    display: none
}
#docs-offline-optinpromo-title {
    font-size: 19px;
    font-weight: 500;
    margin: 12px 0
}
.docs-offline-optinpromo-notice {
    color: #767676;
    font-size: 11px;
    margin: 14px 0
}
.docs-offline-optinpromo-notice a {
    text-decoration: none
}
.docs-offline-optinpromo hr {
    border-top-color: #e1e1e1;
    border-top-style: solid;
    border-width: 1px 0 0 0
}
.docs-offline-optinpromo-confirm-buttons {
    margin-top: 15px
}
.docs-offline-welcomepromo {
    width: 400px
}
.docs-offline-welcomepromo .modal-dialog-content {
    padding-right: 80px;
    position: relative
}
.doc-offline-welcomepromo-img {
    position: absolute;
    right: 0;
    top: -25px
}
.docs-gm-dialogs #docs-offline-optinpromo-title,
.docs-gm-dialogs .docs-offline-optinpromo-buttons {
    padding: 0
}
.docs-labelinputmenuitem {
    outline: none;
    padding-right: 30px;
    padding-left: 30px
}
#docs-omnibox-toolbar .docs-omnibox-autocomplete {
    margin-right: 4px
}
.docs-omnibox-autocomplete {
    margin-top: 4px
}
.docs-omnibox-input {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    width: 100%;
    min-width: 178px
}
.docs-omnibox-input::-webkit-input-placeholder {
    color: #777;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 11px;
    font-weight: 500;
    opacity: 1;
    padding-top: 2px
}
.docs-omnibox-input::-moz-placeholder {
    color: #777;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 11px;
    font-weight: 500;
    opacity: 1
}
.docs-omnibox-input:-ms-input-placeholder {
    color: #777;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 11px;
    font-weight: 500;
    opacity: 1
}
.docs-gm-sidebars .docs-omnibox-input.jfk-textinput {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    color: #3c4043;
    padding: 1px 8px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-weight: 400;
    line-height: 16px;
    height: 20px
}
.docs-gm-sidebars .docs-omnibox-input.jfk-textinput::placeholder {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-weight: 400;
    line-height: 16px
}
.docs-gm-sidebars .docs-omnibox-input.jfk-textinput:focus {
    border: 2px solid #1a73e8;
    box-shadow: none;
    padding: 0px 7px
}
.docs-omnibox-autocomplete .ac-renderer {
    -webkit-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
    box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
    border: 1px solid #ccc;
    background-color: #fff;
    min-width: 250px;
    outline: medium none;
    position: fixed;
    width: auto;
    z-index: 1003
}
.docs-omnibox-autocomplete .ac-highlighted {
    font-weight: 500
}
.docs-omnibox-autocomplete .ac-active {
    background-color: #eee

}
.docs-omnibox-row-content {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.docs-promo-title-prefix {
    color: #d25342;
    font-weight: 500
}
.docs-promo-title {
    color: #333;
    font-weight: 500
}
.docs-promo-content {
    color: #666;
    cursor: pointer
}
.docs-promo-dismiss-link {
    color: #15c;
    cursor: pointer
}
.jfk-bubble.jfk-bubble-promo.docs-promo-bubble .jfk-bubble-arrowdown .jfk-bubble-arrowimplbefore,
.jfk-bubble.jfk-bubble-promo.docs-promo-bubble .jfk-bubble-arrowup .jfk-bubble-arrowimplbefore {
    border-color: rgba(0, 0, 0, .1) transparent
}
.jfk-bubble.jfk-bubble-promo.docs-promo-bubble .jfk-bubble-arrowleft .jfk-bubble-arrowimplbefore,
.jfk-bubble.jfk-bubble-promo.docs-promo-bubble .jfk-bubble-arrowright .jfk-bubble-arrowimplbefore {
    border-color: transparent rgba(0, 0, 0, .1)
}
.jfk-bubble.jfk-bubble-promo.docs-promo-bubble .jfk-bubble-arrowdown .jfk-bubble-arrowimplafter {
    border: 10px solid;
    border-bottom-width: 0;
    border-color: #fafafa transparent
}
.jfk-bubble.jfk-bubble-promo.docs-promo-bubble .jfk-bubble-arrowup .jfk-bubble-arrowimplafter {
    border: 10px solid;
    border-top-width: 0;
    border-color: #fafafa transparent
}
.jfk-bubble.jfk-bubble-promo.docs-promo-bubble .jfk-bubble-arrowleft .jfk-bubble-arrowimplafter {
    border: 10px solid;
    border-left-width: 0;
    border-color: transparent #fafafa
}
.jfk-bubble.jfk-bubble-promo.docs-promo-bubble .jfk-bubble-arrowright .jfk-bubble-arrowimplafter {
    border: 10px solid;
    border-right-width: 0;
    border-color: transparent #fafafa
}
.jfk-bubble.docs-promo-bubble {
    background-color: #fafafa;
    border: none;
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    -webkit-box-shadow: rgba(255, 255, 255, .9) 0 1px 0 inset, rgba(0, 0, 0, .03) 0 -1px 0 inset, rgba(0, 0, 0, .15) 0 15px 10px, rgba(0, 0, 0, .3) 0 8px 36px;
    -moz-box-shadow: rgba(255, 255, 255, .9) 0 1px 0 inset, rgba(0, 0, 0, .03) 0 -1px 0 inset, rgba(0, 0, 0, .15) 0 15px 10px, rgba(0, 0, 0, .3) 0 8px 36px;
    box-shadow: rgba(255, 255, 255, .9) 0 1px 0 inset, rgba(0, 0, 0, .03) 0 -1px 0 inset, rgba(0, 0, 0, .15) 0 15px 10px, rgba(0, 0, 0, .3) 0 8px 36px;
    padding: 0
}
.docs-promo-text-container {
    width: 363px;
    word-wrap: break-word
}
.docs-promo-text-container-ltr {
    float: right
}
.docs-promo-container {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    padding: 24px 16px 0 16px
}
.docs-promo-icon-container {
    width: 48px;
    height: 48px;
    margin-right: 16px;
    float: left
}
.docs-promo-header {
    color: #000;
    opacity: 0.87;
    font-size: 15px;
    font-weight: 500
}
.docs-promo-header-prefix {
    color: #d25342
}
.docs-promo-body {
    color: #666;
    font-size: 13px;
    line-height: 20px;
    padding-top: 20px
}
.docs-promo-action-row {
    font-weight: 500;
    padding-top: 20px;
    padding-right: 8px;
    padding-bottom: 24px;
    position: relative;
    text-align: right
}
.docs-promo-action-row a,
.docs-promo-action-row a:link,
.docs-promo-action-row a:active,
.docs-promo-action-row a:hover,
.docs-promo-action-row a:visited {
    text-decoration: none
}
.docs-promo-action-row a,
.docs-promo-action-row a:link,
.docs-promo-action-row a:active,
.docs-promo-action-row a:hover,
.docs-promo-action-row a:visited {
    color: #4285f4
}
.docs-promo-action-container {
    color: #4285f4;
    cursor: pointer;
    text-transform: uppercase
}
.docs-promo-action-button-right {
    margin-left: 12.5px;
    float: right
}
.docs-promo-action-button-left {
    margin-right: 12.5px
}
.docs-revisions-chromecover-titlebar {
    -ms-flex-align: center;
    -moz-box-align: center;
    -webkit-box-align: center;
    box-align: center;
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    box-pack: start;
    -ms-flex-pack: start;
    -webkit-box-pack: start;
    -webkit-justify-content: flex-start;
    justify-content: flex-start;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    font-size: 16px;
    max-width: 50vw
}
.docs-gm-sidebars .docs-revisions-chromecover-titlebar {
    font-size: 18px;
    line-height: 24px
}
.docs-revisions-chromecover-titlebar-name-label {
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: normal;
    font-weight: var(--docs-material-font-weight-bold, normal);
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.docs-gm-sidebars .docs-revisions-chromecover-titlebar-name-label {
    font-weight: 400
}
.docs-revisions-chromecover-titlebar[class*="docs-hc"] .docs-revisions-chromecover-titlebar-button-action {
    border: 1px solid #fff
}
.docs-revisions-chromecover-titlebar-button-back-container {
    height: 100%;
    min-width: 58px
}
.docs-revisions-chromecover-titlebar-button-back {
    background-color: transparent;
    border: 0;
    cursor: pointer;
    left: 18px;
    margin: 0;
    outline: 0;
    padding: 0
}
.docs-revisions-chromecover-titlebar-button-back.docs-material .docs-icon {
    height: 21px;
    width: 21px;
    margin: 0;
    padding-bottom: 3px
}
.docs-revisions-chromecover-titlebar-button-action {
    -ms-flex-align: center;
    -moz-box-align: center;
    -webkit-box-align: center;
    box-align: center;
    -webkit-align-items: center;
    align-items: center;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    -webkit-tap-highlight-color: transparent;
    background-color: #0f9d58;
    border: none;
    color: #fff;
    cursor: pointer;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    height: 36px;
    margin: 0 0 0 24px;
    outline: none;
    padding: 0 16px;
    text-transform: uppercase;
    white-space: nowrap;
    will-change: box-shadow, filter, background-color, color
}
.docs-gm-sidebars .docs-revisions-chromecover-titlebar-button-action {
    padding: 0 24px;
    text-transform: none
}
.docs-revisions-chromecover-titlebar-button-action,
.docs-revisions-chromecover-titlebar-button-action.goog-flat-button-active,
.docs-revisions-chromecover-titlebar-button-action.goog-flat-button-hover {
    -webkit-transition-duration: 0.28s;
    -moz-transition-duration: 0.28s;
    -o-transition-duration: 0.28s;
    transition-duration: 0.28s;
    -webkit-transition-property: box-shadow, filter, background-color, color;
    -moz-transition-property: box-shadow, filter, background-color, color;
    -o-transition-property: box-shadow, filter, background-color, color;
    transition-property: box-shadow, filter, background-color, color;
    -webkit-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1)
}
.docs-revisions-chromecover-titlebar-button-action.goog-flat-button-active,
.docs-revisions-chromecover-titlebar-button-action.goog-flat-button-focused {
    filter: brightness(88%)
}
.docs-revisions-chromecover-titlebar-button-action.goog-flat-button-active {
    -webkit-box-shadow: 0 6px 10px 0 rgba(0, 0, 0, 0.14), 0 1px 18px 0 rgba(0, 0, 0, 0.12), 0 3px 5px -1px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0 6px 10px 0 rgba(0, 0, 0, 0.14), 0 1px 18px 0 rgba(0, 0, 0, 0.12), 0 3px 5px -1px rgba(0, 0, 0, 0.2);
    box-shadow: 0 6px 10px 0 rgba(0, 0, 0, 0.14), 0 1px 18px 0 rgba(0, 0, 0, 0.12), 0 3px 5px -1px rgba(0, 0, 0, 0.2)
}
.docs-revisions-chromecover-titlebar-button-action.goog-flat-button-hover:not(.goog-flat-button-active) {
    -webkit-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.12), 0 1px 5px 0 rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.12), 0 1px 5px 0 rgba(0, 0, 0, 0.2);
    box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 3px 1px -2px rgba(0, 0, 0, 0.12), 0 1px 5px 0 rgba(0, 0, 0, 0.2)
}
.docs-revisions-chromecover-content {
    -ms-flex-align: center;
    -moz-box-align: center;
    -webkit-box-align: center;
    box-align: center;
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: horizontal;
    -webkit-box-orient: horizontal;
    box-orient: horizontal;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    box-pack: start;
    -ms-flex-pack: start;
    -webkit-box-pack: start;
    -webkit-justify-content: flex-start;
    justify-content: flex-start;
    height: inherit
}
.docs-revisions-chromecover-content-exclude-sidebar-width {
    width: calc(100% - 250px)
}
.docs-gm-sidebars .docs-revisions-chromecover-content-exclude-sidebar-width {
    width: calc(100% - 300px)
}
.docs-revisions-chromecover-content-color-default {
    background-color: #424242;
    color: #fff
}
.docs-gm-sidebars .docs-revisions-chromecover-content-color-default {
    background-color: #fff;
    color: #202124
}
.docs-revisions-icon {
    cursor: pointer;
    direction: ltr;
    height: 24px;
    min-height: 24px;
    min-width: 24px;
    outline: none;
    position: relative;
    text-align: left;
    vertical-align: middle;
    width: 24px
}
.docs-hc-gecko .docs-revisions-icon {
    filter: invert(100%)
}
.docs-hc-ie .docs-revisions-icon {
    -ms-high-contrast-adjust: none;
    background-color: #fff
}
.docs-revisions-icon-rtl {
    -webkit-transform: scaleX(-1);
    -moz-transform: scaleX(-1);
    -ms-transform: scaleX(-1);
    -o-transform: scaleX(-1);
    transform: scaleX(-1)
}
.docs-revisions-icon-focused:before {
    -webkit-transform: scale(1.375);
    -moz-transform: scale(1.375);
    -ms-transform: scale(1.375);
    -o-transform: scale(1.375);
    transform: scale(1.375);
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    background-color: #000;
    content: '';
    display: block;
    height: inherit;
    opacity: .12;
    position: absolute;
    width: inherit
}
.docs-revisions-icon-img-mask {
    height: inherit;
    overflow: hidden;
    position: absolute;
    width: inherit
}
.docs-revisions-icon-img:before {
    content: url(//ssl.gstatic.com/docs/common/revisions_sprite1.svg)
}
.docs-revisions-icon-img {
    height: 72px;
    position: absolute;
    width: 24px
}
.docs-revisions-icon-open .docs-revisions-icon-arrow {
    left: 0;
    top: -48px
}
.docs-revisions-icon-arrow {
    left: 0;
    top: 0
}
.docs-revisions-icon-overflow {
    left: 0;
    top: -24px
}
.docs-revisions-sidebar {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    background-color: #fff;
    height: 100%;
    outline-style: none;
    position: absolute;
    right: 0;
    width: 250px;
    z-index: 2
}
.docs-gm-sidebars .docs-revisions-sidebar {
    overflow: hidden;
    box-shadow: -3px 0px 6px -3px rgba(60, 64, 67, .15), 3px 0px 6px -3px rgba(60, 64, 67, .15);
    width: 300px
}
.docs-revisions-sidebar-header {
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none
}
.docs-gm-sidebars .docs-revisions-sidebar-header {
    background-color: #fff;
    color: #202124
}
.docs-revisions-sidebar[class*="docs-hc"] {
    border-left: 1px solid #fff
}
.docs-revisions-sidebar[class*="docs-hc"]>.docs-revisions-sidebar-header {
    border-bottom: 1px solid #fff
}
.docs-revisions-sidebar-header-bg-color-brand {
    background-color: #0f9d58
}
.docs-revisions-sidebar-header-text-color-brand {
    color: #fff
}
.docs-revisions-sidebar-title {
    -ms-flex-align: center;
    -moz-box-align: center;
    -webkit-box-align: center;
    box-align: center;
    -webkit-align-items: center;
    align-items: center;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px;
    height: 60px;
    padding: 18px;
    width: 100%
}
.docs-gm-sidebars .docs-revisions-sidebar-title {
    font-size: 16px;
    line-height: 24px;
    padding: 20px 16px
}
.docs-revisions-sidebar-name-filter-switch-container {
    -ms-flex-align: center;
    -moz-box-align: center;
    -webkit-box-align: center;
    box-align: center;
    -webkit-align-items: center;
    align-items: center;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    border-top: 1px solid rgba(255, 255, 255, 0.2);
    height: 47px;
    justify-content: space-between;
    padding: 14px 14px 14px 18px;
    width: 100%
}
.docs-gm-sidebars .docs-revisions-sidebar-name-filter-switch-container {
    border-bottom: 1px solid #dadce0;
    border-top: 1px solid #dadce0;
    padding: 12px 16px;
    height: 40px
}
.docs-revisions-sidebar-name-filter-switch-container label {
    color: #fff;
    cursor: pointer;
    font-size: 12px;
    font-weight: normal;
    opacity: 0.87;
    word-break: break-word
}
.docs-gm-sidebars .docs-revisions-sidebar-name-filter-switch-container label {
    color: #3c4043;
    line-height: 16px
}
.docs-revisions-sidebar-revisions-list {
    position: relative;
    overflow: auto;
    overflow-x: hidden
}
body:not(.docs-gm-sidebars) .docs-revisions-sidebar-revisions-list::-webkit-scrollbar {
    width: 11px
}
body:not(.docs-gm-sidebars) .docs-revisions-sidebar-revisions-list::-webkit-scrollbar-thumb {
    border-width: 1px
}
body:not(.docs-gm-sidebars) .docs-revisions-sidebar-revisions-list::-webkit-scrollbar-track {
    border-width: 0
}
.docs-revisions-sidebar-actions {
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0;
    border-top: 1px solid #cfcfcf;
    padding: 9px 14px
}
.docs-revisions-sidebar-detail-button,
#docs-revisions-sidebar-iw-button {
    margin-top: 9px
}
.docs-revisions-sidebar-date-group {
    -ms-flex-align: center;
    -moz-box-align: center;
    -webkit-box-align: center;
    box-align: center;
    -webkit-align-items: center;
    align-items: center;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    background-color: #f5f5f5;
    border-bottom: 1px solid #eee;
    color: #616161;
    font-size: 13px;
    font-weight: 500;
    height: 35px;
    padding-left: 18px
}
.docs-gm-sidebars .docs-revisions-sidebar-date-group {
    color: #3c4043;
    background-color: #fff;
    font-size: 11px;
    font-weight: 500;
    line-height: 21px;
    text-transform: uppercase
}
.docs-revisions-sidebar-revisions-list-container {
    overflow: auto
}
.docs-revisions-sidebar-revisions-empty-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-align: center;
    -moz-box-align: center;
    -webkit-box-align: center;
    box-align: center;
    -webkit-align-items: center;
    align-items: center;
    -ms-flex: 1 0 auto;
    -webkit-flex: 1 0 auto;
    flex: 1 0 auto
}
.docs-revisions-sidebar-revisions-empty {
    color: #616161;
    margin: 0 18px;
    text-align: center
}
.docs-gm-sidebars .docs-revisions-sidebar-revisions-empty-details {
    color: #80868b;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    line-height: 20px
}
.docs-revisions-sidebar-revisions-empty-title {
    font-size: 15px;
    font-weight: 500
}
.docs-gm-sidebars .docs-revisions-sidebar-revisions-empty-title {
    color: #3c4043;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px;
    font-weight: 500;
    line-height: 24px
}
.docs-revisions-sidebar-revisions-empty-details,
.docs-revisions-sidebar-revisions-empty-title {
    margin-bottom: 8px
}
a.docs-revisions-sidebar-revisions-empty-learn-more {
    color: #4285f4
}
.docs-gm-sidebars a.docs-revisions-sidebar-revisions-empty-learn-more {
    color: #1a73e8;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    line-height: 20px
}
.docs-ui-toast.docs-revisions-snack {
    z-index: 1001
}
.docs-revisions-snack .docs-ui-toast-control {
    font-weight: 500;
    text-transform: uppercase
}
.docs-revisions-snapshot-prompt .jfk-textinput {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    height: 29px;
    margin-top: 16px;
    width: 100%
}
.docs-revisions-snapshot-prompt-loading-indicator,
.docs-revisions-snapshot-prompt-loading-indicator .docs-spinner {
    -ms-flex-align: center;
    -moz-box-align: center;
    -webkit-box-align: center;
    box-align: center;
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    box-pack: center;
    -ms-flex-pack: center;
    -webkit-box-pack: center;
    -webkit-justify-content: center;
    justify-content: center
}
.docs-revisions-snapshot-prompt-loading-indicator {
    min-height: 96px;
    min-width: 300px
}
.docs-revisions-snapshot-prompt-loading-indicator .docs-spinner {
    height: 32px;
    width: 32px
}
.docs-revisions-snapshot-prompt-loading-indicator .docs-quantum-spinner {
    margin: 0;
    position: initial
}
.docs-revisions-switch {
    cursor: pointer;
    margin-left: 14px
}
.docs-revisions-switch[class*="docs-hc"]>.apps-ui-material-slide-toggle-thumb,
.docs-revisions-switch[class*="docs-hc"]>.apps-ui-material-slide-toggle-track {
    border: 1px solid #fff;
    will-change: border-style
}
.docs-revisions-switch .apps-ui-material-slide-toggle-thumb {
    background-color: #bdbdbd
}
.docs-gm-sidebars .docs-revisions-switch .apps-ui-material-slide-toggle-thumb {
    background-color: #fff
}
.docs-revisions-switch .apps-ui-material-slide-toggle-track {
    background-color: #fff;
    opacity: .3
}
.docs-gm-sidebars .docs-revisions-switch .apps-ui-material-slide-toggle-track {
    background-color: #9aa0a6;
    opacity: 1
}
.docs-revisions-switch.apps-ui-material-slide-toggle-container-checked .apps-ui-material-slide-toggle-thumb {
    background-color: #fafafa
}
.docs-gm-sidebars .docs-revisions-switch.apps-ui-material-slide-toggle-container-checked .apps-ui-material-slide-toggle-thumb {
    background-color: #0f9d58
}
.docs-revisions-switch.apps-ui-material-slide-toggle-container-checked .apps-ui-material-slide-toggle-track {
    background-color: #000;
    opacity: .38
}
.docs-gm-sidebars .docs-revisions-switch.apps-ui-material-slide-toggle-container-checked .apps-ui-material-slide-toggle-track {
    background-color: #0f9d58
}
.docs-revisions-tile {
    outline: none;
    position: relative
}
.docs-revisions-tile-content-wrapper {
    padding-bottom: 12px;
    border-bottom: 1px solid #eee
}
.docs-revisions-tile-selected {
    background-color: #e2f3eb
}
.docs-revisions-tile-hover:not(.docs-revisions-tile-selected) {
    background-color: #f5f5f5
}
.docs-revisions-tile-header {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    font-size: 13px;
    font-size: var(--docs-material-font-size-normal, 13px);
    padding: 12px 18px 3px 36px;
    position: relative
}
.docs-revisions-tile-actions,
.docs-revisions-tile-collaborator-list {
    margin: 0 18px 0 36px
}
.docs-gm-sidebars .docs-revisions-tile-actions {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    line-height: 16px;
    padding-top: 3px
}
.docs-revisions-tile-collaborator {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-box-orient: vertical;
    -webkit-box-orient: vertical;
    box-orient: vertical;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    font-size: 12px
}
.docs-revisions-tile-collaborator-name {
    -ms-flex-align: center;
    -moz-box-align: center;
    -webkit-box-align: center;
    box-align: center;
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    color: #585858
}
.docs-gm-sidebars .docs-revisions-tile-collaborator {
    line-height: 16px
}
.docs-gm-sidebars .docs-revisions-tile-collaborator-name {
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.docs-revisions-tile-collaborator-link {
    line-height: 1;
    margin-top: 3px
}
.docs-gm-sidebars .docs-revisions-tile-collaborator-link {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    line-height: 16px;
    margin-top: 3px
}
.docs-revisions-tile-indented {
    margin-left: 50px
}
.docs-revisions-tile-indented .docs-revisions-tile-header {
    padding-left: 0
}
.docs-revisions-tile-indented .docs-revisions-tile-actions,
.docs-revisions-tile-indented .docs-revisions-tile-collaborator-list {
    margin-left: 0
}
.docs-revisions-tile-caption-v0 {
    color: #808080;
    font-size: 11px
}
.docs-revisions-tile-show-v0 {
    color: #4275d6;
    font-size: 11px
}
.docs-revisions-tile-show-v0-link {
    cursor: pointer;
    font-weight: 500
}
.docs-revisions-tile-swatch {
    width: 8px;
    height: 8px;
    margin-right: 5px
}
.docs-gm-sidebars .docs-revisions-tile-swatch {
    border-radius: 50%
}
.docs-revisions-tile-arrow-button,
.docs-revisions-tile-menu-button {
    position: absolute
}
.docs-revisions-tile-arrow-button {
    left: 9px;
    top: 10px
}
.docs-revisions-tile-menu-button {
    right: 9px;
    top: 10px
}
.docs-revisions-tile-shade {
    border-bottom: 1px solid #eee;
    cursor: progress;
    height: 100%;
    position: absolute;
    width: 100%;
    z-index: 1
}
.docs-revisions-tile-shade:before {
    background-color: #fff;
    content: '';
    display: block;
    height: inherit;
    opacity: 0.95;
    width: inherit
}
.docs-revisions-tile-shade .docs-spinner {
    -ms-flex-align: center;
    -moz-box-align: center;
    -webkit-box-align: center;
    box-align: center;
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    box-pack: center;
    -ms-flex-pack: center;
    -webkit-box-pack: center;
    -webkit-justify-content: center;
    justify-content: center;
    -webkit-transform: scale(0.5);
    -moz-transform: scale(0.5);
    -ms-transform: scale(0.5);
    -o-transform: scale(0.5);
    transform: scale(0.5);
    height: 48px;
    left: 50%;
    margin: -24px 0 0 -24px;
    position: absolute;
    top: 50%;
    width: 48px
}
.docs-revisions-tile-shade .docs-quantum-spinner {
    margin: 0;
    position: initial
}
.docs-revisions-tile-descriptor {
    color: #000;
    font-size: 14px
}
.docs-gm-sidebars .docs-revisions-tile-descriptor {
    font-style: italic
}
.docs-revisions-tile-selected .docs-revisions-tile-descriptor {
    font-weight: 500
}
.docs-gm-sidebars .docs-revisions-tile-selected .docs-revisions-tile-descriptor,
.docs-gm-sidebars .docs-revisions-tile-selected .docs-revisions-tile-text-box~.docs-revisions-tile-descriptor {
    color: #188038
}
.docs-revisions-tile-text-box~.docs-revisions-tile-descriptor {
    color: #585858;
    font-size: 12px;
    font-weight: normal;
    margin-top: 3px
}
.docs-gm-sidebars .docs-revisions-tile-descriptor,
.docs-gm-sidebars .docs-revisions-tile-text-box~.docs-revisions-tile-descriptor {
    color: #3c4043;
    font-size: 12px;
    font-weight: 400;
    line-height: 16px
}
.docs-revisions-tile-text-box {
    -webkit-transition-duration: 0.28s;
    -moz-transition-duration: 0.28s;
    -o-transition-duration: 0.28s;
    transition-duration: 0.28s;
    -webkit-transition-property: border-color;
    -moz-transition-property: border-color;
    -o-transition-property: border-color;
    transition-property: border-color;
    -webkit-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    transition-timing-function: cubic-bezier(0.4, 0.0, 0.2, 1);
    background: transparent;
    border-radius: 2px;
    border: 1px solid transparent;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    margin: -3px;
    margin-right: 18px;
    outline: 0;
    padding: 2px;
    resize: none;
    will-change: border-color
}
.docs-revisions-tile-text-box:hover:enabled {
    border-color: #9e9e9e
}
.docs-revisions-tile-text-box:focus:enabled {
    border-color: #498dff
}
.docs-revisions-tile-text-box:disabled {
    color: #000;
    pointer-events: none;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none
}
.docs-revisions-tile-selected .docs-revisions-tile-text-box {
    font-weight: 500
}
.docs-gm-sidebars .docs-revisions-tile-text-box {
    font-weight: 400;
    line-height: 20px
}
.docs-gm-sidebars .docs-revisions-tile-selected .docs-revisions-tile-text-box {
    color: #188038;
    font-weight: 700
}
.docs-gm-sidebars docs-revisions-tile-text-box:disabled {
    color: #3c4043
}
.alt-text-dialog-content textarea {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
#alt-text-dialog-title,
#alt-text-dialog-description {
    width: 400px
}
#alt-text-dialog-description {
    height: 100px;
    padding-top: 6px;
    padding-left: 9px
}
.alt-text-dialog-content td {
    padding-top: 10px;
    vertical-align: top
}
.alt-text-dialog-content tr {
    margin: 5px 0
}
.alt-text-dialog-content label {
    font-weight: 500;
    padding-right: 30px;
    position: relative;
    top: 5px
}
.alt-text-dialog-intro {
    max-width: 500px;
    padding: 5px 0
}
.docs-bubble {
    background-color: #fff;
    border-radius: 2px;
    border: 1px solid;
    border-color: #bbb #bbb #a8a8a8;
    -moz-box-shadow: 0 1px 3px rgba(0, 0, 0, .2);
    -webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, .2);
    -ms-box-shadow: 0 1px 3px rgba(0, 0, 0, .2);
    box-shadow: 0 1px 3px rgba(0, 0, 0, .2);
    color: #666;
    cursor: default;
    padding: 12px 20px;
    position: absolute;
    z-index: 502;
    white-space: nowrap
}
.docs-bubble.docs-linkbubble-bubble {
    z-index: 503
}
.docs-bubble-link,
.docs-bubble a {
    color: #15c!important;
    cursor: pointer;
    text-decoration: none!important
}
.docs-bubble a {
    display: inline-block;
    max-width: 400px;
    text-overflow: ellipsis;
    overflow: hidden;
    vertical-align: bottom
}
.docs-bubble-link:hover,
.docs-bubble a:hover {
    text-decoration: underline!important
}
.docs-bubble-label {
    font-weight: 500
}
a.docs-bubble-link-disabled {
    color: #ccc!important;
    text-decoration: none!important
}
.docs-bubble .docs-bubble-button .docs-icon {
    vertical-align: baseline;
    width: 18px;
    height: 18px;
    margin: 0px
}
.docs-bubble .docs-bubble-button {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: transparent;
    background-image: none;
    cursor: pointer;
    height: 18px;
    width: 18px;
    border-radius: 50%;
    border-width: 0px;
    border-style: solid;
    border-color: transparent;
    box-shadow: none;
    background-clip: padding-box;
    cursor: pointer;
    -webkit-tap-highlight-color: transparent;
    min-width: auto;
    min-width: unset;
    margin-right: 0px;
    padding: 6px
}
.docs-bubble .docs-bubble-button.jfk-button:hover,
.docs-bubble .docs-bubble-button.jfk-button:focus {
    background-color: rgba(0, 0, 0, .06)
}
.docs-bubble .docs-bubble-button.jfk-button:hover:active,
.docs-bubble .docs-bubble-button.jfk-button.goog-toolbar-button-checked {
    background-color: #e6f4ea
}
.docs-hc-gecko .docs-bubble-button,
.docs-hc-ie .docs-bubble-button {
    border: 1px solid transparent
}
.docs-clipboardshortcutsdialog {
    color: #666
}
.docs-clipboardshortcutsdialog-shortcut {
    padding-right: 40px
}
.docs-clipboardshortcutsdialog-mac .docs-clipboardshortcutsdialog-shortcut {
    padding-right: 95px
}
.docs-clipboardshortcutsdialog-shortcut-command {
    padding-bottom: 5px
}
.docs-clipboardshortcutsdialog-shortcuts {
    padding: 15px 0
}
.docs-clipboardshortcutsdialog-shortcut-command {
    line-height: 1.0;
    font-size: 36px;
    font-weight: 500
}
.modal-dialog.color-dialog {
    padding: 10px
}
.color-dialog>.modal-dialog-title {
    display: none
}
.color-dialog>.modal-dialog-buttons {
    margin-top: 8px;
    padding-left: 18px
}
.docs-colormenuitems-header {
    padding-left: 5px
}
.docs-colormenuitems-custom-header {
    margin-left: -23px
}
.docs-gm .colormenuitems-custom-header-add-button .docs-colormenuitems-custom-header,
.docs-gm .docs-colormenuitems-scheme-header {
    margin-left: 5px
}
.docs-gm .docs-colormenuitems .goog-menuitem.colormenuitems-custom-header-add-button {
    border-radius: 4px;
    border-width: 1px 0;
    font-size: 13px;
    padding: 2px 0
}
.docs-gm .goog-menuitem.colormenuitems-custom-header-add-button.goog-menuitem-highlight {
    border-width: 0
}
.docs-gm .docs-colormenuitems-scheme-header {
    padding: 4px 0 4px 5px
}
.docs-gm .goog-menu .goog-menuitem.colormenuitems-no-color {
    border-color: transparent;
    border-style: dotted;
    border-width: 1px;
    padding: 5px 15px 5px 38px
}
.docs-gm .docs-colormenuitems .docs-colormenuitems-scheme-header,
.docs-gm .docs-colormenuitems .docs-colormenuitems-custom-header {
    color: #3c4043;
    font-size: 11px;
    font-weight: 500;
    letter-spacing: .8px;
    padding-left: 0px;
    text-transform: uppercase
}
.docs-gm .docs-colormenuitems .docs-text-color-state-change-button.jfk-button {
    background-color: #fff;
    background-image: none;
    border: none;
    box-shadow: none;
    color: #5f6368;
    cursor: pointer;
    font-size: 14px
}
.docs-gm .docs-colormenuitems .docs-text-color-state-change-button.jfk-button-checked {
    border-bottom: 2px solid #0f9d58;
    color: #202124
}
.docs-colormenuitems.goog-menu {
    padding: 10px
}
.docs-colormenuitems .jfk-palette-table {
    margin: 0;
    padding: 3px
}
.docs-colormenuitems .jfk-palette-cell-hover {
    border: 1px solid #fff;
    outline: 1px solid #000
}
.docs-colormenuitems-theme-header {
    padding-top: 5px
}
.docs-colormenuitems-custom-palette .jfk-palette-cell {
    border-color: #ccc;
    height: 16px;
    width: 16px
}
.docs-colormenuitems-custom-palette .jfk-palette-cell-selected {
    border-color: black;
    outline: none
}
.goog-color-menu-button.goog-menu-button {
    background-color: #f5f5f5;
    background-image: -webkit-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -o-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: linear-gradient(top, #f5f5f5, #f1f1f1)
}
.goog-color-menu-button .goog-menu-button-outer-box,
.goog-color-menu-button .goog-menu-button-inner-box {
    border-color: rgba(0, 0, 0, 0.1)
}
.goog-color-menu-button.goog-menu-button-focused .goog-menu-button-outer-box,
.goog-color-menu-button.goog-menu-button-focused .goog-menu-button-inner-box {
    border-color: #4d90fe
}
.goog-color-menu-button.goog-menu-button-open .goog-menu-button-outer-box,
.goog-color-menu-button.goog-menu-button-open .goog-menu-button-inner-box {
    border-color: rgba(0, 0, 0, 0.1)
}
.goog-color-menu-button.goog-menu-button-hover .goog-menu-button-outer-box,
.goog-color-menu-button.goog-menu-button-hover .goog-menu-button-inner-box {
    border-color: rgba(0, 0, 0, 0.1)!important
}
.goog-color-menu-button.goog-menu-button-hover .goog-menu-button-outer-box {
    box-shadow: 0 1px 1px rgba(0, 0, 0, .1)
}
.docs-flatcolormenubutton.goog-flat-menu-button {
    min-width: 0px
}
.docs-flatcolormenubutton .goog-flat-menu-button-caption {
    display: inline-block;
    height: 14px;
    outline: 1px solid #bbb;
    vertical-align: middle;
    width: 14px
}
.docs-copy-link {
    width: 500px
}
.copy-link-dialog {
    color: black;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    white-space: normal
}
.copy-link-butter-holder {
    position: absolute;
    top: 0px;
    padding-top: 16px;
    left: 220px
}
.copy-link-dialog button.copy-link-done-button,
.copy-link-dialog button.copy-link-done-button:hover {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: #4d90fe;
    background-color: #4d90fe;
    background-image: -webkit-linear-gradient(top, #4d90fe, #4787ed);
    background-image: -moz-linear-gradient(top, #4d90fe, #4787ed);
    background-image: -ms-linear-gradient(top, #4d90fe, #4787ed);
    background-image: -o-linear-gradient(top, #4d90fe, #4787ed);
    background-image: linear-gradient(top, #4d90fe, #4787ed);
    border: 1px solid #3079ed;
    color: #fff
}
.docs-chromeextensioninstalldialog-image {
    vertical-align: top
}
.docs-chromeextensioninstalldialog-textpart {
    width: 360px;
    padding: 0 0 15px 25px;
    color: #333
}
.docs-chromeextensioninstalldialog-note {
    padding: 25px 0 0 0;
    color: #666
}
.docs-chromeextensioninstalldialog-noteV2 {
    color: #666;
    padding: 10px 0 0 0
}
.docs-chromeextensioninstalldialog-shortcuts {
    color: #666
}
.docs-findbar-input {
    width: 170px;
    height: 19px
}
.docs-gm-dialogs .docs-findbar-content,
.docs-gm-dialogs .docs-gotobar-content {
    height: 36px
}
.docs-slidingdialog .docs-findbar-text {
    border: 1px solid #aaa;
    font-size: 11px;
    height: 16px;
    margin-right: 4px;
    padding: 2px;
    width: 172px
}
.docs-slidingdialog #docs-findbar-spinner {
    display: inline-block;
    position: relative;
    -webkit-transition: left 300ms ease-out;
    -moz-transition: left 300ms ease-out;
    -o-transition: left 300ms ease-out;
    transition: left 300ms ease-out;
    -webkit-transition: width 300ms ease-out;
    -moz-transition: width 300ms ease-out;
    -o-transition: width 300ms ease-out;
    transition: width 300ms ease-out;
    vertical-align: middle
}
.docs-gm-dialogs .docs-slidingdialog #docs-findbar-button-previous,
.docs-gm-dialogs .docs-slidingdialog #waffle-gotobar-button-go {
    margin-left: 8px;
    margin-right: 8px
}
.docs-slidingdialog #docs-findbar-button-next {
    margin-right: 8px
}
.docs-gm-dialogs .docs-slidingdialog .goog-toolbar-separator {
    height: 24px;
    width: 2px;
    margin: 0 8 0 0px;
    position: center;
    vertical-align: middle
}
.docs-slidingdialog #docs-findbar-button-more-options {
    margin-right: 8px
}
.docs-findbar-button-previous-rtl {
    margin-left: -1px
}
.docs-findbar-content .jfk-button-disabled {
    background-color: #f5f5f5;
    border-color: rgba(0, 0, 0, 0.1);
    border-color: #dcdcdc
}
.docs-gm-dialogs .docs-findbar-content .jfk-button-disabled,
.docs-gm-dialogs .docs-gotobar-content .jfk-button-disabled {
    opacity: .38
}
.docs-gm-dialogs .docs-findbar-content .jfk-button,
.docs-gm-dialogs .docs-gotobar-content .jfk-button {
    background-image: none;
    background-color: transparent;
    border-color: transparent;
    margin: 0 8px 0 0;
    min-width: 24px;
    vertical-align: middle
}
.docs-gm-dialogs .docs-findbar-content .jfk-button-hover,
.docs-gm-dialogs .docs-gotobar-content .jfk-button-hover {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: rgba(0, 0, 0, .06);
    background-image: none;
    cursor: pointer;
    border-color: transparent!important;
    border-radius: 2px;
    border-width: 1px
}
.docs-gm-dialogs .docs-findbar-content .jfk-button-active,
.docs-gm-dialogs .docs-gotobar-content .jfk-button-active {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: rgba(0, 0, 0, 0.12);
    background-image: none;
    cursor: pointer;
    border-color: transparent!important;
    border-radius: 2px;
    border-width: 1px
}
.docs-findinput-container {
    background: #fff;
    border: 1px solid #d9d9d9;
    border-top: 1px solid #c0c0c0;
    min-width: 20px;
    padding: 0 8px;
    width: 100%
}
.docs-findinput-container-focus {
    border: 1px solid #4d90fe;
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    outline: none
}
.docs-gm-dialogs .docs-findinput-container,
.docs-gm-dialogs .docs-gotoinput-container {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    color: #3c4043;
    padding: 1px 8px;
    font-size: 14px;
    height: 36px;
    margin: 8px 0;
    margin: 0
}
.docs-gm-dialogs .docs-findinput-container-focus,
.docs-gm-dialogs .docs-gotoinput-container:focus {
    border: 2px solid #1a73e8;
    box-shadow: none;
    padding: 0px 7px
}
.docs-findinput-input,
.docs-findinput-input:focus {
    background: transparent!important;
    border: none!important;
    box-shadow: none!important;
    -moz-box-shadow: none!important;
    -webkit-box-shadow: none!important;
    font-size: 13px;
    height: 25px;
    margin: 0;
    outline: none!important;
    padding: 1px 0px!important;
    width: 100%
}
.docs-findinput-count-container {
    max-width: 120px;
    overflow: hidden;
    padding: 0 8px 0 4px;
    text-align: right
}
.docs-findinput-count {
    color: #ccc;
    white-space: nowrap
}
#fontSizeSelect .goog-toolbar-menu-button-caption,
#docs-font-size .goog-toolbar-menu-button-caption {
    overflow: hidden;
    text-overflow: ellipsis;
    width: 20px;
    white-space: nowrap
}
#fontSizeSelect .goog-toolbar-combo-button-caption,
#docs-font-size .goog-toolbar-combo-button-caption {
    width: 48px!important
}
#fontSizeSelect .goog-toolbar-combo-button-input,
#docs-font-size .goog-toolbar-combo-button-input {
    width: 28px
}
.hsv,
.hsva {
    position: relative;
    width: 182px;
    height: 185px
}
.hsv label span,
.hsva label span {
    display: none
}
.hsv-hs-backdrop,
.hsv-hs-image,
.hsva-hs-backdrop,
.hsva-hs-image {
    position: absolute;
    top: 45px;
    left: 10px;
    width: 128px;
    height: 128px;
    border: 1px solid #999
}
.hsv-hs-backdrop,
.hsva-hs-backdrop {
    background-color: #000
}
.hsv-hs-image,
.hsv-v-image,
.hsv-hs-handle,
.hsv-v-handle,
.hsva-hs-image,
.hsva-v-image,
.hsva-a-image,
.hsva-hs-handle,
.hsva-v-handle,
.hsva-a-handle,
.hsva-swatch-backdrop {
    background-image: url(//ssl.gstatic.com/docs/drawings/images/hsva-sprite-sm.png)
}
.hsv-noalpha .hsv-hs-image,
.hsv-noalpha .hsv-v-image,
.hsv-noalpha .hsv-hs-handle,
.hsv-noalpha .hsv-v-handle,
.hsva-noalpha .hsva-hs-image,
.hsva-noalpha .hsva-v-image,
.hsva-noalpha .hsva-a-image,
.hsva-noalpha .hsva-hs-handle,
.hsva-noalpha .hsva-v-handle,
.hsva-noalpha .hsva-a-handle,
.hsva-noalpha .hsva-swatch-backdrop {
    background-image: url(//ssl.gstatic.com/docs/drawings/images/hsva-sprite-sm.gif)
}
.hsv-hs-image,
.hsva-hs-image {
    background-position: 0 0
}
.hsv-hs-handle,
.hsva-hs-handle {
    position: absolute;
    left: 5px;
    top: 40px;
    width: 11px;
    height: 11px;
    overflow: hidden;
    background-position: 0 -128px
}
.hsv-v-image,
.hsva-v-image,
.hsva-a-image {
    position: absolute;
    top: 45px;
    left: 155px;
    width: 9px;
    height: 128px;
    border: 1px solid #999;
    background-color: #fff;
    background-position: -128px 0
}
.hsv-v-handle,
.hsva-v-handle,
.hsva-a-handle {
    position: absolute;
    top: 40px;
    left: 148px;
    width: 25px;
    height: 11px;
    background-position: -11px -128px;
    overflow: hidden
}
.hsv-swatch,
.hsva-swatch,
.hsva-swatch-backdrop {
    position: absolute;
    top: 10px;
    right: auto;
    left: 10px;
    width: 30px;
    height: 22px;
    border: 1px solid #999;
    background-color: #fff
}
.hsv-input,
.hsva-input {
    position: absolute;
    top: 10px;
    right: auto;
    left: 50px;
    width: 75px
}
.hsva {
    width: 205px
}
.hsva-a-image {
    left: 182px;
    background-position: -137px 0
}
.hsva-a-handle {
    left: 175px
}
.hsva-swatch,
.hsva-swatch-backdrop {
    background-position: -36px -128px
}
.hsva-swatch {
    z-index: 5
}
.hsva-swatch-backdrop {
    z-index: 1
}
.docs-loading-animation {
    width: 28px;
    height: 6px;
    position: absolute;
    margin: auto;
    bottom: 0;
    left: 0;
    right: 0;
    top: 0
}
.docs-loading-animation-dot-1,
.docs-loading-animation-dot-2,
.docs-loading-animation-dot-3 {
    background-color: rgba(0, 0, 0, .2);
    border-radius: 6px;
    display: inline-block;
    height: 6px;
    position: absolute;
    width: 6px
}
.docs-loading-animation-dot-1 {
    -webkit-animation: docs-loading-animation-pulse 1s ease-in-out infinite 0s;
    -moz-animation: docs-loading-animation-pulse 1s ease-in-out infinite 0s;
    -o-animation: docs-loading-animation-pulse 1s ease-in-out infinite 0s;
    animation: docs-loading-animation-pulse 1s ease-in-out infinite 0s;
    left: 0
}
.docs-loading-animation-dot-2 {
    -webkit-animation: docs-loading-animation-pulse 1s ease-in-out infinite .33s;
    -moz-animation: docs-loading-animation-pulse 1s ease-in-out infinite .33s;
    -o-animation: docs-loading-animation-pulse 1s ease-in-out infinite .33s;
    animation: docs-loading-animation-pulse 1s ease-in-out infinite .33s;
    left: 50%;
    margin-left: -3px
}
.docs-loading-animation-dot-3 {
    -webkit-animation: docs-loading-animation-pulse 1s ease-in-out infinite .66s;
    -moz-animation: docs-loading-animation-pulse 1s ease-in-out infinite .66s;
    -o-animation: docs-loading-animation-pulse 1s ease-in-out infinite .66s;
    animation: docs-loading-animation-pulse 1s ease-in-out infinite .66s;
    right: 0
}
@-webkit-keyframes docs-loading-animation-pulse {
    0%,
    40%,
    100% {
        background-color: rgba(0, 0, 0, .2);
        -webkit-transform: scale(1);
        -moz-transform: scale(1);
        -ms-transform: scale(1);
        -o-transform: scale(1);
        transform: scale(1)
    }
    15% {
        background-color: rgba(0, 0, 0, 1);
        -webkit-transform: scale(1.2);
        -moz-transform: scale(1.2);
        -ms-transform: scale(1.2);
        -o-transform: scale(1.2);
        transform: scale(1.2)
    }
}
@keyframes docs-loading-animation-pulse {
    0%,
    40%,
    100% {
        background-color: rgba(0, 0, 0, .2);
        -webkit-transform: scale(1);
        -moz-transform: scale(1);
        -ms-transform: scale(1);
        -o-transform: scale(1);
        transform: scale(1)
    }
    15% {
        background-color: rgba(0, 0, 0, 1);
        -webkit-transform: scale(1.2);
        -moz-transform: scale(1.2);
        -ms-transform: scale(1.2);
        -o-transform: scale(1.2);
        transform: scale(1.2)
    }
}
.docs-slidingdialog-button-close:focus {
    outline: 1px solid #4d90fe
}
.docs-gm-dialogs .docs-slidingdialog-close-container {
    padding-top: 3px;
    vertical-align: middle
}
.docs-gm-dialogs .docs-slidingdialog-close-container .goog-flat-button {
    cursor: pointer
}
.docs-gm-dialogs .docs-slidingdialog .docs-icon-close {
    opacity: 1
}
.docs-slidingdialog {
    background-color: #fff;
    border-bottom: 1px solid #d9d9d9;
    border-top: none;
    border-left: 1px solid #d9d9d9;
    border-right: 1px solid #d9d9d9;
    margin-top: -1px;
    padding: 10px 12px;
    outline: none
}
.docs-gm-dialogs .docs-slidingdialog {
    border-bottom-right-radius: 8px;
    border-bottom-left-radius: 8px;
    padding: 16px 12px
}
.docs-slidingdialog .jfk-textinput {
    border-top-color: #d9d9d9;
    margin-right: 0
}
.docs-slidingdialog .jfk-textinput:focus {
    border-top-color: #4d90fe
}
.docs-slidingdialog .goog-custom-button-inner-box {
    padding: 1px 2px 0 2px
}
.docs-slidingdialog .goog-custom-button {
    margin: -2px 0 0 0
}
.docs-slidingdialog .docs-icon-up,
.docs-slidingdialog .docs-icon-down,
.docs-slidingdialog .docs-icon-close,
.docs-slidingdialog .docs-icon-ellipsis,
.docs-slidingdialog .docs-icon-overflow-three-dots {
    opacity: .40
}
.docs-gm-dialogs .docs-slidingdialog .docs-icon-img {
    opacity: 1
}
.docs-slidingdialog .jfk-button {
    vertical-align: top
}
.docs-slidingdialog .goog-flat-button {
    background-color: transparent;
    border: 0;
    cursor: default;
    margin: 0;
    padding: 0
}
.docs-slidingdialog .goog-flat-button-hover {
    background-color: transparent
}
.docs-slidingdialog-holder {
    margin-top: -1px;
    overflow: hidden;
    position: absolute;
    right: 44px;
    z-index: 507;
    min-width: 300px
}
.docs-slidingdialog-wrapper {
    left: 0;
    position: relative;
    width: 100%
}
.jfk-button.docs-submenuitem-splitbutton {
    background-color: #eee;
    border-top: 1px solid #f2f2f2;
    border-bottom: 1px solid #f2f2f2;
    border-bottom-right-radius: 0;
    border-radius: 0;
    border-right: none!important;
    border-top-right-radius: 0;
    color: #6e6e6e;
    cursor: pointer;
    font-size: 70%;
    font-weight: normal;
    height: 57px;
    left: auto;
    line-height: 59px;
    margin: 0;
    min-height: 26px;
    min-width: 0;
    padding: 0;
    position: absolute;
    right: 0;
    top: 0;
    width: 34px;
    -moz-border-radius-topright: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-top-right-radius: 0;
    -webkit-border-bottom-right-radius: 0
}
.goog-menuitem.docs-submenuitem {
    border: none;
    border-bottom: 1px solid #e6e6e6;
    height: 59px;
    padding-top: 0;
    padding-bottom: 0
}
.goog-menuitem.docs-submenuitem .goog-menuitem-content {
    height: 59px;
    line-height: 59px
}
.goog-menuitem.docs-submenuitem .goog-menuitem-checkbox {
    height: 59px;
    top: 0
}

.docs-squarehandleselectionbox-border {
    position: absolute;
    border: 1px solid #0096fd;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    z-index: 30;
    background-color: rgba(0, 0, 0, 0)
}
.docs-squarehandleselectionbox-handle {
    position: absolute;
    border: 1px solid #fff;
    background-color: #0096fd;
    width: 7px;
    height: 7px;
    font-size: 0;
    z-index: 551
}
.docs-ui-toast {
    align-items: center;
    border-radius: 2px;
    display: flex;
    flex-direction: row;
    background-color: #323232;
    bottom: 24px;
    color: white;
    font-size: 14px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    left: 24px;
    line-height: 20px;
    min-width: 288px;
    max-width: 568px;
    outline: none;
    padding: 17px 24px;
    position: absolute;
    z-index: 999
}
.docs-gm-dialogs .docs-ui-toast {
    background-color: #202124;
    border-radius: 4px;
    box-shadow: 0 4px 8px 3px rgba(60, 64, 67, .15);
    color: #dadce0;
    padding: 16px 24px
}
.docs-ui-toast-content {
    flex-grow: 1;
    flex-shrink: 1;
    display: inline-block
}
.docs-ui-toast-control-bar {
    flex-grow: 0;
    flex-shrink: 0;
    color: #a1c2fa;
    cursor: pointer;
    display: inline-block;
    margin-left: 24px
}
.docs-gm-dialogs .docs-ui-toast-control-bar {
    color: #34a853
}
.docs-ui-toast-control {
    display: inline-block;
    outline: none;
    padding-left: 10px;
    font-weight: 500
}
.docs-gm-dialogs .docs-ui-toast-control {
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px;
    font-weight: 500;
    text-transform: none
}
.docs-ui-toast-close-bar {
    cursor: pointer;
    display: inline-block;
    margin-left: 24px
}
.docs-ui-toast-close {
    display: inline-block;
    background-color: transparent;
    border: 0
}
.goog-toolbar-combo-button {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    background: 0;
    border-color: transparent;
    border-style: solid;
    border-width: 1px;
    outline: none;
    padding: 0;
    height: 24px;
    color: #333;
    line-height: 24px;
    list-style: none;
    font-size: 11px;
    font-weight: 500;
    text-decoration: none;
    vertical-align: middle;
    cursor: default;
    top: 2px
}
.goog-toolbar-combo-button-outer-box,
.goog-toolbar-combo-button-inner-box {
    border: 0;
    vertical-align: top
}
.goog-toolbar-combo-button-outer-box {
    margin: 0;
    padding: 0
}
.goog-toolbar-combo-button-inner-box {
    padding: 0 2px;
    margin: 0 1px
}
.goog-toolbar-combo-button-hover {
    -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, .1);
    -moz-box-shadow: 0 1px 1px rgba(0, 0, 0, .1);
    box-shadow: 0 1px 1px rgba(0, 0, 0, .1);
    background-color: #f8f8f8;
    background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -o-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
    border-color: #c6c6c6!important;
    color: #222
}
.goog-toolbar-combo-button-active {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    background-color: #f6f6f6;
    background-image: -webkit-linear-gradient(top, #f6f6f6, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f6f6f6, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f6f6f6, #f1f1f1);
    background-image: -o-linear-gradient(top, #f6f6f6, #f1f1f1);
    background-image: linear-gradient(top, #f6f6f6, #f1f1f1);
    border-color: #c6c6c6
}
.goog-toolbar-combo-button-open {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, .1);
    background-color: #eee;
    background-image: -webkit-linear-gradient(top, #eee, #e0e0e0);
    background-image: -moz-linear-gradient(top, #eee, #e0e0e0);
    background-image: -ms-linear-gradient(top, #eee, #e0e0e0);
    background-image: -o-linear-gradient(top, #eee, #e0e0e0);
    background-image: linear-gradient(top, #eee, #e0e0e0);
    border-color: #ccc;
    color: #222
}
.goog-toolbar-combo-button-disabled {
    color: #222!important;
    opacity: 0.3;
    filter: alpha(opacity=30)
}
.goog-toolbar-combo-button-dropdown {
    background: url(//ssl.gstatic.com/ui/v1/disclosure/small-grey-disclosure-arrow-down.png) center no-repeat;
    float: right;
    margin: 9px 0 0 0px;
    padding: 0 0 0 1px;
    min-width: 7px;
    opacity: .8;
    vertical-align: middle;
    width: 5px;
    height: 7px;
    *float: none;
    *position: relative;
    *top: -3px
}
.goog-toolbar-combo-button-caption {
    padding: 0;
    margin: 0 0 0 -3px
}
.docs-toolbar-small-separator+div.goog-toolbar-combo-button {
    margin: 4px 1px 0 -1px
}
.goog-toolbar-combo-button-input {
    background: transparent;
    border: 1px solid transparent!important;
    color: #333;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif!important;
    font-size: 12px!important;
    font-weight: 500!important;
    height: 20px!important;
    overflow: hidden!important
}
.goog-toolbar-combo-button-hover .goog-toolbar-combo-button-input {
    border-right: 1px solid #d9d9d9!important
}
.goog-toolbar-combo-button-open .goog-toolbar-combo-button-input {
    background: transparent;
    border-right: 1px solid transparent!important
}
.goog-toolbar-combo-button-input:focus {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    -webkit-user-select: text!important;
    -moz-user-select: text!important;
    background: #fff;
    border: 1px solid #4d90fe!important;
    height: 20px;
    outline: none
}
.docs-toolbar-zoom-combobox .goog-toolbar-menu-button-caption {
    overflow: hidden;
    text-overflow: ellipsis;
    width: 20px;
    white-space: nowrap
}
.docs-toolbar-zoom-combobox .goog-toolbar-combo-button-caption {
    width: 48px!important
}
.docs-toolbar-zoom-combobox .goog-toolbar-combo-button-input {
    width: 28px
}
.docs-material-dialog {
    background: #fff;
    border-radius: 2px;
    border: none;
    box-shadow: 0px 16px 24px 2px rgba(0, 0, 0, 0.14), 0px 6px 30px 5px rgba(0, 0, 0, 0.12), 0px 8px 10px -5px rgba(0, 0, 0, 0.2);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    position: absolute;
    z-index: 1003
}
.docs-material-dialog-bg {
    background-color: #000;
    left: 0;
    position: absolute;
    top: 0;
    z-index: 1002
}
.docs-material-dialog:focus {
    outline: none
}
.docs-material-dialog-title {
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    padding: 24px 24px 20px 24px
}
.docs-material-dialog-title-draggable {
    cursor: move
}
.docs-material-dialog-title-text {
    font: 500 21px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    padding-right: 38px
}
.docs-material-dialog-title-close {
    border: 1px solid transparent;
    border-radius: 2px;
    box-sizing: border-box;
    cursor: pointer;
    display: block;
    height: 20px;
    opacity: 0.54;
    position: absolute;
    right: 24px;
    top: 26px;
    width: 20px
}
.docs-material-dialog-title-close:focus {
    border-color: #4285f4;
    opacity: 1.0;
    outline: none
}
.docs-material-dialog-title-close:hover {
    opacity: 1.0
}
.docs-material-dialog-content {
    padding: 24px
}
.docs-material-dialog-buttons {
    float: right;
    padding: 8px 4px 14px 4px
}
.docs-material-dialog-buttons:after {
    clear: both;
    content: "";
    display: block;
    height: 0;
    width: 0
}
.docs-material-gm-dialog {
    background-color: #fff;
    border: 1px solid transparent;
    border-radius: 8px;
    box-shadow: 0 4px 8px 3px rgba(60, 64, 67, .15);
    position: absolute;
    z-index: 1003
}
.docs-material-gm-dialog-bg {
    background-color: #000;
    left: 0;
    position: absolute;
    top: 0;
    z-index: 1002
}
.docs-material-gm-dialog:focus {
    outline: none
}
.docs-material-gm-dialog-title {
    border-bottom: none;
    padding: 24px
}
.docs-material-gm-dialog-title-text {
    color: #202124;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 22px;
    font-weight: 400;
    line-height: 28px
}
.docs-material-gm-dialog-title-close {
    height: 24px;
    position: absolute;
    right: 24px;
    top: 26px;
    width: 24px
}
.docs-material-gm-dialog-content {
    min-width: 312px;
    padding: 0px 24px 24px
}
.docs-material-gm-dialog-buttons {
    display: flex;
    justify-content: flex-end;
    padding: 24px
}
.docs-material-gm-dialog .docs-material-button-fill-primary.docs-material-button {
    margin-left: 12px;
    text-transform: none
}
.docs-material-gm-dialog .docs-material-button-hairline-default.docs-material-button {
    text-transform: none
}
.docs-charts-editor-material-color-picker {
    color: rgba(0, 0, 0, 0.87);
    cursor: pointer;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    line-height: 21px;
    outline: none;
    width: 100%
}
.docs-charts-editor-material-color-picker-disabled {
    color: rgba(0, 0, 0, 0.12);
    cursor: default
}
.docs-charts-editor-material-color-picker-outer-box {
    -webkit-transition: border-color 0.3s ease;
    -moz-transition: border-color 0.3s ease;
    -o-transition: border-color 0.3s ease;
    transition: border-color 0.3s ease;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    margin-bottom: 1px;
    padding-bottom: 5px;
    width: 100%
}
.docs-charts-editor-material-color-picker-hover .docs-charts-editor-material-color-picker-outer-box,
.docs-charts-editor-material-color-picker-focused .docs-charts-editor-material-color-picker-outer-box {
    border-bottom-color: rgba(0, 0, 0, 0.38)
}
.docs-charts-editor-material-color-picker-open .docs-charts-editor-material-color-picker-outer-box {
    border-bottom-width: 2px;
    border-bottom-color: #4285f4;
    margin-bottom: 0px
}
.docs-charts-editor-material-color-picker-inner-box {
    width: 100%
}
.docs-charts-editor-material-color-picker-disabled .docs-charts-editor-material-color-picker-outer-box {
    border-bottom: 1px dotted rgba(0, 0, 0, 0.12)
}
.docs-charts-editor-material-color-picker-indicator {
    border: 1px solid rgba(0, 0, 0, 0.12);
    border-radius: 2px;
    float: left;
    height: 20px;
    margin-top: 6px;
    position: relative;
    top: 1px;
    width: 20px
}
.docs-charts-editor-material-color-picker-text {
    overflow: hidden;
    padding-left: 4px;
    padding-right: 28px;
    position: relative;
    text-overflow: ellipsis;
    top: 10px;
    vertical-align: middle;
    white-space: nowrap
}
.docs-charts-editor-material-color-picker-dropdown {
    position: absolute;
    right: 8px;
    top: 0px
}
.docs-charts-editor-material-color-picker-dropdown-icon {
    -webkit-transition: opacity 0.3s ease;
    -moz-transition: opacity 0.3s ease;
    -o-transition: opacity 0.3s ease;
    transition: opacity 0.3s ease;
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI1IiBoZWlnaHQ9IjMiPjxwb2x5Z29uIHBvaW50cz0iMCwwIDUsMCAyLjUsMyIgZmlsbD0iIzAwMCIvPjwvc3ZnPg==") no-repeat;
    background-size: contain;
    height: 8px;
    opacity: 0.38;
    position: relative;
    top: 19px;
    width: 8px
}
.docs-gm .docs-charts-editor-material-color-picker-dropdown-icon {
    opacity: 1
}
.docs-charts-editor-material-color-picker-hover .docs-charts-editor-material-color-picker-dropdown-icon,
.docs-charts-editor-material-color-picker-focused .docs-charts-editor-material-color-picker-dropdown-icon {
    opacity: 0.54
}
.docs-gm .docs-charts-editor-material-color-picker-hover .docs-charts-editor-material-color-picker-dropdown-icon,
.docs-gm .docs-charts-editor-material-color-picker-focused .docs-charts-editor-material-color-picker-dropdown-icon {
    opacity: 1
}
.docs-charts-editor-material-color-picker-disabled .docs-charts-editor-material-color-picker-dropdown-icon {
    opacity: 0.12
}
.docs-gm .docs-charts-editor-material-color-picker-disabled .docs-gm .docs-charts-editor-material-color-picker-dropdown-icon {
    opacity: .38
}
.docs-charts-editor-material-combo-box {
    height: 26px;
    line-height: 26px;
    outline: 0;
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-combo-box {
    height: 42px;
    line-height: 42px
}
.docs-charts-editor-material-combo-box-disabled {
    cursor: default
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-combo-box-disabled {
    color: #5f6368;
    opacity: .38;
    cursor: default
}
.docs-charts-editor-material-combo-box .docs-charts-editor-material-combo-box-outer-box {
    -webkit-transition: border-color 0.3s ease;
    -moz-transition: border-color 0.3s ease;
    -o-transition: border-color 0.3s ease;
    transition: border-color 0.3s ease;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    height: 26px;
    line-height: 26px;
    margin-bottom: 1px;
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-combo-box .docs-charts-editor-material-combo-box-outer-box {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    cursor: pointer;
    padding: 8px 6px 8px 8px;
    width: 100%;
    height: 42px;
    line-height: 42px;
    padding: 8px
}
.docs-charts-editor-material-combo-box-hover .docs-charts-editor-material-combo-box-outer-box,
.docs-charts-editor-material-combo-box-focused .docs-charts-editor-material-combo-box-outer-box {
    border-bottom-color: rgba(0, 0, 0, 0.38)
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-combo-box-hover .docs-charts-editor-material-combo-box-outer-box {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid #dadce0
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-combo-box-focused .docs-charts-editor-material-combo-box-outer-box {
    background-color: rgba(60, 64, 67, 0.06);
    border: 1px solid #dadce0
}
.docs-charts-editor-material-combo-box-open .docs-charts-editor-material-combo-box-outer-box {
    border-bottom-width: 2px;
    border-bottom-color: #4285f4;
    margin-bottom: 0px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-combo-box-open .docs-charts-editor-material-combo-box-outer-box {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid transparent
}
.docs-charts-editor-material-combo-box-disabled .docs-charts-editor-material-combo-box-outer-box {
    border-bottom: 1px dotted rgba(0, 0, 0, 0.12)
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-combo-box-disabled .docs-charts-editor-material-combo-box-outer-box {
    border: 1px solid #dadce0;
    cursor: default
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-combo-box-inner-box {
    align-items: center;
    display: flex;
    justify-content: space-between;
    position: relative;
    width: 100%;
    height: 100%
}
.docs-charts-editor-material-combo-box-inner-box {
    width: 100%
}
.docs-charts-editor-material-combo-box-caption {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    padding-right: 28px;
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-combo-box-caption {
    padding-right: 0
}
.docs-charts-editor-material-combo-box-input,
.docs-charts-editor-material-combo-box-input:focus {
    background: none;
    border: none;
    box-shadow: none;
    color: rgba(0, 0, 0, 0.87);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    height: 26px;
    line-height: 26px;
    padding: 0;
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-combo-box-caption .docs-charts-editor-material-combo-box-input,
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-combo-box-caption .docs-charts-editor-material-combo-box-input:focus {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    height: 20px;
    line-height: 20px;
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    border: none;
    padding: 0
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-combo-box-disabled .docs-charts-editor-material-combo-box-input {
    color: rgba(0, 0, 0, 0.26)
}
.docs-charts-editor-material-combo-box-disabled .docs-charts-editor-material-combo-box-input {
    background: none;
    color: rgba(0, 0, 0, 0.12);
    cursor: default
}
.docs-charts-editor-material-combo-box-dropdown {
    position: absolute;
    right: 8px;
    top: 10px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-combo-box-dropdown {
    align-items: center;
    display: flex;
    height: 24px;
    justify-content: center;
    width: 24px;
    position: static
}
.docs-charts-editor-material-combo-box-dropdown-icon {
    -webkit-transition: opacity 0.3s ease;
    -moz-transition: opacity 0.3s ease;
    -o-transition: opacity 0.3s ease;
    transition: opacity 0.3s ease;
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI1IiBoZWlnaHQ9IjMiPjxwb2x5Z29uIHBvaW50cz0iMCwwIDUsMCAyLjUsMyIgZmlsbD0iIzAwMCIvPjwvc3ZnPg==") no-repeat;
    background-size: contain;
    cursor: pointer;
    height: 8px;
    opacity: 0.38;
    width: 8px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-combo-box-dropdown-icon {
    background: no-repeat url(//ssl.gstatic.com/docs/common/material_common_sprite134_grey_medium.svg) 0 -1364px;
    height: 18px;
    width: 18px;
    opacity: 1
}
.docs-charts-editor-material-combo-box-hover .docs-charts-editor-material-combo-box-dropdown-icon,
.docs-charts-editor-material-combo-box-focused .docs-charts-editor-material-combo-box-dropdown-icon {
    opacity: 0.54
}
.docs-charts-editor-material-combo-box-disabled .docs-charts-editor-material-combo-box-dropdown-icon {
    opacity: 0.12
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-combo-box-disabled .docs-charts-editor-material-combo-box-dropdown-icon {
    opacity: .26
}
.docs-charts-editor-material-icon-menu-button {
    cursor: pointer;
    height: 26px;
    margin: 0;
    min-width: 40px;
    outline: none;
    user-select: none
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-icon-menu-button {
    height: auto;
    min-width: 34px
}
.docs-charts-editor-material-icon-menu-button-disabled {
    cursor: default
}
.docs-charts-editor-material-icon-menu-button .docs-icon-img {
    -webkit-transition: opacity 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: opacity 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: opacity 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: opacity 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    opacity: 0.54
}
.docs-gm .docs-charts-editor-material-icon-menu-button .docs-icon-img {
    opacity: 1.0
}
.docs-charts-editor-material-icon-menu-button-disabled .docs-icon-img {
    opacity: 0.12
}
.docs-gm .docs-charts-editor-material-icon-menu-button-disabled .docs-icon-img {
    opacity: .38
}
.docs-charts-editor-material-icon-menu-button-outer-box {
    -webkit-transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    background: rgba(0, 0, 0, 0.04);
    border-radius: 1px;
    height: 26px;
    line-height: 26px;
    margin-right: 4px;
    padding: 0px 4px;
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-icon-menu-button-outer-box {
    background: #fff;
    border: 2px solid #fff;
    border-radius: 4px;
    height: 100%;
    line-height: 34px;
    margin-right: 0;
    padding: 0
}
.docs-charts-editor-material-icon-menu-button-open .docs-charts-editor-material-icon-menu-button-outer-box {
    background: rgba(0, 0, 0, 0.12)
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-icon-menu-button-open .docs-charts-editor-material-icon-menu-button-outer-box {
    background: #e6f4ea
}
.docs-charts-editor-material-icon-menu-button-inner-box {
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-icon-menu-button-caption {
    margin-left: 2px
}
.docs-charts-editor-material-icon-menu-button-dropdown {
    position: absolute;
    right: 0;
    top: 0
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-icon-menu-button-dropdown {
    left: 15px
}
.docs-charts-editor-material-icon-menu-button-dropdown-icon {
    -webkit-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI1IiBoZWlnaHQ9IjMiPjxwb2x5Z29uIHBvaW50cz0iMCwwIDUsMCAyLjUsMyIgZmlsbD0iIzAwMCIvPjwvc3ZnPg==") no-repeat;
    background-size: contain;
    height: 8px;
    opacity: 0.54;
    position: relative;
    top: 9px;
    width: 8px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-icon-menu-button-dropdown-icon {
    background: no-repeat url(//ssl.gstatic.com/docs/common/material_common_sprite134_grey_medium.svg) 0 -1364px;
    height: 18px;
    opacity: 1;
    width: 18px
}
.docs-charts-editor-material-icon-menu-button-focused .docs-charts-editor-material-icon-menu-button-dropdown-icon,
.docs-charts-editor-material-icon-menu-button-open .docs-charts-editor-material-icon-menu-button-dropdown-icon {
    opacity: 0.87
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-icon-menu-button-open .docs-icon-img {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_green.svg)
}
.docs-gm .docs-charts-editor-material-icon-menu-button-focused .docs-gm .docs-charts-editor-material-icon-menu-button-dropdown-icon,
.docs-gm .docs-charts-editor-material-icon-menu-button-open .docs-gm .docs-charts-editor-material-icon-menu-button-dropdown-icon {
    opacity: 1
}
.docs-charts-editor-material-icon-menu-button-disabled .docs-charts-editor-material-icon-menu-button-dropdown-icon {
    opacity: 0.12
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-icon-menu-button-disabled .docs-charts-editor-material-icon-menu-button-dropdown-icon {
    opacity: .26
}
.docs-gm .docs-charts-editor-material-icon-menu-button-disabled .docs-gm .docs-charts-editor-material-icon-menu-button-dropdown-icon {
    opacity: .38
}
.docs-charts-editor-material-menu-button {
    color: rgba(0, 0, 0, 0.87);
    cursor: pointer;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    height: 26px;
    line-height: 26px;
    outline: 0;
    width: 100%
}
.docs-charts-editor-material-menu-button-disabled {
    color: rgba(0, 0, 0, 0.12);
    cursor: default
}
.docs-charts-editor-material-menu-button-outer-box {
    -webkit-transition: border-color 0.3s ease;
    -moz-transition: border-color 0.3s ease;
    -o-transition: border-color 0.3s ease;
    transition: border-color 0.3s ease;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    height: 26px;
    line-height: 26px;
    margin-bottom: 1px;
    width: 100%
}
.docs-charts-editor-material-menu-button-hover .docs-charts-editor-material-menu-button-outer-box,
.docs-charts-editor-material-menu-button-focused .docs-charts-editor-material-menu-button-outer-box {
    border-bottom-color: rgba(0, 0, 0, 0.38)
}
.docs-charts-editor-material-menu-button-open .docs-charts-editor-material-menu-button-outer-box {
    border-bottom-width: 2px;
    border-bottom-color: #4285f4;
    margin-bottom: 0px
}
.docs-charts-editor-material-menu-button-disabled .docs-charts-editor-material-menu-button-outer-box {
    border-bottom: 1px dotted rgba(0, 0, 0, 0.12)
}
.docs-charts-editor-material-menu-button-inner-box {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    width: 100%
}
.docs-charts-editor-material-menu-button-caption {
    display: inline-block;
    line-height: 26px;
    overflow: hidden;
    padding-right: 28px;
    position: relative;
    text-overflow: ellipsis;
    white-space: nowrap;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1
}
.docs-charts-editor-material-menu-button-dropdown {
    position: absolute;
    right: 8px;
    top: 10px;
    white-space: nowrap
}
.docs-charts-editor-material-menu-button-dropdown-icon {
    -webkit-transition: opacity 0.3s ease;
    -moz-transition: opacity 0.3s ease;
    -o-transition: opacity 0.3s ease;
    transition: opacity 0.3s ease;
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI1IiBoZWlnaHQ9IjMiPjxwb2x5Z29uIHBvaW50cz0iMCwwIDUsMCAyLjUsMyIgZmlsbD0iIzAwMCIvPjwvc3ZnPg==") no-repeat;
    background-size: contain;
    height: 8px;
    opacity: 0.38;
    width: 8px
}
.docs-charts-editor-material-menu-button-hover .docs-charts-editor-material-menu-button-dropdown-icon,
.docs-charts-editor-material-menu-button-focused .docs-charts-editor-material-menu-button-dropdown-icon {
    opacity: 0.54
}
.docs-gm .docs-charts-editor-material-menu-button-hover .docs-charts-editor-material-menu-button-dropdown-icon,
.docs-gm .docs-charts-editor-material-menu-button-focused .docs-charts-editor-material-menu-button-dropdown-icon {
    opacity: 1
}
.docs-charts-editor-material-menu-button-disabled .docs-charts-editor-material-menu-button-dropdown-icon {
    opacity: 0.12
}
.docs-gm .docs-charts-editor-material-menu-button-disabled .docs-gm .docs-charts-editor-material-menu-button-dropdown-icon {
    opacity: .38
}
.docs-charts-editor-material-text-area textarea {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    -webkit-transition: border-bottom-color 0.3s ease;
    -moz-transition: border-bottom-color 0.3s ease;
    -o-transition: border-bottom-color 0.3s ease;
    transition: border-bottom-color 0.3s ease;
    background: none;
    border: none;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    color: rgba(0, 0, 0, 0.87);
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    height: 26px;
    line-height: 26px;
    min-height: 26px;
    outline: none;
    padding: 0;
    width: 100%;
    resize: none;
    white-space: pre;
    overflow-wrap: normal;
    overflow-y: scroll;
    overflow-x: hidden
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-text-area textarea {
    -webkit-transition: border-color 0.3s ease;
    -moz-transition: border-color 0.3s ease;
    -o-transition: border-color 0.3s ease;
    transition: border-color 0.3s ease;
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 400;
    height: 42px;
    line-height: 36px;
    min-height: 42px
}
.docs-charts-editor-material-text-area textarea::placeholder {
    color: rgba(0, 0, 0, 0.38)
}
.docs-charts-editor-material-text-area textarea::-webkit-input-placeholder {
    color: rgba(0, 0, 0, 0.38)
}
.docs-charts-editor-material-text-area textarea::-moz-placeholder {
    color: rgba(0, 0, 0, 0.38)
}
.docs-charts-editor-material-text-area textarea:-ms-input-placeholder {
    color: rgba(0, 0, 0, 0.38)
}
.docs-charts-editor-material-text-area textarea::-ms-input-placeholder {
    color: rgba(0, 0, 0, 0.38)
}
.docs-charts-editor-material-text-area textarea:hover,
.docs-charts-editor-material-text-area-hover textarea {
    border-bottom-color: rgba(0, 0, 0, 0.38)
}
.docs-charts-editor-material-text-area textarea:focus,
.docs-charts-editor-material-text-area-focus textarea {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    border: none;
    border-bottom: 2px solid #4285f4
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-text-area textarea:focus,
.docs-charts-editor-material-text-area-focus textarea {
    border: 2px solid #4285f4
}
.docs-charts-editor-material-text-area textarea:disabled,
.docs-charts-editor-material-text-area-disabled textarea {
    background: none;
    border-bottom: 1px dotted rgba(0, 0, 0, 0.12);
    color: rgba(0, 0, 0, 0.12)
}
.docs-charts-editor-material-textbutton {
    -webkit-transition: background 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: background 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: background 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: background 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    background: rgba(0, 0, 0, 0.04);
    border-radius: 2px;
    cursor: pointer;
    height: 26px;
    margin-right: 4px;
    outline: none;
    padding: 4px;
    text-align: center
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-textbutton {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #dadce0!important;
    color: #188038;
    height: 24px;
    padding: 3px 12px 5px;
    margin-right: 0
}
.docs-charts-editor-material-textbutton-label {
    color: #2196f3;
    font-size: 12px;
    text-transform: uppercase
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-textbutton-label {
    color: #188038;
    font-size: 14px;
    letter-spacing: .25px;
    line-height: 14px;
    text-transform: none
}
.docs-charts-editor-material-textbutton-outer-box {
    vertical-align: -webkit-baseline-middle
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-textbutton-outer-box {
    vertical-align: baseline
}
.docs-charts-editor-material-textbutton-hover,
.docs-charts-editor-material-textbutton-focused {}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-textbutton-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #f8fcf9;
    border: 1px solid #c8e7d1!important;
    height: 24px;
    padding: 3px 12px 5px
}
.docs-charts-editor-material-textbutton-checked {
    background: rgba(0, 0, 0, 0.12)
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-textbutton-checked {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    border: 1px solid transparent!important;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    height: 24px;
    padding: 3px 12px 5px
}
.docs-charts-editor-material-textbutton-disabled {
    cursor: default
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-textbutton-disabled {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #f1f3f4!important;
    color: #3c4043;
    opacity: 0.38;
    height: 24px;
    padding: 3px 12px 5px
}
.docs-charts-editor-material-textbutton .docs-icon-img {
    -webkit-transition: opacity 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: opacity 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: opacity 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: opacity 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    opacity: 0.54
}
.docs-gm .docs-charts-editor-material-textbutton .docs-icon-img {
    opacity: 1
}
.docs-charts-editor-material-textbutton-focused .docs-icon-img,
.docs-charts-editor-material-textbutton-checked .docs-icon-img {
    opacity: 0.87
}
.docs-gm .docs-charts-editor-material-textbutton-focused .docs-icon-img,
.docs-gm .docs-charts-editor-material-textbutton-checked .docs-icon-img {
    opacity: 1
}
.docs-charts-editor-material-textbutton-disabled .docs-icon-img {
    opacity: 0.12
}
.docs-gm .docs-charts-editor-material-textbutton-disabled .docs-icon-img {
    opacity: .38
}
.docs-charts-editor-material-text-input input {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    -webkit-transition: border-bottom-color 0.3s ease;
    -moz-transition: border-bottom-color 0.3s ease;
    -o-transition: border-bottom-color 0.3s ease;
    transition: border-bottom-color 0.3s ease;
    background: none;
    border: none;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    color: rgba(0, 0, 0, 0.87);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    height: 26px;
    line-height: 26px;
    outline: none;
    padding: 0;
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-text-input .jfk-textinput {
    -webkit-transition: border-color 0.3s ease;
    -moz-transition: border-color 0.3s ease;
    -o-transition: border-color 0.3s ease;
    transition: border-color 0.3s ease;
    height: 42px;
    line-height: 42px;
    margin: 0
}
.docs-charts-editor-material-text-input input::placeholder {
    color: rgba(0, 0, 0, 0.38)
}
.docs-charts-editor-material-text-input input::-webkit-input-placeholder {
    color: rgba(0, 0, 0, 0.38)
}
.docs-charts-editor-material-text-input input::-moz-placeholder {
    color: rgba(0, 0, 0, 0.38)
}
.docs-charts-editor-material-text-input input:-ms-input-placeholder {
    color: rgba(0, 0, 0, 0.38)
}
.docs-charts-editor-material-text-input input::-ms-input-placeholder {
    color: rgba(0, 0, 0, 0.38)
}
.docs-charts-editor-material-text-input input:hover,
.docs-charts-editor-material-text-input-hover input {
    border-bottom-color: rgba(0, 0, 0, 0.38)
}
.docs-charts-editor-material-text-input input:focus,
.docs-charts-editor-material-text-input-focus input {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    border: none;
    border-bottom: 2px solid #4285f4
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-text-input input:focus,
.docs-charts-editor-material-text-input-focus input {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    border: 2px solid #4285f4
}
.docs-charts-editor-material-text-input input:disabled,
.docs-charts-editor-material-text-input-disabled input {
    background: none;
    border-bottom: 1px dotted rgba(0, 0, 0, 0.12);
    color: rgba(0, 0, 0, 0.12)
}
.docs-charts-editor-material-togglebutton {
    -webkit-transition: background 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: background 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: background 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: background 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    background: rgba(0, 0, 0, 0.04);
    border-radius: 2px;
    cursor: pointer;
    height: 26px;
    line-height: 26px;
    margin-right: 4px;
    outline: none;
    text-align: center;
    width: 26px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-togglebutton {
    background: #fff;
    border: 2px solid #fff;
    border-radius: 4px;
    height: 34px;
    line-height: 34px;
    margin-right: 0;
    width: 30px
}
.docs-charts-editor-material-togglebutton-hover,
.docs-charts-editor-material-togglebutton-focused {}
.docs-charts-editor-material-togglebutton-checked {
    background: rgba(0, 0, 0, 0.12)
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-togglebutton-checked {
    background: #e6f4ea
}
.docs-charts-editor-material-togglebutton-checked.docs-charts-editor-material-togglebutton-hover,
.docs-charts-editor-material-togglebutton-checked.docs-charts-editor-material-togglebutton-focused {}
.docs-charts-editor-material-togglebutton-checked.docs-charts-editor-material-togglebutton-active {}
.docs-charts-editor-material-togglebutton-disabled {
    cursor: default
}
.docs-charts-editor-material-togglebutton .docs-icon-img {
    -webkit-transition: opacity 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: opacity 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: opacity 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: opacity 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    opacity: 0.54
}
.docs-gm .docs-charts-editor-material-togglebutton .docs-icon-img {
    opacity: 1
}
.docs-charts-editor-material-togglebutton-focused .docs-icon-img,
.docs-charts-editor-material-togglebutton-checked .docs-icon-img {
    opacity: 0.87
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-togglebutton-checked .docs-icon-img {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_green.svg)
}
.docs-gm .docs-charts-editor-material-togglebutton-focused .docs-icon-img,
.docs-gm .docs-charts-editor-material-togglebutton-checked .docs-icon-img {
    opacity: 1
}
.docs-charts-editor-material-togglebutton-disabled .docs-icon-img {
    opacity: 0.12
}
.docs-gm .docs-charts-editor-material-togglebutton-disabled .docs-icon-img {
    opacity: .38
}
.docs-charts-editor-material-toolbar-color-picker {
    cursor: pointer;
    height: 26px;
    min-width: 40px;
    outline: none;
    user-select: none
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-toolbar-color-picker {
    color: #3c4043;
    outline: none;
    width: 100%;
    height: 42px;
    max-width: 100%;
    width: auto
}
.docs-charts-editor-material-toolbar-color-picker-disabled {
    cursor: default
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-toolbar-color-picker-disabled {
    color: #5f6368;
    opacity: .38;
    cursor: default
}
.docs-charts-editor-material-toolbar-color-picker-outer-box {
    -webkit-transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: background 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    background: rgba(0, 0, 0, 0.04);
    border-radius: 2px;
    height: 100%;
    padding: 2px 4px;
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-toolbar-color-picker-outer-box {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    cursor: pointer;
    padding: 8px 6px 8px 8px;
    width: 100%;
    background: #fff;
    max-width: 100%;
    width: auto
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-toolbar-color-picker-hover .docs-charts-editor-material-toolbar-color-picker-outer-box {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid #dadce0
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-toolbar-color-picker-disabled .docs-charts-editor-material-toolbar-color-picker-outer-box {
    border: 1px solid #dadce0;
    cursor: default
}
.docs-charts-editor-material-toolbar-color-picker-open .docs-charts-editor-material-toolbar-color-picker-outer-box {
    background: rgba(0, 0, 0, 0.12)
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-toolbar-color-picker-open .docs-charts-editor-material-toolbar-color-picker-outer-box {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid transparent
}
.docs-charts-editor-material-toolbar-color-picker-inner-box {
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-toolbar-color-picker-inner-box {
    align-items: center;
    display: flex;
    justify-content: space-between;
    position: relative;
    width: 100%;
    height: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-toolbar-color-picker-content-container {
    width: 80%
}
.docs-charts-editor-material-toolbar-color-picker-indicator {
    border-bottom: 3px solid transparent;
    height: 18px;
    width: 22px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-toolbar-color-picker-indicator {
    height: 22px;
    width: 22px;
    border-radius: 50%;
    border: 1px solid #dadce0;
    margin: 0;
    outline: none
}
.docs-charts-editor-material-toolbar-color-picker-disabled .docs-charts-editor-material-toolbar-color-picker-indicator {
    opacity: 0.12
}
.docs-gm .docs-charts-editor-material-toolbar-color-picker-disabled .docs-charts-editor-material-toolbar-color-picker-indicator {
    opacity: .38
}
.docs-charts-editor-material-toolbar-color-picker-indicator .docs-icon {
    -webkit-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -webkit-transform: scale(0.9);
    -moz-transform: scale(0.9);
    -ms-transform: scale(0.9);
    -o-transform: scale(0.9);
    transform: scale(0.9);
    height: 14px;
    left: 1px;
    opacity: 0.54;
    width: 18px
}
.docs-gm .docs-charts-editor-material-toolbar-color-picker-indicator .docs-icon {
    opacity: 1
}
.docs-charts-editor-material-toolbar-color-picker-focused .docs-charts-editor-material-toolbar-color-picker-indicator .docs-icon,
.docs-charts-editor-material-toolbar-color-picker-open .docs-charts-editor-material-toolbar-color-picker-indicator .docs-icon {
    opacity: 0.87
}
.docs-gm .docs-charts-editor-material-toolbar-color-picker-focused .docs-charts-editor-material-toolbar-color-picker-indicator .docs-icon,
.docs-gm .docs-charts-editor-material-toolbar-color-picker-open .docs-charts-editor-material-toolbar-color-picker-indicator .docs-icon {
    opacity: 1
}
.docs-charts-editor-material-toolbar-color-picker-text {
    -webkit-transition: color 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: color 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: color 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: color 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    color: rgba(0, 0, 0, 0.54);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 11px;
    padding: 3px 8px 3px 2px;
    top: 1px
}
.docs-gm .docs-charts-editor-material-toolbar-color-picker-text {
    color: rgba(0, 0, 0, 0.87)
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-toolbar-color-picker-text {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    height: 20px;
    line-height: 20px;
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    height: 100%;
    padding: 3px 5px;
    max-width: 65%
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-toolbar-color-picker-caption {
    height: 100%
}
.docs-charts-editor-material-toolbar-color-picker-focused .docs-charts-editor-material-toolbar-color-picker-text,
.docs-charts-editor-material-toolbar-color-picker-open .docs-charts-editor-material-toolbar-color-picker-text {
    color: rgba(0, 0, 0, 0.87)
}
.docs-charts-editor-material-toolbar-color-picker-disabled .docs-charts-editor-material-toolbar-color-picker-text {
    color: rgba(0, 0, 0, 0.12)
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-toolbar-color-picker-disabled .docs-charts-editor-material-toolbar-color-picker-text {
    color: rgba(0, 0, 0, 0.26)
}
.docs-charts-editor-material-toolbar-color-picker-dropdown {
    float: right
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-toolbar-color-picker-dropdown {
    align-items: center;
    display: flex;
    height: 24px;
    justify-content: center;
    width: 24px
}
.docs-charts-editor-material-toolbar-color-picker-dropdown-icon {
    -webkit-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI1IiBoZWlnaHQ9IjMiPjxwb2x5Z29uIHBvaW50cz0iMCwwIDUsMCAyLjUsMyIgZmlsbD0iIzAwMCIvPjwvc3ZnPg==") no-repeat;
    background-size: contain;
    height: 8px;
    opacity: 0.54;
    position: relative;
    top: 9px;
    width: 8px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-toolbar-color-picker-dropdown-icon {
    background: no-repeat url(//ssl.gstatic.com/docs/common/material_common_sprite134_grey_medium.svg) 0 -1364px;
    height: 18px;
    width: 18px;
    opacity: 1;
    top: 0
}
.docs-charts-editor-material-toolbar-color-picker-focused .docs-charts-editor-material-toolbar-color-picker-dropdown-icon,
.docs-charts-editor-material-toolbar-color-picker-open .docs-charts-editor-material-toolbar-color-picker-dropdown-icon {
    opacity: 0.87
}
.docs-gm .docs-charts-editor-material-toolbar-color-picker-focused .docs-charts-editor-material-toolbar-color-picker-dropdown-icon,
.docs-gm .docs-charts-editor-material-toolbar-color-picker-open .docs-charts-editor-material-toolbar-color-picker-dropdown-icon {
    opacity: 1
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-material-toolbar-color-picker-open .docs-charts-editor-material-toolbar-color-picker-dropdown-icon {
    -moz-transform: rotate(180deg);
    -webkit-transform: rotate(180deg);
    -ms-transform: rotate(180deg);
    transform: rotate(180deg)
}
.docs-charts-editor-material-toolbar-color-picker-disabled .docs-charts-editor-material-toolbar-color-picker-dropdown-icon {
    opacity: 0.12
}
.docs-gm .docs-charts-editor-material-toolbar-color-picker-disabled .docs-charts-editor-material-toolbar-color-picker-dropdown-icon {
    opacity: .38
}
.docs-charts-editor-overflow-menu-button {
    outline: none;
    cursor: pointer
}
.docs-charts-editor-overflow-menu-button-icon {
    -webkit-transition: opacity 0.3s ease;
    -moz-transition: opacity 0.3s ease;
    -o-transition: opacity 0.3s ease;
    transition: opacity 0.3s ease;
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyMCIgdmlld2JveD0iMCAwIDIwIDIwIiBoZWlnaHQ9IjIwIj48cGF0aCBkPSJtMTAgNmMxLjEgMCAyLTAuOSAyLTJzLTAuOS0yLTItMi0yIDAuOS0yIDIgMC45IDIgMiAyem0wIDJjLTEuMSAwLTIgMC45LTIgMnMwLjkgMiAyIDIgMi0wLjkgMi0yLTAuOS0yLTItMnptMCA2Yy0xLjEgMC0yIDAuOS0yIDJzMC45IDIgMiAyIDItMC45IDItMi0wLjktMi0yLTJ6Ii8+PC9zdmc+") no-repeat;
    opacity: 0.38;
    height: 21px;
    position: relative;
    right: 5px;
    top: 6px;
    width: 21px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-overflow-menu-button-icon {
    right: 12px;
    top: 7px
}
.docs-charts-editor-overflow-menu-button-hover .docs-charts-editor-overflow-menu-button-icon,
.docs-charts-editor-overflow-menu-button-focused .docs-charts-editor-overflow-menu-button-icon {
    opacity: 0.54
}
.docs-charts-editor-overflow-menu-button-disabled .docs-charts-editor-overflow-menu-button-icon {
    opacity: 0.12
}
.docs-charts-editor-overflow-menu-button-caption {
    min-height: 21px;
    overflow: hidden;
    padding-right: 28px;
    position: absolute;
    text-overflow: ellipsis;
    top: 10px;
    white-space: nowrap
}
.docs-charts-editor-material-icon-menu-button-palette .toolbar-icon,
.docs-charts-editor-material-icon-menu-button-palette .docs-common-icon {
    margin: 3px 5px 4px 2px
}
.docs-charts-editor-material-icon-menu-button-palette .goog-palette-cell {
    border: 0
}
.docs-charts-editor-material-icon-menu-button-palette .goog-palette-table {
    border: 0;
    margin: 0 4px
}
.docs-charts-editor-material-icon-menu-button-palette .goog-palette-cell-hover {
    background: #eeeeee
}
.docs-charts-editor-chip-content {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    background-color: #f0f0f0;
    border-radius: 32px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    height: 32px;
    overflow: hidden;
    position: relative;
    white-space: nowrap
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-chip-content {
    border-radius: 36px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    height: 36px
}
.docs-charts-editor-chip-content>* {
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0
}
.docs-charts-editor-chip-label {
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    -webkit-flex-shrink: 1;
    -ms-flex-negative: 1;
    flex-shrink: 1;
    cursor: default;
    line-height: 32px;
    margin-left: 16px;
    overflow: hidden;
    text-overflow: ellipsis;
    vertical-align: top
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-chip-label {
    line-height: 36px;
    margin-right: 10px
}
.docs-charts-editor-chip-button {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    cursor: pointer;
    margin: 0;
    min-width: 0;
    outline: 0;
    padding: 0;
    position: absolute;
    right: 0
}
.docs-charts-editor-chip.docs-charts-editor-chip-invalid .docs-charts-editor-chip-content {
    border: 1px solid #db4437
}
.docs-charts-editor-chip.docs-charts-editor-chip-invalid .docs-charts-editor-chip-error-message {
    display: block
}
.docs-charts-editor-chip-error-message {
    color: #db4437;
    display: none;
    font-size: 11px;
    left: 8px;
    position: relative;
    top: 3px
}
.docs-charts-editor-collapsible-header {
    -webkit-transition: color 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: color 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: color 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: color 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    color: rgba(0, 0, 0, 0.54);
    cursor: pointer;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 500;
    height: 42px;
    line-height: 42px;
    position: relative
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-collapsible-header {
    background-color: #f8f9fa;
    color: #80868b;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    height: 56px;
    line-height: 56px
}
.docs-charts-editor-collapsible-header.goog-control-open {
    color: rgba(0, 0, 0, 0.87)
}
.docs-charts-editor-collapsible-header.goog-control-disabled {
    color: rgba(0, 0, 0, 0.26);
    cursor: default
}
.docs-charts-editor-collapsible-header.goog-control-focused {
    color: rgba(0, 0, 0, 0.87);
    outline: none
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-collapsible-header.goog-control-focused {
    color: #3c4043
}
.docs-charts-editor-collapsible-title {
    height: 42px;
    line-height: 42px;
    margin: 0 2px 0 16px;
    overflow: hidden;
    text-overflow: ellipsis;
    width: 190px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-collapsible-title {
    height: 56px;
    line-height: 56px;
    padding: 0 36px
}
.docs-charts-editor-collapsible-summary {
    color: rgba(0, 0, 0, 0.54);
    height: 42px;
    line-height: 42px;
    overflow: hidden;
    position: absolute;
    right: 42px;
    text-align: right;
    text-overflow: ellipsis;
    width: 115px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-collapsible-summary {
    height: 56px;
    line-height: 56px
}
.goog-control-disabled .docs-charts-editor-collapsible-summary {
    color: #888
}
.docs-charts-editor-collapsible-icon {
    -webkit-transition: all 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: all 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: all 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: all 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxOCIgaGVpZ2h0PSIxOCIgdmlld0JveD0iMCAwIDE4IDE4Ij48ZyBzdHlsZT0iZmlsbDpub25lO3N0cm9rZS13aWR0aDoxO3N0cm9rZTpub25lIj48ZyB0cmFuc2Zvcm09InRyYW5zbGF0ZSg5IDkpc2NhbGUoMSAtMSl0cmFuc2xhdGUoLTkgLTkpIj48cmVjdCB3aWR0aD0iMTgiIGhlaWdodD0iMTgiLz48cG9seWdvbiBwb2ludHM9IjkgNSAzIDExIDQuNCAxMi40IDkgNy44IDEzLjYgMTIuNCAxNSAxMSIgZmlsbD0iIzAwMCIvPjwvZz48L2c+PC9zdmc+");
    height: 18px;
    opacity: 0.54;
    position: absolute;
    right: 16px;
    top: 11px;
    width: 18px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-collapsible-icon {
    background: none;
    height: 20px;
    left: 16px;
    top: 20px;
    transform: rotate(-90deg);
    width: 20px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-collapsible-icon .docs-icon {
    height: 20px;
    vertical-align: top;
    width: 20px
}
.goog-control-checked .docs-charts-editor-collapsible-icon {
    opacity: 0.87;
    transform: rotate(-180deg)
}
.docs-gm-sidebars .waffle-gm-sidebar .goog-control-checked .docs-charts-editor-collapsible-icon {
    top: 14px;
    transform: none
}
.docs-gm-sidebars .waffle-gm-sidebar .goog-control-focused .docs-charts-editor-collapsible-icon {
    opacity: 0.87
}
.goog-control-disabled .docs-charts-editor-collapsible-icon {
    display: none
}
.docs-charts-editor-collapsible-content {
    -webkit-transition: max-height 0.25s cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: max-height 0.25s cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: max-height 0.25s cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: max-height 0.25s cubic-bezier(0.4, 0.0, 0.2, 1);
    overflow: hidden
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-collapsible-content {
    background-color: #fff
}
.docs-charts-editor-collapsible-content-animating {
    -webkit-transition: none;
    -moz-transition: none;
    -o-transition: none;
    transition: none
}
.docs-charts-editor-collapsible-content>div {
    padding: 0 16px 6px 16px
}
.docs-charts-editor-collapsible-content.docs-charts-editor-collapsible-content-no-padding>div {
    padding: 0
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-customize-tab .docs-charts-editor-bundle.docs-charts-editor-parent-bundle>.docs-charts-editor-collapsible-opened {
    -webkit-box-shadow: 0 1px 3px 1px rgba(60, 64, 67, .15);
    -moz-box-shadow: 0 1px 3px 1px rgba(60, 64, 67, .15);
    box-shadow: 0 1px 3px 1px rgba(60, 64, 67, .15);
    border: 2px solid #fff;
    border-radius: 8px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-collapsible-opened .docs-charts-editor-collapsible-header {
    background-color: #fff;
    color: #3c4043
}
.docs-charts-editor-labeledinput-error {
    color: #db4437;
    display: none;
    font-size: 11px;
    margin-bottom: 4px;
    margin-top: 4px
}
.docs-charts-editor-labeledinput-haserror .docs-charts-editor-labeledinput-error {
    display: block
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-labeledinput-haserror input:hover {
    border-color: #c53929
}
.docs-charts-editor-labeledinput-haserror input,
.docs-charts-editor-labeledinput-haserror input:focus {
    border-bottom: 2px solid #db4437
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-labeledinput-haserror input,
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-labeledinput-haserror input:focus {
    border: 2px solid #db4437
}
.docs-charts-editor-labeledinput-haserror input:hover:not(:focus) {
    border-bottom-color: #c53929
}
.docs-charts-editor-labeledselect-menu-style-wide {
    width: 255px
}
.docs-charts-editor-labeledselect-menu-style-narrow {
    width: 146px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-material-gm-labeled-select-disabled .docs-material-gm-labeled-select-caption {
    color: rgba(0, 0, 0, 0.26)
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-material-gm-labeled-select-disabled .docs-material-gm-labeled-select-dropdown-icon {
    opacity: .26
}
.docs-explore-icon {
    direction: ltr;
    text-align: left;
    overflow: hidden;
    position: relative;
    vertical-align: middle
}
.docs-explore-img:before {
    content: url(//ssl.gstatic.com/docs/common/menu_feature_sprite7.svg)
}
.docs-explore-img {
    height: 4332px;
    position: absolute;
    width: 72px
}
.docs-explore-hc-gecko .docs-explore-icon {
    filter: invert(100%)
}
.docs-explore-hc-ie .docs-explore-icon {
    -ms-high-contrast-adjust: none;
    background-color: white
}
.docs-explore-auto-awesome-grey {
    left: 0;
    top: -4314px
}
.docs-explore-back-white {
    left: 0;
    top: -4194px
}
.docs-explore-back-white-rtl {
    left: -36px;
    top: -640px
}
.docs-explore-cite-black {
    left: -42px;
    top: -2992px
}
.docs-explore-cite-black-18 {
    left: -48px;
    top: -4128px
}
.docs-explore-docs-18 {
    left: 0;
    top: -2974px
}
.docs-explore-drawing-18 {
    left: -50px;
    top: -3034px
}
.docs-explore-email-18 {
    left: -36px;
    top: -3946px
}
.docs-explore-excel-18 {
    left: -24px;
    top: -4128px
}
.docs-explore-expand-down {
    left: 0;
    top: -1748px
}
.docs-explore-expand-up {
    left: 0;
    top: -164px
}
.docs-explore-file-18 {
    left: 0;
    top: -1080px
}
.docs-explore-filter-button-black-18 {
    left: 0;
    top: -434px
}
.docs-explore-folder-18 {
    left: -20px;
    top: -4194px
}
.docs-explore-form-18 {
    left: -18px;
    top: -1122px
}
.docs-explore-forward-arrow-black {
    left: 0;
    top: -4170px
}
.docs-explore-forward-arrow-black-rtl {
    left: -18px;
    top: -988px
}
.docs-explore-google-logo {
    left: -24px;
    top: -3840px
}
.docs-explore-group-blue-18 {
    left: -18px;
    top: -4314px
}
.docs-explore-group-black-18 {
    left: 0;
    top: -1122px
}
.docs-explore-image-18 {
    left: -24px;
    top: -164px
}
.docs-explore-insert-black {
    left: 0;
    top: -3840px
}
.docs-explore-insert-black-18 {
    left: -18px;
    top: -640px
}
.docs-explore-keep-yellow-18 {
    left: 0;
    top: -3658px
}
.docs-explore-lock-black-18 {
    left: -50px;
    top: -2474px
}
.docs-explore-more-black {
    left: -48px;
    top: -4146px
}
.docs-explore-pdf-18 {
    left: 0;
    top: -988px
}
.docs-explore-powerpoint-18 {
    left: -18px;
    top: -3946px
}
.docs-explore-preview-white {
    left: 0;
    top: -4128px
}
.docs-explore-question-green {
    left: -50px;
    top: -2454px
}
.docs-explore-search-black {
    left: -18px;
    top: -2992px
}
.docs-explore-search-close-white {
    left: 0;
    top: -1098px
}
.docs-explore-search-history-black {
    left: 0;
    top: -452px
}
.docs-explore-sheets-18 {
    left: -36px;
    top: -4314px
}
.docs-explore-sites-18 {
    left: 0;
    top: -1944px
}
.docs-explore-slides-18 {
    left: -24px;
    top: -1098px
}
.docs-explore-thumb-down-18 {
    left: -50px;
    top: -3052px
}
.docs-explore-thumb-up-18 {
    left: 0;
    top: -2522px
}
.docs-explore-video-18 {
    left: 0;
    top: -3946px
}
.docs-explore-word-18 {
    left: -50px;
    top: -3016px
}
.docs-explore-show-more-14 {
    left: 0;
    top: -4152px
}
.docs-explore-promo-icon-wrapper {
    background-color: white;
    border-radius: 50px;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    height: 100px;
    left: -46px;
    position: absolute;
    top: -36px;
    width: 100px
}
.docs-explore-promo-icon {
    cursor: pointer;
    display: block;
    margin: auto
}
.waffle-assistant-entry {
    background-color: rgba(255, 255, 255, 0.8);
    border: none;
    border-left: 1px solid #c2c2c2;
    float: right;
    height: 38px;
    padding-right: 10px
}
.waffle-assistant-entry-button {
    border: 1px solid transparent;
    cursor: pointer;
    height: 34px;
    -webkit-transition: padding 0.5s cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: padding 0.5s cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: padding 0.5s cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: padding 0.5s cubic-bezier(0.4, 0.0, 0.2, 1);
    width: 100%
}
.waffle-assistant-entry-button-icon {
    display: inline-block;
    position: relative;
    padding: 7px 0 7px 8px
}
.waffle-assistant-entry-label {
    color: #0f9d58;
    display: inline-block;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    overflow: hidden;
    padding-left: 8px;
    -webkit-transition: all 0.5s cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: all 0.5s cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: all 0.5s cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: all 0.5s cubic-bezier(0.4, 0.0, 0.2, 1);
    vertical-align: middle
}
.waffle-assistant-entry-button-black-icon {
    display: none;
    opacity: .54
}
.waffle-assistant-entry-inactive {
    border-left: 1px solid transparent;
    background-color: transparent
}
.waffle-assistant-entry-inactive .waffle-assistant-entry-button-black-icon {
    display: block
}
.waffle-assistant-entry-inactive .waffle-assistant-entry-button-green-icon {
    display: none
}
.waffle-assistant-entry-inactive .waffle-assistant-entry-label {
    color: #737373;
    opacity: 0;
    padding-right: 0
}
.waffle-assistant-entry-expanded {
    background-color: rgba(255, 255, 255, 0.8);
    border-left: 1px solid #c2c2c2
}
.waffle-assistant-entry-expanded .waffle-assistant-entry-label {
    opacity: 1;
    padding-right: 6px
}
.waffle-assistant-entry-opened {
    background-color: #dadada;
    border-left: 1px solid #c2c2c2;
    -webkit-box-shadow: inset 0 0 6px rgba(0, 0, 0, .22);
    -moz-box-shadow: inset 0 0 6px rgba(0, 0, 0, .22);
    box-shadow: inset 0 0 6px rgba(0, 0, 0, .22)
}
.waffle-assistant-entry-opened .waffle-assistant-entry-button-black-icon {
    display: block
}
.waffle-assistant-entry-opened .waffle-assistant-entry-button-green-icon {
    display: none
}
.waffle-assistant-entry-opened .waffle-assistant-entry-label {
    color: #737373
}
.waffle-assistant-link-button {
    color: #4285f4;
    display: inline;
    text-decoration: underline
}
.waffle-assistant-link-button:hover,
.waffle-assistant-link-button:focus {
    cursor: pointer;
    text-decoration: underline
}
.waffle-assistant-link-button:focus {
    margin: 0 2px;
    outline-color: #4285f4;
    outline-width: 2px
}
.waffle-assistant-button {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    -webkit-justify-content: center;
    justify-content: center;
    border: 1px solid transparent;
    border-radius: 2px;
    font-size: 11px;
    font-weight: 500;
    margin-right: 0;
    min-width: 40px;
    opacity: 0.8;
    padding: 0;
    text-align: center;
    white-space: nowrap
}
.waffle-assistant-button-focused {
    border: 1px solid #5e97f6;
    outline: none
}
.waffle-assistant-button-hover,
.waffle-assistant-button-focused,
.waffle-assistant-button-holder .waffle-assistant-button.waffle-assistant-button-hover,
.waffle-assistant-button-holder .waffle-assistant-button.waffle-assistant-button-focused {
    cursor: pointer;
    opacity: 1
}
.waffle-assistant-button-holder .waffle-assistant-button {
    height: 24px;
    min-width: 24px;
    opacity: 0.6;
    padding: 2px
}
.waffle-assistant-dragged-formula {
    -webkit-box-shadow: 1px 1px 4px rgba(0, 0, 0, 0.28);
    -moz-box-shadow: 1px 1px 4px rgba(0, 0, 0, 0.28);
    box-shadow: 1px 1px 4px rgba(0, 0, 0, 0.28);
    background-color: #fff;
    border: 1px solid #e0e0e0;
    line-height: 22px;
    overflow-wrap: break-word;
    word-wrap: break-word
}
.waffle-assistant-formula-insertion-rect {
    background-color: #000;
    opacity: 0.06
}
.waffle-assistant-visible {
    visibility: visible
}
.docs-ui-toast.waffle-assistant-toast {
    -webkit-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    bottom: 60px;
    color: rgba(255, 255, 255, 0.87);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 500;
    left: auto;
    line-height: 20px;
    min-width: 0;
    padding: 14px 24px;
    right: 15px;
    width: 286px
}
.waffle-assistant-toast-content {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    font-weight: 400;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.waffle-assistant-toast-action {
    color: #a0c1fc;
    text-transform: uppercase
}
.waffle-assistant-panel-title-bar {
    height: 20px
}
.waffle-assistant-panel-back-button {
    cursor: pointer
}
.waffle-assistant-panel-back-button-icon {
    height: 20px;
    margin-bottom: 1px
}
.waffle-assistant-panel-pane {
    height: 100%
}
.waffle-assistant-sidepanel.waffle-sidebar-container {
    -webkit-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    background: #f1f1f1;
    width: 320px
}
.waffle-assistant-title.waffle-sidebar-title {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    -webkit-transition: height .3s;
    -moz-transition: height .3s;
    -o-transition: height .3s;
    transition: height .3s;
    background-color: #0f9d58;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    line-height: 20px;
    min-height: 36px;
    padding: 0px
}
.waffle-assistant-title .waffle-sidebar-title-close {
    right: 11px;
    top: 6px
}
.waffle-assistant-title-bar,
.waffle-assistant-panel-title-bar {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center
}
.waffle-assistant-replaceable-title,
.waffle-assistant-title-bar {
    padding: 8px 12px
}
.waffle-assistant-replaceable-title .waffle-assistant-title-bar {
    padding: 0
}
.waffle-assistant-title-text {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    -webkit-align-items: center;
    align-items: center;
    font-weight: 500;
    padding-left: 12px
}
.waffle-assistant-title-icon {
    height: 20px;
    position: relative;
    width: 20px
}
.waffle-assistant-sidepane-content.waffle-sidebar-content {
    overflow: hidden
}
.waffle-assistant-scroll-pane {
    background: #f1f1f1;
    height: 100%;
    overflow-x: hidden;
    overflow-y: auto
}
.waffle-assistant-scroll-pane-content {
    height: 100%
}
.waffle-assistant-scroll-pane-feature-content {
    height: 100%
}
.waffle-assistant-expanded-panel {
    height: 100%;
    width: 320px
}
.waffle-assistant-spinner-container {
    text-align: center;
    pointer-events: none;
    position: absolute;
    width: 100%
}
.waffle-assistant-expanded-panel .waffle-assistant-spinner-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    -webkit-justify-content: center;
    justify-content: center;
    height: 100%
}
.waffle-assistant-empty-list {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    background: #fff;
    color: rgb(46%, 46%, 46%);
    height: 100%;
    text-align: center;
    width: 320px
}
.waffle-assistant-empty-list-content {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    margin: auto 24px;
    width: 100%
}
.waffle-assistant-empty-list svg {
    padding-bottom: 24px
}
.waffle-assistant-empty-list-title {
    color: rgb(46%, 46%, 46%);
    font-size: 15px;
    font-weight: 500
}
.waffle-assistant-empty-list-body {
    color: rgb(46%, 46%, 46%);
    font-size: 13px;
    padding: 8px 0
}
.waffle-assistant-empty-list-link {
    font-size: 13px;
    font-weight: 400;
    margin: 0
}
.waffle-assistant-empty-list-link span,
.waffle-assistant-empty-list-link a {
    color: #1a73e8;
    cursor: pointer
}
.waffle-assistant-empty-list-link a:hover {
    text-decoration: none
}
.waffle-assistant-feature-section {
    -webkit-box-shadow: 0 2px 2px rgba(0, 0, 0, 0.10);
    -moz-box-shadow: 0 2px 2px rgba(0, 0, 0, 0.10);
    box-shadow: 0 2px 2px rgba(0, 0, 0, 0.10);
    background: white;
    margin-bottom: 8px
}
.waffle-assistant-feature-section:last-child {
    margin-bottom: 0
}
.waffle-assistant-section-header {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    padding: 16px 16px 0 16px;
    position: relative;
    width: 288px
}
.waffle-assistant-section-title {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    color: rgba(0, 0, 0, 0.54);
    font-size: 13px;
    font-weight: 600;
    height: 15px;
    line-height: 15px;
    text-transform: uppercase
}
.jfk-button.waffle-assistant-section-more-button {
    border: 0;
    color: #1a73e8;
    cursor: pointer;
    height: 15px;
    font-size: 13px;
    line-height: 15px;
    margin-right: 16px;
    text-transform: uppercase
}
.jfk-button.waffle-assistant-section-more-button:focus {
    border: 1px solid #5e97f6;
    outline: none
}
.waffle-assistant-section-content {
    padding-bottom: 10px
}
.waffle-assistant-scroll-pane::-webkit-scrollbar {
    width: 12px
}
.docs-gm-sidebars .waffle-assistant-scroll-pane::-webkit-scrollbar-thumb {
    background-color: #dadce0
}
.waffle-assistant-scroll-pane::-webkit-scrollbar-thumb {
    background-color: rgba(0, 0, 0, 0.2);
    background-clip: padding-box;
    border: solid transparent;
    border-width: 1px 1px 1px 2px;
    box-shadow: none;
    min-height: 28px;
    padding: 1px
}
.docs-gm-sidebars .waffle-assistant-scroll-pane::-webkit-scrollbar-thumb:hover {
    background-color: #bdc1c6
}
.waffle-assistant-scroll-pane::-webkit-scrollbar-thumb:hover {
    box-shadow: none
}
.docs-gm-sidebars .waffle-assistant-scroll-pane::-webkit-scrollbar-thumb:active {
    background-color: #80868b
}
.docs-gm-sidebars .waffle-assistant-scroll-pane::-webkit-scrollbar-track {
    border: none
}
.waffle-assistant-scroll-pane::-webkit-scrollbar-track {
    background-clip: border-box;
    background-color: #f8f8f8;
    border: solid #d9d9d9;
    border-width: 1px;
    box-shadow: none
}
.docs-gm-sidebars .waffle-assistant-scroll-pane::-webkit-scrollbar-track:hover {
    border: none
}
.waffle-assistant-scroll-pane::-webkit-scrollbar-track:hover {
    background-color: #f8f8f8;
    background-clip: border-box;
    box-shadow: none;
    border: solid #d9d9d9;
    border-width: 1px
}
.waffle-assistant-card {
    background: #fff;
    border-bottom: 1px solid #e0e0e0;
    margin-bottom: 8px;
    outline: 0;
    overflow: hidden;
    position: relative
}
.waffle-assistant-feature-section .waffle-assistant-card {
    margin-bottom: 0
}
.waffle-assistant-panel-pane .waffle-assistant-card {
    -webkit-box-shadow: 0 2px 2px rgba(0, 0, 0, 0.10);
    -moz-box-shadow: 0 2px 2px rgba(0, 0, 0, 0.10);
    box-shadow: 0 2px 2px rgba(0, 0, 0, 0.10)
}
.waffle-assistant-card-spinner-container {
    position: absolute;
    text-align: center;
    top: 50%;
    transform: translateY(-50%);
    width: 100%
}
.waffle-assistant-card-inner {
    position: relative
}
.waffle-assistant-padded-card {
    padding: 15px
}
.waffle-assistant-button-holder {
    background-color: rgba(255, 255, 255, 0.7);
    padding: 3px;
    position: absolute;
    top: 0;
    z-index: 1
}
.waffle-assistant-dragger-card .waffle-assistant-button-holder,
.waffle-assistant-dragger-card .waffle-assistant-chart-highlights,
.waffle-assistant-dragger-card .waffle-assistant-facet-section {
    display: none
}
.waffle-assistant-card-draggable {
    cursor: move
}
.waffle-assistant-readonly .waffle-assistant-card:hover {
    cursor: default
}
.waffle-assistant-card-options {
    -webkit-border-radius: 0 0 0 2px;
    -moz-border-radius: 0 0 0 2px;
    border-radius: 0 0 0 2px;
    -webkit-box-shadow: -1px 1px 3px #d3d3d3;
    -moz-box-shadow: -1px 1px 3px #d3d3d3;
    box-shadow: -1px 1px 3px #d3d3d3;
    right: 0
}
.waffle-assistant-padded-card {
    padding: 15px
}
.waffle-assistant-feedback-card-content {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    vertical-align: middle;
    line-height: 19px
}
.waffle-assistant-feedback-card-text {
    margin: 2px 0
}
.waffle-assistant-feedback-card {
    -webkit-box-shadow: 0px 2px 4px rgba(0, 0, 0, .3);
    -moz-box-shadow: 0px 2px 4px rgba(0, 0, 0, .3);
    box-shadow: 0px 2px 4px rgba(0, 0, 0, .3);
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    background-color: white;
    cursor: default;
    margin: 5px;
    max-height: 500px;
    overflow: hidden;
    padding: 15px;
    width: 250px
}
.waffle-assistant-feedback-card-close-button {
    -webkit-align-self: flex-start;
    align-self: flex-start;
    min-width: auto
}
.waffle-assistant-card .waffle-assistant-feedback-card {
    -webkit-transition: all .1s;
    -moz-transition: all .1s;
    -o-transition: all .1s;
    transition: all .1s
}
.waffle-assistant-dragger-card .waffle-assistant-feedback-card {
    display: none
}
.waffle-assistant-card .waffle-assistant-feedback-card-hidden {
    padding: 0 15px 0 15px;
    margin: 0 5px 0 5px;
    max-height: 0
}
.waffle-assistant-insert-chart-button.jfk-button,
.waffle-assistant-zoom-button.jfk-button,
.waffle-assistant-thumbs-down-button.jfk-button,
.waffle-assistant-thumbs-up-button.jfk-button {
    cursor: pointer;
    display: block;
    height: 24px;
    margin: 0 auto 0 auto;
    min-width: 24px;
    opacity: .6;
    padding: 1px;
    width: 24px
}
.waffle-assistant-insert-chart-button.jfk-button:hover,
.waffle-assistant-zoom-button.jfk-button:hover,
.waffle-assistant-thumbs-down-button.jfk-button:hover,
.waffle-assistant-thumbs-up-button.jfk-button:hover {
    opacity: .8
}
.waffle-assistant-insert-chart-button.jfk-button:active,
.waffle-assistant-zoom-button.jfk-button:active,
.waffle-assistant-thumbs-down-button.jfk-button:active,
.waffle-assistant-thumbs-up-button.jfk-button:active {
    opacity: 1
}
.waffle-assistant-thumbs-down-icon {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -150px 0;
    height: 24px;
    width: 24px
}
.waffle-assistant-thumbs-up-icon {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -113px -46px;
    height: 24px;
    width: 24px
}
.waffle-assistant-button-separator {
    border-bottom: 1px solid #d3d3d3;
    height: 0;
    margin: 3px;
    width: 21px
}
.waffle-assistant-card-feedback-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: flex-end;
    align-items: flex-end;
    -webkit-justify-content: center;
    justify-content: center;
    background: rgba(0, 0, 0, 0.38);
    height: 100%;
    position: absolute;
    width: 100%;
    z-index: 1
}
.waffle-assistant-feedback-card-hidden {
    display: none!important
}
.waffle-assistant-thumbs-container,
.waffle-assistant-facet-thumbs-container {
    border-top: 1px dashed #e0e0e0;
    color: #616161
}
.waffle-assistant-thumbs {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    height: 40px;
    line-height: 16px;
    padding: 0 15px
}
.waffle-assistant-thumbs-button-holder {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-assistant-thumbs-up-button,
.waffle-assistant-thumbs-down-button {
    min-width: 30px!important
}
.waffle-assistant-thumbs-text {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    text-transform: uppercase
}
.waffle-assistant-quicksum-panel {
    background: #fff;
    border-bottom: 1px solid #e0e0e0;
    line-height: 19px;
    margin-bottom: 8px;
    padding: 15px;
    position: relative
}
.waffle-assistant-scroll-pane-feature-content .waffle-assistant-quicksum-panel {
    -webkit-box-shadow: 0 2px 2px rgba(0, 0, 0, 0.10);
    -moz-box-shadow: 0 2px 2px rgba(0, 0, 0, 0.10);
    box-shadow: 0 2px 2px rgba(0, 0, 0, 0.10)
}
.waffle-assistant-quicksum-entry {
    border: 1px solid transparent;
    color: #757575;
    cursor: move;
    font-family: Roboto, Arial, sans-serif;
    padding: 0 5px
}
.waffle-assistant-quicksum-entry:hover,
.waffle-assistant-quicksum-entry:focus {
    border: 1px solid #5e97f6
}
.waffle-assistant-quicksum-panel-readonly .waffle-assistant-quicksum-entry:hover,
.waffle-assistant-quicksum-panel-readonly .waffle-assistant-quicksum-entry:focus {
    border: 1px solid transparent
}
.waffle-assistant-quicksum-panel-readonly .waffle-assistant-quicksum-entry {
    border: 1px solid transparent;
    cursor: default
}
.waffle-assistant-quicksum-entry-name {
    font-weight: 500;
    margin-right: 10px
}
.waffle-assistant-quicksum-entry-value {
    float: right
}
.waffle-assistant-walkthrough-promo-content {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    line-height: 22px;
    padding: 15px 20px;
    width: 300px
}
.waffle-assistant-walkthrough-promo-header {
    font-size: 20px
}
.waffle-assistant-walkthrough-promo-button {
    cursor: pointer;
    font-size: 14px;
    font-weight: 500;
    text-transform: uppercase
}
.waffle-assistant-walkthrough-promo-continue-button {
    color: #5e97f5;
    margin-right: 10px
}
.waffle-assistant-walkthrough-promo-close-button {
    margin-left: 10px;
    opacity: 0.7
}
.waffle-april2018-promo-base,
.waffle-assistant-entry-promo {
    background-color: #0f9d58;
    border-color: #0f9d58;
    bottom: -500px;
    right: -450px
}
.waffle-april2018-promo-content,
.waffle-assistant-entry-promo .docs-explore-promo-content {
    left: -300px;
    top: -170px;
    width: 360px
}
.range-border.waffle-assistant-table-range-border {
    border-color: #0f9d58;
    border-style: dashed;
    line-height: 0
}
.waffle-assistant-table-range-rect {
    background-color: #0f9d58;
    opacity: 0.06;
    pointer-events: none
}
.range-border.waffle-assistant-header-range-border {
    border-color: #f09300;
    border-style: dashed;
    line-height: 0
}
.waffle-assistant-header-range-rect {
    background-color: #f09300;
    opacity: 0.06;
    pointer-events: none
}
.waffle-assistant-card .docs-charts-tooltip {
    font-size: 10px;
    padding: 4px 8px;
    line-height: 1.1em
}
.waffle-assistant-highlight-styled-rect {
    background-color: #34a853;
    opacity: 0.06;
    pointer-events: none
}
.range-border.waffle-assistant-highlight-styled-border {
    border-color: #34a853;
    border-style: dashed
}
.waffle-assistant-mouseover-highlight-styled-rect {
    background-color: #34a853;
    opacity: 0.25;
    pointer-events: none
}
.range-border.waffle-assistant-mouseover-highlight-styled-border {
    border-color: #34a853;
    border-style: dashed
}
.waffle-inline-assistant-sidebar-category {
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    padding: 16px 16px 0
}
.waffle-inline-assistant-sidebar-intro {
    color: #80868b;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 400;
    padding: 16px 16px 6px
}
.waffle-inline-assistant-sidebar-empty-container {
    margin: 20px;
    text-align: center
}
.waffle-inline-assistant-sidebar-empty-message {
    font-size: 14px;
    font-style: italic;
    margin-bottom: 20px
}
.waffle-inline-assistant-sidebar-empty-check-container {
    background-color: #34a853;
    width: 50px;
    border-radius: 50%;
    display: inline-block
}
.waffle-inline-assistant-sidebar-empty-check {
    filter: invert(100%);
    height: 30px;
    padding: 10px
}
.waffle-assistant-floating-popup {
    -webkit-box-shadow: 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12), 0px 2px 4px -1px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12), 0px 2px 4px -1px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12), 0px 2px 4px -1px rgba(0, 0, 0, 0.2);
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    background: white;
    border-radius: 10px;
    bottom: 30px;
    left: 55px;
    padding: 18px;
    position: absolute;
    width: 320px;
    z-index: 20
}
.waffle-assistant-popup-view {
    -webkit-box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    -moz-box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    display: table;
    position: absolute
}
.waffle-assistant-popup-suggestion {
    background: #fff;
    border: 1px solid #ccc;
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    outline: none;
    margin: 10px;
    padding: 12px 14px;
    position: relative;
    text-align: left;
    cursor: pointer
}
.waffle-assistant-popup-suggestion:hover,
.waffle-assistant-popup-suggestion:focus {
    background: rgba(0, 0, 0, .06)
}
.waffle-assistant-popup-suggestion:active {
    background: rgba(0, 0, 0, 0.12)
}
.waffle-assistant-popup-suggestion-text {
    font-size: 14px;
    line-height: 21px;
    white-space: normal;
    word-wrap: break-word
}
.waffle-assistant-popup-suggestion-text .waffle-assistant-feedback-button {
    float: right
}
.docs-material-gm-checkbox.waffle-assistant-card-checkbox {
    float: left;
    margin-top: -1px;
    position: absolute;
    top: 50%;
    transform: translateY(-50%)
}
.waffle-assistant-card-unchecked-hovered-checkbox {
    opacity: 0.7
}
.waffle-inline-assistant-sidebar-accept {
    float: right;
    margin: 16px
}
.waffle-inline-assistant-sidebar-survey-container {
    padding: 16px 16px 0
}
.waffle-inline-assistant-sidebar-survey-link {
    color: #80868b!important;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: bold;
    text-decoration: underline
}
.waffle-inline-assistant-sidebar .waffle-sidebar-footer-container {
    background-color: white;
    border-top: 1px solid #dadce0
}
.waffle-assistant-card-text {
    font-size: 14px;
    line-height: 28px;
    margin-left: 32px;
    white-space: normal;
    word-wrap: break-word
}
.waffle-assistant-popup-range {
    color: #34a853;
    font-weight: 500
}
.waffle-assistant-popup-nf-type {
    font-weight: 500
}
.waffle-assistant-popup-button-row {
    margin-top: 18px;
    text-align: right
}
.jfk-button-action.waffle-assistant-popup-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff
}
.jfk-button-action.waffle-assistant-popup-button.goog-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #2a8947;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.jfk-button-action.waffle-assistant-popup-button.goog-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #4f9e67;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.jfk-button-action.waffle-assistant-popup-button.goog-button-hover.goog-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.jfk-button-standard.waffle-assistant-popup-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #dadce0!important;
    color: #188038
}
.jfk-button-standard.waffle-assistant-popup-button.goog-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #f8fcf9;
    border: 1px solid #c8e7d1!important
}
.jfk-button-standard.waffle-assistant-popup-button.goog-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #e7f5eb;
    border: 1px solid #bbe2c6!important
}
.jfk-button-standard.waffle-assistant-popup-button.goog-button-hover.goog-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    border: 1px solid #b5e0c1!important
}
.waffle-assistant-popup-button-review {
    margin-right: 0
}
.waffle-assistant-popup-button-dismiss {
    background-color: #f1f3f4
}
.waffle-assistant-popup-logo {
    float: left;
    margin-right: 18px;
    min-width: 0;
    outline: none;
    padding: 3px
}
.waffle-feedback-troubleshoot-item {
    color: #5f6368;
    font-size: 11px;
    width: 168px
}
.waffle-feedback-troubleshoot-item-icon,
.waffle-feedback-troubleshoot-item-text {
    display: inline
}
.waffle-assistant-feedback-dialog,
.waffle-assistant-feedback-product-info-dialog {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.waffle-assistant-feedback-dialog {
    min-width: 464px;
    max-width: 512px
}
.waffle-assistant-feedback-dialog .docs-material-gm-dialog-content {
    font-size: 14px;
    padding-bottom: 0
}
.waffle-assistant-feedback-dialog-radio-button {
    padding: 8px
}
.waffle-assistant-feedback-dialog-radio-button .jfk-radiobutton-radio {
    left: 0
}
.waffle-assistant-feedback-dialog-radio-button .jfk-radiobutton-label {
    margin-left: 16px
}
.waffle-assistant-feedback-dialog-feedback-radio-buttons-control .waffle-assistant-feedback-dialog-radio-button {
    display: block
}
.waffle-assistant-feedback-dialog-legal {
    margin-right: 16px;
    max-width: 256px
}
.waffle-assistant-feedback-dialog-legal-information-text {
    color: #80868b
}
.waffle-assistant-feedback-dialog-product-info-display-text {
    color: #5f6368;
    cursor: pointer;
    padding-top: 10px;
    text-decoration: underline
}
.waffle-assistant-feedback-dialog-header {
    color: #1967d2;
    font-weight: 500;
    padding: 8px 0;
    text-transform: uppercase
}
.waffle-assistant-feedback-product-info-dialog .docs-material-gm-dialog-content {
    max-height: 568px;
    overflow: auto;
    overflow-wrap: break-word;
    width: 466px
}
.waffle-assistant-feedback-product-info-dialog dt {
    font-weight: 500
}
.waffle-assistant-feedback-dialog .jfk-textinput {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    color: #3c4043;
    padding: 1px 8px;
    font-size: 14px;
    height: 36px;
    margin: 8px 0
}
.waffle-assistant-feedback-dialog textarea.jfk-textinput {
    height: auto;
    height: unset;
    min-height: 52px;
    min-width: 100%;
    max-height: 52px;
    padding: 7px 8px
}
.waffle-assistant-feedback-dialog .jfk-textinput:focus {
    border: 2px solid #1a73e8;
    box-shadow: none;
    padding: 0px 7px
}
.waffle-assistant-feedback-dialog textarea.jfk-textinput:focus {
    padding: 6px 7px
}
.waffle-assistant-insert-chart-button.jfk-button {
    position: relative;
    left: -1px
}
.waffle-assistant-zoom-button.jfk-button {
    position: relative;
    left: 1px
}
.waffle-assistant-chart-preview {
    cursor: move;
    height: 238px;
    width: 271px
}
.waffle-assistant-readonly .waffle-assistant-chart-preview {
    cursor: default
}
.waffle-assistant-chart-preview.waffle-assistant-dragged-card {
    background-color: #fff;
    border: 1px solid #e0e0e0;
    z-index: 1000
}
.waffle-assistant-chart-highlights {
    border-left: 3px solid #0f9d58;
    color: #616161;
    cursor: text;
    padding-left: 15px;
    margin-top: 20px;
    margin-bottom: 20px;
    -webkit-user-select: text;
    -moz-user-select: text;
    -ms-user-select: text
}
.waffle-assistant-facet-section {
    background-color: #fafafa;
    cursor: default
}
.waffle-assistant-facet-header {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    padding: 8px 16px
}
.waffle-assistant-facet-content-wrapper {
    max-height: 1000px;
    position: relative;
    -webkit-transition: all .2s;
    -moz-transition: all .2s;
    -o-transition: all .2s;
    transition: all .2s
}
.waffle-assistant-facet-charts-wrapper-hidden,
.waffle-assistant-facet-charts-wrapper-hidden .waffle-assistant-facet-charts-container {
    margin-top: 0;
    margin-bottom: 0;
    max-height: 0
}
.waffle-assistant-facet-charts-container {
    overflow-y: hidden;
    margin: 24px 16px 0;
    max-height: 1000px;
    -webkit-transition: all .2s;
    -moz-transition: all .2s;
    -o-transition: all .2s;
    transition: all .2s;
    width: 350px
}
.waffle-assistant-pie-icon {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -501px 0;
    display: inline-block;
    height: 24px;
    margin-right: 10px;
    opacity: .5;
    vertical-align: middle;
    width: 24px
}
.waffle-assistant-facet-chart-larger-icon {
    height: 24px;
    width: 24px
}
.waffle-assistant-facet-top-text {
    color: #757575;
    display: inline-block;
    overflow: hidden;
    text-overflow: ellipsis;
    vertical-align: middle;
    width: 185px
}
.waffle-assistant-facet-title {
    font-weight: 500
}
.waffle-assistant-facet-toggle {
    color: #4285f4;
    cursor: pointer;
    float: right;
    font-size: 13px;
    font-weight: normal;
    line-height: 24px;
    margin-right: 0;
    min-width: initial;
    outline: none;
    text-align: right
}
.waffle-assistant-facet-toggle:hover {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none
}
.waffle-assistant-facet-chart-row {
    margin-bottom: 16px;
    white-space: nowrap
}
.waffle-assistant-single-facet {
    display: inline-block;
    margin-right: 16px;
    vertical-align: bottom
}
.waffle-assistant-single-facet-title {
    color: #757575;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    white-space: normal;
    width: 130px
}
.waffle-assistant-faceted-chart {
    border: 1px solid #e0e0e0;
    cursor: move;
    height: 98px;
    margin-top: 5px;
    outline: none;
    overflow: hidden;
    width: 134px
}
.waffle-assistant-facet-by-color-container {
    padding: 15px
}
.waffle-assistant-facet-by-color {
    border: none;
    height: 270px;
    margin-top: 0;
    overflow: hidden;
    width: 271px
}
.waffle-assistant-facet-white-section {
    background-color: #fff
}
.waffle-assistant-readonly .waffle-assistant-faceted-chart {
    cursor: default
}
.waffle-assistant-word-cloud-card {
    padding: 16px 16px 24px
}
.waffle-assistant-word-cloud-content-container {
    background-color: #fff;
    color: rgba(0, 0, 0, .54);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.waffle-assistant-word-cloud-title {
    color: #757575;
    font-size: 13px;
    margin-bottom: 10px
}
.waffle-assistant-styled-rect {
    opacity: 0.1
}
.waffle-assistant-answers-logging-message-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    background: #f4f4f4;
    margin: 10px 0;
    padding: 7px
}
.waffle-assistant-answers-logging-message {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    color: #757575;
    font-size: 11px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    line-height: 20px;
    margin-left: 5px
}
.waffle-assistant-answers-learn-more,
.waffle-assistant-answers-logging-opt-out {
    padding: 0 5px;
    text-decoration: none
}
.waffle-assistant-answers-logging-opt-out {
    border-left: 1px solid rgba(0, 0, 0, 0.12)
}
.waffle-assistant-section-content .waffle-assistant-answers-input {
    margin: 16px 16px 0
}
.waffle-assistant-suggested-questions {
    padding-bottom: 15px
}
.waffle-assistant-section-content .waffle-assistant-answers-input {
    padding-bottom: 5px
}
.waffle-assistant-replaceable-title .waffle-assistant-answers-input {
    margin: 10px 0;
    padding-bottom: 0px
}
.waffle-assistant-answers-query-box {
    -webkit-box-shadow: 0px 0px 2px 0px rgba(0, 0, 0, 0.12), 0px 2px 2px 0px rgba(0, 0, 0, 0.24);
    -moz-box-shadow: 0px 0px 2px 0px rgba(0, 0, 0, 0.12), 0px 2px 2px 0px rgba(0, 0, 0, 0.24);
    box-shadow: 0px 0px 2px 0px rgba(0, 0, 0, 0.12), 0px 2px 2px 0px rgba(0, 0, 0, 0.24);
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    background: #fafafa;
    border-radius: 2px;
    height: 40px;
    line-height: 40px
}
.waffle-assistant-replaceable-title .waffle-assistant-answers-query-box {
    background: #fafafa;
    width: 295px
}
.waffle-assistant-answers-query-box.waffle-assistant-answers-query-box-focused,
.waffle-assistant-answers-query-box:hover {
    background: #fff
}
.waffle-assistant-replaceable-title .waffle-assistant-answers-query-box-focused,
.waffle-assistant-replaceable-title .waffle-assistant-answers-query-box:hover {
    background: #fafafa
}
.waffle-assistant-replaceable-title .waffle-assistant-answers-query-box-focused {
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0
}
.waffle-assistant-answers-input-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 8;
    -webkit-flex: 8;
    flex: 8
}
.waffle-assistant-replaceable-title .waffle-assistant-answers-input-box {
    padding: 0 5px 0 10px
}
.waffle-assistant-answers-input-box {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    background: transparent;
    border: none;
    height: 40px;
    line-height: 15px;
    outline: none;
    padding: 0 5px;
    width: 100%
}
.waffle-assistant-answers-input-with-icon .waffle-assistant-answers-input-box {
    padding-left: 40px
}
.waffle-assistant-answers-input-box::-webkit-input-placeholder {
    color: #9e9e9e!important;
    font: 13px Roboto, RobotoDraft, Helvetica, Arial, sans-serif!important
}
.waffle-assistant-answers-input-box::-moz-placeholder {
    color: #9e9e9e!important;
    font: 13px Roboto, RobotoDraft, Helvetica, Arial, sans-serif!important;
    line-height: 40px!important
}
.waffle-assistant-answers-input-box:-moz-placeholder {
    color: #9e9e9e!important;
    font: 13px Roboto, RobotoDraft, Helvetica, Arial, sans-serif!important;
    line-height: 40px!important
}
.waffle-assistant-answers-input-box:-ms-input-placeholder {
    color: #9e9e9e!important;
    font: 13px Roboto, RobotoDraft, Helvetica, Arial, sans-serif!important
}
.waffle-assistant-answers-search-icon {
    display: none;
    position: absolute
}
.waffle-assistant-answers-input-with-icon .waffle-assistant-answers-search-icon {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    -webkit-justify-content: center;
    justify-content: center
}
.waffle-assistant-answers-search-icon,
.waffle-assistant-answers-input-controls {
    height: 40px;
    width: 40px
}
.waffle-assistant-answers-query-box-button {
    height: 40px
}
.waffle-assistant-answers-search-icon .docs-icon-img,
.waffle-assistant-answers-clear-query-button .docs-icon-img {
    opacity: 0.7
}
.waffle-assistant-answers-spinner-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    -webkit-justify-content: center;
    justify-content: center;
    height: 40px;
    width: 40px
}
.waffle-assistant-answers-spinner-container .waffle-spinner {
    height: 25px;
    width: 25px
}
.waffle-assistant-answers-output {
    background: rgba(0, 0, 0, 0.12)
}
.waffle-assistant-answers-toolbar-ac-renderer,
.waffle-assistant-answers-ac-renderer {
    -webkit-box-shadow: 0px 0px 2px 0px rgba(0, 0, 0, 0.12), 0px 2px 2px 0px rgba(0, 0, 0, 0.24);
    -moz-box-shadow: 0px 0px 2px 0px rgba(0, 0, 0, 0.12), 0px 2px 2px 0px rgba(0, 0, 0, 0.24);
    box-shadow: 0px 0px 2px 0px rgba(0, 0, 0, 0.12), 0px 2px 2px 0px rgba(0, 0, 0, 0.24);
    background: #fafafa;
    border-bottom-left-radius: 2px;
    border-bottom-right-radius: 2px;
    color: #616161;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    line-height: 20px;
    position: absolute;
    width: 295px;
    z-index: 10000
}
.waffle-assistant-answers-toolbar-ac-renderer {
    -webkit-transform: translate(-1px, -5px);
    -moz-transform: translate(-1px, -5px);
    -ms-transform: translate(-1px, -5px);
    -o-transform: translate(-1px, -5px);
    transform: translate(-1px, -5px);
    background: #fff;
    border-bottom-left-radius: 8px;
    border-bottom-right-radius: 8px;
    width: 250px
}
.waffle-assistant-answers-ac-row {
    cursor: default;
    padding: 10px
}
.waffle-assistant-answers-ac-row-suggested-query:first-child,
:not(.waffle-assistant-answers-ac-row-suggested-query)+.waffle-assistant-answers-ac-row-suggested-query,
.waffle-assistant-answers-ac-row-session-query:first-child,
:not(.waffle-assistant-answers-ac-row-session-query)+.waffle-assistant-answers-ac-row-session-query,
.waffle-assistant-answers-ac-row-entity:first-child,
:not(.waffle-assistant-answers-ac-row-entity)+.waffle-assistant-answers-ac-row-entity {
    border-top: 1px solid rgba(0, 0, 0, 0.12)
}
.waffle-assistant-answers-ac-active {
    background: #f5f5f5;
    cursor: pointer
}
.waffle-assistant-answers-ac-highlighted {
    font-weight: 700
}
.waffle-assistant-answers-ac-suggestion {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-assistant-answers-ac-suggestion-icon-container {
    margin-right: 5px;
    opacity: 0.7;
    width: 24px
}
.waffle-assistant-answers-ac-suggestion-text {
    -ms-flex: 8;
    -webkit-flex: 8;
    flex: 8;
    overflow: hidden;
    text-overflow: ellipsis;
    -webkit-box-orient: vertical;
    -webkit-line-clamp: 3;
    display: -webkit-box;
    max-height: 60px;
    overflow: hidden;
    overflow-wrap: break-word;
    word-wrap: break-word
}
.waffle-assistant-answercard-content {
    -webkit-user-select: auto;
    -moz-user-select: auto;
    -ms-user-select: auto;
    color: #757575
}
.waffle-assistant-answercard-question-container,
.waffle-assistant-answercard-answer-container,
.waffle-assistant-answercard-error-container {
    line-height: 20px
}
.waffle-assistant-answercard-answer-container,
.waffle-assistant-answercard-error-container,
.waffle-assistant-answercard-question-container {
    padding: 5px 0
}
.waffle-assistant-answercard-answer-container {
    margin-top: 5px
}
.waffle-assistant-answercard-question-container.waffle-assistant-button,
.waffle-assistant-answercard-error-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-assistant-answercard-question-container.waffle-assistant-button {
    -webkit-align-items: initial;
    align-items: initial;
    color: #757575;
    padding: 5px 16px;
    opacity: 1;
    text-align: left;
    white-space: normal;
    font-weight: 400;
    font-size: 13px
}
.waffle-assistant-answercard-question-container.waffle-assistant-button-hover,
.waffle-assistant-answercard-question-container.waffle-assistant-button-focused {
    background-color: #f5f5f5;
    outline: none
}
.waffle-assistant-answercard-question-header,
.waffle-assistant-answercard-answer-header {
    color: #0f9d58;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 500;
    padding-bottom: 3px;
    text-transform: uppercase
}
.waffle-assistant-button .waffle-assistant-answercard-question-header {
    opacity: 0.7
}
.waffle-assistant-button .waffle-assistant-answercard-question-header,
.waffle-assistant-answercard-error-image {
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    height: 18px;
    margin-right: 10px;
    width: 18px
}
.waffle-assistant-answercard-error-image {
    opacity: 0.5
}
.waffle-assistant-answercard-question-content,
.waffle-assistant-answercard-interpret-content,
.waffle-assistant-answercard-answer-content,
.waffle-assistant-answercard-error-content {
    overflow: hidden
}
.waffle-assistant-answercard-interpret-content {
    font-style: italic;
    padding-bottom: 6px
}
.waffle-assistant-button .waffle-assistant-answercard-question-content,
.waffle-assistant-answercard-error-content {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1
}
.waffle-assistant-answercard-question,
.waffle-assistant-answercard-interpret,
.waffle-assistant-answercard-answer-col,
.waffle-assistant-answercard-formula,
.waffle-assistant-answercard-error {
    overflow: hidden;
    text-overflow: ellipsis
}
.waffle-assistant-answercard-question,
.waffle-assistant-answercard-interpret,
.waffle-assistant-errorcard-text {
    -webkit-user-select: text;
    -moz-user-select: text;
    -ms-user-select: text
}
.waffle-assistant-answercard-question-unused-phrase {
    text-decoration: line-through
}
.waffle-assistant-answercard-question-used-entity {
    font-weight: 700
}
.waffle-assistant-answercard-answer-rowheader {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    border-bottom: 1px solid #979797;
    font-weight: 700;
    margin-top: 0;
    padding: 4px 0 0
}
.waffle-assistant-answercard-answer-rows {
    max-height: 200px;
    overflow-x: hidden;
    overflow-y: auto
}
.waffle-assistant-answercard-answer-row {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    border-bottom: 1px dashed #979797;
    padding: 4px 0
}
.waffle-assistant-answercard-answer-row:first-child {
    margin-top: 0
}
.waffle-assistant-answercard-answer-list-row.waffle-assistant-answercard-answer-row {
    font-weight: 400
}
.waffle-assistant-answercard-answer-list-row.waffle-assistant-answercard-answer-row:last-child {
    border-bottom: 1px dashed #979797
}
.waffle-assistant-answercard-answer-row:last-child {
    border: none;
    margin-bottom: 0
}
.waffle-assistant-answercard-answer-col {
    -ms-flex: 2;
    -webkit-flex: 2;
    flex: 2;
    margin: 0 2px
}
.waffle-assistant-answercard-answer-col:first-child {
    margin-left: 0
}
.waffle-assistant-answercard-answer-col:last-child {
    margin-right: 0
}
.waffle-assistant-answercard-answer-col:nth-child(even) {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    text-align: right
}
.waffle-assistant-answercard-answer-empty {
    color: rgba(0, 0, 0, 0.54);
    font-weight: 400;
    font-style: italic
}
.waffle-assistant-answercard-answer {
    color: rgba(0, 0, 0, 0.54);
    font-weight: 700
}
.waffle-assistant-answercard-info-msgs {
    font-size: 12px;
    color: #949494;
    line-height: 15px;
    margin: 5px 0
}
.waffle-assistant-answercard-formula-holder {
    color: #757575;
    font-size: 12px;
    font-style: italic;
    line-height: 18px;
    margin-top: 10px
}
.waffle-assistant-answercard-formula {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    border: 1px solid #4285f4;
    margin-top: 5px
}
.waffle-assistant-readonly-card .waffle-assistant-answercard-formula {
    border: 1px solid transparent
}
.waffle-assistant-answercard-formula-display {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-assistant-answercard-formula-help {
    background: #4285f4;
    color: #fff;
    padding-left: 5px
}
.waffle-assistant-answercard-see-formula-link,
.waffle-assistant-answercard-hide-formula-link {
    color: #757575
}
.waffle-assistant-answercard-formula-icon {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    -webkit-justify-content: center;
    justify-content: center;
    background: rgba(0, 0, 0, 0.12);
    min-height: 28px;
    width: 30px
}
.waffle-assistant-answercard-formula-text-container {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    border-radius: 3px;
    overflow-wrap: break-word;
    word-wrap: break-word;
    white-space: pre-wrap
}
.waffle-assistant-answercard-formula-text:hover,
.waffle-assistant-answercard-formula-text:focus {
    outline: none
}
.waffle-assistant-answercard-formula-text:hover {
    cursor: move
}
.waffle-assistant-readonly-card .waffle-assistant-answercard-formula-text:hover {
    cursor: default
}
.waffle-assistant-answercard-formula-text {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    background: #f5f5f5;
    max-width: 257px;
    padding: 5px
}
.waffle-assistant-answercard-feedback-container {
    border-top: 1px dashed #e0e0e0;
    padding: 0 15px
}
.waffle-assistant-answercard-feedback-link {
    color: #757575;
    line-height: 40px
}
.waffle-assistant-answers-range-styled-rect {
    opacity: 0.20
}
.waffle-assistant-answers-styled-rect {
    opacity: 0.06
}
.waffle-assistant-answers-range-styled-rect,
.waffle-assistant-answers-styled-rect {
    background-color: #0f9d58;
    pointer-events: none
}
.waffle-assistant-answers-range-styled-border,
.waffle-assistant-answers-styled-border {
    border-color: #0f9d58!important;
    border-style: dashed!important;
    line-height: 0
}
.waffle-assistant-answers-suggestioncard {
    color: #757575
}
.waffle-assistant-answers-suggestioncard .waffle-assistant-answercard-error-container {
    padding: 15px;
    padding-bottom: 0
}
.waffle-assistant-suggestionscard-header {
    color: #0f9d58;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 500;
    line-height: 20px;
    padding-bottom: 3px;
    padding-left: 15px;
    padding-right: 15px;
    padding-top: 20px;
    text-transform: uppercase
}
.waffle-assistant-errorcard-content,
.waffle-assistant-errorcard-text {
    line-height: 20px
}
.waffle-assistant-answers-previousheadercard {
    color: #757575;
    padding: 20px 15px 10px;
    text-transform: uppercase
}
.waffle-assistant-answercard-chart {
    height: 200px;
    width: 278px
}
.waffle-assistant-answercard-pivot-content {
    margin-bottom: 10px;
    max-height: 200px;
    overflow: hidden;
    width: 278px
}
.waffle-pivottable-pivot-canvas {
    border: 1px solid rgba(0, 0, 0, 0.12)
}
.waffle-pivottable-pivot-canvas:hover,
.waffle-pivottable-pivot-canvas:focus {
    border: 1px solid #4285f4;
    cursor: pointer
}
.waffle-assistant-answercard-tabs {
    -ms-flex-align: center;
    -moz-box-align: center;
    -webkit-box-align: center;
    box-align: center;
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    box-pack: center;
    -ms-flex-pack: center;
    -webkit-box-pack: center;
    -webkit-justify-content: center;
    justify-content: center;
    text-align: center
}
.waffle-assistant-answercard-chart-tab,
.waffle-assistant-answercard-formula-tab,
.waffle-assistant-answercard-pivot-tab {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    line-height: 18px
}
.waffle-assistant-answercard-chart-tab.goog-tab.goog-tab-selected,
.waffle-assistant-answercard-formula-tab.goog-tab.goog-tab-selected,
.waffle-assistant-answercard-pivot-tab.goog-tab.goog-tab-selected {
    background: #9e9e9e;
    color: #fff;
    cursor: default;
    font-weight: 500
}
.waffle-assistant-answercard-chart-tab.goog-tab,
.waffle-assistant-answercard-formula-tab.goog-tab,
.waffle-assistant-answercard-pivot-tab.goog-tab {
    border: 1px solid rgba(0, 0, 0, 0.1);
    color: #8f8f8f;
    cursor: pointer;
    padding: 2px 4px;
    text-decoration: none
}
.waffle-assistant-answercard-chart-tab.goog-tab {
    border-top-right-radius: 2px;
    border-bottom-right-radius: 2px
}
.waffle-assistant-answercard-formula-tab.goog-tab,
.waffle-assistant-answercard-pivot-tab.goog-tab {
    border-top-left-radius: 2px;
    border-bottom-left-radius: 2px
}
.waffle-assistant-answercard-tabs.goog-tab-bar {
    background: inherit;
    margin-bottom: 10px
}
.waffle-assistant-answercard-insert-chart,
.waffle-assistant-answercard-insert-pivot {
    color: rgba(0, 0, 0, 0.87);
    float: right;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 500;
    margin: 0 5px
}
.waffle-assistant-answercard-chart-type-select,
.waffle-assistant-answercard-chart-type-select:hover,
.waffle-assistant-answercard-chart-type-select:focus {
    background: none;
    border-color: transparent;
    color: rgba(0, 0, 0, 0.87);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: normal;
    padding: 0 18px 0 0
}
.waffle-assistant-answercard-chart-type-select:hover .goog-flat-menu-button-caption {
    text-decoration: underline
}
.waffle-answers-panel {
    height: 100%
}
.waffle-dbsource-configbar-answers-wrapper {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    -webkit-justify-content: flex-end;
    justify-content: flex-end;
    opacity: 0.28;
    position: relative
}
.waffle-dbsource-configbar-answers-wrapper.waffle-assistant-answers-toolbar-enabled {
    opacity: 1
}
.waffle-dbsource-configbar-answers-wrapper .waffle-assistant-answers-input {
    margin: 0;
    padding-bottom: 0px;
    width: 250px
}
.waffle-dbsource-configbar-answers-wrapper .waffle-assistant-answers-query-box,
.waffle-dbsource-configbar-answers-wrapper.waffle-assistant-answers-toolbar-enabled .waffle-assistant-answers-query-box {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    -webkit-transition: all 200ms ease-out;
    -moz-transition: all 200ms ease-out;
    -o-transition: all 200ms ease-out;
    transition: all 200ms ease-out;
    background: #f1f3f4;
    border-radius: 8px;
    height: 36px;
    line-height: 36px;
    width: 250px
}
.waffle-dbsource-configbar-answers-wrapper.waffle-assistant-answers-toolbar-enabled .waffle-assistant-answers-query-box.waffle-assistant-answers-query-box-focused,
.waffle-dbsource-configbar-answers-wrapper.waffle-assistant-answers-toolbar-enabled .waffle-assistant-answers-query-box:hover {
    -webkit-box-shadow: 0px 3px 4px 0px rgba(0, 0, 0, 0.14), 0px 3px 3px -2px rgba(0, 0, 0, 0.12), 0px 1px 8px 0px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 3px 4px 0px rgba(0, 0, 0, 0.14), 0px 3px 3px -2px rgba(0, 0, 0, 0.12), 0px 1px 8px 0px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 3px 4px 0px rgba(0, 0, 0, 0.14), 0px 3px 3px -2px rgba(0, 0, 0, 0.12), 0px 1px 8px 0px rgba(0, 0, 0, 0.2);
    background: white
}
.waffle-dbsource-configbar-answers-wrapper .waffle-assistant-answers-query-box.waffle-assistant-answers-query-box-focused,
.waffle-dbsource-configbar-answers-wrapper .waffle-assistant-answers-query-box:hover {
    background: #f1f3f4
}
.waffle-dbsource-configbar-answers-wrapper .waffle-assistant-answers-search-icon,
.waffle-dbsource-configbar-answers-wrapper .waffle-assistant-answers-input-controls,
.waffle-dbsource-configbar-answers-wrapper .waffle-assistant-answers-query-box-button {
    height: 36px
}
.waffle-dbsource-configbar-answers-wrapper .waffle-assistant-answers-input-box {
    color: #80868b;
    font-size: 14px;
    height: 36px
}
.waffle-answers-bar .waffle-assistant-answers-query-box {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    border: 1px solid #dadce0;
    border-radius: 8px;
    background: #fff;
    opacity: 0.5
}
.waffle-answers-bar.waffle-assistant-answers-toolbar-enabled .waffle-assistant-answers-query-box {
    opacity: 1
}
.waffle-answers-bar .waffle-assistant-answers-input {
    margin: 2px 4px 2px;
    width: 250px
}
.waffle-answers-bar.waffle-assistant-answers-toolbar-enabled .waffle-assistant-answers-query-box.waffle-assistant-answers-query-box-focused,
.waffle-answers-bar.waffle-assistant-answers-toolbar-enabled .waffle-assistant-answers-query-box:hover {
    -webkit-box-shadow: 0px 1px 1px 0px rgba(0, 0, 0, 0.14), 0px 2px 1px -1px rgba(0, 0, 0, 0.12), 0px 1px 3px 0px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 1px 1px 0px rgba(0, 0, 0, 0.14), 0px 2px 1px -1px rgba(0, 0, 0, 0.12), 0px 1px 3px 0px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 1px 1px 0px rgba(0, 0, 0, 0.14), 0px 2px 1px -1px rgba(0, 0, 0, 0.12), 0px 1px 3px 0px rgba(0, 0, 0, 0.2)
}
.waffle-assistant-datavalidation-rule-group {
    margin: 16px
}
.waffle-assistant-datavalidation-rule-holder {
    border: 1px solid #ccc;
    cursor: pointer;
    display: block;
    margin-bottom: 5px;
    padding: 1px;
    width: 258px
}
.waffle-assistant-datavalidation-description {
    color: rgba(0, 0, 0, 0.54);
    display: inline-block;
    text-overflow: ellipsis
}
.waffle-assistant-datavalidation-apply-button.jfk-button {
    color: #1a73e8;
    cursor: pointer;
    display: inline-block;
    float: right;
    font-size: 13px;
    text-align: right;
    text-transform: uppercase
}
.waffle-assistant-datavalidation-range {
    font-weight: 500
}
.waffle-assistant-datavalidation-details {
    display: inline-block;
    margin-bottom: 12px;
    width: 100%
}
.waffle-assistant-datavalidation-detail-chip {
    background-color: #eeeeee;
    border: 1px solid #e0e0e0;
    border-radius: 11px;
    color: rgba(0, 0, 0, .87);
    display: inline-block;
    line-height: 21px;
    margin: 3px;
    max-width: 234px;
    overflow: hidden;
    padding: 0 16px;
    text-overflow: ellipsis;
    white-space: nowrap
}
.waffle-assistant-conditionalformat-rule-group {
    margin: 16px
}
.waffle-assistant-conditionalformat-rule-holder {
    border: 1px solid #ccc;
    cursor: pointer;
    display: block;
    margin-bottom: 5px;
    padding: 1px;
    width: 258px
}
.waffle-assistant-conditionalformat-format-preview {
    border: 1px solid transparent;
    display: inline-table;
    height: 21px;
    margin: 1px;
    overflow: hidden;
    text-align: center
}
.waffle-assistant-conditionalformat-format-preview.one-rule {
    max-width: 254px;
    width: 254px
}
.waffle-assistant-conditionalformat-format-preview.two-rules {
    max-width: 125px;
    width: 125px
}
.waffle-assistant-conditionalformat-format-preview.three-rules {
    max-width: 82px;
    width: 82px
}
.waffle-assistant-conditionalformat-format-preview-label {
    display: block;
    height: 17px;
    line-height: 17px;
    max-height: 17px;
    padding: 2px;
    text-overflow: ellipsis
}
.waffle-assistant-conditionalformat-format-preview.one-rule .waffle-assistant-conditionalformat-format-preview-label {
    max-width: 250px;
    width: 250px
}
.waffle-assistant-conditionalformat-format-preview.two-rules .waffle-assistant-conditionalformat-format-preview-label {
    max-width: 121px;
    width: 121px
}
.waffle-assistant-conditionalformat-format-preview.three-rules .waffle-assistant-conditionalformat-format-preview-label {
    max-width: 78px;
    width: 78px
}
.waffle-assistant-conditionalformat-description {
    color: #757575;
    display: inline-block;
    height: 21px;
    line-height: 21px;
    text-overflow: ellipsis;
    width: 237px
}
.waffle-assistant-conditionalformat-edit-button.jfk-button {
    cursor: pointer;
    width: 21px
}
.waffle-assistant-banding-recommendation {
    margin: 16px;
    overflow: hidden
}
.waffle-assistant-banding-color-picker-container {
    padding-bottom: 5px
}
.waffle-assistant-banding-color-picker-container .waffle-banding-color-picker-table {
    border-spacing: 8px;
    margin-left: -8px
}
.waffle-assistant-banding-range-wrapper {
    border: 1px solid transparent;
    color: #757575;
    display: inline-block;
    float: left;
    line-height: 21px;
    text-align: left
}
.waffle-assistant-banding-range {
    font-weight: 500
}
.waffle-assistant-formatting-edit-button {
    color: #5e97f5;
    cursor: pointer;
    display: inline-block;
    float: right;
    text-align: right;
    text-transform: uppercase
}
.waffle-assistant-insert-pivottable-button.jfk-button {
    left: -1px
}
.waffle-assistant-pivottable-rule-group {
    margin: 16px
}
.waffle-assistant-pivottable-rule-holder {
    border: 1px solid #ccc;
    cursor: pointer;
    display: block;
    margin-bottom: 5px;
    padding: 1px;
    width: 258px
}
.waffle-assistant-pivottable-description {
    color: #757575;
    display: inline-block;
    height: 21px;
    line-height: 21px;
    text-overflow: ellipsis;
    width: 237px
}
.waffle-assistant-zoom-button.jfk-button {
    left: 1px;
    position: relative
}
.waffle-pivottable-preview-pane {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-justify-content: center;
    justify-content: center;
    max-height: 80%;
    max-width: 80%
}
.waffle-pivot-suggestion-preview-insert.jfk-button-focused {
    border: 1px solid #5e97f6!important;
    outline: none
}
.waffle-pivottable-canvas {
    overflow: auto;
    background: white
}
.waffle-pivottable-canvas-content {
    padding: 25px
}
.waffle-pivottable-preview-interpret {
    -webkit-align-items: left;
    align-items: left;
    color: white;
    max-width: 500px;
    margin-bottom: 10px;
    overflow: visible;
    overflow-wrap: break-word;
    padding: 5px;
    text-overflow: ellipsis
}
.waffle-pivottable-lightbox {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    background-color: rgba(0, 0, 0, 0.85);
    height: 100%;
    left: 0;
    position: absolute;
    top: 0;
    width: 100%;
    z-index: 1000
}
.waffle-assistant-tables-recommendation {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    margin-bottom: 15px;
    overflow: hidden
}
.waffle-assistant-table-range-container {
    margin-right: 20px;
    width: 50%
}
.waffle-assistant-header-range-container {
    width: 50%
}
.waffle-assistant-tables-range-wrapper {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    border: 1px solid transparent;
    border-bottom: 1px solid #d0d0d0;
    color: rgba(0, 0, 0, .54);
    font-size: 11px;
    line-height: 21px;
    text-align: left
}
.waffle-assistant-header-range-container .waffle-assistant-tables-range-wrapper {
    border-bottom: none
}
.waffle-assistant-tables-range-wrapper .waffle-range-selection-input,
.waffle-assistant-tables-range-wrapper .waffle-range-selection-input-focus,
.waffle-assistant-tables-range-wrapper .waffle-range-selection-input:focus {
    border: 1px solid transparent;
    color: rgba(0, 0, 0, .87);
    font-size: 13px;
    line-height: 21px;
    padding: 0 4px!important;
    text-align: left
}
.waffle-assistant-tables-range-wrapper .waffle-range-selection-container-focus {
    border: none;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    outline: none
}
.waffle-assistant-tables-range-wrapper .waffle-range-selection-button {
    cursor: default;
    height: 26px
}
.waffle-assistant-tables-range-wrapper input:disabled {
    background-color: transparent
}
.waffle-assistant-table-canvas {
    border: 1px solid #dcdcdc;
    display: block;
    margin: 0 auto
}
.waffle-assistant-canvas-container {
    margin-top: 10px;
    overflow: hidden
}
.waffle-assistant-tables-edit-headers-button {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-assistant-tables-edit-headers-button .docs-charts-editor-material-menu-button-caption {
    font-size: 13px;
    height: 24px;
    overflow: hidden;
    text-align: left;
    text-overflow: ellipsis;
    width: 100%
}
.waffle-assistant-tables-edit-headers-button .docs-charts-editor-material-menu-button {
    margin: 0;
    width: 100%
}
.waffle-tables-popup {
    background: white;
    border-radius: 2px;
    box-shadow: 0 2px 10px rgba(0, 0, 0, 0.3);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    margin: 0 10px;
    outline: none;
    overflow: hidden;
    position: relative;
    top: 45px
}
.waffle-tables-popup-answers-enabled {
    top: 38px
}
.waffle-tables-popup-header {
    background-color: #eeeeee;
    padding: 12px 15px 12px 20px
}
.waffle-tables-popup-title {
    color: rgba(0, 0, 0, 87);
    font-size: 16px;
    font-weight: 500
}
.waffle-tables-popup-content {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    padding: 16px 16px 0
}
.waffle-tables-popup-buttons {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    flex-direction: row-reverse;
    padding: 8px 8px 8px 24px
}
.waffle-tables-popup-button {
    background: none;
    border: none;
    border-radius: 2px;
    color: #4285f4;
    cursor: pointer;
    display: inline-block;
    height: 36px;
    margin-left: 8px;
    min-width: 64px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    letter-spacing: 0;
    line-height: 36px;
    overflow: hidden;
    outline: none;
    padding: 0 8px;
    position: relative;
    text-align: center;
    text-decoration: none;
    text-transform: uppercase;
    vertical-align: middle
}
.waffle-assistant-tables-edit-range-button {
    border: none;
    float: right;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 500;
    height: 100%;
    padding: 0 14px;
    text-transform: uppercase;
    white-space: nowrap
}
.waffle-assistant-sidepane-tables-range {
    float: left;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    padding: 12px 0px 12px 12px;
    position: relative;
    top: 50%;
    transform: translateY(-50%);
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis
}
.waffle-tables-bar-content {
    overflow: hidden;
    text-overflow: ellipsis
}
.waffle-sidebar-tables-bar {
    -webkit-box-shadow: inset 0 -2px 2px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 -2px 2px rgba(0, 0, 0, .1);
    box-shadow: inset 0 -2px 2px rgba(0, 0, 0, .1);
    background: #f1f1f1;
    color: #5f5f5f;
    height: 40px;
    overflow: hidden;
    vertical-align: middle;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-assistant-tables-range-wrapper .waffle-range-selection-container {
    border: none
}
.waffle-sidebar-overlay {
    background-color: rgba(51, 51, 51, 0.3);
    bottom: 0;
    left: 0;
    overflow-y: auto;
    position: absolute;
    right: 0;
    top: 0;
    z-index: 1003
}
.waffle-assistant-table-bar-range {
    font-weight: 500
}
.waffle-assistant-table-first-header {
    display: inline-block;
    font-weight: 500;
    max-width: 95px;
    overflow: hidden;
    padding-bottom: 2px;
    text-overflow: ellipsis;
    vertical-align: middle;
    white-space: nowrap
}
.waffle-assistant-tables-scroll-pane {
    bottom: 0;
    height: auto;
    left: 0;
    position: absolute;
    right: 0;
    top: 40px
}
.waffle-assistant-tables-range-error {
    color: #c53929;
    font-size: 11px;
    padding-top: 2px
}
.waffle-assistant-tables-range-error-input {
    border-bottom: 1px solid #c53929
}
.docs-action-new-badge {
    background-color: #c6dafc;
    border-radius: 2px;
    color: #2a56c6;
    display: inline-block;
    float: right;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 11px;
    font-weight: 500;
    margin-left: 15px;
    margin-top: -4px;
    padding: 5px 8px;
    text-transform: uppercase
}
.docs-gm .docs-action-new-badge {
    background-color: transparent;
    border-radius: 4px;
    border: 1px solid #188038;
    box-sizing: border-box;
    color: #188038;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    height: 24px;
    line-height: 24px;
    margin-top: -2px;
    padding: 0px 8px;
    text-transform: none;
    vertical-align: middle
}
.docs-action-new-badge-submenu .docs-action-new-badge {
    margin-right: -27px
}
.docs-action-new-badge-submenu {
    display: inline-block;
    margin-bottom: -4px;
    margin-right: -5px;
    min-width: calc(100% - 40px)
}
.docs-action-new-badge-text-ie {
    float: left
}
.docs-action-new-badge-clearfix-ie:after {
    clear: both;
    content: "";
    display: table
}
.docs-action-updated-dot {
    background-color: #188038;
    border-radius: 50%;
    display: inline-block;
    float: right;
    height: 9px;
    width: 9px;
    margin-top: 5px
}
.docs-action-updated-dot-submenu .docs-action-updated-dot {
    margin-right: -15px
}
.docs-action-updated-dot-submenu {
    display: inline-block;
    margin-bottom: -6px;
    margin-right: -5px;
    min-width: calc(100% - 40px)
}
.docs-action-updated-dot-shortcut-keys .docs-action-updated-dot {
    margin-right: -27px
}
.docs-action-updated-dot-shortcut-keys {
    display: inline-block;
    margin-bottom: -4px;
    margin-right: 12px
}
.apps-marquee {
    font: bold 13px Arial, sans-serif;
    height: 0;
    left: 20%;
    position: fixed;
    _position: absolute;
    text-align: center;
    top: 0;
    width: 60%;
    z-index: 1001
}
.apps-marquee-item {
    display: inline-block;
    margin: 0 5px 4px;
    color: #fff999
}
.apps-marquee-text {
    background: #fff999;
    border-color: #fff999;
    border-style: solid;
    border-width: 0 3px;
    color: black;
    padding: 2px 5px 2px
}
.apps-marquee-round-bottom {
    border-left: 3px dotted transparent;
    border-right: 3px dotted transparent;
    border-top: 3px solid
}
.apps-marquee-round-top {
    border-left: 3px dotted transparent;
    border-right: 3px dotted transparent;
    border-bottom: 3px solid
}
.apps-marquee-warning {
    color: #a00
}
.apps-marquee-warning .apps-marquee-text {
    background: #a00;
    border-color: #a00;
    color: white
}
.apps-promo {
    position: absolute;
    z-index: 10000;
    font-size: 11px
}
.apps-promo-arrow-container {
    position: relative
}
.apps-promo-arrow {
    position: absolute;
    background: transparent url(//ssl.gstatic.com/docs/common/promo_arrows-0.png) no-repeat
}
.apps-promo-close {
    position: relative;
    top: -5px;
    width: 16px;
    height: 16px;
    float: right;
    cursor: pointer;
    background: transparent url(//ssl.gstatic.com/docs/common/promo_close-0.png) no-repeat
}
.apps-promo-popup {
    background: #fff;
    box-shadow: 0 7px 7px #666;
    -moz-box-shadow: 0 7px 7px #666;
    -webkit-box-shadow: 0 7px 7px #666;
    border: 1px solid #ccc;
    width: 275px;
    padding: 15px;
    padding-right: 10px
}
.apps-promo-header-content {
    font-weight: bold;
    font-size: 14px
}
.apps-promo-content {
    padding-top: 15px;
    font-size: 13px
}
.apps-promo-buttons {
    padding-top: 15px;
    padding-left: 4px
}
.apps-promo-buttons a {
    font-size: 13px;
    vertical-align: middle;
    margin-left: 15px
}
.apps-promo-buttons-inner {
    display: inline
}
.apps-promo-buttons-inner .goog-imageless-button-content {
    white-space: nowrap
}
.apps-toast {
    font-size: 13px;
    bottom: -200px;
    width: 227px;
    display: block;
    opacity: 1;
    position: absolute;
    z-index: 50
}
.apps-toast-top {
    height: 18px;
    width: 227px;
    opacity: 1;
    background: url("//ssl.gstatic.com/docs/common/toastBackTop-ltr-1.png")
}
.apps-toast-fill {
    height: 92px;
    width: 227px;
    opacity: 1;
    background: url("//ssl.gstatic.com/docs/common/toastBackFill-0.png");
    z-index: 51
}
.apps-toast-title {
    font-weight: bold;
    padding: 0px 20px
}
.apps-toast-content {
    padding: 0 20px 8px
}

.waffle,
.grid-fixed-table {
    font-size: 13px;
    table-layout: fixed;
    border-collapse: separate;
    border-style: none;
    border-spacing: 0;
    width: 0;
    cursor: default
}
.mimic-overlay {
    position: absolute;
    z-index: 4
}
.mimic-overlay-canvas {
    display: block
}
.scroll-container {
    position: absolute;
    overflow: auto;
    border-width: 0;
    padding: 0;
    margin: 0;
    z-index: 1;
    top: 0;
    left: 0
}
.native-scrollbar {
    overflow: auto;
    position: absolute;
    border-width: 0;
    padding: 0;
    margin: 0;
    top: 0;
    left: 0
}
.static-overlay-container {
    z-index: 6
}
.grid-container {
    background-color: #eee;
    /*overflow: hidden;*/
    position: relative;
    z-index: 0
}
.grid-table-container {
    overflow: hidden;
    z-index: 3;
    position: relative
}
.ritz.grid-container table.waffle svg {
    display: block
}
.fixed-table-container {
    overflow: visible;
    z-index: 4
}
.docs-guides-htmlguiderenderer {
    z-index: 14
}
.fixed4-inner-container,
.fixed4-outer-container,
.grid4-inner-container,
.grid4-outer-container {
    position: relative;
    vertical-align: top
}
.fixed4-outer-container,
.grid4-outer-container {
    overflow: visible
}
.fixed4-inner-container,
.grid4-inner-container {
    overflow: hidden
}
.fixed4-inner-container {
    z-index: 4
}
.grid4-inner-container {
    z-index: 3
}
.grid-fixed-wrapper {
    overflow: hidden;
    white-space: nowrap
}
.grid-scrollable-wrapper {
    white-space: nowrap
}
.uberlay {
    position: absolute;
    height: 0;
    width: 0;
    top: 0
}
.overlay-container-ltr {
    position: absolute;
    height: 0;
    width: 0;
    top: 0;
    left: 0
}
.overlay-container-rtl {
    position: absolute;
    height: 0;
    width: 0;
    top: 0;
    right: 0
}
.focused-overlay-container {
    position: absolute;
    overflow: hidden;
    pointer-events: none
}
.grid-vertical-scroll {
    width: 20px
}
.grid-horizontal-scroll {
    height: 20px;
    float: right
}
.header-bg {
    background-color: #e8eef7
}
.waffle-measurement-table {
    position: absolute;
    width: 0;
    height: 0;
    overflow: hidden
}
.cell-input {
    width: 100%;
    height: 100%;
    margin: 0;
    outline: none;
    cursor: text;
    -webkit-user-modify: read-write-plaintext-only;
    white-space: pre-wrap;
    -webkit-transform: translateZ(0);
    background-color: white
}
.waffle-formula-preview-decorator {
    background: white;
    -webkit-border-radius: 1px;
    -moz-border-radius: 1px;
    border-radius: 1px;
    box-shadow: 0 1px 2px rgba(0, 0, 0, 0.5);
    color: #3266d5;
    font-family: Inconsolata, monospace, arial, sans, sans-serif;
    font-size: 13px;
    line-height: 17px;
    padding: 3px 2px 3px 7px
}
.waffle-formula-preview-decorator.waffle-formula-preview-equals-aligned::before,
.waffle-formula-preview-decorator.waffle-formula-preview-partial::before {
    background-color: white;
    bottom: -4.5px;
    -webkit-box-shadow: 2px 2px 2px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 2px 2px 2px rgba(0, 0, 0, 0.2);
    box-shadow: 2px 2px 2px rgba(0, 0, 0, 0.2);
    content: '\0000a0';
    display: block;
    margin-left: -5px;
    height: 10px;
    position: absolute;
    -webkit-transform: rotate(45deg);
    -moz-transform: rotate(45deg);
    -ms-transform: rotate(45deg);
    -o-transform: rotate(45deg);
    transform: rotate(45deg);
    width: 10px
}
.waffle-formula-preview-decorator.waffle-formula-preview-partial::before {
    left: 50%
}
.waffle-formula-preview-result {
    display: inline-block;
    max-width: 280px;
    overflow: hidden;
    text-overflow: ellipsis;
    vertical-align: top
}
.waffle-formula-preview-button {
    display: inline-block;
    margin: -2px;
    opacity: .35;
    -webkit-transform: scale(.6, .6);
    -moz-transform: scale(.6, .6);
    -ms-transform: scale(.6, .6);
    -o-transform: scale(.6, .6);
    transform: scale(.6, .6)
}
.waffle-formula-preview-button:hover {
    opacity: .7
}
.selection {
    position: absolute;
    opacity: 0.20;
    z-index: 5
}
.input-box {
    position: absolute;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-style: normal;
    font-variant: normal;
    font-weight: 400;
    text-align: left;
    top: -10000px;
    max-height: 9900px;
    max-width: 9900px;
    border: 2px #5292f7 solid;
    padding: 0 2px;
    margin: 0;
    z-index: 15;
    resize: none;
    overflow: auto;
    white-space: pre-wrap;
    outline: none;
    -webkit-box-shadow: 0 2px 5px rgba(0, 0, 0, 0.4);
    -moz-box-shadow: 0 2px 5px rgba(0, 0, 0, 0.4);
    box-shadow: 0 2px 5px rgba(0, 0, 0, 0.4);
    word-wrap: break-word
}
.docs-gm .input-box {
    border-color: #1a73e8;
    -webkit-box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    -moz-box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.input-box-disable-box-shadow {
    box-shadow: none
}
.IE .input-box {
    padding-top: 1px
}
.disabled-input {
    -webkit-user-modify: read-only;
    color: #777
}
.text-sizer,
.input-capturer {
    position: absolute;
    top: -4000px
}
.range-border {
    position: absolute;
    border-width: 0;
    border-style: solid;
    padding: 0;
    _overflow: hidden
}
.border-opacity {
    filter: alpha(opacity=30);
    opacity: 0.3
}
.cell-border {
    line-height: 1px
}
.active-cell-border {
    border-color: #4285f4;
    line-height: 1px;
    z-index: 7
}
.docs-gm .active-cell-border {
    border-color: #1a73e8
}
.selection-border {
    border-color: #4285f4;
    line-height: 0;
    z-index: 7
}
.docs-gm .selection-border {
    border-color: #1a73e8
}
.selection-border-cover {
    position: absolute;
    z-index: 7
}
.selection-border-dragging {
    border-style: dashed;
    border-color: #4285f4;
    line-height: 0;
    z-index: 7
}
.docs-gm .selection-border-dragging {
    border-color: #1a73e8
}
.waffle-clipboard-border {
    border-color: #4285f4;
    border-style: dashed;
    line-height: 0
}
.docs-gm .waffle-clipboard-border {
    border-color: #1a73e8
}
.autofill-border {
    border-color: gray;
    border-style: dashed;
    line-height: 0
}
.array-border {
    border-color: #1a73e8;
    border-style: solid;
    line-height: 0
}
.autofill-handle {
    position: absolute;
    background-color: #4285f4;
    border: 1px solid white;
    width: 6px;
    height: 6px;
    _overflow: hidden;
    z-index: 8;
    margin-top: 1px
}
.docs-gm .autofill-handle {
    background-color: #1a73e8
}
.autofill-handle-rtl {
    border-width: 1px 1px 0 0
}
.autofill-handle-ltr {
    border-width: 1px 0 0 1px
}
.autofill-cover {
    position: absolute;
    cursor: crosshair;
    width: 8px;
    height: 8px;
    z-index: 9
}
.postpaste-parent {
    background: #f5f5f5;
    border: 1px solid #d9d9d9;
    -webkit-box-shadow: inset 0 1px 0 0 #fff;
    -moz-box-shadow: inset 0 1px 0 0 #fff;
    box-shadow: inset 0 1px 0 0 #fff;
    background-color: #f5f5f5;
    background-image: -webkit-linear-gradient(top, #f5f5f5, #eee);
    background-image: -moz-linear-gradient(top, #f5f5f5, #eee);
    background-image: -ms-linear-gradient(top, #f5f5f5, #eee);
    background-image: -o-linear-gradient(top, #f5f5f5, #eee);
    background-image: linear-gradient(top, #f5f5f5, #eee);
    position: absolute;
    z-index: 8
}
.docs-gm .postpaste-parent {
    background: #fff;
    border: none;
    box-shadow: 0 1px 3px 1px rgba(60, 64, 67, .15);
    border-radius: 4px
}
.goog-toolbar-menu-button.postpaste-container {
    margin: 0;
    min-width: 0px;
    border-color: transparent!important
}
.docs-gm .goog-toolbar-menu-button.postpaste-container {
    border: none!important;
    height: 100%;
    width: 100%
}
.docs-gm .postpaste-container.goog-toolbar-menu-button-open.goog-toolbar-menu-button-hover {
    background: #ceead6
}
.goog-toolbar-menu-button-focused.postpaste-container {
    border-color: #c6c6c6!important
}
.goog-toolbar-menu-button-open.postpaste-container {
    border-color: #c6c6c6!important
}
.goog-menuitem.postpaste-menu-item {
    padding-right: 26px;
    padding-left: 15px
}
.post-paste-menu {
    margin: 12px 3px 0 0
}
.goog-toolbar-menu-button-dropdown.postpaste-arrow {
    right: 0;
    margin-right: -3px;
    margin-left: -15px
}
.docs-gm .postpaste-clipboard-icon {
    margin-left: 8px;
    margin-top: 4px
}
.docs-gm .overlay-container-rtl .postpaste-clipboard-icon {
    margin-right: 26px
}
.docs-gm .goog-toolbar-menu-button-dropdown.postpaste-arrow {
    left: 0;
    margin-left: 32px;
    margin-top: 4px;
    position: absolute
}
.docs-gm .overlay-container-rtl .goog-toolbar-menu-button-dropdown.postpaste-arrow {
    margin-right: 10px
}
.waffle-texttocolumns-overlay {
    position: absolute;
    z-index: 8
}
.waffle-dbsource-container {
    position: absolute;
    z-index: 8
}
.waffle-texttocolumns-wrapper {
    background: #f5f5f5;
    border: 1px solid #d9d9d9;
    padding: 2px
}
.waffle-texttocolumns-separator-label {
    font-size: 11px;
    font-weight: 500;
    margin: 2px;
    top: 0
}
.waffle-texttocolumns-custom-input {
    position: absolute;
    top: 3px;
    width: 120px
}
.waffle-blameview {
    background: #fff;
    border-radius: 8px;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    display: flex;
    outline: none;
    overflow: hidden;
    position: absolute;
    width: 240px
}
.waffle-blameview-cell-ref {
    font-family: Inconsolata, monospace, arial, sans, sans-serif;
    font-style: normal
}
.waffle-blameview-formula-text {
    font-family: Inconsolata, monospace, arial, sans, sans-serif;
    font-style: normal
}
a.waffle-blameview-image-link {
    color: #1a73e8;
    font-style: italic;
    text-decoration: underline
}
.freezebar .freezebar-drop,
.freezebar .freezebar-handle-bar,
.resizer,
.resizer-hover .resizer-handle-bar,
.resizer-drop,
.rowcol-dragger .rowcol-dragger-handle,
.rowcol-dragger .rowcol-dragger-handle-bar,
.rowcol-dragger .rowcol-dragger-drop {
    display: none;
    outline: 0
}
.freezebar-active .freezebar-drop,
.freezebar-active .freezebar-handle-bar,
.resizer-hover,
.resizer-active,
.resizer-active .resizer-handle-bar,
.resizer-active .resizer-drop,
.rowcol-dragger-hover .rowcol-dragger-handle,
.rowcol-dragger-active .rowcol-dragger-handle,
.rowcol-dragger-active .rowcol-dragger-handle-bar,
.rowcol-dragger-active .rowcol-dragger-drop {
    display: block
}
.resizer {
    z-index: 7;
    position: absolute
}
.resizer-handle {
    position: relative;
    border-style: none
}
.resizer-horizontal-handle {
    height: 5px;
    cursor: n-resize;
    background: #4d90fe
}
.resizer-vertical-handle {
    width: 5px;
    cursor: e-resize;
    background: #4d90fe
}
.resizer-rtl .resizer-vertical-handle {
    cursor: w-resize
}
.resizer-horizontal-handle-bar {
    position: absolute;
    height: 1px;
    background-color: #4d90fe;
    top: 2px;
    overflow: hidden
}
.resizer-vertical-handle-bar {
    position: absolute;
    width: 1px;
    background-color: #4d90fe;
    left: 2px;
    border: 0;
    padding: 0;
    overflow: hidden
}
.freezebar-handle,
.freezebar-drop {
    position: absolute;
    z-index: 6
}
.freezebar-handle-bar,
.freezebar-drop-bar {
    position: relative;
    z-index: 7
}
.freezebar-vertical-handle-bar {
    width: 2px;
    background: #dbe5f7;
    border-color: #a5c6fe;
    border-style: solid;
    border-width: 0 1px;
    opacity: 0.45;
    filter: alpha(opacity=45)
}
.freezebar-horizontal-handle-bar {
    height: 2px;
    background: #dbe5f7;
    border-color: #a5c6fe;
    border-style: solid;
    border-width: 1px 0;
    opacity: 0.45;
    filter: alpha(opacity=45)
}
.freezebar-vertical-handle {
    width: 4px;
    background: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAYCAIAAABSh8vJAAAAEElEQVQYV2PYgwQYRjnEcgDquNOBEawK+wAAAABJRU5ErkJggg==") no-repeat
}
.overlay-container-rtl .freezebar-vertical-handle {
    background: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAYCAIAAABSh8vJAAAAEElEQVQYV2PYgwQYRjnEcgDquNOBEawK+wAAAABJRU5ErkJggg==") no-repeat;
    background-position: top right
}
.freezebar-vertical-handle-invisible {
    width: 4px
}
.freezebar-active .freezebar-vertical-handle {
    width: 5px
}
.freezebar-hover .freezebar-horizontal-handle {
    background: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAC4AAAAECAIAAAB+7JowAAAAFUlEQVQY02NYeuzfIEEMo04Z3E4BAHKzu4gtAIWGAAAAAElFTkSuQmCC") no-repeat;
    z-index: 7
}
.freezebar-hover .freezebar-vertical-handle {
    background: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAYCAIAAABSh8vJAAAAE0lEQVQYV2NYeuwfHDGMcojlAADmjOdhimOdggAAAABJRU5ErkJggg==") no-repeat;
    z-index: 7
}
.overlay-container-rtl .freezebar-hover .freezebar-horizontal-handle {
    background: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAC4AAAAECAIAAAB+7JowAAAAFUlEQVQY02NYeuzfIEEMo04Z3E4BAHKzu4gtAIWGAAAAAElFTkSuQmCC") no-repeat;
    background-position: top right
}
.overlay-container-rtl .freezebar-hover .freezebar-vertical-handle {
    background: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAYCAIAAABSh8vJAAAAE0lEQVQYV2NYeuwfHDGMcojlAADmjOdhimOdggAAAABJRU5ErkJggg==") no-repeat;
    background-position: top right
}
.freezebar-horizontal-handle {
    height: 4px;
    background: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAC4AAAAECAIAAAB+7JowAAAAEklEQVQY02PYM2gAw6hTBrdTAFI0lXC16jX6AAAAAElFTkSuQmCC") no-repeat
}
.overlay-container-rtl .freezebar-horizontal-handle {
    background: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAC4AAAAECAIAAAB+7JowAAAAEklEQVQY02PYM2gAw6hTBrdTAFI0lXC16jX6AAAAAElFTkSuQmCC") no-repeat;
    background-position: top right
}
.overlay-container-rtl .freezebar-horizontal-drop {
    background-position: right
}
.freezebar-horizontal-handle-invisible {
    height: 4px
}
.freezebar-active .freezebar-horizontal-handle {
    height: 5px
}
.freezebar-origin-rtl,
.freezebar-origin-ltr {
    height: 23px;
    width: 45px;
    position: absolute;
    top: 0px;
    border: 1px #ccc solid
}
.freezebar-origin-ltr {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -205px 0;
    left: 0px;
    border-width: 0 1px 1px 0
}
.freezebar-origin-rtl {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -305px -62px;
    right: 0px;
    border-width: 0 0 1px 1px
}
.freezebar-vertical-drop {
    background: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAQAAAAYCAIAAABSh8vJAAAAEklEQVQYV2NInfsHjhhGOcRyAFpkv0GBZT1JAAAAAElFTkSuQmCC") no-repeat;
    width: 4px
}
.freezebar-horizontal-drop {
    background: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAC4AAAAECAIAAAB+7JowAAAAFUlEQVQoz2NInftnkCCGUacMbqcAAL1HbqBCYk6sAAAAAElFTkSuQmCC") no-repeat;
    height: 4px
}
.freezebar-vertical-drop-bar {
    width: 4px;
    background-color: #afbbd1;
    border-width: 2px 1px 2px 2px
}
.freezebar-horizontal-drop-bar {
    height: 4px;
    overflow: hidden;
    background-color: #afbbd1;
    border-width: 2px 2px 1px 2px
}
.waffle-incelldropdownselect-menu-vertical {
    overflow-y: auto
}
.rowcol-dragger {
    position: absolute;
    z-index: 6
}
.rowcol-dragger-drop-bar,
.rowcol-dragger-handle-bar {
    z-index: 6;
    position: absolute;
    background-color: #777;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    box-sizing: border-box
}
.rowcol-dragger-handle-bar {
    border: 2px solid #36c;
    opacity: 0.20;
    filter: alpha(opacity=20)
}
.rowcol-dragger-horizontal-handle {
    width: 36px
}
.rowcol-dragger-horizontal-drop-bar {
    height: 2px
}
.rowcol-dragger-vertical-handle {
    height: 23px
}
.rowcol-dragger-vertical-drop-bar {
    width: 2px
}
.rowcol-dragger-handle,
.rowcol-dragger-drop {
    position: absolute;
    z-index: 6
}
.jfk-freestanding-menu-button.waffle-kennedy-column-menu-button {
    background: url("data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iNyIgaGVpZ2h0PSI0IiAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj48cGF0aCBmaWxsPSIjQkRCREJEIiBkPSJNMCAwTDcgMCBMMy41IDR6Ii8+PC9zdmc+") center no-repeat;
    background-color: #f8f8f8;
    z-index: 7
}
.jfk-freestanding-menu-button-hover.waffle-kennedy-column-menu-button {
    background: url("data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iNyIgaGVpZ2h0PSI0IiAgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj48cGF0aCBmaWxsPSIjNjE2MTYxIiBkPSJNMCAwTDcgMCBMMy41IDR6Ii8+PC9zdmc+") center no-repeat;
    background-color: #f8f8f8
}
a.in-cell-link {
    text-decoration: underline;
    cursor: default
}
.docs-bubble-link.docs-bubble-link-visited {
    color: #673ab7!important
}
.docs-gm .docs-material .docs-link-insertlinkbubble .docs-icon-grid,
.docs-gm .docs-material .docs-link-insertlinkbubble .docs-icon-grid:before {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_green.svg)
}
.annotation-bubble {
    position: absolute;
    z-index: 14;
    margin: 0 0 0 -2px;
    padding: 0;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    max-width: 200px
}
.annotation-editable {
    background-color: white;
    border: none;
    border-left: 3px solid #222;
    box-shadow: 0px 3px 6px rgba(0, 0, 0, 0.2);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    margin: 0;
    padding: 6px;
    width: 100%
}
.docs-gm .annotation-editable {
    border: 1px solid rgba(60, 64, 67, .15);
    border-radius: 4px;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    color: #5f6368;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-weight: 500;
    outline: none;
    padding: 8px
}
.annotation-attribution {
    background-color: #fff;
    padding: 13px 10px;
    font-size: 13px;
    box-shadow: 0px 3px 6px rgba(0, 0, 0, 0.2)
}
.annotation-attribution-invalid {
    border-left: 5px solid #ff5621
}
.annotation-attribution-help {
    border-left: 5px solid #f29400
}
.annotation-attribution-error {
    border-left: 5px solid #c53929
}
.annotation-importrange {
    background-color: #ffffff;
    border: 1px solid #ff0000;
    box-shadow: 2px 2px 6px #888;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    margin: 0;
    overflow-x: hidden;
    text-align: left;
    vertical-align: top;
    width: 100%
}
.annotation-attribution-rebranded strong {
    display: block;
    font-size: 13px;
    font-weight: 500;
    margin-bottom: 6px
}
.annotation-attribution-error strong {
    color: #c53929
}
.annotation-attribution-help strong {
    color: #f29400
}
.annotation-attribution-invalid strong {
    color: #ff5621
}
.annotation-attribution-rebranded span {
    display: block;
    line-height: 1.25em
}
.annotation-importrange-error-msg-box {
    margin-bottom: 10px;
    text-align: left
}
.waffle-footer-container {
    height: 4000px;
    position: relative;
    z-index: 3
}
.waffle-background-container {
    background-color: #eee;
    width: 50000px;
    height: 0px;
    position: absolute;
    top: 0;
    z-index: -1
}
.addRowsWidget-ltr {
    color: #222;
    float: left;
    padding: 6px 0 0 45px;
    direction: ltr
}
.addRowsWidget-rtl {
    color: #222;
    float: right;
    padding: 6px 45px 0 0;
    direction: ltr
}
div.addRowsButton-ltr {
    margin-top: 0;
    margin-right: 2px;
    vertical-align: middle
}
div.addRowsButton-rtl {
    margin-top: 0;
    margin-left: 2px;
    vertical-align: middle
}
div.addRowsText {
    color: #000000;
    padding-top: 5px;
    vertical-align: middle
}
.addRowsError-ltr {
    color: #c00;
    float: left;
    padding: 13px 0 0 10px
}
.addRowsError-rtl {
    color: #c00;
    float: right;
    padding: 13px 10px 0 0
}
.addRowsInput {
    margin: 0 4px 0 4px;
    vertical-align: middle
}
.waffle-formula-help-popup P {
    margin-top: 0
}
.waffle-formula-help-popup a:visited {
    color: #15c
}
.waffle-formula-help-popup {
    position: absolute;
    top: 0px;
    left: 0px;
    -moz-border-radius: 2px 2px 2px 2px;
    border-radius: 2px 2px 2px 2px;
    -moz-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
    -webkit-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
    box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
    background-color: #ffffff;
    border: 1px solid #cccccc;
    padding: 16px;
    width: 400px;
    margin-left: -1px;
    margin-top: -1px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 400;
    font-style: normal;
    color: #333333;
    white-space: normal
}
.waffle-input-box-decorator {
    border-style: none;
    border-width: 0px;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    font-weight: 500;
    overflow: visible;
    position: absolute;
    white-space: nowrap;
    z-index: 15
}
.waffle-input-box-locator {
    background-color: #4589eb;
    border-radius: 1px;
    box-shadow: 0px 1px 2px rgba(0, 0, 0, 0.5);
    color: white;
    font-size: 12px;
    line-height: 14px;
    padding: 6px 7px 4px 7px
}
.waffle-input-box-formula-help-decorator {
    background: #6da1ff;
    border: 2px solid #5790f6;
    border-right: none;
    color: white;
    -webkit-border-radius: 2px 0 0 2px;
    -moz-border-radius: 2px 0 0 2px;
    border-radius: 2px 0 0 2px;
    cursor: pointer;
    font-size: 11px;
    height: 20px;
    line-height: 13px;
    padding: 2px 2px
}
.waffle-formula-bar-formula-help-decorator {
    -webkit-border-radius: 2px 2px 2px 2px;
    -moz-border-radius: 2px 2px 2px 2px;
    border-radius: 2px 2px 2px 2px;
    border-right: 2px solid #5790f6;
    height: 18px;
    line-height: 11px
}
.waffle-collab-presence {
    z-index: 7;
    position: absolute;
    padding: 0px 1px 0px 2px;
    background-color: #65ad89;
    color: white;
    font-size: 10px;
    font-weight: 500;
    -moz-box-sizing: border-box
}
.docs-gm-sidebars .waffle-collab-presence {
    border-radius: 2px;
    box-sizing: border-box;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-weight: 500;
    line-height: 12px;
    padding: 1px 2px
}
#waffle-loading-screen {
    background-color: #fff;
    width: 100%;
    font-size: 15px;
    display: none
}
.waffle-loading-rows {
    width: 100%;
    font-size: 12px;
    padding: 5px 30px
}
.waffle-loading-rows-spinner {
    vertical-align: text-bottom;
    width: 16px;
    height: 16px;
    margin: 0px 10px
}
.waffle-hyperlink-icon {
    display: inline-block;
    position: absolute
}
.waffle-hyperlink-icon-visited:after {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -565px -12px;
    cursor: pointer;
    width: 12px;
    height: 12px;
    display: block;
    float: right;
    content: "";
    margin-top: 4px;
    margin-bottom: -1px
}
.waffle-hyperlink-icon:after {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -70px -24px;
    cursor: pointer;
    width: 12px;
    height: 12px;
    display: block;
    float: right;
    content: "";
    margin-top: 4px;
    margin-bottom: -1px
}
.waffle-hyperlink-tooltip:hover {
    background: #fff;
    box-shadow: 0px 0px 2px 0px rgba(0, 0, 0, 0.20), 0px 2px 3px 0px rgba(0, 0, 0, 0.30)
}
.waffle-hyperlink-tooltip {
    background: #fcfcfc;
    box-shadow: 0px 0px 2px 0px rgba(0, 0, 0, 0.15), 0px 1px 2px 0px rgba(0, 0, 0, 0.40);
    border-radius: 1px;
    display: inline-block;
    padding: 5px 18px 5px 7px;
    position: absolute
}
.waffle-hyperlink-tooltip-link {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    color: #15c;
    line-height: 19px;
    padding: 5px 7px 5px 0;
    text-decoration: none;
    white-space: nowrap
}
a.waffle-hyperlink-tooltip-link {
    color: #15c
}
.waffle-hyperlink-tooltip-link:hover {
    text-decoration: none
}
.waffle-column-menu-button {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -168px -43px;
    cursor: pointer;
    list-style: none;
    width: 12px;
    height: 12px;
    outline: none;
    position: absolute;
    z-index: 7
}
.waffle-column-menu-button-hover,
.waffle-column-menu-button-checked,
.waffle-column-menu-button-focused {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -83px -34px
}
.waffle-column-menu-button-disabled {
    cursor: default;
    filter: alpha(opacity=30);
    opacity: 0.3
}
.waffle-disclaimer {
    font-size: 11px;
    background-color: #ececec;
    color: #656565;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
    height: 20px
}
#waffle-disclaimer-content {
    border-bottom: 1px solid #c0c0c0;
    border-left: 0 none;
    border-right: 0 none;
    padding-left: 47px
}
.waffle-disclaimer-link {
    color: #77c;
    padding-left: 3px
}
.apps-toast {
    z-index: 16
}
.apps-toast-fill {
    z-index: 17
}
.trix-offscreen {
    position: absolute;
    left: -10000px;
    top: -10000px
}
#promo-target {
    display: inline
}
#waffle-grid-container {
    margin-right: auto
}
#docs-editor-container {
    touch-action: none;
    -ms-scroll-chaining: none
}
.border-style-menu-item-container {
    background-position: left 15px center;
    padding-left: 30px!important;
    padding-right: 40px!important
}
.border-style-menu-item {
    height: 12px;
    min-height: 12px!important
}
.border-style-menu-item .border-style-menu-icon {
    position: relative;
    left: 15px;
    top: -4px
}
@media all and (-ms-high-contrast:none),
(-ms-high-contrast:active) {
    .border-style-menu-item .border-style-menu-icon {
        position: relative;
        left: 15.5px;
        top: -4.78px
    }
}
@media screen and (-moz-windows-theme) {
    .border-style-menu-item .border-style-menu-icon {
        position: relative;
        left: 15px;
        top: -4.5px
    }
}
#t-border-palette .goog-palette-cell-selected {
    background-color: #e1e1e1
}
#t-border-palette .goog-palette-cell {
    padding: 2px
}
#t-border-palette .goog-palette-table {
    border-right: 1px solid #eee
}
span.jfk-checkbox {
    margin-bottom: 1px
}
.match-paren {
    background-color: #e5e5e5;
    font-weight: 500
}
.match-string {
    background-color: #eee
}
.error-code,
.boolean {
    color: #15c
}
.active-range {
    box-shadow: 0 0 6px 2px #333;
    opacity: 0.1;
    pointer-events: none
}
.inactive {
    opacity: 0.5
}
.formula-error {
    color: #dd4b39
}
.argument-error,
.formula-eval-error {
    color: #dd4b39;
    text-decoration: underline
}
.number {
    color: #15c
}
.string {
    color: green
}
.default-formula-text-color {
    color: black
}
.insert-range-indicator {
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSI4IiBoZWlnaHQ9IjMiIHN0eWxlPSJmaWxsOm5vbmU7c3Ryb2tlOiNjY2MiPjxwYXRoIGQ9Ik0wLjUgMEwwLjUgM00wIDIuNUw4IDIuNU03LjUgM0w3LjUgMCIvPjwvc3ZnPg==") bottom no-repeat;
    background-size: contain;
    width: 8px;
    margin-left: 2px;
    cursor: default
}
.insert-range-indicator:after {
    content: " "
}
.formula-replace-text {
    text-decoration: underline
}
.trix-tooltip-link {
    color: #4285f4
}
.trix-tooltip-link:hover {
    text-decoration: underline
}
.formula-content {
    font-family: Inconsolata, monospace, arial, sans, sans-serif;
    font-size: 14px
}
#apps-debug-tracers {
    display: none
}
.jfk-bubble.waffle-error-bubble {
    background-color: #fff3f2;
    border: 1px solid #db4437;
    border-radius: 1px;
    box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.1);
    color: #c53929;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 11px;
    line-height: 17px;
    max-width: 200px;
    padding: 8px;
    transition: opacity 200ms ease-in
}
.waffle-function-localization-promo {
    background-color: #fafafa;
    bottom: 100px;
    -webkit-box-shadow: 1px 2px 5px rgba(0, 0, 0, 0.28);
    -moz-box-shadow: 1px 2px 5px rgba(0, 0, 0, 0.28);
    box-shadow: 1px 2px 5px rgba(0, 0, 0, 0.28);
    color: #616161;
    height: 180px;
    padding: 20px;
    position: absolute;
    right: 25px;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    width: 350px;
    z-index: 1000
}
.waffle-function-localization-promo-title {
    font-size: 18px;
    font-weight: 500;
    margin: 5px 0 20px 0
}
.waffle-function-localization-promo-body {
    font-size: 13px;
    line-height: 22px
}
.waffle-function-localization-promo-button-bar {
    bottom: 25px;
    right: 25px;
    line-height: 22px;
    position: absolute
}
.jfk-button.waffle-function-localization-promo-no-button {
    color: #0f9d58;
    cursor: pointer;
    margin-right: 10px;
    padding: 5px
}
.jfk-button.waffle-function-localization-promo-yes-button {
    background-color: #0f9d58;
    color: #fafafa;
    cursor: pointer;
    padding: 5px
}
.apps-ui-material-slide-toggle-container-checked .apps-ui-material-slide-toggle-track,
.apps-ui-material-slide-toggle-container-checked .apps-ui-material-slide-toggle-thumb {
    background-color: #4285f4
}
.apps-actiondatawidget-shortcut-desc {
    width: 278px
}
.apps-actiondatawidget-shortcut-key {
    line-height: 17px;
    width: 251px;
    padding-left: 24px
}
.apps-actiondatawidget-content {
    width: 100%
}
::-ms-clear,
::-ms-reveal {
    display: none
}
.waffle-rich-text-link,
a.waffle-rich-text-link {
    color: #15c;
    text-decoration: underline
}
.waffle-rich-text-link-popup {
    background-color: #fff;
    border: 1px solid;
    border-color: #bbb #bbb #a8a8a8;
    padding: 12px 20px;
    position: absolute;
    white-space: nowrap;
    z-index: 15
}
.waffle-dataconnectormenu-note {
    color: rgba(0, 0, 0, 0.38);
    font-size: 11px;
    padding-left: 8px
}
.docs-gm-dialogs .waffle-cellinput-range-picker,
.waffle-cellinput-range-picker {
    width: 100px;
    font-size: 14px;
    height: 28px;
    border: 2px solid #d9d9d9;
    margin: 5px 5px 0 0
}
.docs-gm-dialogs .waffle-cellinput-range-picker:focus {
    border: 2px solid #d9d9d9;
    padding: 1px 8px
}
.docs-charts-editor {
    margin-right: 10px
}
.docs-charts-editor .docs-charts-editor-toggle-tabs {
    position: absolute;
    top: 0;
    width: 100%
}
.docs-charts-editor .docs-charts-editor-scroll-pane {
    bottom: 0;
    position: absolute;
    top: 43px;
    overflow: auto;
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor .docs-charts-editor-scroll-pane .docs-charts-editor-customize-tab {
    background-color: #f8f9fa;
    bottom: 0;
    position: absolute;
    top: 0;
    width: 100%
}
.docs-charts-editor-control-label {
    color: #616161;
    font-size: 11px;
    line-height: 16px;
    margin-right: 2px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-control-label {
    color: #5f6368;
    display: block;
    font-size: 12px;
    line-height: 15px;
    margin-bottom: 8px
}
.docs-charts-editor-row,
.docs-charts-editor-tall-row {
    font-size: 0
}
.docs-charts-editor-row>.docs-charts-editor-col {
    font-size: 13px;
    vertical-align: top
}
.docs-charts-editor-row>.docs-charts-editor-col>div {
    margin: 10px 0 10px 0
}
.docs-charts-editor-checkboxes-container {
    margin: 10px 0
}
.docs-charts-editor-checkboxes-container-no-bottom-margin {
    margin: 10px 0 0
}
.docs-charts-editor-checkboxes-container .docs-material-gm-labeled-checkbox {
    padding: 4px 0
}
.docs-charts-editor-row>.docs-charts-editor-col>div>.docs-material-labeled-checkbox {
    margin: 0
}
.docs-charts-editor-tall-row>.docs-charts-editor-col>div {
    margin: 20px 0 20px 0
}
.docs-charts-editor-tall-row:first-child .docs-charts-editor-col>div {
    margin-top: 10px
}
.docs-charts-editor-col.col-100 {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    width: 100%
}
.docs-charts-editor-col.col-50 {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    display: inline-block;
    width: 50%
}
.docs-charts-editor-col.col-50:first-of-type {
    padding-right: 10px
}
.docs-charts-editor-col.col-50:last-of-type {
    padding-left: 10px
}
.docs-charts-editor-col.col-70-left {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    display: inline-block;
    padding-right: 10px;
    width: 70%
}
.docs-charts-editor-col.col-30-right {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    display: inline-block;
    padding-left: 10px;
    width: 30%
}
.docs-charts-editor-col.col-60-left {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    display: inline-block;
    padding-right: 10px;
    width: 60%
}
.docs-charts-editor-col.col-40-right {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    display: inline-block;
    padding-left: 10px;
    width: 40%
}
.docs-charts-editor-col.col-50 .docs-material-gm-labeled-checkbox-content {
    max-width: 80%
}
.docs-charts-editor-col.col-50>div>.docs-material-labeled-checkbox {
    margin-top: 24px
}
.docs-charts-editor-scroll-pane.docs-charts-editor-scroll-pane-custom-sidebar::-webkit-scrollbar {
    width: 12px
}
.docs-charts-editor-scroll-pane.docs-charts-editor-scroll-pane-custom-sidebar::-webkit-scrollbar-thumb {
    background-color: rgba(0, 0, 0, 0.2);
    background-clip: padding-box;
    border: solid transparent;
    border-width: 1px 2px 1px 2px;
    box-shadow: none;
    min-height: 28px;
    padding: 1px
}
.docs-charts-editor-scroll-pane.docs-charts-editor-scroll-pane-custom-sidebar::-webkit-scrollbar-thumb:hover {
    box-shadow: none
}
.docs-charts-editor-scroll-pane.docs-charts-editor-scroll-pane-custom-sidebar::-webkit-scrollbar-track {
    background-clip: border-box;
    background-color: #f5f5f5;
    border: solid #e0e0e0;
    border-width: 1px;
    box-shadow: none
}
.docs-charts-editor-scroll-pane.docs-charts-editor-scroll-pane-custom-sidebar::-webkit-scrollbar-track:hover {
    background-color: #f5f5f5;
    background-clip: border-box;
    box-shadow: none;
    border: solid #e0e0e0;
    border-width: 1px
}
.docs-charts-editor-bundle.docs-charts-editor-parent-bundle {
    border-bottom: 1px solid rgba(0, 0, 0, 0.12)
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-customize-tab .docs-charts-editor-bundle.docs-charts-editor-parent-bundle {
    border-bottom: 2px solid #f8f9fa
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-customize-tab .docs-charts-editor-bundle.docs-charts-editor-parent-bundle>div {
    border: 2px solid #f8f9fa
}
.docs-charts-editor-bundle.docs-charts-editor-parent-bundle.docs-charts-editor-open-bundle {
    padding: 8px 16px 6px 16px
}
.docs-charts-editor-selector-bundle-selector-wrapper {
    padding: 0 16px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-selector-bundle-selector-wrapper {
    padding: 8px 16px
}
.docs-charts-editor-selector-bundle-selector-label {
    color: rgba(0, 0, 0, 0.54);
    display: inline-block;
    line-height: 26px;
    vertical-align: top
}
.docs-charts-editor-selector-bundle-selector {
    display: inline-block;
    padding-left: 12px;
    max-width: 160px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-selector-bundle-selector {
    max-width: 100%;
    padding-left: 0;
    width: 100%
}
.docs-charts-editor-selector-bundle-selector .docs-material-labeled-select-outer-box {
    border: none;
    margin-bottom: 0px
}
.docs-charts-editor-selector-bundle-selector .docs-material-gm-labeled-select-outer-box {
    -webkit-box-shadow: 0 1px 3px 1px rgba(60, 64, 67, .15);
    -moz-box-shadow: 0 1px 3px 1px rgba(60, 64, 67, .15);
    box-shadow: 0 1px 3px 1px rgba(60, 64, 67, .15);
    border: none;
    margin-bottom: 0px
}
.docs-charts-editor-selector-bundle-selector .docs-material-labeled-select-caption {
    font-weight: 500
}
.docs-charts-editor-selector-bundle-selector .docs-material-gm-labeled-select-caption {
    color: #188038;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    letter-spacing: .25px
}
.docs-charts-editor-selector-bundle-selector .docs-material-labeled-select-content {
    display: none
}
.docs-charts-editor-selector-bundle-selector .docs-material-gm-labeled-select-content {
    display: none
}
.docs-charts-editor-selector-bundle-selector .docs-material-gm-labeled-select-focused .docs-material-gm-labeled-select-outer-box,
.docs-charts-editor-selector-bundle-selector .docs-material-gm-labeled-select-open .docs-material-gm-labeled-select-outer-box {
    background-color: #f1f3f4
}
.docs-charts-editor-selector-bundle-selector .docs-material-gm-labeled-select-hover .docs-material-gm-labeled-select-outer-box {
    background-color: #f8f9fa
}
.docs-charts-editor-selector-bundle {
    background: #fafafa;
    padding: 4px 16px 6px 16px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-selector-bundle {
    background: transparent
}
.docs-charts-editor-selector-bundle .docs-charts-editor-selector-bundle-header {
    color: #616161;
    font-size: 13px;
    margin-bottom: -4px;
    padding-top: 8px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-selector-bundle .docs-charts-editor-selector-bundle-header {
    color: #3c4043;
    font-size: 14px;
    font-weight: 500;
    letter-spacing: .2px;
    line-height: 24px;
    padding: 10px 0
}
.docs-charts-editor-bundle-container {
    padding: 0 16px 6px
}
.docs-charts-editor-basic-bundle .docs-charts-editor-bundle.docs-charts-editor-parent-bundle {
    border-bottom: none
}
.docs-charts-editor-basic-bundle .docs-charts-editor-bundle.docs-charts-editor-parent-bundle.docs-charts-editor-open-bundle {
    padding-bottom: 0px
}
.docs-charts-editor-basic-bundle .docs-charts-editor-row,
.docs-charts-editor-data-picker-bundle .docs-charts-editor-row {
    overflow: hidden
}
.docs-charts-editor-data-picker-bundle .docs-charts-editor-bundle.docs-charts-editor-parent-bundle {
    border-bottom: none;
    padding-top: 0
}
.docs-charts-editor-alert-bundle {
    color: rgba(0, 0, 0, 0.54);
    line-height: 22px;
    text-align: center
}
.docs-charts-editor-alert-bundle .docs-charts-editor-bundle.docs-charts-editor-parent-bundle {
    -ms-flex-align: center;
    -moz-box-align: center;
    -webkit-box-align: center;
    box-align: center;
    -webkit-align-items: center;
    align-items: center;
    border-bottom: none;
    bottom: 0;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}
.docs-charts-editor-alert-bundle .docs-charts-editor-bundle.docs-charts-editor-parent-bundle>div {
    width: 100%
}
.docs-charts-editor-alert-bundle-icon {
    background-image: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyNCIgaGVpZ2h0PSIyNCIgdmlld0JveD0iMCAwIDI0IDI0IiBmaWxsPSIjRTBFMEUwIj48cGF0aCBkPSJNOSAxN0g3di03aDJ2N3ptNCAwaC0yVjdoMnYxMHptNCAwaC0ydi00aDJ2NHptMi41IDJoLTE1VjVoMTV2MTR6bTAtMTZoLTE1Yy0xIDAtMiAxLTIgMnYxNGMwIDEgMSAyIDIgMmgxNWMxIDAgMi0xIDItMlY1YzAtMS0xLTItMi0yeiIvPjxwYXRoIGZpbGw9Im5vbmUiIGQ9Ik0wIDBoMjR2MjRIMHoiLz48L3N2Zz4=");
    background-position: center;
    background-repeat: no-repeat;
    background-size: 100px 100px;
    height: 100px;
    width: 100%
}
.docs-charts-editor-pill-remove-button {
    -webkit-transition: background-color 0.2s ease;
    -moz-transition: background-color 0.2s ease;
    -o-transition: background-color 0.2s ease;
    transition: background-color 0.2s ease;
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAyNCAyNCI+ICA8cGF0aCBmaWxsPSIjZjBmMGYwIiBkPSJNMTkgNi40MUwxNy41OSA1IDEyIDEwLjU5IDYuNDEgNSA1IDYuNDEgMTAuNTkgMTIgNSAxNy41OSA2LjQxIDE5IDEyIDEzLjQxIDE3LjU5IDE5IDE5IDE3LjU5IDEzLjQxIDEyeiIvPjwvc3ZnPg==");
    background-color: #bfbfbf;
    border-radius: 16px;
    bottom: 2px;
    height: 16px;
    margin: 8px;
    position: absolute;
    width: 16px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-pill-remove-button {
    background: none;
    border: none;
    float: right;
    position: relative;
    width: auto
}
.docs-charts-editor-pill-remove-button.jfk-button-hover {
    background-color: #aaa
}
.docs-charts-editor-pill {
    background-color: #fff;
    border-radius: 6px;
    box-shadow: 0 0 2px 0 #bdbdbd;
    padding-left: 10px;
    padding-right: 10px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-pill {
    border-radius: 0;
    box-shadow: none;
    padding-left: 0;
    padding-right: 0
}
.docs-charts-editor-pill-remove {
    position: relative;
    width: 16px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-pill-remove {
    width: 100%
}
.docs-charts-editor-pill-flex {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.docs-charts-editor-pill-flex-col {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    -ms-flex: 50%;
    -webkit-flex: 50%;
    flex: 50%;
    display: inline-block;
    padding-left: 10px
}
.docs-charts-editor-pill-flex-col:first-of-type {
    padding-left: 0px
}
.docs-charts-editor-pill-fixed-col {
    padding-left: 10px
}
.docs-charts-editor-pill-fixed-col:first-of-type {
    padding-left: 0px
}
.docs-charts-editor-column-names-menu-wrapper {
    display: none
}
.docs-charts-editor-column-names-menu-enabled {
    width: 460px!important
}
.docs-charts-editor-column-names-menu-enabled .docs-charts-editor-toggle-tabs {
    border-bottom: 1px solid #dadce0
}
.docs-charts-editor-column-names-menu-enabled .docs-charts-editor-basic-tab {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    height: 100%;
    overflow: hidden
}
.docs-charts-editor-column-names-menu-enabled .docs-charts-editor-basic-tab-bundle-wrapper {
    border-right: 1px solid #dadce0;
    height: 100%;
    overflow-y: auto;
    width: 300px
}
.docs-charts-editor-column-names-menu-enabled .docs-charts-editor-column-names-menu-wrapper {
    display: block;
    height: 100%;
    overflow-y: auto;
    width: 160px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-customize-tab hr {
    background-color: #dadce0;
    border: 0;
    height: 1px;
    margin: 17px -16px
}
.docs-charts-editor-charttype-select-icon {
    float: left
}
.docs-charts-editor-charttype-select-icon>svg {
    height: 18px;
    width: 18px;
    margin-right: 10px;
    vertical-align: sub
}
.docs-material-select-disabled .docs-charts-editor-charttype-select-icon {
    opacity: 0.12
}
.docs-charts-editor-charttype-new {
    background-color: #000;
    border: 1px solid #fff;
    border-radius: 1px;
    bottom: 1px;
    color: #fff;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 10px;
    font-weight: 500;
    height: 16px;
    line-height: 17px;
    opacity: .54;
    padding: 0 4px;
    position: absolute;
    right: 1px;
    text-transform: uppercase
}
.docs-charts-editor-chart-type-select .docs-material-gm-select-caption {
    width: 100%
}
.docs-charts-editor-charttype-menu {
    -webkit-box-shadow: 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12), 0px 2px 4px -1px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12), 0px 2px 4px -1px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12), 0px 2px 4px -1px rgba(0, 0, 0, 0.2);
    background-color: white;
    margin-left: -12px;
    margin-top: 5px;
    overflow-x: hidden;
    overflow-y: scroll;
    padding: 10px 16px;
    position: absolute;
    width: 270px;
    z-index: 3
}
.docs-charts-editor-charttype-option {
    border: 1px solid #bdbdbd;
    cursor: pointer;
    height: 45px;
    margin: 0 23px 10px 0;
    overflow: hidden;
    padding: 2px;
    position: relative;
    width: 67px
}
.docs-charts-editor-palette-label {
    color: rgba(0, 0, 0, 0.87);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px
}
.docs-charts-editor-charttype-menu .goog-palette {
    display: inline-block;
    margin-bottom: 0px;
    margin-top: 10px
}
.docs-charts-editor-charttype-menu .goog-palette-cell {
    border: 0;
    cursor: inherit
}
.docs-charts-editor-charttype-menu .goog-palette-table {
    border: 0;
    margin: 5px 0 0 0
}
.goog-palette-cell-hover .docs-charts-editor-charttype-option {
    border: 1px solid #9e9e9e
}
.goog-palette-cell-selected .docs-charts-editor-charttype-option {
    -webkit-box-shadow: 0 0 0 4px #c6dafc;
    -moz-box-shadow: 0 0 0 4px #c6dafc;
    box-shadow: 0 0 0 4px #c6dafc
}
.docs-charts-editor-charttype-option-canvas {
    direction: ltr;
    height: 45px;
    width: 67px
}
.docs-charts-editor-charttype-option-gviz-org-chart {
    -webkit-transform: scale(0.61, 0.68);
    -moz-transform: scale(0.61, 0.68);
    -ms-transform: scale(0.61, 0.68);
    -o-transform: scale(0.61, 0.68);
    transform: scale(0.61, 0.68);
    background: url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -1428px no-repeat
}
.docs-charts-editor-charttype-option-gviz-radar-chart {
    -webkit-transform: scale(0.60, 0.60);
    -moz-transform: scale(0.60, 0.60);
    -ms-transform: scale(0.60, 0.60);
    -o-transform: scale(0.60, 0.60);
    transform: scale(0.60, 0.60);
    background: url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -2233px no-repeat
}
.docs-charts-editor-charttype-option-gviz-annotated-timeline-chart {
    -webkit-transform: scale(0.61, 0.68);
    -moz-transform: scale(0.61, 0.68);
    -ms-transform: scale(0.61, 0.68);
    -o-transform: scale(0.61, 0.68);
    transform: scale(0.61, 0.68);
    background: url("//ssl.gstatic.com/charts/static/thumbs17.png") 0 -1895px no-repeat
}
.docs-charts-editor-charttype-option-gviz-table-chart {
    -webkit-transform: scale(0.61, 0.68);
    -moz-transform: scale(0.61, 0.68);
    -ms-transform: scale(0.61, 0.68);
    -o-transform: scale(0.61, 0.68);
    transform: scale(0.61, 0.68);
    background: url("//ssl.gstatic.com/charts/static/thumbs17.png") 0 -1351px no-repeat
}
.docs-charts-editor-charttype-option-gviz-geo-chart {
    -webkit-transform: scale(0.61, 0.68);
    -moz-transform: scale(0.61, 0.68);
    -ms-transform: scale(0.61, 0.68);
    -o-transform: scale(0.61, 0.68);
    transform: scale(0.61, 0.68);
    background: url("//ssl.gstatic.com/charts/static/thumbs17.png") 0 -2772px no-repeat
}
.docs-charts-editor-charttype-option-gviz-geo-chart-with-markers {
    -webkit-transform: scale(0.61, 0.68);
    -moz-transform: scale(0.61, 0.68);
    -ms-transform: scale(0.61, 0.68);
    -o-transform: scale(0.61, 0.68);
    transform: scale(0.61, 0.68);
    background: url("//ssl.gstatic.com/charts/static/thumbs17.png") 0 -612px no-repeat
}
.docs-charts-editor-charttype-option-disabled-chart {
    opacity: 0.25
}
.docs-charts-editor-charttype-option-gviz-org-chart,
.docs-charts-editor-charttype-option-gviz-radar-chart,
.docs-charts-editor-charttype-option-gviz-annotated-timeline-chart,
.docs-charts-editor-charttype-option-gviz-table-chart,
.docs-charts-editor-charttype-option-gviz-geo-chart,
.docs-charts-editor-charttype-option-gviz-geo-chart-with-markers {
    -webkit-transform-origin: 0 0;
    -moz-transform-origin: 0 0;
    -ms-transform-origin: 0 0;
    -o-transform-origin: 0 0;
    transform-origin: 0 0;
    float: left;
    height: 67px;
    width: 110px
}
.docs-charts-editor-gauge-colored-range-bundle {
    border-top: 1px dashed #9e9e9e;
    margin-top: 20px;
    padding-top: 5px
}
.docs-charts-editor-gauge-colored-range-bundle .docs-charts-editor-row>.docs-charts-editor-col>div {
    margin: 0
}
.docs-charts-editor-gauge-colored-range-bundle .docs-charts-editor-row {
    margin-top: 10px
}
.docs-charts-editor-pie-slice-format-labeledsection {
    color: #3c4043;
    font-size: 14px;
    font-weight: 500;
    letter-spacing: .2px;
    line-height: 24px;
    margin-bottom: 0;
    padding: 10px 0
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-pie-slice-options hr {
    background-color: #dadce0;
    border: 0;
    height: 1px;
    margin: 17px -16px
}
.docs-charts-editor-recommendation-zippy {
    background-color: #e6f4ea;
    border: 1px solid #ceead6;
    border-radius: 4px
}
.docs-charts-editor-recommendation-zippy-header {
    padding: 4px 0
}
.docs-charts-editor-recommendation-zippy-header-icon {
    display: inline-block;
    padding: 0 8px
}
.docs-charts-editor-recommendation-zippy-header-text {
    color: #3c4043;
    font-weight: 500
}
.docs-charts-editor-recommendation-zippy-toggle {
    font-weight: 400
}
.docs-charts-editor-recommendation-zippy-header-left {
    float: left;
    line-height: 32px
}
.docs-charts-editor-recommendation-zippy-header-right {
    float: right
}
.docs-charts-editor-recommendation-zippy-header:after {
    content: "";
    clear: both;
    display: table
}
.docs-charts-editor-recommendation-zippy-body {
    padding: 0 4px;
    text-align: center
}
.docs-charts-editor-recommendation-zippy .goog-palette-cell {
    border: 0;
    cursor: inherit
}
.docs-charts-editor-recommendation-zippy .goog-palette-table {
    border: 0;
    margin: 5px 0 0 0;
    width: 100%
}
.docs-charts-editor-recommendation-zippy .waffle-charteditor-recommendation-palette.goog-palette {
    border-bottom: none;
    display: inline-block;
    margin: 0;
    padding: 0;
    width: 100%
}
.docs-charts-editor-recommendation-zippy .waffle-charteditor-recommendation-option {
    background-color: white;
    height: 75px;
    margin: 4px 6px 8px 8px;
    max-width: 114px;
    padding: 0;
    width: initial
}
.docs-charts-editor-series-select-color {
    height: 10px;
    left: -15px;
    margin: 0;
    position: relative;
    top: 1px;
    width: 10px
}
.docs-gm-sidebars .docs-charts-editor-series-select-color {
    border-radius: 50%;
    height: 15px;
    top: 3px;
    width: 15px
}
.docs-charts-editor-series-select .docs-material-gm-labeled-select-caption>div {
    color: #202124;
    padding-left: 20px
}
.docs-charts-editor-series-point-shape-icon {
    fill: rgba(0, 0, 0, 0.87);
    height: 12px;
    margin-bottom: -1px;
    margin-right: 9px;
    width: 12px
}
.goog-menuitem-content .docs-charts-editor-series-point-shape-icon {
    margin-left: -12px
}
.docs-charts-editor-series-line-dash-type-icon {
    height: 2px;
    stroke: rgba(0, 0, 0, 0.87);
    width: 75px;
    vertical-align: middle
}
.docs-charts-editor-series-item-selection-dialog-input-default-caption {
    color: #bdbdbd
}
.docs-charts-editor-series-format-labeledsection .docs-charts-editor-control-label.docs-charts-editor-labeledsection,
.docs-charts-editor-series-format-data-point-button .docs-charts-editor-control-label.docs-charts-editor-labeledactionablebutton-label {
    color: #3c4043;
    font-size: 14px;
    font-weight: 500;
    letter-spacing: .2px;
    line-height: 24px;
    margin-bottom: 0;
    padding: 10px 0
}
.docs-charts-editor-series-format-label-hide {
    display: none
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-series-format-data-point-button>div {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    justify-content: space-between
}
.docs-charts-editor-series-format-data-point-button .docs-charts-editor-labeledactionablebutton {
    padding: 10px 0
}
.col-50.docs-charts-editor-series-format-data-point-button {
    padding: 10px 0;
    text-align: right
}
.docs-charts-editor-series-single-item-style-item-select {
    max-width: 70%
}
.docs-charts-editor-table-border-container {
    background: #fdfdfd;
    border-top: 1px solid #e0e0e0;
    padding: 0 16px 6px
}
.docs-charts-editor-table-border-container .docs-charts-editor-col.col-50>div>.docs-material-labeled-checkbox {
    margin-top: 24px
}
.docs-charts-editor-textstyle-toolbar {
    border: 1px solid #d8d8d8;
    border-radius: 1px;
    margin: 6px 0;
    padding: 0 4px
}
#docs-charts-editor-textstyle-font-family .goog-toolbar-menu-button-caption {
    overflow-x: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    width: 67px
}
#docs-charts-editor-textstyle-font-size .goog-toolbar-combo-button-caption {
    width: 32px
}
#docs-charts-editor-textstyle-font-size .goog-toolbar-combo-button-input {
    width: 12px
}
.docs-charts-editor-textstyle-container {
    border: 1px solid #dadce0;
    border-radius: 4px;
    display: inline-block;
    height: 40px;
    line-height: 40px
}
.docs-charts-editor-textstyle-separator {
    border-left: 1px solid #dadce0;
    height: 25px;
    margin: 7px 1px;
    vertical-align: top
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-textstyle-italic {
    margin-left: -1px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-col.docs-charts-editor-waterfall-connector-line-color {
    width: 48%
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-col.docs-charts-editor-waterfall-connector-line-thickness {
    width: 52%
}
.docs-charts-editor-waterfall-add-total-button {
    color: #4285f4;
    font-weight: 500;
    padding: 2px 1px 0px 1px;
    text-transform: uppercase
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-waterfall-last-value-total .docs-material-gm-labeled-checkbox-content {
    width: 80%
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-charts-editor-waterfall-add-total-column {
    margin-bottom: 10px
}
.docs-charts-editor-waterfall-total-column-label {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1
}
.waffle-charteditor-external-menu-button,
.waffle-charteditor-external-menu-button-outer-box,
.waffle-charteditor-external-menu-button-inner-box,
.waffle-charteditor-external-menu-button-caption,
.waffle-charteditor-external-menu-button-dropdown {
    cursor: pointer;
    display: block
}
.waffle-charteditor-data-constraint-disabled .waffle-charteditor-external-menu-button,
.waffle-charteditor-data-constraint-disabled .waffle-charteditor-external-menu-button-outer-box,
.waffle-charteditor-data-constraint-disabled .waffle-charteditor-external-menu-button-inner-box,
.waffle-charteditor-data-constraint-disabled .waffle-charteditor-external-menu-button-caption,
.waffle-charteditor-data-constraint-disabled .waffle-charteditor-external-menu-button-dropdown {
    cursor: not-allowed
}
.waffle-charteditor-external-menu-button {
    outline: none
}
.waffle-charteditor-external-menu-button-dropdown {
    height: 0
}
.docs-charts-editor-chip.waffle-charteditor-external-menu-button-focused:not(.waffle-charteditor-external-menu-button-open) .docs-charts-editor-chip-content,
.waffle-charteditor-pickerchip.waffle-charteditor-external-menu-button-focused:not(.waffle-charteditor-external-menu-button-open) .docs-charts-editor-chip-content {
    outline: 5px auto #4285f4;
    outline-offset: -3px
}
.waffle-charteditor-filter-button-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-charteditor-filter-button-label {
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    color: #3c4043;
    font-weight: 500;
    line-height: 44px;
    text-transform: uppercase
}
.waffle-charteditor-filter-card {
    background-color: #f0f0f0;
    border-radius: 8px;
    padding: 10px
}
.waffle-charteditor-filter-card:not(:last-child) {
    margin-bottom: 10px
}
.waffle-charteditor-filter-card-top-row {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    padding-bottom: 8px
}
.waffle-charteditor-filter-card-top-row>div {
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0
}
.waffle-charteditor-filter-card-top-row>.waffle-charteditor-filter-card-label {
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    -webkit-flex-shrink: 1;
    -ms-flex-negative: 1;
    flex-shrink: 1;
    overflow: hidden;
    text-overflow: ellipsis
}
.waffle-charteditor-filter-card-label {
    color: #424242;
    font-size: 14px;
    padding-left: 8px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-charteditor-filter-card-select .jfk-select {
    text-align: left;
    width: 100%
}
.waffle-charteditor-numeric-group-control-container {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-charteditor-numeric-group-control-checkbox {
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1
}
.waffle-charteditor-sort-button-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-charteditor-sort-button-label {
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    color: #3c4043;
    font-weight: 500;
    line-height: 44px;
    text-transform: uppercase
}
.waffle-charteditor-sort-order-toggle {
    background: none;
    border: 0;
    color: #5f6368;
    cursor: pointer;
    font-style: italic
}
.waffle-charteditor-sidebar.waffle-sidebar-container {
    width: 320px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    z-index: 2
}
.waffle-charteditor-sidebar .waffle-sidebar-title {
    padding: 11px 12px;
    font-weight: 500
}
.waffle-charteditor-content {
    background-color: #fff;
    height: 100%
}
.waffle-charteditor-rangepicker-modification-disabled {
    display: none;
    font-size: 14px;
    margin-top: 15px
}
.waffle-charteditor-rangepicker-checkboxes-container {
    margin: 10px 0
}
.waffle-charteditor-rangepicker-checkboxes-container .docs-material-gm-labeled-checkbox {
    padding: 4px 0
}
.waffle-charteditor-rangepicker-labels-as-text {
    margin-left: 28px
}
.waffle-charteditor-rangepicker-has-external-data .waffle-charteditor-rangepicker-labels-as-text {
    margin-left: 0
}
.docs-charts-editor-row>.waffle-charteditor-rangepicker-data-picker>div {
    margin-top: 0
}
.waffle-charteditor-rangepicker-data-transformation .waffle-charteditor-rangepicker-modification-disabled {
    display: block
}
.waffle-charteditor-rangepicker-data-transformation .waffle-charteditor-rangepicker-checkboxes-container,
.waffle-charteditor-rangepicker-data-transformation .waffle-charteditor-rangepicker-merge {
    display: none
}
.waffle-charteditor-rangepicker-error-label {
    color: #db4437;
    font-size: 13px
}
.waffle-charteditor-unsupported-chart-type {
    -webkit-box-shadow: 0px 3px 4px 0px rgba(0, 0, 0, 0.14), 0px 3px 3px -2px rgba(0, 0, 0, 0.12), 0px 1px 8px 0px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 3px 4px 0px rgba(0, 0, 0, 0.14), 0px 3px 3px -2px rgba(0, 0, 0, 0.12), 0px 1px 8px 0px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 3px 4px 0px rgba(0, 0, 0, 0.14), 0px 3px 3px -2px rgba(0, 0, 0, 0.12), 0px 1px 8px 0px rgba(0, 0, 0, 0.2);
    background: #ffebee;
    color: rgba(0, 0, 0, 0.87);
    letter-spacing: 0.04em;
    position: absolute;
    top: 0px;
    z-index: 1
}
.waffle-charteditor-unsupported-chart-type-message {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    font-size: 14px;
    padding: 16px
}
.waffle-charteditor-recommendation-palette.goog-palette {
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    margin-bottom: 10px;
    padding-bottom: 20px;
    width: 265px
}
.waffle-charteditor-recommendation-palette .docs-charts-editor-palette-label {
    text-transform: uppercase
}
.waffle-charteditor-recommendation-option {
    -webkit-box-shadow: 0 0 0 4px #ddd;
    -moz-box-shadow: 0 0 0 4px #ddd;
    box-shadow: 0 0 0 4px #ddd;
    cursor: pointer;
    height: 80px;
    margin: 3px 12px 10px 0;
    overflow: hidden;
    padding: 2px;
    position: relative;
    width: 123px
}
.goog-palette-cell-hover .waffle-charteditor-recommendation-option {
    -webkit-box-shadow: 0 0 0 4px #bbc7ed;
    -moz-box-shadow: 0 0 0 4px #bbc7ed;
    box-shadow: 0 0 0 4px #bbc7ed
}
.goog-palette-cell-selected .waffle-charteditor-recommendation-option {
    -webkit-box-shadow: 0 0 0 4px #6485f1;
    -moz-box-shadow: 0 0 0 4px #6485f1;
    box-shadow: 0 0 0 4px #6485f1
}
.waffle-charteditor-recommendation-option-canvas {
    direction: ltr
}
.waffle-charteditor-recommendation-chip {
    background-color: #4285f4;
    border: 1px solid #fff;
    bottom: 6px;
    color: #fff;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 10px;
    font-weight: 500;
    height: 13px;
    line-height: 13px;
    max-width: 84px;
    overflow-x: hidden;
    padding: 2px 7px 0 7px;
    position: absolute;
    right: 6px;
    text-overflow: ellipsis;
    white-space: nowrap
}
.waffle-charteditor-recommendation-option .waffle-assistant-feedback-button {
    margin: 0;
    position: absolute;
    right: 0;
    top: 0
}
.waffle-charteditor-picker-button-wrapper {
    -ms-flex-align: center;
    -moz-box-align: center;
    -webkit-box-align: center;
    box-align: center;
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-justify-content: center;
    justify-content: center;
    cursor: pointer;
    height: 28px
}
.waffle-charteditor-data-constraint-disabled .waffle-charteditor-picker-button-wrapper {
    cursor: not-allowed
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-charteditor-picker-button-wrapper {
    height: 32px;
    margin-right: 12px
}
.waffle-charteditor-pickerchip .docs-charts-editor-chip-label {
    cursor: pointer
}
.waffle-charteditor-data-constraint-disabled .waffle-charteditor-pickerchip .docs-charts-editor-chip-label {
    cursor: not-allowed
}
.waffle-charteditor-pickerchip .docs-charts-editor-chip-content {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    background-color: transparent;
    border: 1px dashed rgba(0, 0, 0, 0.38)
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-charteditor-pickerchip .docs-charts-editor-chip-content {
    border: 1px solid #dadce0
}
.waffle-charteditor-data-constraint-disabled .docs-charts-editor-chip-content {
    opacity: 0.5
}
.waffle-charteditor-pickerchip-button {
    -webkit-transition: opacity 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: opacity 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: opacity 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: opacity 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    margin-right: 8px;
    margin-top: 1px;
    opacity: .7
}
.jfk-button-hover .waffle-charteditor-pickerchip-button {
    opacity: 1
}
.waffle-charteditor-pickerchip.docs-charts-editor-chip-invalid .docs-charts-editor-chip-content {
    background-color: #f0f0f0
}
.waffle-charteditor-pickerchip .docs-charts-editor-chip-label {
    color: #9e9e9e
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-charteditor-pickerchip .docs-charts-editor-chip-label {
    color: #80868b;
    font-weight: 500
}
.waffle-charteditor-data-constraint-header {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-charteditor-data-constraint-name,
.waffle-charteditor-annotation-chip-label {
    color: #616161;
    font-size: 11px;
    vertical-align: top
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-charteditor-data-constraint-name,
.waffle-charteditor-annotation-chip-label {
    color: #3c4043;
    font-weight: 500;
    letter-spacing: .8px;
    margin-top: 10px;
    text-transform: uppercase
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-charteditor-annotation-chip-label {
    color: #80868b;
    line-height: 16px
}
.waffle-charteditor-data-constraint-name {
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    margin-top: 10px;
    overflow: hidden
}
.waffle-charteditor-data-constraint-aggregate-type .docs-material-gm-labeled-select-outer-box {
    padding: 0 0 0 8px
}
.waffle-charteditor-data-constraint-chip {
    color: #424242;
    font-size: 13px;
    margin-top: 10px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-charteditor-data-constraint-chip {
    font-size: 14px;
    margin-top: 8px
}
.waffle-charteditor-data-constraint {
    position: relative
}
.waffle-charteditor-annotation-chip-wrapper {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-charteditor-annotation-chip-wrapper {
    display: block;
    margin-bottom: 15px;
    margin-left: 50px
}
.waffle-charteditor-annotation-chip {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1
}
.waffle-charteditor-annotation-chip-label {
    margin-right: 10px;
    line-height: 32px
}
.waffle-charteditor-chip-icon {
    left: 8px;
    margin-left: 10px;
    margin-top: 7px;
    top: 7px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-charteditor-chip-icon {
    margin-left: 15px;
    margin-top: 9px
}
.waffle-charteditor-chip-delete-button {
    -webkit-transition: background-color 0.2s ease;
    -moz-transition: background-color 0.2s ease;
    -o-transition: background-color 0.2s ease;
    transition: background-color 0.2s ease;
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAyNCAyNCI+ICA8cGF0aCBmaWxsPSIjZjBmMGYwIiBkPSJNMTkgNi40MUwxNy41OSA1IDEyIDEwLjU5IDYuNDEgNSA1IDYuNDEgMTAuNTkgMTIgNSAxNy41OSA2LjQxIDE5IDEyIDEzLjQxIDE3LjU5IDE5IDE5IDE3LjU5IDEzLjQxIDEyeiIvPjwvc3ZnPg==");
    background-color: #bfbfbf;
    border: 0;
    border-radius: 16px;
    cursor: pointer;
    height: 16px;
    margin: 8px;
    width: 16px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-charteditor-chip-delete-button {
    margin: 10px
}
.waffle-charteditor-chip-delete-button:hover {
    background-color: #aaa
}
.waffle-charteditor-series-aggregate-type {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-charteditor-series-aggregate-type-label {
    color: #616161;
    font-style: italic;
    padding: 0 5px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-charteditor-series-aggregate-type-label {
    padding: 0 10px
}
#docs-editor.companion-enabled {
    width: 100%
}
#docs-editor.companion-enabled #waffle-grid-container {
    width: calc(100% - 56px)
}
#docs-editor.companion-enabled #grid-bottom-bar {
    width: calc(100% - 56px)
}
#docs-editor.companion-enabled #grid-bottom-bar.grid-bottom-bar-rtl-companion-collapsed {
    width: 100%
}
#docs-editor.companion-enabled #grid-bottom-bar.grid-bottom-bar-rtl {
    right: 56px
}
#docs-editor.companion-enabled #grid-bottom-bar.grid-bottom-bar-rtl.grid-bottom-bar-rtl-companion-collapsed {
    right: 0
}
#docs-editor.companion-enabled #grid-bottom-bar.grid-bottom-bar-rtl-companion-open {
    right: calc(56px + 300px)
}
.docs-ui-toast.waffle-assistant-toast.waffle-assistant-toast-companion {
    right: calc(56px + 15px)
}
.waffle-assistant-entry-expanded.companion-collapsed {
    border-right: 1px solid #c2c2c2
}
.companion-collapser-button-container.companion-collapser-button-container-elevated {
    margin-bottom: auto
}
.docs-companion-app-switcher-container-collapsed .companion-collapser-button-container,
.docs-companion-app-switcher-container-collapsed .companion-collapser-button {
    height: 38px
}
.docs-jfk-styling .companion-collapser-button,
.docs-jfk-styling .companion-collapser-button .app-switcher-button-icon-container,
.docs-jfk-styling .companion-collapser-button .app-switcher-button-icon-background {
    transition: all 0s ease 0s
}
.companion-collapser-button.app-switcher-button-checked {
    right: 0
}
.companion-collapser-button.app-switcher-button-checked .app-switcher-button-icon-container,
.companion-collapser-button.app-switcher-button-checked .app-switcher-button-icon-background {
    box-shadow: none;
    margin: 8px;
    padding: 10px;
    top: calc(-1*8px);
    width: 20px
}
.companion-collapser-button.app-switcher-button-checked .app-switcher-button-icon-background {
    background-color: transparent;
    border: transparent 1px solid;
    border-radius: 0
}
.docs-gm .companion-collapser-button {
    transition: none
}
.docs-gm .companion-collapser-button .app-switcher-button-icon-container,
.docs-gm .companion-collapser-button .app-switcher-button-icon-background {
    transition-property: background-color
}
.docs-gm .companion-collapser-button:not(.app-switcher-button-checked) .app-switcher-button-icon-container,
.docs-gm .companion-collapser-button:not(.app-switcher-button-checked) .app-switcher-button-icon-background {
    transition-property: margin-top
}
.docs-gm .companion-collapser-button.app-switcher-button-hover.app-switcher-button-checked .app-switcher-button-icon-background {
    background-color: #f1f3f4
}
.docs-gm .companion-collapser-button.app-switcher-button-focused.app-switcher-button-checked .app-switcher-button-icon-background {
    background-color: #e8eaed
}
.companion-collapser-button.app-switcher-button-checked .app-switcher-button-icon {
    margin-left: 0
}
.docs-jfk-styling .companion-collapser-button.app-switcher-button-checked .app-switcher-button-icon-container,
.docs-jfk-styling .companion-collapser-button.app-switcher-button-checked .app-switcher-button-icon-background {
    top: -10px
}
.docs-jfk-styling .companion-collapser-button .app-switcher-button-icon {
    border: transparent 1px solid;
    transition: all 0s ease 0s
}
.docs-jfk-styling .companion-collapser-button.app-switcher-button-hover.app-switcher-button-checked .app-switcher-button-icon-background {
    background-color: transparent
}
.docs-jfk-styling .companion-collapser-button.app-switcher-button-hover.app-switcher-button-checked .app-switcher-button-icon {
    border-color: #c6c6c6
}
.docs-jfk-styling .companion-collapser-button.app-switcher-button-focused.app-switcher-button-checked .app-switcher-button-icon {
    outline: -webkit-focus-ring-color auto 5px
}
.waffle-dashboard-fab-plus-button {
    bottom: 40px;
    position: absolute;
    right: 55px;
    z-index: 20
}
.waffle-dashboard-fab-list {
    bottom: 100px;
    position: absolute;
    right: 55px;
    z-index: 20
}
.waffle-dashboard-fab-buttons {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    -webkit-justify-content: center;
    justify-content: center;
    background-color: #fafafa;
    border-radius: 50%;
    box-shadow: 0 10px 10px #bdbdbd;
    cursor: pointer;
    height: 60px;
    margin-top: 20px;
    outline: none;
    width: 60px
}
.waffle-dashboard-fab-buttons:last-child {
    margin-bottom: 20px
}
.waffle-dashboard-fab-buttons:hover,
.waffle-dashboard-fab-buttons:focus {
    background-color: #eeeeee
}
.waffle-dashboard-fab-icons {
    -webkit-transform: scale(1.3);
    -moz-transform: scale(1.3);
    -ms-transform: scale(1.3);
    -o-transform: scale(1.3);
    transform: scale(1.3)
}
.waffle-dataconnector-close-badge {
    background-color: rgba(0, 0, 0, 0.12);
    border-radius: 50%;
    box-sizing: border-box;
    height: 18px;
    position: relative;
    width: 18px
}
.waffle-dataconnector-close-badge svg {
    height: 80%;
    left: 50%;
    position: absolute;
    top: 50%;
    transform: translate(-50%, -50%);
    width: 80%
}
.waffle-dataconnector-close-badge polygon {
    fill: #fff
}
.waffle-dataconnector-close-badge-hover {
    background-color: rgba(0, 0, 0, 0.38);
    cursor: pointer
}
.waffle-dataconnector-connectioncard {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    align-items: center;
    background: #fff;
    border-radius: 30px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    padding: 12px;
    width: 360px
}
.waffle-dataconnector-connectioncard-hover {
    background-color: #f0f0f0
}
.waffle-dataconnector-connectioncard-focused {
    background-color: #e8f0fe;
    outline: none
}
.waffle-dataconnector-connectioncard-icon {
    -webkit-transform: scale(1.4, 1.4);
    -moz-transform: scale(1.4, 1.4);
    -ms-transform: scale(1.4, 1.4);
    -o-transform: scale(1.4, 1.4);
    transform: scale(1.4, 1.4);
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxOCIgaGVpZ2h0PSIxOCIgdmlld0JveD0iMCAwIDE4IDE4Ij4KICA8ZyBmaWxsPSIjMDAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiPgogICAgPGVsbGlwc2UgY3g9IjkiIGN5PSI1IiByeD0iNyIgcnk9IjMiLz4KICAgIDxwYXRoIGQ9Ik0xNiw3IEwxNiw4Ljk5OTk5OTgzIEMxNiwxMC42NTY4NTQyIDEyLjg2NTk5MzIsMTIgOSwxMiBDNS4xMzQwMDY3NSwxMiAyLDEwLjY1Njg1NDIgMiw5IEwyLDcgQzIsOC42NTY4NTQyNSA1LjEzNDAwNjc1LDEwIDksMTAgQzEyLjg2NTk5MzIsMTAgMTYsOC42NTY4NTQyNSAxNiw3IFoiLz4KICAgIDxwYXRoIGQ9Ik0xNiwxMSBMMTYsMTIuOTk5OTk5OCBDMTYsMTQuNjU2ODU0MiAxMi44NjU5OTMyLDE2IDksMTYgQzUuMTM0MDA2NzUsMTYgMiwxNC42NTY4NTQyIDIsMTMgTDIsMTEgQzIsMTIuNjU2ODU0MiA1LjEzNDAwNjc1LDE0IDksMTQgQzEyLjg2NTk5MzIsMTQgMTYsMTIuNjU2ODU0MiAxNiwxMSBaIi8+CiAgPC9nPgo8L3N2Zz4K") no-repeat;
    background-size: cover;
    display: inline-block;
    height: 1em;
    margin-right: 12px;
    width: 1em
}
.waffle-dataconnector-connectioncard-body {
    border-left: 1px solid transparent
}
.waffle-dataconnector-connectioncard-header {
    color: rgba(0, 0, 0, 0.87);
    font-weight: bold;
    line-height: 18px
}
.waffle-dataconnector-connectioncard-type {
    color: rgba(0, 0, 0, 0.54)
}
.waffle-dataconnector-connectionmanager {
    width: 512px
}
.waffle-dataconnector-connectionmanager .waffle-dataconnector-modal-footer {
    padding: 0
}
.waffle-dataconnector-connectionmanager-content {
    height: 357px;
    overflow-y: scroll;
    position: relative
}
.waffle-dataconnector-connectionmanager.waffle-dataconnector-connectionmanager-loading .waffle-dataconnector-connectionmanager-connections {
    display: none
}
.waffle-dataconnector-connectionmanager-content::-webkit-scrollbar {
    height: 16px;
    overflow: visible;
    width: 12px
}
.waffle-dataconnector-connectionmanager-content .waffle-spinner {
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%)
}
.waffle-dataconnector-connectionmanager-header {
    color: rgba(0, 0, 0, 0.54);
    font: 500 13px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    margin: 12px
}
.waffle-dataconnector-connectionmanager-no-connections-message {
    position: absolute;
    text-align: center;
    top: 50%;
    width: 100%
}
.waffle-dataconnector-pill {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    background: white;
    border-radius: 40px;
    box-shadow: 0px 1px 1px 0px rgba(0, 0, 0, 0.14), 0px 2px 1px -1px rgba(0, 0, 0, 0.12), 0px 1px 3px 0px rgba(0, 0, 0, 0.2);
    box-sizing: border-box;
    padding: 5px 20px;
    position: absolute
}
.waffle-dataconnector-pill-info {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-dataconnector-pill-timestamp {
    color: #4285f4;
    height: 32px;
    line-height: 32px;
    margin-right: 10px;
    white-space: nowrap
}
.waffle-dataconnector-pill-gm .waffle-dataconnector-pill-timestamp,
.waffle-dataconnector-pill-gm .waffle-dataconnector-pill-progress {
    color: #188038
}
.waffle-dataconnector-pill-progress {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    color: #4285f4;
    height: 32px;
    line-height: 32px
}
.waffle-dataconnector-pill-error {
    color: #db4437;
    height: 32px;
    line-height: 32px;
    margin-right: 10px
}
.waffle-dataconnector-pill-error .waffle-dataconnector-error-icon {
    height: 18px;
    margin-right: 4px;
    position: relative;
    top: 4px;
    width: 18px
}
.waffle-dataconnector-pill-menu-button {
    margin: 0;
    padding: 0
}
.waffle-dataconnector-menu-icon {
    position: relative;
    top: 3px
}
.waffle-dataconnector-pill-menu svg {
    -webkit-transform: scale(1.4, 1.4);
    -moz-transform: scale(1.4, 1.4);
    -ms-transform: scale(1.4, 1.4);
    -o-transform: scale(1.4, 1.4);
    transform: scale(1.4, 1.4);
    bottom: -0.125em;
    height: 1em;
    margin-right: 8px;
    position: relative;
    width: 1em
}
.waffle-dataconnector-pill-menuitem {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    height: 32px;
    line-height: 32px
}
.waffle-dataconnector-pill-menuitem-refreshquery,
.waffle-dataconnector-pill-menuitem-truncation {
    padding-right: 15px!important
}
.waffle-dataconnector-pill-menuitem-accel {
    margin-left: auto;
    padding: 0 20px 0 40px;
    text-align: center;
    color: #9e9e9e
}
.waffle-dataconnector-pill-menuitem-refreshquery-info svg {
    margin: 0
}
.waffle-dataconnector-pill-menuitem-refreshquery-info-progress {
    font-style: italic
}
.waffle-dataconnector-pill-menuitem-refreshquery-info-error-button {
    color: #db4437;
    text-decoration: underline
}
.waffle-dataconnector-pill-spinner {
    border-radius: 50%;
    box-shadow: inset 0 0 0 2px;
    color: #4285f4;
    display: inline-block;
    height: 18px;
    margin: 7px 0;
    position: relative;
    width: 18px;
    margin-right: 7px
}
.waffle-dataconnector-pill-gm .waffle-dataconnector-pill-spinner {
    border-radius: 50%;
    box-shadow: inset 0 0 0 2px;
    color: #188038;
    display: inline-block;
    height: 18px;
    margin: 7px 0;
    position: relative;
    width: 18px;
    margin-right: 7px
}
.waffle-dataconnector-pill-spinner:before {
    -webkit-animation: waffle-dataconnector-pill-spinner-animation 2s infinite ease 1.5s;
    -moz-animation: waffle-dataconnector-pill-spinner-animation 2s infinite ease 1.5s;
    -o-animation: waffle-dataconnector-pill-spinner-animation 2s infinite ease 1.5s;
    animation: waffle-dataconnector-pill-spinner-animation 2s infinite ease 1.5s;
    -webkit-transform-origin: 11px 10px;
    -moz-transform-origin: 11px 10px;
    -ms-transform-origin: 11px 10px;
    -o-transform-origin: 11px 10px;
    transform-origin: 11px 10px;
    background: #fff;
    border-radius: 20px 0 0 20px;
    content: "";
    height: 20px;
    left: -1px;
    position: absolute;
    top: -1px;
    width: 11px
}
.waffle-dataconnector-pill-spinner:after {
    -webkit-animation: waffle-dataconnector-pill-spinner-animation 2s infinite ease;
    -moz-animation: waffle-dataconnector-pill-spinner-animation 2s infinite ease;
    -o-animation: waffle-dataconnector-pill-spinner-animation 2s infinite ease;
    animation: waffle-dataconnector-pill-spinner-animation 2s infinite ease;
    -webkit-transform-origin: 0 10px;
    -moz-transform-origin: 0 10px;
    -ms-transform-origin: 0 10px;
    -o-transform-origin: 0 10px;
    transform-origin: 0 10px;
    background: #fff;
    border-radius: 0 20px 20px 0;
    content: "";
    height: 20px;
    left: 10px;
    position: absolute;
    top: -1px;
    width: 11px
}
@keyframes waffle-dataconnector-pill-spinner-animation {
    0% {
        transform: rotate(0deg)
    }
    100% {
        transform: rotate(360deg)
    }
}
.grid-shim-bottom {
    background-color: #f8f8f8;
    border-top: 1px solid #e5e5e5
}
.grid-shim-end-ltr,
.grid-shim-end-rtl {
    background: #f8f8f8;
    height: 100%;
    position: absolute;
    top: 0
}
.grid-shim-end-ltr {
    border-left: 1px solid #e5e5e5
}
.grid-shim-end-rtl {
    border-right: 1px solid #e5e5e5
}
.grid-shim-end-ltr {
    right: 0
}
.grid-shim-end-rtl {
    left: 0
}
.grid-bottom-bar {
    background-color: #eee;
    z-index: 18
}
.docs-gm .grid-bottom-bar {
    background-color: #f1f3f4;
    border-top: 1px solid #e8eaed
}
.docs-gm .grid-bottom-bar td {
    line-height: 0
}
.docs-gm .grid-bottom-bar .goog-toolbar {
    min-height: 0
}
.grid-bottom-bar,
.grid-shim-bottom {
    width: 100%
}
.docs-sheet-active-tab .docs-sheet-tab-dropdown {
    background: none
}
.docs-sheet-add .docs-sheet-button-inner-box,
.docs-sheet-add .docs-sheet-button-icon {
    background-position: -180px -37px
}
.docs-sheet-add.docs-sheet-button-hover .docs-sheet-button-inner-box,
.docs-sheet-add.docs-sheet-button-hover .docs-sheet-button-icon {
    background-position: -642px 0
}
.docs-sheet-left .docs-sheet-button-inner-box,
.docs-sheet-left .docs-sheet-button-icon {
    background-position: -430px -62px
}
.docs-sheet-left.docs-sheet-button-hover .docs-sheet-button-inner-box,
.docs-sheet-left.docs-sheet-button-hover .docs-sheet-button-icon {
    background-position: -757px -44px
}
.docs-sheet-left.docs-sheet-button-disabled .docs-sheet-button-inner-box,
.docs-sheet-left.docs-sheet-button-disabled .docs-sheet-button-icon {
    background-position: -430px -62px
}
.docs-sheet-right .docs-sheet-button-inner-box,
.docs-sheet-right .docs-sheet-button-icon {
    background-position: -509px -62px
}
.docs-sheet-right.docs-sheet-button-hover .docs-sheet-button-inner-box,
.docs-sheet-right.docs-sheet-button-hover .docs-sheet-button-icon {
    background-position: -597px -37px
}
.docs-sheet-right.docs-sheet-button-disabled .docs-sheet-button-inner-box,
.docs-sheet-right.docs-sheet-button-disabled .docs-sheet-button-icon {
    background-position: -509px -62px
}
.docs-sheet-all .docs-sheet-button-inner-box,
.docs-sheet-all .docs-sheet-button-icon {
    background-position: -791px -67px
}
.docs-sheet-all.docs-sheet-button-hover .docs-sheet-button-inner-box,
.docs-sheet-all.docs-sheet-button-hover .docs-sheet-button-icon {
    background-position: -217px -62px
}
.docs-sheet-button-inner-box:hover,
.docs-sheet-button-outer-box:hover {
    border-color: #c6c6c6!important
}
.docs-sheet-button-inner-box {
    background: none
}
.docs-sheet-button-icon {
    background: url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") no-repeat;
    margin: 2px
}
.docs-sheet-comment-indicator {
    background: none;
    color: white;
    font-size: 11px;
    font-weight: 500;
    text-align: center
}
.docs-sheet-outer-container {
    vertical-align: top
}
.docs-sheet-container {
    height: 30px;
    overflow: hidden;
    top: -1px
}
.docs-gm .docs-sheet-container {
    height: 40px;
    line-height: normal;
    margin-top: -1px;
    top: 0
}
div.docs-sheet-container-bar {
    background: none;
    border: none;
    font-size: 13px;
    padding: 0 0 0 0.5em;
    margin: 0 2px 2px 2px;
    overflow-x: auto;
    overflow-y: hidden;
    white-space: nowrap
}
.docs-sheet-container-bar .docs-sheet-tab-open {
    border-top: none;
    -moz-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2)!important;
    -webkit-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2)!important;
    box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2)!important;
    z-index: 1004
}
.docs-sheet-tab-open {
    border-top: 1px solid #fff
}
div.docs-sheet-button-bar {
    background: none;
    border: none;
    padding: 2px 4px 4px 0;
    margin: 0 0 0 2px;
    overflow: hidden;
    white-space: nowrap
}
.docs-sheet-tab {
    text-decoration: none;
    list-style: none;
    vertical-align: top;
    outline: none;
    height: 24px;
    z-index: 1003;
    color: #666;
    background-color: #e9e9e9;
    border-style: solid;
    border-width: 1px;
    border-color: #ccc;
    border-top-color: #aaa;
    cursor: pointer;
    padding: 2px;
    margin: 0 0 2px 0;
    min-width: 30px;
    border-radius: 0 0 2px 2px
}
.docs-gm .docs-sheet-tab {
    align-items: center;
    background-color: #f1f3f4;
    border-bottom: none;
    border-left: 1px solid #e8eaed;
    border-radius: 0;
    border-right: 1px solid #e8eaed;
    border-top: 1px solid #e8eaed;
    display: inline-flex;
    height: 39px;
    margin-right: -1px;
    padding: 0 12px 0 16px
}
.docs-sheet-tab.docs-sheet-tab-selected {
    background-color: #fff;
    color: #222
}
.docs-sheet-tab-hover {
    color: #444;
    background-color: #f1f1f1;
    margin: 0 0 2px 0
}
.docs-gm .docs-sheet-tab-hover {
    background-color: #e8eaed;
    border-top-color: #e8eaed
}
.docs-sheet-active-tab {
    color: #222;
    cursor: default;
    background-color: #fff;
    border-color: #aaa;
    border-top-color: #fff;
    border-width: 0 1px 1px 1px;
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.15);
    font-weight: 500;
    margin: 0 0 2px 0;
    z-index: 1004
}
.docs-gm .docs-sheet-active-tab {
    background-color: #fff;
    border-top-color: #f1f3f4;
    box-shadow: 0 1px 3px 1px rgba(60, 64, 67, .15)
}
.docs-sheet-tab-menu {
    border-color: #aaa!important
}
.docs-gm .docs-sheet-tab-menu {
    border-color: transparent!important
}
.docs-sheet-tab-outer-box {
    border-color: #e4e4e4
}
.docs-sheet-active-tab .docs-sheet-tab-outer-box {
    border-color: #d8d8d8
}
.docs-sheet-tab-outer-box {
    border-width: 1px 0;
    padding: 0;
    margin: 0 -1px;
    white-space: nowrap;
    padding: 3px 0 3px 5px
}
.docs-gm .docs-sheet-tab-outer-box {
    margin-top: -2px;
    padding: 0
}
.docs-sheet-button-outer-box {
    margin: 0;
    border-width: 1px 0;
    padding: 0
}
.docs-sheet-button-inner-box {
    margin: 0 -1px;
    border-width: 0 1px;
    white-space: nowrap
}
.docs-sheet-menu-inner-box {
    padding: 1px 2px
}
.docs-gm .docs-sheet-button-outer-box,
.docs-gm .docs-sheet-button-inner-box {
    border: none
}
.docs-gm .docs-sheet-button-disabled {
    opacity: .38
}
::root .docs-sheet-tab,
::root .docs-sheet-tab-outer-box {
    line-height: 0
}
::root .docs-sheet-tab-caption,
::root .docs-sheet-tab-dropdown {
    line-height: normal
}
.docs-sheet-tab-color {
    height: 3px;
    margin: 3px -20px 0 -5px
}
.docs-gm .docs-sheet-tab-outer-box,
.docs-gm .docs-sheet-tab-inner-box,
.docs-gm .docs-sheet-tab-caption {
    position: static
}
.docs-gm .docs-sheet-tab-color {
    bottom: 0;
    height: 4px;
    left: 0;
    margin: 0;
    position: absolute;
    right: 0
}
.docs-sheet-active-tab .docs-sheet-tab-dropdown {
    display: inline-block
}
.docs-sheet-tab .docs-sheet-tab-dropdown {
    display: inline-block;
    margin-top: -7px
}
.docs-gm .docs-sheet-tab .docs-sheet-tab-dropdown {
    border-radius: 2px;
    margin: 0;
    opacity: 1
}
.docs-sheet-tab-dropdown {
    opacity: 0.3;
    filter: alpha(opacity=30);
    margin: -2px -1px -2px -2px
}
.docs-sheet-active-tab .docs-sheet-tab-dropdown:hover {
    cursor: pointer;
    opacity: 1;
    filter: alpha(opacity=100)
}
.docs-sheet-tab-dropdown {
    vertical-align: middle
}
.docs-gm .docs-sheet-active-tab .docs-sheet-tab-dropdown {
    border: 1px solid transparent;
    margin-left: -1px;
    margin-right: -1px;
    opacity: 1.0
}
.docs-gm .docs-sheet-active-tab .docs-sheet-tab-dropdown:hover {
    background-color: #e6f4ea
}
.docs-gm .docs-sheet-active-tab .docs-sheet-tab-dropdown:active {
    background-color: #ceead6
}
.docs-gm .docs-sheet-tab-open .docs-sheet-tab-dropdown,
.docs-gm .docs-sheet-tab-open .docs-sheet-tab-dropdown:hover {
    background-color: #e6f4ea
}
.docs-gm .docs-sheet-tab-edit .docs-sheet-tab-dropdown {
    display: none
}
.docs-sheet-tab-caption {
    margin-right: 2px;
    vertical-align: middle;
    white-space: pre
}
.docs-gm .docs-sheet-tab-caption {
    margin-right: 3px
}
.docs-sheet-tab-rtl .docs-sheet-tab-caption {
    margin-right: 0;
    margin-left: 2px
}
.docs-gm .docs-sheet-tab-rtl .docs-sheet-tab-caption {
    margin-left: 3px
}
.docs-material .docs-sheet-tab-caption .docs-icon {
    float: none;
    margin: -3px 5px 0 0
}
.docs-gm .docs-material.docs-sheet-tab .docs-icon .docs-icon-arrow-dropdown {
    left: -40px;
    top: -3410px
}
.docs-gm .docs-material.docs-sheet-tab .docs-icon .docs-icon-comment-blank {
    left: -52px;
    top: -658px
}
.docs-gm .docs-material.docs-sheet-tab .docs-icon .docs-icon-database {
    left: -20px;
    top: -172px
}
.docs-gm .docs-material.docs-sheet-tab .docs-icon .docs-icon-locked {
    left: 0;
    top: -3830px
}
.docs-gm .docs-material.docs-sheet-active-tab .docs-icon .docs-icon-arrow-dropdown {
    left: 0;
    top: -1364px
}
.docs-gm .docs-material.docs-sheet-active-tab .docs-icon .docs-icon-comment-blank {
    left: 0;
    top: -3950px
}
.docs-gm .docs-material.docs-sheet-active-tab .docs-icon .docs-icon-database {
    left: -40px;
    top: -1808px
}
.docs-gm .docs-material.docs-sheet-active-tab .docs-icon .docs-icon-locked {
    left: 0;
    top: -1216px
}
.docs-sheet-tab-name {
    padding: 3px 1px;
    font-size: 13px;
    font-size: var(--docs-material-font-size-normal, 13px)
}
.docs-gm .docs-sheet-tab-name {
    color: #80868b;
    display: inline-block;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    letter-spacing: .025rem
}
.docs-gm .docs-sheet-active-tab .docs-sheet-tab-name {
    color: #188038
}
.docs-sheet-tab-name[contenteditable="true"] {
    border: 1px solid #d9d9d9;
    display: inline-block;
    height: 16px;
    min-width: 8px;
    margin: -4px -1px;
    -moz-user-modify: read-write-plaintext-only;
    -webkit-user-modify: read-write-plaintext-only;
    -moz-user-select: text!important;
    -ms-user-select: text!important;
    -webkit-user-select: text!important
}
.docs-gm .docs-sheet-tab-name[contenteditable="true"] {
    border: 2px solid #1a73e8;
    border-radius: 4px;
    color: #222;
    height: auto;
    margin: 0 -5px 0 -5px;
    padding: 4px 22px 4px 4px
}
.docs-sheet-tab-name[contenteditable="true"]:focus {
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    border: 1px solid #4d90fe;
    outline: none
}
.docs-gm .docs-sheet-tab-name[contenteditable="true"]:focus {
    border: 2px solid #1a73e8;
    box-shadow: none
}
.docs-sheet-tab-name-error {
    border-color: red!important
}
.docs-sheet-button-inner-box {
    width: 25px;
    height: 25px
}
.docs-sheet-button,
.docs-sheet-menu-button {
    margin: 0 3px;
    cursor: pointer
}
.docs-gm .docs-sheet-button {
    border: 1px solid transparent;
    border-radius: 2px;
    outline: none
}
.docs-gm .docs-sheet-button-hover {
    background-color: #f1f3f4
}
.docs-gm .docs-sheet-button-active {
    background-color: #e8eaed
}
.docs-gm .docs-sheet-button-open {
    background-color: #e6f4ea
}
.docs-sheet-button-outer-box,
.docs-sheet-button-inner-box {
    border-style: solid;
    vertical-align: top;
    border-color: transparent
}
.docs-sheet-button-disabled,
.docs-sheet-button-disabled .docs-sheet-button-outer-box,
.docs-sheet-button-disabled .docs-sheet-button-inner-box {
    cursor: default
}
.docs-sheet-tab .docs-icon-locked {
    margin-left: -3px
}
.docs-material .docs-sheet-tab .docs-icon-locked {
    margin-left: 0
}
.docs-icon.docs-sheet-lock-container {
    float: left;
    margin-top: -3px;
    width: 16px
}
.docs-sheet-comment-indicator-container {
    float: left;
    margin-top: -3px;
    width: 22px
}
.docs-icon-img-container.docs-sheet-database-icon {
    width: 18px;
    height: 18px;
    margin-top: 2px
}
.docs-material .docs-icon-img-container.docs-sheet-database-icon {
    margin-top: 0
}
.docs-sheet-database-icon {
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxOCIgaGVpZ2h0PSIxOCIgdmlld0JveD0iMCAwIDE4IDE4Ij4KICA8ZyBmaWxsPSIjMDAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiPgogICAgPGVsbGlwc2UgY3g9IjkiIGN5PSI1IiByeD0iNyIgcnk9IjMiLz4KICAgIDxwYXRoIGQ9Ik0xNiw3IEwxNiw4Ljk5OTk5OTgzIEMxNiwxMC42NTY4NTQyIDEyLjg2NTk5MzIsMTIgOSwxMiBDNS4xMzQwMDY3NSwxMiAyLDEwLjY1Njg1NDIgMiw5IEwyLDcgQzIsOC42NTY4NTQyNSA1LjEzNDAwNjc1LDEwIDksMTAgQzEyLjg2NTk5MzIsMTAgMTYsOC42NTY4NTQyNSAxNiw3IFoiLz4KICAgIDxwYXRoIGQ9Ik0xNiwxMSBMMTYsMTIuOTk5OTk5OCBDMTYsMTQuNjU2ODU0MiAxMi44NjU5OTMyLDE2IDksMTYgQzUuMTM0MDA2NzUsMTYgMiwxNC42NTY4NTQyIDIsMTMgTDIsMTEgQzIsMTIuNjU2ODU0MiA1LjEzNDAwNjc1LDE0IDksMTQgQzEyLjg2NTk5MzIsMTQgMTYsMTIuNjU2ODU0MiAxNiwxMSBaIi8+CiAgPC9nPgo8L3N2Zz4K") no-repeat
}
.docs-sheet-database-icon-container {
    float: left;
    margin-top: -3px;
    width: 20px
}
.docs-sheet-form-icon-container {
    float: left;
    margin-top: -3px;
    opacity: 0.5;
    width: 22px
}
.docs-sheet-active-tab .docs-sheet-form-icon-container {
    opacity: 1
}
.docs-sheet-comment-indicator {
    display: block;
    height: 16px;
    line-height: 12px;
    width: 16px;
    position: absolute;
    top: 4px;
    left: 3px;
    margin-top: 0px
}
.docs-material .docs-sheet-comment-indicator {
    height: 12px;
    left: 1px;
    line-height: 12px;
    top: 2px
}
.docs-sheet-all-sheet-menu-item {
    white-space: nowrap
}
.docs-sheet-all-sheet-menu-item-hidden .goog-menuitem-content {
    color: #888
}
.docs-sheet-all-sheet-menu-item-swatch {
    border-radius: 9px;
    display: inline-block;
    height: 9px;
    margin-right: 8px;
    width: 9px
}
.docs-sheet-status-container {
    width: 158px;
    overflow: hidden;
    padding: 0;
    border-left: 1px solid #ccc
}
.docs-sheet-status-container-avs {
    overflow: hidden;
    padding: 0
}
.docs-sheet-status {
    max-width: 150px;
    float: right;
    margin-right: 8px;
    overflow: hidden
}
.docs-sheet-status-avs {
    max-width: 150px;
    float: right;
    margin-right: 8px;
    overflow: hidden;
    position: relative;
    top: 3px
}
.docs-gm-sidebars .docs-sheet-status-avs {
    top: 4px;
    max-width: 170px
}
.docs-sheet-status>.jfk-select {
    line-height: 29px;
    margin: 0 3px 0 6px;
    max-width: 119px
}
.docs-sheet-status-avs>.jfk-select {
    line-height: 29px;
    max-width: 119px
}
.docs-gm-sidebars .docs-sheet-status-avs .goog-flat-menu-button {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    cursor: pointer;
    padding: 8px 6px 8px 8px;
    width: 100%;
    align-items: center;
    background: white;
    color: #3c4043;
    display: inline-flex;
    justify-content: space-between;
    outline: none;
    padding: 4px;
    position: relative;
    max-width: 139px;
    width: auto;
    width: unset
}
.docs-gm-sidebars .docs-sheet-status-avs .goog-flat-menu-button-disabled {
    color: #5f6368;
    opacity: .38;
    cursor: default
}
.docs-gm-sidebars .docs-sheet-status-avs .goog-flat-menu-button:active {
    background-color: #fff;
    border: 1px solid transparent;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.docs-gm-sidebars .docs-sheet-status-avs .goog-flat-menu-button-hover {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid #dadce0;
    box-shadow: none
}
.docs-gm-sidebars .docs-sheet-status-avs .goog-flat-menu-button-focused {
    background-color: rgba(60, 64, 67, 0.06);
    border: 1px solid #dadce0
}
.docs-gm-sidebars .docs-sheet-status-avs .goog-flat-menu-button-open {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid transparent
}
.docs-gm-sidebars .docs-sheet-status-avs .goog-flat-menu-button-hover.goog-flat-menu-button-open {
    background-color: rgba(60, 64, 67, 0.06)
}
.docs-gm-sidebars .docs-sheet-status-avs .goog-flat-menu-button-focused.goog-flat-menu-button-open {
    background-color: rgba(60, 64, 67, 0.08)
}
.docs-gm-sidebars .docs-sheet-status-avs .goog-flat-menu-button-disabled {
    border: 1px solid #dadce0;
    cursor: default
}
.docs-gm-sidebars .docs-sheet-status-avs .goog-flat-menu-button-caption {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    height: 20px;
    line-height: 20px;
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    font-size: 11px
}
.docs-gm-sidebars .docs-sheet-status-avs .goog-flat-menu-button-disabled .goog-flat-menu-button-caption {
    color: #5f6368;
    opacity: .38;
    cursor: default
}
.docs-gm-sidebars .docs-sheet-status-avs .goog-flat-menu-button-dropdown {
    background: no-repeat url(//ssl.gstatic.com/docs/common/material_common_sprite134_grey_medium.svg) 0 -1364px;
    height: 18px;
    width: 18px;
    border: none;
    margin-top: 0;
    position: relative;
    right: 0;
    top: 0
}
.docs-gm-sidebars .docs-sheet-status-avs .goog-flat-menu-button-disabled .goog-flat-menu-button-dropdown {
    opacity: .38
}
.docs-gm-sidebars .docs-sheet-status-avs .goog-flat-menu-button-disabled.goog-flat-menu-button:active {
    border: 1px solid #dadce0;
    cursor: default;
    box-shadow: none
}
.docs-gm-sidebars .docs-sheet-status-avs .goog-flat-menu-button-open .goog-flat-menu-button-dropdown {
    -moz-transform: rotate(180deg);
    -webkit-transform: rotate(180deg);
    -ms-transform: rotate(180deg);
    transform: rotate(180deg)
}
.docs-gm-sidebars .docs-sheet-status-avs .jfk-radiobutton-disabled .jfk-radiobutton-label {
    color: #5f6368;
    opacity: .38;
    cursor: default
}
.docs-sheet-status .goog-flat-menu-button-caption,
.docs-sheet-status-avs .goog-flat-menu-button-caption {
    text-overflow: ellipsis
}
.waffle-quicksum-container {
    color: #333;
    font-size: 11px;
    font-weight: 500;
    height: 30px;
    line-height: 30px;
    margin-right: 22px;
    overflow: hidden;
    text-align: right
}
.waffle-autovis-quicksum {
    height: 34px;
    margin: 1px
}
.jfk-button.waffle-autovis-quicksum-button {
    border: 1px solid transparent;
    cursor: pointer;
    height: 28px;
    margin: 0;
    padding: 2px;
    position: relative;
    width: 154px
}
.docs-sheet-fade {
    position: absolute;
    display: block;
    top: 0;
    width: 6px;
    height: 100%;
    z-index: 1005
}
.docs-sheet-fade div {
    background-color: #d7d7d7;
    width: 2px;
    float: right;
    position: relative;
    height: 100%
}
.docs-sheet-fade-left {
    left: 0
}
.docs-sheet-fade-right {
    right: 0
}
.docs-sheet-fade1 {
    opacity: 0.82;
    filter: alpha(opacity=82)
}
.docs-sheet-fade2 {
    opacity: 0.62;
    filter: alpha(opacity=62)
}
.docs-sheet-fade3 {
    opacity: 0.4;
    filter: alpha(opacity=40)
}
.waffle-slicereditor-sidebar.waffle-sidebar-container {
    width: 320px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    z-index: 2
}
.waffle-slicer-editor-send-feedback-container {
    text-align: end
}
.waffle-slicer-editor-style-tab .waffle-slicer-editor-style-format-option,
.waffle-slicer-editor-style-color-option-non-gm .docs-charts-editor-material-toolbar-color-picker-outer-box {
    background-color: #f1f3f4
}
.goog-menu-vertical .waffle-slicer-editor-column-selector-menu-seperator {
    margin-left: 0
}
.waffle-slicer-editor-column-selector-menu-item {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    border: 1px solid transparent;
    line-height: 20px;
    margin: 0;
    padding: 5px;
    width: 286px
}
.waffle-slicer-editor-column-selector-menu-item-name {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    margin: 0 20px 0 10px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.waffle-slicer-editor-column-selector-menu-item-range {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    opacity: 0.5;
    max-width: 143px
}
.waffle-slicer-editor-column-selector-menu-item-rect {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1
}
.waffle-slicer-editor-column-selector-menu-item-sheet-name {
    overflow: hidden;
    text-overflow: ellipsis
}
.waffle-slicer-editor-setup-tab .waffle-slicer-editor-style-tab {
    width: 100%
}
.waffle-slicer-editor-sidebar-col {
    width: 50%;
    margin-right: 10px
}
.waffle-slicer-editor-sidebar-col:last-child {
    margin-right: 0
}
.waffle-slicer-editor-sidebar-control-label {
    color: #616161;
    font-size: 11px;
    line-height: 16px;
    margin-bottom: 8px;
    margin-right: 2px
}
.waffle-slicer-editor-sidebar-custom-row {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-slicer-editor-sidebar-title-input-box {
    width: 100%
}
.waffle-slicer-editor-sidebar-title-input-box>input {
    border-left: none;
    border-right: none;
    border-top: none;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 18px;
    height: 100%;
    padding: 0;
    width: 100%
}
.waffle-slicer-editor-sidebar-title-input-box>input:disabled {
    opacity: 0.75
}
.waffle-slicer-editor-sidebar-title-input-box>input:focus {
    border: none;
    border-bottom: 2px solid #4285f4
}
.waffle-slicer-editor-sidebar-row {
    padding: 10px 16px
}
.waffle-slicer-editor-sidebar-align .goog-toolbar-menu-button-dropdown {
    margin: 0
}
.waffle-slicer-editor-sidebar-align-menu-items .goog-palette-table {
    border: 0;
    margin: 0 4px
}
.waffle-slicer-editor-sidebar-align-menu-items .goog-palette-cell {
    border: 0;
    padding: 2px
}
.waffle-slicer-editor-sidebar-align-menu-items .goog-palette-cell-hover {
    background: #eeeeee
}
.waffle-slicer-editor-sidebar-rangepicker-error-label {
    color: #db4437;
    font-size: 13px
}
.waffle-slicer-editor-apply-to-pivot-table-row {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center
}
.waffle-slicer-editor-apply-to-pivot-table-checkbox {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-slicer-editor-apply-to-pivot-table-checkbox-label {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    margin: 0 5px
}
.waffle-slicer-editor-sidebar-title-format {
    border: 1px solid #dadce0;
    border-radius: 4px;
    display: inline-block;
    height: 40px;
    line-height: 40px
}
.waffle-slicer-editor-textstyle-separator {
    border-left: 1px solid #dadce0;
    height: 25px;
    margin: 7px 1px;
    vertical-align: top
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-slicer-editor-sidebar-title-input {
    -webkit-transition: border-color 0.3s ease;
    -moz-transition: border-color 0.3s ease;
    -o-transition: border-color 0.3s ease;
    transition: border-color 0.3s ease;
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 400;
    height: 42px;
    line-height: 36px;
    margin-bottom: 0;
    min-height: 42px;
    resize: none
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-slicer-editor-sidebar-title-input-label {
    color: #5f6368;
    font-size: 12px;
    line-height: 15px;
    margin-bottom: 8px
}
.docs-multi-menu-col {
    float: left
}
.docs-multi-menu-col .goog-menuheader {
    color: #777;
    font-size: 11px;
    padding: .3em .5em .3em 0.5em;
    text-transform: uppercase
}
.dialog-separator {
    border-bottom: 1px solid #e5e5e5;
    margin: 0 -42px 20px
}
.nfd-inputall,
.nfd-input,
.nfd-apply,
.nfd-inner-input-content {
    display: inline-block
}
.nfd-inputall .nfd-input {
    font-size: 13px;
    height: auto;
    height: unset;
    padding: 4px 8px;
    width: 300px
}
.nfd-input input {
    border: none;
    font-size: 13px;
    margin: 0;
    outline: none;
    padding: 0;
    width: 100%
}
.nfd-input {
    min-height: 18px;
    position: relative
}
.nfd-input.nfd-input-focus {
    border: 1px solid #4d90fe;
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    outline: none
}
.nfd-input span:focus {
    outline: none
}
.nfd-date-time-left-most {
    display: inline-block;
    min-width: 1px
}
.jfk-button.nfd-apply {
    margin-left: 10px;
    margin-right: 0;
    vertical-align: top
}
.nfd-inner-input-content {
    text-align: right
}
.nfd-input .goog-flat-menu-button {
    line-height: 17px
}
.nfd-date-time-input .goog-flat-menu-button {
    margin: 1px 2px
}
.nfd-input .jfk-select .goog-flat-menu-button-dropdown {
    margin-top: -9px
}
.nfd-input table {
    border-spacing: 0;
    width: 100%
}
.nfd-inner-input {
    min-width: 25px;
    width: 100%
}
.nfd-dialog.modal-dialog-content {
    width: 400px
}
.nfd-dialog-content {
    border: 1px solid #e5e5e5;
    cursor: pointer;
    height: 400px;
    margin-top: 22px;
    overflow-y: scroll;
    -webkit-tap-highlight-color: transparent
}
.nfd-dialog-content ul {
    list-style: none;
    margin: 0;
    padding: 0
}
.nfd-format-pill {
    border-bottom: 1px solid #e5e5e5;
    border-left: 1px solid transparent;
    font-size: 15px;
    padding: 16px;
    position: relative
}
.nfd-format-pill:focus {
    border-left: 1px solid #4d90fe;
    outline: none
}
.nfd-format-pill:hover {
    background-color: #f1f1f1
}
.nfd-format-display {
    display: inline-block
}
.nfd-format-sample {
    color: #777;
    display: inline-block;
    position: absolute;
    right: 20px
}
.nfd-pill-container li:last-child {
    border-bottom: none
}
.cnf-sample-table {
    border-spacing: 0;
    display: inline-table
}
.cnf-sample-wrapper {
    position: relative
}
.cnf-help-link {
    position: absolute;
    right: 0
}
td.nfd-sample-label {
    color: #777;
    padding-left: 0;
    padding-right: 5px
}
.number-format-menu .goog-menuitem {
    padding-right: 1em
}
.nfd-date-time-menu-button {
    float: right;
    top: 5px
}
.nfd-date-time-menu-button:focus {
    outline: none
}
.nfd-input.nfd-invalid {
    border: 1px solid #dd4b39
}
.nfd-date-time-menu .goog-menuitem {
    padding-left: 6px;
    padding-right: 4em
}
.docs-gm-dialogs .nfd-dialog.modal-dialog {
    padding: 24px
}
.docs-gm-dialogs .nfd-dialog .dialog-separator {
    display: none
}
.docs-gm-dialogs .nfd-inputall .nfd-input {
    height: initial;
    margin-top: 0;
    min-height: 36px;
    padding: 2px 8px;
    width: 366px
}
.docs-gm-dialogs .nfd-input>input {
    height: 18px;
    padding: 6px 0
}
.docs-gm-dialogs .nfd-inner-input {
    height: 16px;
    line-height: 16px;
    padding: 7px 0
}
.docs-gm-dialogs .nfd-input.nfd-input-focus {
    box-shadow: none;
    border: 2px solid #1a73e8;
    box-shadow: none;
    padding: 0px 7px
}
.docs-gm-dialogs .nfd-input.nfd-input-focus>input {
    padding: 7px 0
}
.docs-gm-dialogs .nfd-input.nfd-input-focus .nfd-inner-input {
    padding: 8px 0
}
.docs-gm-dialogs .nfd-input input {
    font-size: inherit
}
.docs-gm-dialogs .nfd-dialog.modal-dialog-content {
    min-width: 464px;
    width: auto;
    width: unset
}
.docs-gm-dialogs .nfd-dialog-content {
    margin-top: 8px
}
.docs-gm-dialogs .nfd-input .goog-flat-menu-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #dadce0!important;
    color: #188038;
    height: 24px;
    padding: 3px 12px 5px;
    border-radius: 24px;
    color: #3c4043;
    font-size: 12px;
    padding: 3px 24px 3px 10px
}
.docs-gm-dialogs .nfd-input .goog-flat-menu-button-caption {
    font-weight: 500
}
.docs-gm-dialogs .nfd-input .goog-flat-menu-button.goog-flat-menu-button-hover {
    background: #f8f9fa
}
.docs-gm-dialogs .nfd-date-time-pill {
    margin: 2px 0
}
.docs-gm-dialogs .nfd-input .nfd-currency-other-formats {
    padding-top: 4px;
    margin-right: 0
}
.docs-gm-dialogs .nfd-date-time-menu-button {
    background: no-repeat url(//ssl.gstatic.com/docs/common/material_common_sprite134.svg) -40px -3126px;
    border: none;
    height: 18px;
    margin: 6px 0;
    width: 18px
}
.docs-gm-dialogs .nfd-input .goog-flat-menu-button-dropdown {
    background: no-repeat url(//ssl.gstatic.com/docs/common/material_common_sprite134.svg) 0 -2794px;
    height: 18px;
    left: 18px;
    top: 0;
    width: 18px
}
.docs-gm-dialogs .jfk-button.nfd-apply {
    margin-left: 9px
}
.goog-palette {
    cursor: default;
    outline: none
}
.goog-palette-table {
    border: 1px solid #666;
    border-collapse: collapse;
    margin: 5px
}
.goog-palette-cell {
    border: 0;
    border-right: 1px solid #666;
    cursor: pointer;
    height: 18px;
    margin: 0;
    text-align: center;
    vertical-align: middle;
    width: 18px
}
.goog-palette-cell .goog-palette-colorswatch {
    border: none;
    font-size: x-small;
    height: 18px;
    position: relative;
    width: 18px
}
.goog-palette-cell-hover .goog-palette-colorswatch {
    border: 1px solid #fff;
    height: 16px;
    width: 16px
}
.goog-palette-cell-selected .goog-palette-colorswatch {
    background: url(//ssl.gstatic.com/editor/editortoolbar.png) no-repeat -368px 0;
    border: 1px solid #333;
    color: #fff;
    font-weight: bold;
    height: 16px;
    width: 16px
}
.goog-palette-customcolor {
    background-color: #fafafa;
    border: 1px solid #eee;
    color: #666;
    font-size: x-small;
    height: 15px;
    position: relative;
    width: 15px
}
.goog-palette-cell-hover .goog-palette-customcolor {
    background-color: #fee;
    border: 1px solid #f66;
    color: #f66
}
.goog-color-menu-button-indicator {
    border-bottom: 4px solid #f0f0f0
}
.goog-color-menu-button .goog-menu-button-inner-box,
.goog-toolbar-color-menu-button .goog-toolbar-menu-button-inner-box {
    padding-top: 2px!important;
    padding-bottom: 2px!important
}
.goog-tab {
    position: relative;
    padding: 4px 8px;
    color: #00c;
    text-decoration: underline;
    cursor: default
}
.goog-tab-bar-top .goog-tab {
    margin: 1px 4px 0 0;
    border-bottom: 0;
    float: left
}
.goog-tab-bar-top:after,
.goog-tab-bar-bottom:after {
    content: " ";
    display: block;
    height: 0;
    clear: both;
    visibility: hidden
}
.goog-tab-bar-bottom .goog-tab {
    margin: 0 4px 1px 0;
    border-top: 0;
    float: left
}
.goog-tab-bar-start .goog-tab {
    margin: 0 0 4px 1px;
    border-right: 0
}
.goog-tab-bar-end .goog-tab {
    margin: 0 1px 4px 0;
    border-left: 0
}
.goog-tab-hover {
    background: #eee
}
.goog-tab-disabled {
    color: #666
}
.goog-tab-selected {
    color: #000;
    background: #fff;
    text-decoration: none;
    font-weight: bold;
    border: 1px solid #6b90da
}
.goog-tab-bar-top {
    padding-top: 5px!important;
    padding-left: 5px!important;
    border-bottom: 1px solid #6b90da!important
}
.goog-tab-bar-top .goog-tab-selected {
    top: 1px;
    margin-top: 0;
    padding-bottom: 5px
}
.goog-tab-bar-bottom .goog-tab-selected {
    top: -1px;
    margin-bottom: 0;
    padding-top: 5px
}
.goog-tab-bar-start .goog-tab-selected {
    left: 1px;
    margin-left: 0;
    padding-right: 9px
}
.goog-tab-bar-end .goog-tab-selected {
    left: -1px;
    margin-right: 0;
    padding-left: 9px
}
.goog-tab-bar {
    margin: 0;
    border: 0;
    padding: 0;
    list-style: none;
    cursor: default;
    outline: none;
    background: #ebeff9
}
.goog-tab-bar-clear {
    clear: both;
    height: 0;
    overflow: hidden
}
.goog-tab-bar-start {
    float: left
}
.goog-tab-bar-end {
    float: right
}
* html .goog-tab-bar-start {
    margin-right: -3px
}
* html .goog-tab-bar-end {
    margin-left: -3px
}
.jfk-scrollbar::-webkit-scrollbar {
    height: 16px;
    overflow: visible;
    width: 16px
}
.jfk-scrollbar::-webkit-scrollbar-button {
    height: 0;
    width: 0
}
.jfk-scrollbar::-webkit-scrollbar-track {
    background-clip: padding-box;
    border: solid transparent;
    border-width: 0 0 0 4px
}
.jfk-scrollbar::-webkit-scrollbar-track:horizontal {
    border-width: 4px 0 0
}
.jfk-scrollbar::-webkit-scrollbar-track:hover {
    background-color: rgba(0, 0, 0, .05);
    box-shadow: inset 1px 0 0 rgba(0, 0, 0, .1)
}
.jfk-scrollbar::-webkit-scrollbar-track:horizontal:hover {
    box-shadow: inset 0 1px 0 rgba(0, 0, 0, .1)
}
.jfk-scrollbar::-webkit-scrollbar-track:active {
    background-color: rgba(0, 0, 0, .05);
    box-shadow: inset 1px 0 0 rgba(0, 0, 0, .14), inset -1px 0 0 rgba(0, 0, 0, .07)
}
.jfk-scrollbar::-webkit-scrollbar-track:horizontal:active {
    box-shadow: inset 0 1px 0 rgba(0, 0, 0, .14), inset 0 -1px 0 rgba(0, 0, 0, .07)
}
.jfk-scrollbar-dark.jfk-scrollbar::-webkit-scrollbar-track:hover {
    background-color: rgba(255, 255, 255, .1);
    box-shadow: inset 1px 0 0 rgba(255, 255, 255, .2)
}
.jfk-scrollbar-dark.jfk-scrollbar::-webkit-scrollbar-track:horizontal:hover {
    box-shadow: inset 0 1px 0 rgba(255, 255, 255, .2)
}
.jfk-scrollbar-dark.jfk-scrollbar::-webkit-scrollbar-track:active {
    background-color: rgba(255, 255, 255, .1);
    box-shadow: inset 1px 0 0 rgba(255, 255, 255, .25), inset -1px 0 0 rgba(255, 255, 255, .15)
}
.jfk-scrollbar-dark.jfk-scrollbar::-webkit-scrollbar-track:horizontal:active {
    box-shadow: inset 0 1px 0 rgba(255, 255, 255, .25), inset 0 -1px 0 rgba(255, 255, 255, .15)
}
.jfk-scrollbar::-webkit-scrollbar-thumb {
    background-color: rgba(0, 0, 0, .2);
    background-clip: padding-box;
    border: solid transparent;
    border-width: 1px 1px 1px 6px;
    min-height: 28px;
    padding: 100px 0 0;
    box-shadow: inset 1px 1px 0 rgba(0, 0, 0, .1), inset 0 -1px 0 rgba(0, 0, 0, .07)
}
.jfk-scrollbar::-webkit-scrollbar-thumb:horizontal {
    border-width: 6px 1px 1px;
    padding: 0 0 0 100px;
    box-shadow: inset 1px 1px 0 rgba(0, 0, 0, .1), inset -1px 0 0 rgba(0, 0, 0, .07)
}
.jfk-scrollbar::-webkit-scrollbar-thumb:hover {
    background-color: rgba(0, 0, 0, .4);
    box-shadow: inset 1px 1px 1px rgba(0, 0, 0, .25)
}
.jfk-scrollbar::-webkit-scrollbar-thumb:active {
    background-color: rgba(0, 0, 0, 0.5);
    box-shadow: inset 1px 1px 3px rgba(0, 0, 0, 0.35)
}
.jfk-scrollbar-dark.jfk-scrollbar::-webkit-scrollbar-thumb {
    background-color: rgba(255, 255, 255, .3);
    box-shadow: inset 1px 1px 0 rgba(255, 255, 255, .15), inset 0 -1px 0 rgba(255, 255, 255, .1)
}
.jfk-scrollbar-dark.jfk-scrollbar::-webkit-scrollbar-thumb:horizontal {
    box-shadow: inset 1px 1px 0 rgba(255, 255, 255, .15), inset -1px 0 0 rgba(255, 255, 255, .1)
}
.jfk-scrollbar-dark.jfk-scrollbar::-webkit-scrollbar-thumb:hover {
    background-color: rgba(255, 255, 255, .6);
    box-shadow: inset 1px 1px 1px rgba(255, 255, 255, .37)
}
.jfk-scrollbar-dark.jfk-scrollbar::-webkit-scrollbar-thumb:active {
    background-color: rgba(255, 255, 255, .75);
    box-shadow: inset 1px 1px 3px rgba(255, 255, 255, .5)
}
.jfk-scrollbar-borderless.jfk-scrollbar::-webkit-scrollbar-track {
    border-width: 0 1px 0 6px
}
.jfk-scrollbar-borderless.jfk-scrollbar::-webkit-scrollbar-track:horizontal {
    border-width: 6px 0 1px
}
.jfk-scrollbar-borderless.jfk-scrollbar::-webkit-scrollbar-track:hover {
    background-color: rgba(0, 0, 0, .035);
    box-shadow: inset 1px 1px 0 rgba(0, 0, 0, .14), inset -1px -1px 0 rgba(0, 0, 0, .07)
}
.jfk-scrollbar-borderless.jfk-scrollbar-dark.jfk-scrollbar::-webkit-scrollbar-track:hover {
    background-color: rgba(255, 255, 255, .07);
    box-shadow: inset 1px 1px 0 rgba(255, 255, 255, .25), inset -1px -1px 0 rgba(255, 255, 255, .15)
}
.jfk-scrollbar-borderless.jfk-scrollbar::-webkit-scrollbar-thumb {
    border-width: 0 1px 0 6px
}
.jfk-scrollbar-borderless.jfk-scrollbar::-webkit-scrollbar-thumb:horizontal {
    border-width: 6px 0 1px
}
.jfk-scrollbar::-webkit-scrollbar-corner {
    background: transparent
}
body.jfk-scrollbar::-webkit-scrollbar-track-piece {
    background-clip: padding-box;
    background-color: #f5f5f5;
    border: solid #fff;
    border-width: 0 0 0 3px;
    box-shadow: inset 1px 0 0 rgba(0, 0, 0, .14), inset -1px 0 0 rgba(0, 0, 0, .07)
}
body.jfk-scrollbar::-webkit-scrollbar-track-piece:horizontal {
    border-width: 3px 0 0;
    box-shadow: inset 0 1px 0 rgba(0, 0, 0, .14), inset 0 -1px 0 rgba(0, 0, 0, .07)
}
body.jfk-scrollbar::-webkit-scrollbar-thumb {
    border-width: 1px 1px 1px 5px
}
body.jfk-scrollbar::-webkit-scrollbar-thumb:horizontal {
    border-width: 5px 1px 1px
}
body.jfk-scrollbar::-webkit-scrollbar-corner {
    background-clip: padding-box;
    background-color: #f5f5f5;
    border: solid #fff;
    border-width: 3px 0 0 3px;
    box-shadow: inset 1px 1px 0 rgba(0, 0, 0, .14)
}
#docs-toolbar-wrapper {
    border-top: 1px solid #d9d9d9;
    border-bottom: 1px solid #d9d9d9;
    min-height: 35px;
    -webkit-box-shadow: inset 0 1px 0 0 #fff;
    -moz-box-shadow: inset 0 1px 0 0 #fff;
    box-shadow: inset 0 1px 0 0 #fff;
    background-color: #f5f5f5;
    background-image: -webkit-linear-gradient(top, #f5f5f5, #eee);
    background-image: -moz-linear-gradient(top, #f5f5f5, #eee);
    background-image: -ms-linear-gradient(top, #f5f5f5, #eee);
    background-image: -o-linear-gradient(top, #f5f5f5, #eee);
    background-image: linear-gradient(top, #f5f5f5, #eee);
    padding: 0 44px 0 58px;
    position: relative
}
#docs-toolbar {
    background: none;
    border-width: 0!important;
    display: inline;
    min-height: 35px;
    padding: 0
}
#docs-primary-toolbars {
    display: block
}
#docs-omnibox-toolbar {
    background: none;
    border-width: 0!important;
    display: inline-block;
    padding: 0;
    vertical-align: middle;
    width: 182px;
    overflow: hidden
}
#docs-side-toolbar {
    background: none;
    border: 0;
    margin: 0 44px 0 0;
    padding: 0;
    position: absolute;
    right: 0;
    top: 0
}
.goog-toolbar {
    margin-bottom: 0;
    outline: 0
}
.goog-toolbar-button,
.goog-toolbar-menu-button {
    margin: 4px 0 0 -1px
}
.goog-toolbar-button-inner-box,
.goog-toolbar-menu-button-inner-box {
    height: 25px;
    min-width: 25px;
    padding: 0;
    text-align: center
}
.docs-toolbar-button-split-left .goog-toolbar-button-inner-box {
    min-width: 23px
}
.goog-toolbar-button-inner-box .docs-icon,
.goog-toolbar-menu-button-caption .docs-icon,
.goog-toolbar-menu-button-caption .goog-color-menu-button-indicator .docs-icon {
    margin-top: -3px
}
.goog-toolbar-menu-button .goog-toolbar-menu-button-outer-box .goog-toolbar-menu-button-inner-box,
.goog-toolbar-button .goog-toolbar-menu-button-outer-box .goog-toolbar-menu-button-inner-box {
    margin: 0 1px
}
.goog-toolbar-menu-button-dropdown {
    margin-left: 4px;
    margin-right: 0;
    margin-top: 9px
}
.goog-toolbar-color-menu-button .goog-toolbar-menu-button-dropdown {
    margin-top: 7px
}
.goog-toolbar-separator.goog-inline-block {
    border-left: 1px solid #d9d9d9;
    height: 35px;
    margin: 0 5px 0 4px;
    vertical-align: top
}
.goog-toolbar-select .goog-toolbar-menu-button-outer-box .goog-toolbar-menu-button-inner-box {
    margin: 0;
    margin-right: 1px
}
.goog-color-menu-button-indicator {
    position: relative;
    height: 19px
}
.goog-toolbar-color-menu-button .goog-toolbar-menu-button-caption {
    top: -2px
}
.docs-toolbar-small-separator.goog-toolbar-separator {
    border-left: 1px solid #ccc;
    display: inline;
    font-size: 11px;
    height: 17px;
    line-height: normal;
    list-style: none;
    margin: 0 -3px 0 -1px;
    outline: none;
    overflow: hidden;
    padding: 0 0 3px 0;
    text-decoration: none;
    vertical-align: middle;
    width: 0
}
.docs-toolbar-small-separator.goog-toolbar-separator,
.docs-toolbar-small-separator.goog-toolbar-separator {
    display: inline-block;
    height: 35px;
    margin: 0 5px 0 4px;
    padding: 0;
    vertical-align: top
}
.docs-toolbar-small-separator.goog-toolbar-separator+.docs-toolbar-small-separator.goog-toolbar-separator {
    display: none
}
.goog-toolbar-button+div.docs-toolbar-small-separator,
div.goog-toolbar-separator+div.docs-toolbar-small-separator,
div.goog-toolbar-menu-button+div.docs-toolbar-small-separator {
    margin-left: 3px
}
.docs-toolbar-small-separator+div.goog-toolbar-button,
.docs-toolbar-small-separator+div.goog-toolbar-menu-button,
.docs-toolbar-small-separator+div[class~=goog-toolbar-select] {
    margin-left: -1px
}
div[class~="goog-toolbar-select"]+div.docs-toolbar-small-separator {
    margin-left: -1px
}
.docs-toolbar-small-separator+div.goog-toolbar-select {
    margin-left: -3px
}
.docs-toolbar-inset-separator.docs-toolbar-small-separator {
    border-left: 1px solid 1px solid #d9d9d9;
    height: 20px;
    margin: 5px 5px 0 4px;
    vertical-align: middle
}
.goog-toolbar-toggle-button.goog-toolbar-button-checked+.goog-toolbar-toggle-button.goog-toolbar-button-checked {
    border-left: 0;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    margin-left: -1px
}
.goog-toolbar-toggle-button.goog-toolbar-button-checked+.goog-toolbar-toggle-button.goog-toolbar-button-checked .goog-toolbar-button-outer-box .goog-toolbar-button-inner-box,
.goog-toolbar-toggle-button.goog-toolbar-button-checked+.goog-toolbar-toggle-button.goog-toolbar-button-checked.goog-toolbar-button-hover .goog-toolbar-button-outer-box .goog-toolbar-button-inner-box {
    margin-left: 1px
}
.goog-toolbar-button .docs-icon,
.goog-toolbar-menu-button .docs-icon {
    opacity: .70
}
.goog-toolbar-button-hover .docs-icon,
.goog-toolbar-button-selected .docs-icon,
.goog-toolbar-button-checked .docs-icon,
.goog-toolbar-menu-button-hover .docs-icon,
.goog-toolbar-menu-button-selected .docs-icon,
.goog-toolbar-menu-button-checked .docs-icon {
    opacity: 0.9
}
.goog-toolbar-button-active .docs-icon,
.goog-toolbar-menu-button-open .docs-icon {
    opacity: 1.0
}
.goog-toolbar-select .goog-toolbar-menu-button-outer-box .goog-toolbar-menu-button-inner-box .goog-toolbar-menu-button-caption {
    margin-left: 10px;
    text-align: left
}
.goog-toolbar-select .goog-toolbar-menu-button-outer-box .goog-toolbar-menu-button-inner-box .goog-toolbar-menu-button-dropdown {
    margin-left: 5px;
    margin-right: 4px
}
.docs-toolbar-button-split-left,
.docs-toolbar-button-split-left * {
    border-top-right-radius: 0!important;
    border-bottom-right-radius: 0!important
}
.docs-toolbar-button-split-right,
.docs-toolbar-button-split-right * {
    border-top-left-radius: 0!important;
    border-bottom-left-radius: 0!important;
    min-width: 5px!important
}
.docs-toolbar-button-split-right .goog-toolbar-menu-button-dropdown {
    margin-left: 3px
}
.docs-toolbar-button-split-sympathy-hover {
    border-color: #c6c6c6
}
.docs-toolbar-button-split-left .goog-toolbar-button-hover,
.docs-toolbar-button-split-right .goog-toolbar-button-hover {
    z-index: 1
}
.docs-toolbar-split-create-button.goog-toolbar-menu-button {
    margin-right: 4px
}
.docs-toolbar-split-create-button .goog-toolbar-menu-button-dropdown {
    background: url(//ssl.gstatic.com/ui/v1/disclosure/small-grey-disclosure-arrow-down.png) center no-repeat;
    height: 7px;
    margin-top: 9px;
    opacity: 1
}
.docs-toolbar-split-create-button {
    background-color: #f5f5f5;
    background-image: -webkit-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: -o-linear-gradient(top, #f5f5f5, #f1f1f1);
    background-image: linear-gradient(top, #f5f5f5, #f1f1f1);
    border-color: #c6c6c6!important
}
.docs-toolbar-split-create-button.goog-toolbar-button-disabled {
    border-right-color: #fff!important
}
.docs-toolbar-split-create-button.goog-toolbar-button-hover,
.docs-toolbar-split-create-button.goog-toolbar-menu-button-hover {
    background-color: #f8f8f8;
    background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -o-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
    border-color: #c6c6c6!important
}
.docs-toolbar-split-create-button.goog-toolbar-button-active,
.docs-toolbar-split-create-button.goog-toolbar-menu-button-active {
    background-color: #f8f8f8;
    background-image: -webkit-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -moz-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -ms-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: -o-linear-gradient(top, #f8f8f8, #f1f1f1);
    background-image: linear-gradient(top, #f8f8f8, #f1f1f1);
    border-color: #c6c6c6!important
}
.docs-toolbar-split-create-button .docs-icon {
    opacity: 1
}
.docs-toolbar-text-button .goog-toolbar-button-outer-box,
.docs-toolbar-text-button .goog-toolbar-menu-button-outer-box {
    padding-left: 4px
}
.docs-toolbar-text-button .goog-toolbar-button-outer-box {
    padding-right: 4px
}
.goog-toolbar-menu-button-outer-box {
    padding-right: 3px
}
.goog-toolbar-menu-button-arrow-hidden.goog-toolbar-menu-button-outer-box {
    padding-right: 0px
}
.jfk-bubble.docs-toolbar-more-bubble {
    padding: 0px;
    z-index: 902!important
}
.docs-toolbar-more-bubble .jfk-bubble-arrowup .jfk-bubble-arrowimplafter {
    border-color: #eee transparent
}
.docs-toolbar-more-toolbar {
    background: #eee;
    border: 0;
    min-height: 35px;
    padding: 0 0 0 10px
}
.docs-collapsable-toolbar {
    white-space: nowrap
}
.docs-collapsable-toolbar-control {
    white-space: normal
}
.docs-hc-gecko .docs-icon-img {
    filter: invert(100%)
}
.docs-hc-gecko .docs-icon-img.docs-icon-document,
.docs-hc-gecko .docs-icon-img.docs-icon-punch,
.docs-hc-gecko .docs-icon-img.docs-icon-presentation,
.docs-hc-gecko .docs-icon-img.docs-icon-spreadsheet,
.docs-hc-gecko .docs-icon-img.docs-icon-form,
.docs-hc-gecko .docs-icon-img.docs-icon-drawing,
.docs-hc-gecko .docs-icon-img.docs-icon-script,
.docs-hc-gecko .docs-icon-img.docs-icon-site {
    filter: none
}
.docs-hc-ie .docs-icon-img {
    -ms-high-contrast-adjust: none;
    background-color: white
}
.docs-icon-toolbar-button-with-text {
    padding-left: 4px;
    padding-right: 4px
}
.docs-icon-toolbar-button-with-text .docs-icon-toolbar-button-with-text-icon-container {
    margin-right: 4px
}
.google-visualization-clickeditor-bubble.jfk-bubble {
    padding: 3px;
    z-index: inherit!important;
    background-color: #f5f5f5;
    font-family: Arial, san-serif;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
    border-color: #dadada
}
.google-visualization-clickeditor-bubble .jfk-bubble-arrowdown .jfk-bubble-arrowimplafter,
.google-visualization-clickeditor-bubble .jfk-bubble-arrowup .jfk-bubble-arrowimplafter {
    border-color: #f5f5f5 transparent
}
.google-visualization-clickeditor-combobox .goog-toolbar-combo-button-input {
    width: 28px;
    padding: 0 0 0 3px;
    position: relative
}
.goog-menuitem .google-visualization-clickeditor-combobox-icon {
    position: absolute;
    top: 4px;
    left: 100px
}
.google-visualization-charteditor-menu .goog-menuheader {
    padding-left: 10px;
    color: #888
}
.google-visualization-clickeditor-combobox .google-visualization-clickeditor-combobox-icon {
    position: absolute;
    height: 100%;
    width: 34px;
    top: 0;
    left: 0;
    background-color: #f5f5f5
}
.goog-toolbar-combo-button-open .google-visualization-clickeditor-combobox-icon {
    filter: alpha(opacity=0);
    opacity: 0
}
.google-visualization-clickeditor-combobox-icon .docs-icon {
    margin: 0 0 0 7px;
    filter: alpha(opacity=60);
    opacity: 0.6
}
.google-visualization-clickeditor-bubble .goog-toolbar-combo-button,
.google-visualization-clickeditor-bubble .goog-toolbar-menu-button,
.google-visualization-clickeditor-bubble .goog-toolbar-button {
    margin: 0;
    top: auto
}
.google-visualization-clickeditor-bubble .goog-toolbar-color-menu-button .goog-toolbar-menu-button-dropdown {
    top: -2px
}
.google-visualization-clickeditor-color .goog-color-menu-button-indicator {
    width: 14px;
    height: 0;
    border-bottom-width: 14px;
    margin: 6px;
    outline: 1px solid #bbb
}
.google-visualization-clickeditor-tooltip {
    font-family: Arial, sans-serif;
    font-weight: normal;
    -webkit-transition: background-color .5s;
    -moz-transition: background-color .5s;
    -ms-transition: background-color .5s;
    -o-transition: background-color .5s;
    transition: background-color .5s
}
.google-visualization-clickeditor-bubble .goog-toolbar-separator {
    height: 20px;
    vertical-align: middle;
    border-color: #ccc
}
.google-visualization-clickeditor-separator {
    width: 98%;
    height: 0;
    border: 1px solid #f8f8f8;
    margin: 3px
}
.google-visualization-clickeditor-input-box {
    padding: 5px
}
.google-visualization-clickeditor-enter-msg {
    font-size: 11px;
    color: #555;
    padding: 4px
}
.google-visualization-clickeditor-bubble .google-visualization-charteditor-input:focus {
    outline-color: #008df0
}
.google-visualization-clickeditor-bubble .google-visualization-charteditor-input-inline-x,
.google-visualization-clickeditor-bubble .google-visualization-charteditor-input-inline-y,
.google-visualization-clickeditor-bubble .google-visualization-charteditor-input-inline-right {
    font-size: 12px;
    margin: 4px
}
.google-visualization-clickeditor-bubble .google-visualization-charteditor-input-inline-x {
    width: 79px
}
.google-visualization-clickeditor-bubble .google-visualization-charteditor-input-inline-y,
.google-visualization-clickeditor-bubble .google-visualization-charteditor-input-inline-right {
    width: 52px
}
.google-visualization-clickeditor-bubble .google-visualization-charteditor-combobox,
.google-visualization-clickeditor-bubble .goog-flat-menu-button {
    margin: 0
}
.goog-flat-menu-button-disabled .goog-flat-menu-button-dropdown {
    border-color: #b8b8b8 transparent
}
.google-visualization-clickeditor-entity-cover {
    position: absolute;
    visibility: hidden;
    overflow: hidden;
    cursor: pointer
}
.google-visualization-clickeditor-entity-cover-stripes {
    position: absolute;
    top: 0;
    width: 100%;
    height: 100%;
    background: url("//ssl.gstatic.com/charts/static/stripes.png") repeat;
    visibility: visible;
    filter: alpha(opacity=10);
    opacity: 0.1
}
.google-visualization-clickeditor-entity-cover-top,
.google-visualization-clickeditor-entity-cover-bottom,
.google-visualization-clickeditor-entity-cover-left,
.google-visualization-clickeditor-entity-cover-right {
    visibility: visible;
    background-color: #008ef1;
    width: 1px;
    height: 1px;
    position: absolute
}
.google-visualization-clickeditor-entity-cover-top,
.google-visualization-clickeditor-entity-cover-bottom {
    width: 100%
}
.google-visualization-clickeditor-entity-cover-left,
.google-visualization-clickeditor-entity-cover-right {
    height: 100%
}
.google-visualization-clickeditor-entity-cover-right {
    right: 0
}
.google-visualization-clickeditor-entity-cover-left {
    left: 0
}
.google-visualization-clickeditor-entity-cover-bottom {
    bottom: 0
}
.google-visualization-clickeditor-entity-cover .google-visualization-clickeditor-mid-input {
    width: 98%;
    filter: alpha(opacity=0);
    opacity: 0
}
.google-visualization-clickeditor-entity-cover .google-visualization-clickeditor-mid-input:focus {
    filter: alpha(opacity=100);
    opacity: 1
}
.google-visualization-clickeditor-header {
    height: 30px;
    background-color: white;
    padding: 3px;
    overflow: hidden
}
.google-visualization-clickeditor-header-text {
    margin-left: 5px;
    font-family: Arial, sans-serif;
    font-size: 12px;
    color: #999;
    white-space: nowrap
}
.jfk-button.google-visualization-clickeditor-header-view,
.jfk-button.google-visualization-clickeditor-header-edit {
    z-index: 0
}
.jfk-button.jfk-button-disabled.google-visualization-clickeditor-header-view,
.jfk-button.jfk-button-disabled.google-visualization-clickeditor-header-edit {
    background: transparent;
    border: none;
    box-shadow: none;
    margin-top: 1px;
    margin-left: 1px;
    opacity: 0.5
}
.google-visualization-clickeditor-header-view .docs-icon,
.google-visualization-clickeditor-header-edit .docs-icon {
    margin-top: -3px;
    margin-left: -2px;
    filter: alpha(opacity=60);
    opacity: 0.6
}
.jfk-button.google-visualization-clickeditor-header-edit {
    margin-right: 5px
}
.google-visualization-clickeditor-context-icon {
    position: absolute;
    right: 10px;
    padding: 0 5px;
    top: 2px
}
.jfk-button.jfk-button-disabled.google-visualization-clickeditor-resize,
.jfk-button.jfk-button-disabled.google-visualization-clickeditor-fit-area {
    background: #f5f5f5
}
.google-visualization-clickeditor-resize,
.google-visualization-clickeditor-fit-area {
    height: 24px;
    line-height: 24px;
    border-color: transparent;
    margin-right: 2px
}
.google-visualization-clickeditor-resize .docs-icon,
.google-visualization-clickeditor-fit-area .docs-icon {
    margin-top: -3px;
    filter: alpha(opacity=60);
    opacity: 0.6
}
.google-visualization-clickeditor-resize-text,
.google-visualization-clickeditor-fit-area-text {
    font-size: 11px;
    font-weight: bold;
    color: #555;
    margin: 0 5px
}
.google-visualization-resizer-overlay {
    position: absolute;
    visibility: hidden
}
.google-visualization-resizer-bar {
    background: url("//ssl.gstatic.com/charts/static/stripes.png") #ffffff;
    position: absolute;
    opacity: 0.1;
    visibility: visible;
    width: 100%;
    height: 100%
}
.google-visualization-resizer-bar:hover {
    opacity: 0.2
}
.google-visualization-resizer-bar-center {
    height: 100%;
    width: 100%;
    cursor: crosshair;
    position: absolute;
    top: 0
}
.google-visualization-resizer-bar-north {
    height: 10px;
    cursor: n-resize;
    top: 0
}
.google-visualization-resizer-bar-south {
    height: 10px;
    cursor: s-resize;
    position: absolute;
    bottom: 0
}
.google-visualization-resizer-bar-east {
    width: 10px;
    cursor: e-resize;
    position: absolute;
    right: 0
}
.google-visualization-resizer-bar-west {
    width: 10px;
    cursor: w-resize;
    position: absolute;
    left: 0
}
.google-visualization-charteditor-dialog {
    height: 508px;
    width: 917px
}
.google-visualization-charteditor-dialog .modal-dialog-title {
    font-family: Arial, sans-serif
}
#google-visualization-charteditor-layout-table,
.google-visualization-charteditor-custom-panel,
#google-visualization-clickeditor,
.google-visualization-charteditor-menu {
    color: #222;
    font-family: Arial, sans-serif;
    font-size: 12px
}
.google-visualization-charteditor-small-input,
.google-visualization-charteditor-mid-input,
.google-visualization-charteditor-input {
    -webkit-border-radius: 1px;
    -moz-border-radius: 1px;
    border-radius: 1px;
    border: 1px solid #d9d9d9;
    border-top: 1px solid silver;
    -webkit-box-sizing: content-box;
    -moz-box-sizing: content-box;
    box-sizing: content-box;
    font-size: 13px;
    height: 16px;
    padding: 5px 2px
}
.google-visualization-charteditor-dialog .goog-flat-menu-button-dropdown,
.google-visualization-clickeditor-bubble .goog-flat-menu-button-dropdown,
.google-visualization-charteditor-custom-panel .goog-flat-menu-button-dropdown {
    background: url(//ssl.gstatic.com/ui/v1/disclosure/small-grey-disclosure-arrow-down.png) center no-repeat;
    border-width: 0;
    height: 7px;
    opacity: 0.8;
    position: absolute;
    top: 10px;
    width: 5px
}
.google-visualization-charteditor-dialog .goog-flat-menu-button,
.google-visualization-clickeditor-bubble .goog-flat-menu-button,
.google-visualization-charteditor-custom-panel .goog-flat-menu-button {
    height: 14px;
    line-height: normal;
    margin: 0 0 0 5px;
    min-width: 0;
    padding: 6px 0 6px 6px;
    text-align: left
}
#google-visualization-clickeditor .goog-flat-menu-button {
    min-width: 34px
}
#google-visualization-charteditor-series-select-div.goog-flat-menu-button,
#google-visualization-charteditor-axes-select-div.goog-flat-menu-button {
    margin: 0;
    width: 100%
}
#google-visualization-charteditor-select-legend-position {
    margin-left: 0
}
.google-visualization-charteditor-axis-select-scale.goog-select {
    margin-left: 0;
    margin-right: 36px
}
#google-visualization-charteditor-select-legend-position .goog-flat-menu-button-caption {
    width: 74px
}
#google-visualization-charteditor-layout-table,
#google-visualization-clickeditor,
.google-visualization-charteditor-custom-panel {
    border: 0;
    font-size: 12px;
    margin: 0;
    padding: 0
}
.google-visualization-charteditor-settings-td,
.google-visualization-charteditor-custom-panel {
    overflow: hidden;
    padding: 0 0 0 4px;
    position: relative;
    left: -4px;
    vertical-align: top;
    width: 288px
}
.google-visualization-charteditor-custom-panel {
    height: 420px;
    line-height: 1.4em
}
.google-visualization-charteditor-preview-td {
    height: 411px;
    left: 346px;
    overflow: hidden;
    padding: 0 0 0 6px;
    position: absolute;
    top: 81px;
    vertical-align: top;
    width: 602px
}
#google-visualization-charteditor-preview-example-template {
    color: #15c
}
#google-visualization-charteditor-help-link {
    color: #1111cc;
    float: right;
    font-size: 12px;
    font-weight: normal
}
.google-visualization-charteditor-dialog-spinner-div {
    height: 370px;
    position: relative;
    text-align: center
}
.google-visualization-charteditor-dialog-spinner {
    background: url('//ssl.gstatic.com/docs/spreadsheets/spinner.gif') no-repeat;
    height: 20px;
    position: relative;
    top: 155px;
    width: 20px
}
#google-visualization-charteditor-panel-wrapper {
    float: left;
    height: 373px;
    width: 300px
}
#google-visualization-charteditor-preview-div-wrapper {
    border: 1px solid #e4e4e4;
    padding: 0;
    position: relative;
    top: 8px
}
#google-visualization-charteditor-preview-div-chart {
    overflow: hidden
}
.google-visualization-charteditor-panel {
    height: 100%;
    width: 100%
}
.google-visualization-charteditor-panel-scroll {
    overflow: auto;
    position: relative
}
.google-visualization-charteditor-panel .goog-menu-button {
    cursor: default
}
#google-visualization-charteditor-custom-data-input {
    position: relative
}
#google-visualization-charteditor-custom-data-input .sites-gviz-datasource-control {
    outline: none
}
#google-visualization-charteditor-panel-navigate-div {
    border-bottom: 1px solid #ccc;
    font-size: 13px;
    line-height: 1.5em;
    margin-bottom: 15px;
    padding: 5px 0 0 10px;
    width: 900px
}
#google-visualization-charteditor-panel-navigate-div.goog-tab-bar {
    background: none;
    cursor: default;
    list-style: none;
    outline: none
}
.google-visualization-charteditor-panel-navigation-cell.goog-tab {
    background: white;
    border: none;
    color: #666;
    cursor: default;
    padding: 3px 10px;
    position: relative;
    text-decoration: none
}
.google-visualization-charteditor-panel-navigation-cell.goog-tab-hover {
    color: #222;
    cursor: pointer
}
.google-visualization-charteditor-panel-navigation-cell.goog-tab-selected {
    color: #202020;
    border: 1px solid #ccc;
    border-bottom-color: white;
    -webkit-border-top-left-radius: 2px;
    -webkit-border-top-right-radius: 2px;
    -moz-border-radius-topleft: 2px;
    -moz-border-radius-topright: 2px;
    border-top-left-radius: 2px;
    border-top-right-radius: 2px;
    cursor: default;
    font-weight: 700;
    margin-bottom: -1px;
    text-decoration: none
}
.google-visualization-charteditor-panel-navigation-cell.goog-tab-selected.goog-tab-hover {
    cursor: default;
    text-decoration: none
}
.google-visualization-charteditor-panel-title {
    font-size: 13px;
    font-weight: 800;
    padding-bottom: 6px;
    position: relative
}
.google-visualization-charteditor-section {
    position: relative
}
#google-visualization-charteditor-options-panel .google-visualization-charteditor-section {
    background: white;
    border: 1px solid #e5e5e5;
    margin-top: -1px;
    padding: 10px 10px 20px;
    width: 260px
}
.google-visualization-charteditor-multi-section-gap {
    height: 4px
}
.google-visualization-charteditor-item-gap {
    height: 15px
}
.google-visualization-charteditor-title-gap {
    height: 10px
}
.google-visualization-charteditor-multi-section-title {
    background: whiteSmoke;
    border: 1px #e5e5e5 solid;
    color: #d14836;
    display: table;
    font-size: 13px;
    font-weight: bold;
    padding: 6px 10px;
    text-align: left;
    width: 260px
}
.google-visualization-charteditor-multi-section-title-text {
    display: table-cell;
    padding-right: 7px
}
.google-visualization-charteditor-multi-section-chooser {
    display: table-cell;
    width: 100%
}
.google-visualization-charteditor-section-title {
    color: #222;
    font-size: 13px;
    font-weight: normal;
    padding: 5px 0
}
.google-visualization-charteditor-data-range {
    color: #222;
    font-size: 13px;
    font-weight: bold;
    padding: 5px 0
}
.google-visualization-charteditor-short-title {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    width: 88px
}
.google-visualization-charteditor-section>div>table {
    border: 0;
    border-collapse: collapse;
    border-spacing: 0;
    margin: 0;
    padding: 0;
    table-layout: fixed;
    width: 250px
}
.google-visualization-charteditor-section>tbody>tr>td {
    margin: 0;
    padding: 0;
    vertical-align: top;
    width: 125px
}
#google-visualization-charteditor-select-series {
    margin: 0!important
}
.google-visualization-charteditor-select-series-color {
    height: 10px;
    left: -15px;
    margin: 0;
    position: relative;
    top: 1px;
    width: 10px
}
.google-visualization-charteditor-series-color-palette .goog-palette-cell {
    border-right: 1px solid #333
}
.google-visualization-charteditor-menu-item-global {
    margin-left: 10px
}
.google-visualization-charteditor-color .goog-flat-menu-button {
    min-width: 38px
}
.google-visualization-charteditor-color .goog-flat-menu-button-disabled {
    background-image: none
}
.google-visualization-charteditor-color .goog-flat-menu-button-disabled .goog-flat-menu-button-dropdown {
    opacity: 0.4
}
.google-visualization-charteditor-color .goog-flat-menu-button-disabled .goog-flat-menu-button-indicator {
    opacity: 0.5
}
.google-visualization-charteditor-color .goog-flat-menu-button-indicator {
    height: 14px;
    margin-left: 4px;
    outline: 1px solid #bbb;
    width: 14px
}
.google-visualization-charteditor-inherit-color {
    height: 25px
}
.google-visualization-charteditor-inherit-color .jfk-palette-colorswatch {
    background-color: #f3f3f3!important
}
.google-visualization-charteditor-inherit-color-header {
    margin: 5px;
    top: -4px
}
.google-visualization-charteditor-none-color.goog-option-selected .goog-menuitem-checkbox {
    border: 1px solid transparent;
    outline: 1px solid black
}
.google-visualization-charteditor-none-color.goog-menuitem {
    color: #333;
    font-family: Arial, sans-serif;
    font-size: 12px;
    padding-left: 20px
}
.google-visualization-charteditor-none-color.goog-option-selected {
    background-image: none
}
.google-visualization-charteditor-theme-header.goog-menuheader {
    color: #333;
    font-family: Arial, sans-serif;
    font-size: 12px;
    margin-top: 4px;
    padding: 5px 0 0 0
}
.google-visualization-charteditor-colormenu .jfk-palette-table {
    margin: 3px 0 0 0;
    padding: 0
}
.google-visualization-charteditor-colormenu.jfk-colormenu {
    padding: 10px
}
.google-visualization-charteditor-none-color .goog-menuitem-checkbox {
    background: url(//ssl.gstatic.com/ui/v1/dialog/close-x.png) no-repeat 50% 50%!important;
    height: 13px;
    margin: 0;
    top: 7px;
    width: 13px
}
.google-visualization-charteditor-color-full .goog-menu-button-caption {
    padding: 0
}
.google-visualization-charteditor-color-full .goog-menu-button-inner-box {
    padding: 2px!important
}
.google-visualization-charteditor-link {
    color: blue;
    font-weight: bold
}
.google-visualization-charteditor-link:hover {
    cursor: pointer;
    text-decoration: underline
}
.google-visualization-charteditor-input {
    width: 98%
}
.google-visualization-charteditor-input-disabled {
    background-color: #f3f3f3;
    border: 1px solid #dadada;
    color: #ccc
}
.google-visualization-charteditor-input-label-disabled {
    color: #ccc
}
.google-visualization-charteditor-mid-input {
    width: 138px
}
.google-visualization-charteditor-glasspane {
    background-color: #eee;
    filter: alpha(opacity=0.6);
    opacity: 0.6
}
.google-visualization-charteditor-help-text {
    color: #ccc;
    font-size: 12px
}
#google-visualization-charteditor-data-preview {
    display: none
}
#google-visualization-charteditor-data-preview-arrow {
    background: url(//ssl.gstatic.com/editor/editortoolbar.png) no-repeat -422px center;
    cursor: default;
    display: none;
    height: 10px;
    top: 50%;
    width: 10px
}
.google-visualization-charteditor-data-mismatch {
    color: #555;
    font-size: 13px;
    line-height: 1em;
    padding: 10px
}
.google-visualization-charteditor-data-mismatch-header {
    color: black;
    font-size: 16px;
    margin-bottom: 10px;
    margin-left: 10px
}
.google-visualization-charteditor-mismatch-icon {
    background: url("//ssl.gstatic.com/charts/static/alert.png") no-repeat;
    height: 18px;
    width: 20px
}
#google-visualization-charteditor-preview-mismatch-thumbnail {
    float: right;
    height: 68px;
    margin: 0 0 0 2px;
    width: 110px
}
.google-visualization-charteditor-tooltip {
    font-family: Arial, sans-serif
}
.google-visualization-charteditor-link {
    color: #333;
    font-weight: normal;
    text-decoration: none
}
.google-visualization-charteditor-link:hover {
    cursor: pointer;
    text-decoration: underline
}
.google-visualization-charteditor-checkbox {
    cursor: default;
    display: inline-block;
    margin: 2px 2px 2px 0;
    overflow: hidden;
    padding: 0;
    position: relative;
    white-space: nowrap
}
.google-visualization-charteditor-checkbox-container .google-visualization-charteditor-checkbox {
    width: 120px
}
.google-visualization-charteditor-combobox.google-visualization-charteditor-combobox-closed {
    background-color: whiteSmoke;
    background-image: -webkit-linear-gradient(top, whiteSmoke, #f1f1f1);
    background-image: -moz-linear-gradient(top, whiteSmoke, #f1f1f1);
    background-image: -ms-linear-gradient(top, whiteSmoke, #f1f1f1);
    background-image: -o-linear-gradient(top, whiteSmoke, #f1f1f1);
    background-image: linear-gradient(top, whiteSmoke, #f1f1f1);
    border: 1px solid gainsboro;
    border: 1px solid rgba(0, 0, 0, 0.1)
}
.google-visualization-charteditor-combobox.google-visualization-charteditor-combobox-disabled {
    background-color: white;
    border: 1px solid #f2f2f2;
    opacity: 1
}
.google-visualization-charteditor-combobox .goog-toolbar-combo-button-input {
    padding: 0 0 0 3px;
    position: relative;
    width: 28px
}
.google-visualization-charteditor-combobox-disabled .goog-toolbar-combo-button-input {
    color: #b8b8b8
}
.google-visualization-charteditor-combobox-disabled .goog-toolbar-combo-button-dropdown {
    opacity: 0.4
}
.google-visualization-charteditor-combobox.goog-toolbar-combo-button {
    margin-left: 4px;
    padding: 1px 0;
    top: auto
}
.google-visualization-charteditor-checkbox-disabled {
    color: #666
}
.google-visualization-charteditor-checkbox .goog-checkbox {
    cursor: default
}
.google-visualization-charteditor-toggle {
    min-width: 24px;
    margin: 0
}
.google-visualization-charteditor-toggle.jfk-button {
    height: 26px;
    line-height: 24px;
    padding: 0;
    z-index: auto
}
.google-visualization-charteditor-toggle-disabled {
    opacity: 0.3
}
.google-visualization-charteditor-toggle-bold-content {
    background: url(//ssl.gstatic.com/docs/common/jfk_sprite40.png) -23px -466px no-repeat;
    height: 16px;
    top: 2px;
    width: 16px
}
.google-visualization-charteditor-toggle-italic-content {
    background: url(//ssl.gstatic.com/docs/common/jfk_sprite40.png) -2px -2176px no-repeat;
    height: 16px;
    top: 2px;
    width: 16px
}
.google-visualization-charteditor-name-input {
    border: 1px solid transparent;
    color: #202020;
    font-family: Arial, sans-serif;
    font-size: 13px;
    font-weight: 800;
    height: 14px;
    padding: 4px;
    width: 400px
}
.google-visualization-charteditor-name-input.google-visualization-charteditor-help-text {
    color: #666;
    font-weight: normal
}
.google-visualization-charteditor-name-input:hover,
.google-visualization-charteditor-name-input:focus {
    border: 1px solid #e4e4e4
}
.google-visualization-charteditor-small-input {
    width: 118px
}
.google-visualization-charteditor-chart-img-div {
    border: 1px solid #ddd;
    margin-top: 5px;
    padding: 2px;
    text-align: center;
    width: 45px
}
.google-visualization-charteditor-chart-type-table {
    background-color: #f6f6f6;
    width: 100%
}
.google-visualization-charteditor-type-select-button .goog-custom-button-inner-box {
    border-width: 1px;
    margin: 0;
    padding: 1px;
    vertical-align: middle
}
.google-visualization-charteditor-type-select-button .goog-custom-button-outer-box {
    border-width: 1px;
    margin: 0;
    padding: 0.5px;
    vertical-align: middle
}
.google-visualization-charteditor-type-select-label {
    border: 0;
    font-size: 10px;
    height: 10px;
    margin: 0;
    margin-top: -4px;
    padding: 0;
    text-align: center;
    vertical-align: text-top
}
.google-visualization-charteditor-thumbnail .jfk-radiobutton-radio {
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    border-radius: 0px;
    border: none;
    left: 0;
    margin: 0;
    position: static;
    top: 0
}
.google-visualization-charteditor-thumbnail .jfk-radiobutton-radio::after {
    content: none
}
.google-visualization-charteditor-thumbnail.jfk-radiobutton {
    border: 4px solid #ddd;
    display: block;
    margin: 4px 12px 8px 0;
    padding: 0px;
    height: 68px;
    width: 110px
}
.google-visualization-charteditor-thumbnail.jfk-radiobutton-checked {
    border: 4px solid #6688ee;
    height: 68px;
    outline-color: #fff;
    width: 110px
}
.google-visualization-charteditor-thumbnail:focus {
    border: 4px solid #c1d9ff;
    cursor: pointer
}
.google-visualization-charteditor-thumbnail.jfk-radiobutton-checked:focus {
    border: 4px solid #6688ee
}
#google-visualization-charteditor-chart-type-categories {
    border-right: 2px dotted #dcdcdc;
    float: left;
    width: 105px
}
#google-visualization-charteditor-chart-type-categories.goog-tab-bar {
    background: none;
    cursor: default;
    list-style: none;
    outline: none
}
.google-visualization-charteditor-category.goog-tab {
    background: white;
    border: none;
    cursor: default;
    font-weight: normal;
    height: 25px;
    margin-bottom: 5px;
    padding: 2px 0;
    position: relative;
    text-decoration: none
}
.google-visualization-charteditor-category.goog-tab-hover {
    cursor: pointer;
    background-color: #f2f2f2
}
.google-visualization-charteditor-category.goog-tab-hover .google-visualization-charteditor-category-label {
    text-decoration: underline
}
.google-visualization-charteditor-category.goog-tab-selected {
    background-color: #ddd!important;
    font-weight: bold
}
.google-visualization-charteditor-category.goog-tab-selected.goog-tab-hover {
    cursor: default;
    background-color: #ddd
}
.google-visualization-charteditor-category.goog-tab-selected.goog-tab-hover .google-visualization-charteditor-category-label {
    text-decoration: none
}
.google-visualization-charteditor-category-label {
    color: #666;
    font-size: 13px;
    font-family: Arial, sans-serif;
    margin-left: 15px;
    position: relative;
    top: -7px
}
.google-visualization-charteditor-category-label {
    text-decoration: inherit
}
.google-visualization-charteditor-mini {
    margin: 2px
}
.google-visualization-charteditor-chart-type-subtypes {
    display: block;
    height: 100%;
    overflow-y: scroll;
    max-height: 372px
}
#google-visualization-charteditor-chart-type-subtypes {
    float: right;
    width: 155px
}
.google-visualization-charteditor-combobox-icon {
    height: 12px;
    left: 9px;
    position: absolute;
    top: 7px;
    width: 12px
}
.google-visualization-charteditor-horizontal-menu {
    padding: 1px 5px 5px 5px
}
.google-visualization-charteditor-float-start {
    float: left
}
.google-visualization-charteditor-float-end {
    float: right
}
.google-visualization-charteditor-float-clear {
    clear: both
}
.google-visualization-charteditor-align-end {
    text-align: right
}
.google-visualization-charteditor-align-start {
    text-align: left
}
.google-visualization-charteditor-display-none {
    display: none
}
.annotationsdiv .goog-custom-button-outer-box,
.annotationsdiv .goog-custom-button-inner-box {
    border: 0;
    margin: 0;
    padding: 0
}
.google-visualization-charteditor-mini-area {
    background: no-repeat url("//ssl.gstatic.com/charts/static/mini3.png") 0 -105px;
    width: 21px;
    height: 21px
}
.google-visualization-charteditor-mini-bar {
    background: no-repeat url("//ssl.gstatic.com/charts/static/mini3.png") 0 -168px;
    width: 21px;
    height: 21px
}
.google-visualization-charteditor-mini-column {
    background: no-repeat url("//ssl.gstatic.com/charts/static/mini3.png") 0 0;
    width: 21px;
    height: 21px
}
.google-visualization-charteditor-mini-combo {
    background: no-repeat url("//ssl.gstatic.com/charts/static/mini3.png") 0 -42px;
    width: 21px;
    height: 21px
}
.google-visualization-charteditor-mini-line {
    background: no-repeat url("//ssl.gstatic.com/charts/static/mini3.png") 0 -126px;
    width: 21px;
    height: 21px
}
.google-visualization-charteditor-mini-map {
    background: no-repeat url("//ssl.gstatic.com/charts/static/mini3.png") 0 -21px;
    width: 21px;
    height: 21px
}
.google-visualization-charteditor-mini-more {
    background: no-repeat url("//ssl.gstatic.com/charts/static/mini3.png") 0 -63px;
    width: 21px;
    height: 21px
}
.google-visualization-charteditor-mini-pie {
    background: no-repeat url("//ssl.gstatic.com/charts/static/mini3.png") 0 -84px;
    width: 21px;
    height: 21px
}
.google-visualization-charteditor-mini-scatter {
    background: no-repeat url("//ssl.gstatic.com/charts/static/mini3.png") 0 -147px;
    width: 21px;
    height: 21px
}
.google-visualization-charteditor-mini-step {
    background: no-repeat url("//ssl.gstatic.com/charts/static/mini3.png") 0 -210px;
    width: 21px;
    height: 21px
}
.google-visualization-charteditor-mini-trend {
    background: no-repeat url("//ssl.gstatic.com/charts/static/mini3.png") 0 -189px;
    width: 21px;
    height: 21px
}
.google-visualization-charteditor-mini-histogram {
    background: no-repeat url("//ssl.gstatic.com/charts/static/mini3.png") 0 -231px;
    width: 21px;
    height: 21px
}
.google-visualization-charteditor-thumbs-annotatedtimeline-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -612px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-annotatedtimeline {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -2507px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-areachart-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -3391px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-areachart {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -2779px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-areachart-stacked-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -408px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-areachart-stacked {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -2031px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-barchart-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -4124px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-barchart {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -3187px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-barchart-stacked-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -3527px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-barchart-stacked {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -816px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-bubblechart-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -136px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-bubblechart {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -1020px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-candlestickchart-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -1156px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-candlestickchart {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -3255px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-columnchart-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -3784px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-columnchart {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -2099px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-columnchart-stacked-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -2983px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-columnchart-stacked {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -1088px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-combochart-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -340px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-combochart {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 0;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-donutchart-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -1360px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-donutchart {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -2371px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-gauge-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -1496px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-gauge {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -476px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-geochart-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -2575px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-geochart-markers-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -68px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-geochart-markers {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -2439px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-geochart {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -4192px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-histogram-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -3323px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-histogram {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -1564px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-imageradarchart-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -3051px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-imageradarchart {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -2235px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-imagesparkline-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -2643px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-imagesparkline {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -2167px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-linechart-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -1632px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-linechart {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -544px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-linechart-smooth-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -1963px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-linechart-smooth {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -3119px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-map-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -4056px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-map-normal {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -1904px;
    width: 100px;
    height: 59px
}
.google-visualization-charteditor-thumbs-map {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -1292px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-map-satellite {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -3595px;
    width: 100px;
    height: 60px
}
.google-visualization-charteditor-thumbs-map-street-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -2915px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-map-street {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -680px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-map-terrain {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -3723px;
    width: 100px;
    height: 61px
}
.google-visualization-charteditor-thumbs-motionchart-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -2711px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-motionchart {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -1836px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-orgchart-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -884px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-orgchart {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -1428px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-piechart-3d-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -952px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-piechart-3d {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -3655px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-piechart-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -2303px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-piechart {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -3852px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-scatterchart-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -272px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-scatterchart {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -3988px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-steppedareachart-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -2847px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-steppedareachart {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -3920px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-table-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -1768px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-table {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -204px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-timeline-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -1224px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-timeline {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -3459px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-treemap-disabled {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -1700px;
    width: 110px;
    height: 68px
}
.google-visualization-charteditor-thumbs-treemap {
    background: no-repeat url("//ssl.gstatic.com/charts/static/thumbs18.png") 0 -748px;
    width: 110px;
    height: 68px
}
.google-visualization-atl.container {}
.google-visualization-atl .border {
    border: 1px solid #808080;
    background-color: #ffffff
}
.google-visualization-atl .containerTable {
    display: table;
    table-layout: fixed;
    width: 100%;
    height: 100%;
    border: 0;
    padding: 0
}
.google-visualization-atl .containerTableRow {
    display: table-row
}
.google-visualization-atl .containerTable .td {
    display: table-cell;
    vertical-align: top;
    padding: 0
}
.google-visualization-atl .chartTdContainer {}
.google-visualization-atl .outerChartContainer {
    overflow: hidden
}
.google-visualization-atl .chartControls {
    display: table;
    border-spacing: 0;
    border-collapse: collapse;
    height: auto;
    width: 100%;
    white-space: nowrap
}
.google-visualization-atl .chartControls.twoRows {
    height: 41px
}
.google-visualization-atl .zoomControls {
    display: table-cell;
    padding: 4px 7px 1px;
    font-size: 10px;
    white-space: nowrap;
    overflow: hidden
}
.google-visualization-atl .zoomControls button.zoomButton {
    margin-right: 0.33em
}
.google-visualization-atl button {
    padding: 0 2px;
    font-size: 9px;
    line-height: 10px
}
.google-visualization-atl .legend {
    display: table-cell;
    padding: 4px 7px 1px;
    font-size: 10px;
    text-align: right;
    white-space: nowrap;
    overflow: hidden
}
.google-visualization-atl .legend-dot {
    display: inline-block;
    height: 8px;
    width: 8px;
    border-radius: 4px;
    margin-right: 2px;
    -webkit-box-shadow: 0px 0px 1px 1px rgba(206, 206, 195, 0.75);
    -moz-box-shadow: 0px 0px 1px 1px rgba(206, 206, 195, 0.75);
    box-shadow: 0px 0px 1px 1px rgba(206, 206, 195, 0.75)
}
.google-visualization-atl .rangeControl {
    overflow: hidden
}
.google-visualization-atl .annotationsTdContainer {
    height: 0;
    border-left: 1px solid #808080
}
.google-visualization-atl .annotationsFilterContainer {
    padding: 4px;
    font-size: 10px;
    white-space: nowrap;
    overflow: hidden
}
.google-visualization-atl .annotationsFilterContainer input {
    font-size: 10px;
    width: 15em
}
.google-visualization-atl .annotationsContainer {}
.google-visualization-atl .annotationsContainer .google-visualization-table-tr-head {
    display: none
}
.google-visualization-atl .annotationsContainer .google-visualization-table-tr-odd,
.google-visualization-atl .annotationsContainer .google-visualization-table-tr-odd td {
    background: none
}
.google-visualization-atl .annotationsContainer .google-visualization-table-tr-even,
.google-visualization-atl .annotationsContainer .google-visualization-table-tr-even td {
    background: none
}
.google-visualization-atl .annotationsContainer .google-visualization-table-tr-sel,
.google-visualization-atl .annotationsContainer .google-visualization-table-tr-sel td {
    background-color: #eeeeee
}
.google-visualization-atl .annotationsContainer .google-visualization-table-td {
    border-width: 0;
    border-bottom-width: 1px;
    vertical-align: top;
    font-size: 0.75em
}
.google-visualization-atl .annotationsContainer .title {
    font-weight: bold
}
.google-visualization-atl .annotationsContainer .date {
    color: #666666;
    font-size: 0.75em;
    white-space: nowrap
}
.google-visualization-table {
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
    display: inline-block;
    vertical-align: bottom
}
.google-visualization-table * {
    -moz-box-sizing: inherit;
    -webkit-box-sizing: inherit;
    box-sizing: inherit
}
.google-visualization-table>div:first-child {
    border: solid #eee;
    border-width: 0
}
.google-visualization-table>div:first-child.scrolling .google-visualization-table-table th,
.google-visualization-table>div:first-child.scrolling .google-visualization-table-table .frozen-column {
    visibility: hidden;
    opacity: 0;
    color: transparent
}
.google-visualization-table>div:first-child.doneScrolling .google-visualization-table-table th {
    -webkit-transition: opacity .25s ease-in .1s;
    -o-transition: opacity .25s ease-in .1s;
    transition: opacity 0.25s ease-in 0.1s
}
.google-visualization-table>div:first-child.doneScrolling .google-visualization-table-table .frozen-column {
    -webkit-transition: visibility, opacity .15s ease-in .15s;
    -o-transition: visibility, opacity .15s ease-in .15s;
    transition: visibility, opacity 0.15s ease-in 0.15s
}
.google-visualization-table-table {
    font-family: arial, helvetica;
    font-size: 10pt;
    cursor: default;
    margin: 0;
    background: white;
    border-spacing: 0;
    border-collapse: separate
}
.google-visualization-table-table * {
    margin: 0
}
.google-visualization-table .gradient {
    background-image: url("//ssl.gstatic.com/charts/static/table-title-bg.gif") repeat-x left bottom;
    background-image: -moz-linear-gradient(top, rgba(255, 255, 255, 0.8) 0%, rgba(255, 255, 255, 0.7) 30%, rgba(255, 255, 255, 0.5) 60%, rgba(255, 255, 255, 0) 100%);
    background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, rgba(255, 255, 255, 0.8)), color-stop(30%, rgba(255, 255, 255, 0.7)), color-stop(60%, rgba(255, 255, 255, 0.5)), color-stop(100%, rgba(255, 255, 255, 0)));
    background-image: -webkit-linear-gradient(top, rgba(255, 255, 255, 0.8) 0%, rgba(255, 255, 255, 0.7) 30%, rgba(255, 255, 255, 0.5) 60%, rgba(255, 255, 255, 0) 100%);
    background-image: -o-linear-gradient(top, rgba(255, 255, 255, 0.8) 0%, rgba(255, 255, 255, 0.7) 30%, rgba(255, 255, 255, 0.5) 60%, rgba(255, 255, 255, 0) 100%);
    background-image: -ms-linear-gradient(top, rgba(255, 255, 255, 0.8) 0%, rgba(255, 255, 255, 0.7) 30%, rgba(255, 255, 255, 0.5) 60%, rgba(255, 255, 255, 0) 100%);
    background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0.8) 0%, rgba(255, 255, 255, 0.7) 30%, rgba(255, 255, 255, 0.5) 60%, rgba(255, 255, 255, 0) 100%);
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ccffffff', endColorstr='#00ffffff', GradientType=0)
}
.google-visualization-table-tr-head {
    background-color: rgb(228, 233, 244);
    font-weight: bold;
    text-align: center
}
.google-visualization-table-sorthdr {
    cursor: pointer
}
.google-visualization-table-sortind {
    color: #ccc;
    padding-left: 4px
}
.unsorted .google-visualization-table-sortind {
    display: none
}
.unsorted .google-visualization-table-sortind:after {
    content: "\002003"
}
.sort-ascending .google-visualization-table-sortind:after {
    content: "\0025b2"
}
.sort-descending .google-visualization-table-sortind:after {
    content: "\0025bc"
}
.google-visualization-table-th {
    cursor: pointer;
    white-space: nowrap
}
.google-visualization-table-td {
    overflow: hidden
}
.google-visualization-table-th,
.google-visualization-table-td {
    padding: 2px 0.35em;
    background-color: inherit;
    background-clip: padding-box
}
.google-visualization-table-table td,
.google-visualization-table-table th {
    border: solid #eee;
    border-width: 0 1px 1px 0;
    padding: 2px 0.35em
}
.google-visualization-table-table th {
    position: relative;
    z-index: 10
}
.google-visualization-table-table td.frozen-column {
    position: relative;
    z-index: 5
}
.google-visualization-table-table thead th.frozen-column {
    z-index: 15
}
.google-visualization-table-table .last-frozen-column {
    border-right: 2px ridge #eee
}
.google-visualization-table-tr-even {
    background-color: #fff
}
.google-visualization-table-tr-odd {
    background-color: #fafafa
}
.google-visualization-table-tr-sel {
    background-color: #d6e9f8
}
.google-visualization-table-tr-over {
    background-color: #e7e9f9
}
.google-visualization-table-td.google-visualization-table-type-bool {
    text-align: center;
    font-family: "Arial Unicode MS", Arial, Helvetica
}
.google-visualization-table-td.google-visualization-table-type-date {
    text-align: center
}
.google-visualization-table-td.google-visualization-table-type-number {
    text-align: right;
    white-space: nowrap
}
.google-visualization-table-seq {
    text-align: right;
    color: #666
}
.google-visualization-table-div-page {
    display: inline-block;
    width: 100%;
    padding: 1px 0 0 1px;
    border: 0;
    background-color: rgb(228, 233, 244);
    font-family: Arial, sans-serif
}
.google-visualization-table-div-page [role="button"] {
    display: inline-block;
    cursor: pointer;
    margin-top: 2px;
    margin-bottom: 2px;
    font-family: "Arial Unicode MS", Arial, Helvetica;
    font-size: 10px;
    line-height: 10px
}
.google-visualization-table-div-page [role="button"] .goog-custom-button-inner-box {
    padding: 1px 1px 2px 1px
}
.google-visualization-table-page-prev,
.google-visualization-table-page-next {}
.google-visualization-table-page-prev:before {
    content: "\0025c4"
}
.google-visualization-table-page-next:before {
    content: "\0025ba"
}
.google-visualization-table-page-numbers {
    display: inline-block;
    zoom: 1;
    margin: 0;
    vertical-align: middle
}
.ie8 .google-visualization-table-page-numbers {
    display: inline
}
.google-visualization-table-page-number {
    display: inline-block;
    background-color: rgb(228, 233, 244);
    border: 1px ButtonShadow outset;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
    color: black;
    font-size: 10px;
    min-width: 10px;
    margin: 2px;
    padding: 0 2px;
    text-align: center;
    text-decoration: none;
    vertical-align: middle
}
.google-visualization-table-page-number.current {
    font-weight: bold;
    font-size: 11px;
    background: #fefefe;
    border-style: inset
}
.google-visualization-table-page-number:hover {
    background: #fefefe;
    border-style: inset
}
.google-visualization-table .transparent {
    background-image: none;
    background-color: transparent;
    border-color: transparent
}
.google-visualization-table .transparentIE6 {
    background: none
}
.google-visualization-table th .transparent,
.google-visualization-table td .transparent {
    color: transparent;
    opacity: 0
}
.google-visualization-table .google-visualization-hidden {
    visibility: hidden;
    pointer-events: none
}
.google-visualization-table-loadtest {
    padding-left: 6px
}
.google-visualization-sparkline-default {
    background-color: #ffffff;
    border-spacing: 0px;
    font-size: small;
    color: gray
}
.google-visualization-sparkline-selected {
    background-color: #d6e9f8;
    padding: 1px;
    border-spacing: 0px;
    font-size: small;
    color: gray
}
.google-visualization-sparkline-over {
    background-color: #e7e9f9;
    padding: 1px;
    border-spacing: 0px;
    font-size: small;
    color: gray
}
.google-visualization-sparkline-image {
    display: block
}
.google-visualization-orgchart-table {
    border: 0;
    text-align: center
}
.google-visualization-orgchart-table * {
    margin: 0;
    padding: 2px
}
.google-visualization-orgchart-space-small {
    width: 4px;
    height: 1px;
    border: 0
}
.google-visualization-orgchart-space-medium {
    width: 10px;
    height: 1px;
    border: 0
}
.google-visualization-orgchart-space-large {
    width: 16px;
    height: 1px;
    border: 0
}
.google-visualization-orgchart-noderow-small {
    height: 12px;
    border: 0
}
.google-visualization-orgchart-noderow-medium {
    height: 30px;
    border: 0
}
.google-visualization-orgchart-noderow-large {
    height: 46px;
    border: 0
}
.google-visualization-orgchart-connrow-small {
    height: 2px;
    font-size: 1px
}
.google-visualization-orgchart-connrow-medium {
    height: 6px;
    font-size: 4px
}
.google-visualization-orgchart-connrow-large {
    height: 10px;
    font-size: 8px
}
.google-visualization-orgchart-node {
    text-align: center;
    vertical-align: middle;
    font-family: arial, helvetica;
    cursor: default;
    border: 2px solid #b5d9ea;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
    -webkit-box-shadow: rgba(0, 0, 0, 0.5) 3px 3px 3px;
    -moz-box-shadow: rgba(0, 0, 0, 0.5) 3px 3px 3px;
    background-color: #edf7ff;
    background: -webkit-gradient(linear, left top, left bottom, from(#edf7ff), to(#cde7ee))
}
.google-visualization-orgchart-nodesel {
    border: 2px solid #e3ca4b;
    background-color: #fff7ae;
    background: -webkit-gradient(linear, left top, left bottom, from(#fff7ae), to(#eee79e))
}
.google-visualization-orgchart-node-small {
    font-size: 0.6em
}
.google-visualization-orgchart-node-medium {
    font-size: 0.8em
}
.google-visualization-orgchart-node-large {
    font-size: 1.2em;
    font-weight: bold
}
.google-visualization-orgchart-linenode {
    border: 0
}
.google-visualization-orgchart-lineleft {
    border-left: 1px solid #3388dd
}
.google-visualization-orgchart-lineright {
    border-right: 1px solid #3388dd
}
.google-visualization-orgchart-linebottom {
    border-bottom: 1px solid #3388dd
}
.waffle-charteditor-chart-area-resizer .docs-squarehandleselectionbox-border {
    -webkit-transition: opacity 250ms cubic-bezier(0.4, 0.0, 1, 1);
    -moz-transition: opacity 250ms cubic-bezier(0.4, 0.0, 1, 1);
    -o-transition: opacity 250ms cubic-bezier(0.4, 0.0, 1, 1);
    transition: opacity 250ms cubic-bezier(0.4, 0.0, 1, 1);
    border: 1px solid #9e9e9e;
    opacity: 0
}
.waffle-charteditor-chart-area-resizer .docs-squarehandleselectionbox-handle {
    -webkit-transition: opacity 250ms cubic-bezier(0.4, 0.0, 1, 1);
    -moz-transition: opacity 250ms cubic-bezier(0.4, 0.0, 1, 1);
    -o-transition: opacity 250ms cubic-bezier(0.4, 0.0, 1, 1);
    transition: opacity 250ms cubic-bezier(0.4, 0.0, 1, 1);
    background: #fff;
    border: 1px solid #9e9e9e;
    opacity: 0
}
.waffle-charteditor-chart-area-resizer:hover .docs-squarehandleselectionbox-border,
.waffle-charteditor-chart-area-resizer:hover .docs-squarehandleselectionbox-handle,
.waffle-charteditor-chart-area-resizer-active .docs-squarehandleselectionbox-border,
.waffle-charteditor-chart-area-resizer-active .docs-squarehandleselectionbox-handle,
.waffle-charteditor-chart-area-resizer-dragging .docs-squarehandleselectionbox-border,
.waffle-charteditor-chart-area-resizer-dragging .docs-squarehandleselectionbox-handle {
    opacity: 1
}
.waffle-charteditor-edit-context-menu {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.waffle-charteditor-edit-context-menu .goog-menuitem {
    padding-left: 30px;
    padding-right: 110px
}
.waffle-charteditor-edit-context-menu-header {
    color: rgba(0, 0, 0, 0.38);
    font-weight: bold;
    padding: 2px 8px 6px 8px;
    text-transform: uppercase
}
.docs-gm .waffle-charteditor-edit-context-menu-submenu-label {
    float: left
}
.waffle-charteditor-select-to-zoom {
    background-color: rgba(0, 0, 255, 0.1);
    border: 1px dashed #9e9e9e;
    position: absolute
}
.waffle-charteditor-text-edit-overlay {
    background-color: #fff;
    border: 1px solid #44a3fa;
    cursor: text;
    color: rgba(0, 0, 0, 0.54);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px;
    line-height: 1;
    outline: 3px solid rgba(68, 163, 250, .3);
    outline-offset: 0;
    position: absolute;
    resize: none;
    z-index: 1
}
.waffle-charteditor-text-edit-overlay-vertical {
    -webkit-transform: rotate(270deg);
    -moz-transform: rotate(270deg);
    -ms-transform: rotate(270deg);
    -o-transform: rotate(270deg);
    transform: rotate(270deg);
    -webkit-transform-origin: top left;
    -moz-transform-origin: top left;
    -ms-transform-origin: top left;
    -o-transform-origin: top left;
    transform-origin: top left
}
.waffle-charts-switching-chart-component-gviz-backed {
    background: white
}
.waffle-dataconnector-dbrecord-sidepane-widget {
    padding: 20px 16px 0
}
.waffle-dataconnector-dbrecord-sidepane-widget-header {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    align-items: center;
    justify-content: space-between
}
.waffle-dataconnector-dbrecord-sidepane-widget-header-label {
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    line-height: 40px
}
.waffle-dataconnector-dbrecord-sidepane-sort-widget-chip,
.waffle-dataconnector-dbrecord-sidepane-projection-widget-chip {
    margin-top: 8px
}
.waffle-dataconnector-dbrecord-sidepane-sort-widget-chip .docs-charts-editor-chip-content,
.waffle-dataconnector-dbrecord-sidepane-projection-widget-chip .docs-charts-editor-chip-content {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    align-items: center
}
.waffle-dataconnector-dbrecord-sidepane-projection-widget-chip .docs-charts-editor-chip-content,
.waffle-dataconnector-dbrecord-sidepane-projection-widget-chip .docs-charts-editor-chip-label,
.waffle-dataconnector-dbrecord-sidepane-sort-widget-chip .docs-charts-editor-chip-content,
.waffle-dataconnector-dbrecord-sidepane-sort-widget-chip .docs-charts-editor-chip-label {
    cursor: move
}
.waffle-dataconnector-dbrecord-chip-nodrag {
    cursor: default
}
.waffle-dataconnector-dbrecord-sidepane-sort-widget-chip-icon,
.waffle-dataconnector-dbrecord-sidepane-projection-widget-chip-icon {
    margin-left: 15px
}
.waffle-dataconnector-dbrecord-sidepane .waffle-dbsource-table-icon {
    height: 24px;
    width: 24px
}
.waffle-dataconnector-dbrecord-sidepane-filter-widget .waffle-filter-filtercard .waffle-filter-filtercard-select .jfk-select {
    width: 100%
}
.waffle-dataconnector-refresh-all-dbobject-item {
    display: inline-block;
    height: 35px;
    padding-left: 18px;
    width: 100%
}
.waffle-dataconnector-refresh-all-dbobject-item-enabled {
    cursor: pointer
}
.waffle-dataconnector-refresh-all-dbobject-item-enabled:hover {
    background-color: #ceead6
}
.waffle-dataconnector-refresh-all-dbobject-item-disabled {
    color: #80868b;
    cursor: default
}
.waffle-dataconnector-refresh-all-dbobject-item-icon-wrapper {
    float: left;
    margin-right: 10px;
    margin-top: 8px
}
.waffle-dataconnector-refresh-all-dbobject-item-title {
    float: left;
    margin-top: 8px
}
.waffle-dataconnector-refresh-all-dbobject-item-status-wrapper {
    float: right;
    margin-right: 32px;
    margin-top: 8px
}
.waffle-dataconnector-refresh-all-dbobject-item-timestamp,
.waffle-dataconnector-refresh-all-dbobject-item-loading,
.waffle-dataconnector-refresh-all-dbobject-item-running {
    color: #80868b
}
.waffle-dataconnector-refresh-all-dbobject-item-error {
    color: #d93025;
    font-weight: bold
}
.waffle-dataconnector-refresh-all-dbobject-list-footer-button-wrapper {
    float: right;
    margin-right: 7px
}
.waffle-dataconnector-refresh-all-dbobject-list-footer {
    display: inline-block;
    margin-bottom: 10px;
    margin-top: 10px;
    width: 100%
}
.waffle-dataconnector-refresh-all-dbobject-list-footer-bytes-wrapper {
    float: left;
    margin-left: 21px;
    margin-top: 9px
}
.waffle-dataconnector-refresh-all-dbobject-item-icon-spinner .waffle-spinner {
    height: 18px;
    width: 18px
}
.waffle-dataconnector-refresh-all-dbobject-item-icon-spinner .waffle-spinner-circle {
    border-width: 2px
}
.waffle-dataconnector-refresh-all-stale-msg {
    background-color: #d93025;
    color: white;
    font-weight: bold;
    padding: 5px;
    text-align: center
}
.waffle-dataconnector-refresh-sidepane-backdrop {
    background-color: #000;
    left: 0;
    position: absolute;
    top: 0;
    z-index: 1002;
    height: 100%;
    opacity: .6;
    width: 100%
}
.waffle-dataconnector-refresh-all-dbobject-list-single-datasource-title {
    font-size: 13px;
    font-weight: bold;
    margin: 20px 20px 12px
}
.waffle-dataconnector-refresh-schedules-widget {
    background-color: #fff;
    border-radius: 5px 5px 0 0;
    border-top: 1px solid #dadce0;
    bottom: 65px;
    position: absolute;
    width: 100%
}
.waffle-dataconnector-refresh-schedules-header {
    display: flex;
    flex-direction: column;
    height: 64px;
    justify-content: center;
    padding: 0 16px
}
.waffle-dataconnector-refresh-schedules-widget-opened .waffle-dataconnector-refresh-schedules-header {
    height: auto
}
.waffle-dataconnector-refresh-schedules-top-section {
    align-items: center;
    display: flex;
    justify-content: space-between;
    padding-bottom: 4px
}
.waffle-dataconnector-refresh-schedules-widget-opened .waffle-dataconnector-refresh-schedules-top-section {
    height: 50px
}
.waffle-dataconnector-refresh-schedules-fullview-section {
    color: #5f6368;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px
}
.waffle-dataconnector-refresh-schedules-fullview-text {
    color: #202124;
    font-size: 14px;
    font-weight: 500;
    line-height: 20px
}
.waffle-dataconnector-refresh-schedules-header .goog-link-button {
    color: #1a73e8;
    text-decoration: none
}
.waffle-dataconnector-refresh-schedules-header-title {
    color: #3c4043;
    display: flex;
    font: 500 14px "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    line-height: 20px
}
.waffle-dataconnector-refresh-schedules-info-icon {
    padding-left: 4px
}
.waffle-dataconnector-refresh-schedules-edit-section {
    padding: 16px
}
.waffle-dataconnector-refresh-schedules-edit-section-row {
    align-items: center;
    display: flex;
    justify-content: space-between;
    margin-bottom: 16px
}
.waffle-dataconnector-refresh-schedules-edit-section-row .docs-material-gm-labeled-select-content {
    margin-bottom: 0px
}
.waffle-dataconnector-refresh-schedules-edit-section-row-label {
    color: #3c4043;
    font: 500 12px "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    line-height: 20px
}
.waffle-dataconnector-refresh-schedules-select {
    width: 176px
}
.waffle-dataconnector-refresh-schedules-select .docs-material-gm-labeled-select-outer-box {
    padding: 0
}
.waffle-dataconnector-refresh-schedules-select .docs-material-gm-labeled-select-caption {
    font-size: 13px;
    height: auto;
    line-height: 16px;
    padding: 4px 0 4px 8px
}
.waffle-dataconnector-refresh-schedules-btns {
    align-items: center;
    display: flex;
    justify-content: flex-end
}
.waffle-dataconnector-refresh-schedules-overview-section {
    font-size: 12px
}
.waffle-dataconnector-refresh-schedules-overview-text {
    color: #5f6368
}
.waffle-dataconnector-refresh-schedules-edit-btn {
    padding-left: 2px
}
.waffle-dataconnector-refresh-schedules-owner-info {
    color: #5f6368;
    font-size: 12px;
    margin: 32px 0 16px 0
}
.waffle-dataconnector-refresh-schedules-widget-opened {
    animation-name: waffle-dataconnector-refresh-schedules-widget-open;
    animation-duration: 300ms;
    bottom: 0;
    box-shadow: 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12), 0px 2px 4px -1px rgba(0, 0, 0, 0.2);
    z-index: 1003
}
@keyframes waffle-dataconnector-refresh-schedules-widget-open {
    from {
        bottom: -300px
    }
    to {
        bottom: 0px
    }
}
.waffle-dataconnector-refresh-schedules-resume-prompt {
    max-width: 420px
}
.waffle-dataconnector-refresh-schedules-resume-prompt .waffle-dataconnector-prompt-content {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    padding: 0 24px 24px
}
.waffle-dataconnector-refresh-schedules-resume-prompt h4 {
    margin: 20px 0 4px 0
}
.waffle-dbsource-advanced-options-menuitem-change-billing-project svg {
    height: 18px;
    left: 10px;
    position: absolute;
    width: 18px
}
.waffle-dbsource-advanced-options-menuitem-change-billing-project-short-caption {
    color: #80868b;
    font-size: 12px
}
.waffle-bigquery-change-billing-project-dialog {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    box-sizing: border-box;
    height: 495px;
    width: 512px
}
.waffle-bigquery-change-billing-project-dialog .waffle-dataconnector-modal-header {
    border-bottom: none;
    box-sizing: border-box;
    height: 73px;
    padding: 24px 24px 25px 24px
}
.waffle-bigquery-change-billing-project-dialog .waffle-dataconnector-modal-title {
    line-height: 24px;
    opacity: 1
}
.waffle-bigquery-change-billing-project-dialog .waffle-dataconnector-modal-close-button {
    height: 34px;
    margin-right: -5px;
    margin-top: -5px;
    width: 34px
}
.waffle-bigquery-change-billing-project-dialog .waffle-dataconnector-modal-close-button svg {
    height: 24px;
    width: 24px
}
.waffle-bigquery-change-billing-project-dialog .waffle-dataconnector-modal-body {
    height: 338px;
    padding: 0;
    z-index: 0
}
.waffle-bigquery-change-billing-project-dialog-project-header {
    color: #5f6368;
    font-size: 14px;
    letter-spacing: 0.29px;
    margin: 0;
    opacity: 1;
    padding: 10px 24px
}
.waffle-bigquery-change-billing-project-dialog .waffle-dataconnector-modal-footer {
    border-top: none;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    padding: 24px;
    z-index: 1
}
.waffle-bigquery-change-billing-project-dialog-footer-wrapper {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row
}
.waffle-bigquery-change-billing-project-dialog-footer-wrapper .docs-material-button {
    margin: 0
}
.waffle-bigquery-change-billing-project-dialog-footer-wrapper .docs-material-button:first-child {
    margin-left: auto
}
.waffle-bigquery-change-billing-project-dialog .waffle-dataconnector-tablepicker-menuitem-content-nexticon {
    display: none
}
.waffle-bigquery-change-billing-project-dialog .waffle-dataconnector-tablepicker-menuitem-content-id {
    margin-left: auto
}
.waffle-bigquerydbsourcesettingsdialog {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    box-sizing: border-box;
    height: 495px;
    width: 512px
}
.waffle-bigquerydbsourcesettingsdialog .waffle-dataconnector-modal-header {
    border-bottom: none;
    box-sizing: border-box;
    height: 73px;
    padding: 24px 24px 25px 24px
}
.waffle-bigquerydbsourcesettingsdialog .waffle-dataconnector-modal-title {
    line-height: 24px;
    opacity: 1
}
.waffle-bigquerydbsourcesettingsdialog .waffle-dataconnector-modal-close-button {
    height: 34px;
    margin-right: -5px;
    margin-top: -5px;
    width: 34px
}
.waffle-bigquerydbsourcesettingsdialog .waffle-dataconnector-modal-close-button svg {
    height: 24px;
    width: 24px
}
.waffle-bigquerydbsourcesettingsdialog .waffle-dataconnector-modal-body {
    height: 376px;
    padding: 0;
    z-index: 0
}
.waffle-bigquerydbsourcesettingsdialog-project-header {
    font: 500 16px/20px "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    letter-spacing: 0.29px;
    margin: 0;
    opacity: 1;
    padding: 10px 24px
}
.waffle-bigquerydbsourcesettingsdialog-transition-out .waffle-dataconnector-modal-title,
.waffle-bigquerydbsourcesettingsdialog-transition-out .waffle-bigquerydbsourcesettingsdialog-project-header {
    opacity: 0;
    transition: opacity 150ms cubic-bezier(0.0, 0.0, 0.2, 1)
}
.waffle-bigquerydbsourcesettingsdialog-error-caption {
    padding: 16px 32px
}
.waffle-bigquerydbsourcesettingsdialog .waffle-dataconnector-modal-footer {
    border-top: none;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    z-index: 1
}
.waffle-bigquerydbsourcesettingsdialog-footer-wrapper {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row
}
.waffle-bigquerydbsourcesettingsdialog-footer-message {
    -webkit-box-flex: 2;
    box-flex: 2;
    -ms-flex-positive: 2;
    -webkit-flex-grow: 2;
    flex-grow: 2;
    color: #5f6368;
    font-size: 12px;
    line-height: 16px;
    margin: 0 24px 0 0;
    width: 329px
}
.waffle-bigquerydbsourcesettingsdialog-footer-wrapper .docs-material-button {
    margin: 0
}
.waffle-bigquerytablepickermodal {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    box-sizing: border-box;
    height: 495px;
    width: 512px
}
.waffle-bigquerytablepickermodal .waffle-dataconnector-modal-header {
    border-bottom: none;
    box-sizing: border-box;
    height: 73px;
    padding: 19px 24px 20px
}
.waffle-bigquerytablepickermodal-back-button {
    background: transparent;
    border-radius: 50%;
    cursor: pointer;
    display: block;
    height: 33px;
    margin-left: -5px;
    opacity: 0;
    position: relative;
    transition: background-color 0.28s cubic-bezier(0.0, 0.0, 0.2, 1), opacity 150ms cubic-bezier(0.0, 0.0, 0.2, 1);
    width: 33px
}
.waffle-bigquerytablepickermodal-transition-in .waffle-bigquerytablepickermodal-back-button {
    opacity: 1
}
.waffle-bigquerytablepickermodal-back-button .docs-icon {
    margin: 5px
}
.waffle-bigquerytablepickermodal-back-button-focused {
    opacity: 1.0;
    background-color: rgba(0, 0, 0, 0.12);
    outline: none
}
.waffle-bigquerytablepickermodal-back-button-hover {
    opacity: 1.0
}
.waffle-bigquerytablepickermodal .waffle-dataconnector-modal-title {
    box-sizing: border-box;
    line-height: 34px;
    opacity: 0;
    padding-right: 0;
    width: 400px
}
.waffle-bigquerytablepickermodal .waffle-dataconnector-modal-close-button {
    height: 34px;
    margin-right: -5px;
    width: 34px
}
.waffle-bigquerytablepickermodal .waffle-dataconnector-modal-close-button svg {
    height: 24px;
    width: 24px
}
.waffle-bigquerytablepickermodal .waffle-dataconnector-modal-body {
    height: 338px;
    padding: 0;
    z-index: 0
}
.waffle-bigquerytablepickermodal-project-menu-header-wrapper {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    align-items: center;
    height: 40px
}
.waffle-bigquerytablepickermodal-project-menu-header {
    -webkit-box-flex: 2;
    box-flex: 2;
    -ms-flex-positive: 2;
    -webkit-flex-grow: 2;
    flex-grow: 2;
    font: 500 16px/20px "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    letter-spacing: 0.29px;
    margin: 0;
    opacity: 0;
    padding: 10px 24px
}
.waffle-bigquerytablepickermodal-transition-in .waffle-dataconnector-modal-title,
.waffle-bigquerytablepickermodal-transition-in .waffle-bigquerytablepickermodal-project-menu-header {
    opacity: 1;
    transition: opacity 150ms cubic-bezier(0.4, 0.0, 1, 1)
}
.waffle-bigquerytablepickermodal-breadcrumbnavigator-wrapper {
    background-color: #f8f9fa;
    padding: 8px 26px
}
.waffle-bigquerytablepickermodal .waffle-dataconnector-modal-footer {
    border-top: none;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    padding: 24px;
    z-index: 1
}
.waffle-bigquerytablepickermodal-footer-wrapper {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-justify-content: space-between;
    justify-content: space-between
}
.waffle-bigquerytablepickermodal-footer-wrapper .docs-material-button {
    margin: 0
}
.waffle-dbobject-estimated-bytes-info {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-dbobject-estimated-bytes-spinner .waffle-spinner {
    height: 18px;
    width: 18px
}
.waffle-dbobject-estimated-bytes-spinner .waffle-spinner-circle {
    border-width: 2px
}
.waffle-dbobject-estimated-bytes-icon {
    margin-right: 8px
}
.waffle-dbobject-estimated-bytes-error {
    color: #db4437;
    text-decoration: underline
}
.waffle-dbobject-estimated-bytes-details {
    color: #5f6368;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 400
}
.waffle-dbobject-estimated-bytes-details-tooltip {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    align-items: center;
    background-color: #000000;
    color: white;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-weight: 500;
    height: 24px;
    text-align: center
}
.waffle-dbsource-column-filtered-menu .goog-menu-filter {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    border-bottom: 1px solid #e0e0e0;
    padding: 6px 6px 12px 10px
}
.waffle-dbsource-column-filtered-menu input {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    border: 0;
    color: rgba(0, 0, 0, 0.87);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    min-width: 0;
    outline: 0
}
.waffle-dbsource-column-filtered-menu .goog-menu-filter:before {
    background: url('data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyNHB4IiBoZWlnaHQ9IjI0cHgiIHZpZXdCb3g9IjAgMCAyNCAyNCIgZmlsbD0iIzc1NzU3NSI+CiAgICA8cGF0aCBkPSJNMTUuNSAxNGgtLjc5bC0uMjgtLjI3QzE1LjQxIDEyLjU5IDE2IDExLjExIDE2IDkuNSAxNiA1LjkxIDEzLjA5IDMgOS41IDNTMyA1LjkxIDMgOS41IDUuOTEgMTYgOS41IDE2YzEuNjEgMCAzLjA5LS41OSA0LjIzLTEuNTdsLjI3LjI4di43OWw1IDQuOTlMMjAuNDkgMTlsLTQuOTktNXptLTYgMEM3LjAxIDE0IDUgMTEuOTkgNSA5LjVTNy4wMSA1IDkuNSA1IDE0IDcuMDEgMTQgOS41IDExLjk5IDE0IDkuNSAxNHoiLz4KICAgIDxwYXRoIGQ9Ik0wIDBoMjR2MjRIMHoiIGZpbGw9Im5vbmUiLz4KPC9zdmc+Cg==');
    content: '';
    height: 24px;
    margin-right: 6px;
    width: 24px
}
.waffle-dbsource-column-filtered-menu-item-icon {
    margin-left: 5px;
    margin-top: 3px
}
.waffle-dbsource-column-filtered-menu-item-match {
    font-weight: 500
}
.docs-gm .goog-menu .goog-menuitem.waffle-dbsource-column-filtered-menu-item {
    padding-right: 20px
}
.waffle-dbsource-column-filtered-menu-item.goog-option-selected {
    background-position: right 5px center
}
.waffle-dbsource-configbar-wrapper {
    background: #f8f9fa;
    border-bottom: 1px solid #c0c0c0;
    height: 110px;
    padding: 16px 16px 0 16px;
    position: relative
}
.waffle-dbsource-configbar {
    background: white;
    border: 1px solid #dadce0;
    border-bottom: none;
    border-radius: 8px 8px 0 0;
    box-sizing: border-box;
    height: 100%;
    overflow-x: auto;
    overflow-y: hidden;
    padding: 16px
}
.waffle-dbsource-configbar-header {
    align-items: center;
    display: flex;
    flex-direction: row;
    font-family: Google Sans, Arial, sans-serif;
    font-weight: 400;
    margin-left: 4px;
    white-space: nowrap
}
.docs-material .docs-icon.waffle-dbsource-configbar-header-icon {
    height: 24px;
    margin-left: 0;
    margin-right: 8px;
    min-width: 24px;
    position: relative
}
.waffle-dbsource-configbar-header-title {
    font-size: 18px;
    line-height: 24px;
    margin-right: 0.5rem
}
.waffle-dbsource-configbar-header-subtitle {
    color: #5f6368;
    font-size: 12px;
    line-height: 24px;
    margin-right: 0.5rem
}
.waffle-dbsource-configbar-actions {
    display: flex;
    flex-direction: row;
    padding: 16px 0
}
.waffle-dbsource-configbar-button-wrapper {
    padding: 0
}
.waffle-dbsource-configbar-button-wrapper .docs-material-button {
    margin: 0
}
.waffle-dbsource-configbar-button-wrapper .docs-material-button-content>div>span {
    vertical-align: middle
}
.waffle-dbsource-configbar-columns-menu-button {
    background: #e6f4ea;
    border-color: #e6f4ea;
    border-radius: 8px;
    height: 36px;
    line-height: 36px;
    padding: 0 10px;
    margin-right: 12px
}
.waffle-dbsource-configbar-columns-menu-button.docs-material-menu-button-flat-default,
.waffle-dbsource-configbar-columns-menu-button.docs-material-menu-button-flat-default-focused {
    border: none
}
.waffle-dbsource-configbar-columns-menu-button .docs-material-menu-button-flat-default-dropdown {
    margin-left: 10px;
    margin-top: 5px
}
.docs-gm .goog-menu .goog-menuitem.waffle-datasource-configbar-columns-menu-loading {
    padding: 6px 15px
}
.waffle-dbsource-configbar-options-wrapper {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    -webkit-justify-content: flex-end;
    justify-content: flex-end
}
.waffle-dbsource-configbar .waffle-dbsource-configbar-secondary-button .docs-material-button-content span {
    color: #5f6368;
    display: inline-block;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    line-height: 24px
}
.waffle-dbsource-configbar .waffle-dbsource-configbar-secondary-button.docs-material-button-hairline-primary.docs-material-button {
    border-radius: 14px;
    height: 24px;
    margin-right: 0;
    padding: 0
}
.waffle-dbsource-configbar .waffle-dbsource-configbar-secondary-button.docs-material-button-hairline-primary.docs-material-button.docs-material-button-hover {
    background-color: #f8f9fa;
    border-color: #dadce0!important
}
.waffle-dbsource-configbar .waffle-dbsource-configbar-secondary-button.docs-material-button-hairline-primary.docs-material-button.docs-material-button-focused {
    background-color: #f1f3f4;
    border-color: #dadce0!important
}
.waffle-dbsource-configbar-secondary-button.docs-material-button-hairline-primary.docs-material-button .waffle-dbsource-configbar-secondary-button-content {
    padding: 0 8px;
    text-decoration: none
}
.waffle-dbsource-configbar .waffle-dbsource-configbar-secondary-button .docs-material-button-content svg {
    margin-right: 5px
}
.waffle-dbsource-configbar .docs-material-button-hairline-primary.docs-material-button {
    margin-left: 0;
    margin-right: 16px;
    padding-left: 12px;
    padding-right: 16px;
    white-space: nowrap
}
.waffle-dbsource-configbar .waffle-dbsource-configbar-secondary-button.docs-material-button-hairline-primary.docs-material-button {
    margin-left: 8px
}
.waffle-dbsource-configbar .docs-material-button-content svg {
    margin-right: 8px;
    vertical-align: middle
}
.waffle-dbsource-configbar-overflow-menu {
    width: 252px
}
.docs-gm .goog-menu.waffle-dbsource-configbar-overflow-menu .goog-menuitem {
    padding: 6px 12px
}
.waffle-dbsource-configbar-overflow-menu-button.docs-material-menu-button-flat-default {
    height: 24px;
    line-height: 24px;
    margin-left: 16px;
    opacity: 0.4;
    padding: 0;
    width: 24px
}
.waffle-dbsource-configbar-separator {
    border-left: 1px #dadce0 solid;
    margin-right: 16px
}
.waffle-dbsource-configbar-overflow-menu-button .docs-material-menu-button-flat-default-dropdown {
    display: none
}
.waffle-create-datasheet-welcome-dialog {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    box-sizing: border-box;
    text-align: center;
    width: 512px
}
.waffle-create-datasheet-welcome-dialog .waffle-dataconnector-modal-header {
    border-bottom: none;
    justify-content: flex-end;
    padding: 24px 24px 0px
}
.waffle-create-datasheet-welcome-dialog .waffle-dataconnector-modal-title {
    display: none
}
.waffle-create-datasheet-welcome-dialog .waffle-dataconnector-modal-body {
    padding: 0
}
.waffle-create-datasheet-welcome-dialog-image {
    height: 155px;
    user-select: none;
    width: 297px
}
.waffle-create-datasheet-welcome-dialog-welcome-message {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-justify-content: center;
    justify-content: center;
    color: #202124;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 22px;
    font-weight: 400
}
.waffle-create-datasheet-welcome-dialog-welcome-message .docs-action-new-badge {
    margin-top: -8px
}
.waffle-create-datasheet-welcome-dialog-welcome-description {
    color: #5f6368;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    letter-spacing: 0.2px;
    line-height: 20px;
    margin: 0 auto;
    max-width: 392px
}
.waffle-create-datasheet-welcome-dialog-continue-button-wrapper {
    padding-top: 24px;
    padding-bottom: 16px
}
.waffle-create-datasheet-welcome-dialog .waffle-dataconnector-modal-footer {
    border-top: none
}
.waffle-create-datasheet-welcome-dialog-switch-message {
    color: #1a73e8;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-weight: 400;
    letter-spacing: 0.3px;
    line-height: 16px;
    margin: 0 auto
}
.waffle-create-datasheet-welcome-dialog-switch-to-dbx {
    text-decoration: none
}
.waffle-create-datasource-sheet-loading-dialog {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    box-sizing: border-box;
    text-align: center;
    width: 512px
}
.waffle-create-datasource-sheet-loading-dialog .waffle-dataconnector-modal-header {
    border-bottom: none;
    justify-content: flex-end;
    padding: 24px 24px 0px
}
.waffle-create-datasource-sheet-loading-dialog .waffle-dataconnector-modal-title {
    display: none
}
.waffle-create-datasource-sheet-loading-dialog .waffle-dataconnector-modal-body {
    padding: 0
}
.waffle-create-datasource-sheet-loading-dialog-tip {
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 400;
    height: 60px;
    letter-spacing: 0.2px;
    line-height: 20px;
    margin: 0 auto;
    max-width: 392px
}
.waffle-create-datasource-sheet-loading-dialog-image {
    height: 343px;
    user-select: none;
    width: 360px
}
.waffle-create-datasource-sheet-loading-dialog .waffle-dataconnector-modal-footer {
    border-top: none
}
.waffle-create-datasource-sheet-success-dialog {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    box-sizing: border-box;
    text-align: center;
    width: 512px
}
.waffle-create-datasource-sheet-success-dialog .waffle-dataconnector-modal-header {
    border-bottom: none;
    justify-content: flex-end;
    padding: 24px 24px 0px
}
.waffle-create-datasource-sheet-success-dialog .waffle-dataconnector-modal-title {
    display: none
}
.waffle-create-datasource-sheet-success-dialog .waffle-dataconnector-modal-body {
    padding: 0
}
.waffle-create-datasource-sheet-success-dialog-image {
    height: 155px;
    width: 297px
}
.waffle-create-datasource-sheet-success-dialog-success-message {
    color: #202124;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 22px;
    font-weight: 400;
    max-width: 328px;
    margin: 22px auto 25px auto
}
.waffle-create-datasource-sheet-success-dialog-success-description {
    color: #5f6368;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 400;
    letter-spacing: 0.2px;
    line-height: 20px;
    margin: 0 auto;
    max-width: 392px
}
.waffle-create-datasource-sheet-success-dialog-datasource-info {
    color: #5f6368;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px
}
.waffle-create-datasource-sheet-success-dialog-datasource-name {
    margin: 24px auto 0px auto
}
.waffle-create-datasource-sheet-success-dialog-metadata-wrapper {
    margin: 8px auto 24px auto
}
.waffle-create-datasource-sheet-success-dialog-start-analyze-button-wrapper {
    margin-bottom: 16px
}
.waffle-create-datasource-sheet-success-dialog-watch-tutorial {
    color: #1a73e8;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-weight: 400;
    letter-spacing: 0.3px;
    line-height: 16px;
    text-decoration-line: none
}
.waffle-create-datasource-sheet-success-dialog .waffle-dataconnector-modal-footer {
    border-top: none
}
.waffle-dbobject-sidepane-footer-estimated-bytes-wrapper {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    align-items: center;
    margin-left: 16px;
    margin-right: 16px
}
.waffle-dbobject-sidepane-footer {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-justify-content: space-between;
    justify-content: space-between;
    align-items: center;
    background-color: white;
    border-top: 1px solid #dadce0;
    color: #5f6368;
    height: 64px
}
.waffle-dbobject-sidepane-footer-refresh-button-wrapper {
    margin-right: 12px
}
.waffle-dbobject-sidepane-footer-refresh-button {
    text-transform: none
}
.waffle-dbobject-sidepane-header {
    background-color: #f8f9fa;
    border-bottom: 1px solid #dadce0;
    display: flex;
    flex-direction: row;
    height: 16px;
    padding: 7px 0px 9px 15px;
    position: relative
}
.waffle-dbobject-sidepane-header-datasource-name {
    color: #5f6368;
    font-size: 12px;
    left: 38px;
    max-width: 244px;
    overflow: hidden;
    position: absolute;
    text-overflow: ellipsis;
    top: 10px;
    white-space: nowrap
}
.waffle-dbsource-endofpreview {
    border-top: 1px solid #dadce0;
    display: block;
    height: 160px;
    padding-top: 28px;
    width: 100%
}
.waffle-dbsource-endofpreview-enable-endofwaffle {
    background-image: url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxIiBoZWlnaHQ9IjgiIHZpZXdCb3g9IjAgMCAxIDgiPiAgPGcgZmlsbD0ibm9uZSIgZmlsbC1ydWxlPSJldmVub2RkIiBzdHJva2U9Im5vbmUiIHN0cm9rZS13aWR0aD0iMSI+ICAgIDxwYXRoIGZpbGw9IiNEQURDRTAiIGQ9Ik0wIDNoMXYxSDB6TTAgN2gxdjFIMHoiLz4gICAgPHBhdGggZmlsbD0iI0YxRjNGNCIgZD0iTTAgMGgxdjNIMHpNMCA0aDF2M0gweiIvPiAgPC9nPjwvc3ZnPg==);
    background-repeat: repeat-x
}
.waffle-dbsource-endofpreview-enable-endofwaffle::before {
    background-color: #f3f3f3;
    background-image: url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxOSIgaGVpZ2h0PSI4IiB2aWV3Qm94PSIwIDAgMTkgOCI+ICA8ZyBmaWxsPSJub25lIj4gICAgPHBhdGggZmlsbD0iI0YxRjNGNCIgZD0iTTE4LjUgN2guNVY0aC02LjVjMS40IDEuOCAzLjYgMyA2IDN6Ii8+ICAgIDxwYXRoIGZpbGw9IiNEQURDRTAiIGQ9Ik0xOC41IDcuNWMtMi43IDAtNS4yLTEuNC02LjYtMy41aC0uNmMxLjUgMi40IDQuMiA0IDcuMiA0aC41di0uNWgtLjV6Ii8+ICAgIDxwYXRoIGZpbGw9IiNEQURDRTAiIGQ9Ik0xOC41IDcuNWguNVY3aC0uNWMtMi40IDAtNC42LTEuMi02LTNoLS42YzEuNCAyLjEgMy45IDMuNSA2LjYgMy41eiIvPiAgICA8cGF0aCBmaWxsPSIjRjFGM0Y0IiBkPSJNNy41IDNIMTlWMEgxLjVjMS40IDEuOCAzLjYgMyA2IDN6Ii8+ICAgIDxwYXRoIGZpbGw9IiNEQURDRTAiIGQ9Ik03LjUgMy41QzQuOCAzLjUgMi4zIDIuMS45IDBILjNjMS41IDIuNCA0LjIgNCA3LjIgNEgxOXYtLjVINy41eiIvPiAgICA8cGF0aCBmaWxsPSIjREFEQ0UwIiBkPSJNNy41IDMuNUgxOVYzSDcuNWMtMi40IDAtNC42LTEuMi02LTNILjljMS40IDIuMSAzLjkgMy41IDYuNiAzLjV6Ii8+ICA8L2c+PC9zdmc+);
    content: "";
    display: block;
    height: 8px;
    left: 0;
    position: absolute;
    top: 1px;
    width: 19px
}
.waffle-dbsource-endofpreview-enable-endofwaffle::after {
    background-color: #f3f3f3;
    background-image: url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxOSIgaGVpZ2h0PSI4IiB2aWV3Qm94PSIwIDAgMTkgOCI+ICA8ZyBmaWxsPSJub25lIj4gICAgPHBhdGggZmlsbD0iI0YxRjNGNCIgZD0iTTE4LjUgN2guNVY0aC02LjVjMS40IDEuOCAzLjYgMyA2IDN6Ii8+ICAgIDxwYXRoIGZpbGw9IiNEQURDRTAiIGQ9Ik0xOC41IDcuNWMtMi43IDAtNS4yLTEuNC02LjYtMy41aC0uNmMxLjUgMi40IDQuMiA0IDcuMiA0aC41di0uNWgtLjV6Ii8+ICAgIDxwYXRoIGZpbGw9IiNEQURDRTAiIGQ9Ik0xOC41IDcuNWguNVY3aC0uNWMtMi40IDAtNC42LTEuMi02LTNoLS42YzEuNCAyLjEgMy45IDMuNSA2LjYgMy41eiIvPiAgICA8cGF0aCBmaWxsPSIjRjFGM0Y0IiBkPSJNNy41IDNIMTlWMEgxLjVjMS40IDEuOCAzLjYgMyA2IDN6Ii8+ICAgIDxwYXRoIGZpbGw9IiNEQURDRTAiIGQ9Ik03LjUgMy41QzQuOCAzLjUgMi4zIDIuMS45IDBILjNjMS41IDIuNCA0LjIgNCA3LjIgNEgxOXYtLjVINy41eiIvPiAgICA8cGF0aCBmaWxsPSIjREFEQ0UwIiBkPSJNNy41IDMuNUgxOVYzSDcuNWMtMi40IDAtNC42LTEuMi02LTNILjljMS40IDIuMSAzLjkgMy41IDYuNiAzLjV6Ii8+ICA8L2c+PC9zdmc+);
    content: "";
    display: block;
    height: 8px;
    position: absolute;
    right: 0;
    top: 1px;
    transform: scaleX(-1);
    width: 19px
}
.waffle-dbsource-endofpreview-header {
    color: #3c4043;
    font: 400 16px/20px "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    letter-spacing: 0.17px;
    padding-bottom: 8px;
    text-align: center
}
.waffle-dbsource-endofpreview-message-line {
    color: #5f6368;
    font: 400 12px/16px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    letter-spacing: 0.3px;
    text-align: center
}
.waffle-dbsource-endofpreview-link-button {
    font: 400 12px/16px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    text-decoration: none
}
.waffle-dbsource-pill {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    background: white;
    border-radius: 8px;
    box-shadow: 0 4px 8px 3px rgba(60, 64, 67, .15);
    box-sizing: border-box;
    color: #4285f4;
    padding: 6px;
    position: absolute;
    white-space: nowrap
}
.waffle-dbsource-pill-info {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    font: 400 14px/32px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    letter-spacing: 0.2px
}
.waffle-dbsource-pill-preview-icon .waffle-dataconnector-preview-icon {
    margin-left: 10px;
    position: relative;
    vertical-align: middle
}
.waffle-dbsource-pill-updated-icon .waffle-dataconnector-updated-icon {
    margin-left: 10px;
    position: relative;
    vertical-align: middle
}
.waffle-dbsource-pill-status {
    color: #202124;
    margin-left: 8px
}
.waffle-dbsource-pill-timestamp {
    color: #5f6368;
    height: 32px;
    line-height: 32px;
    margin: 0 16px;
    white-space: nowrap
}
.waffle-dbsource-pill-progress {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    height: 32px;
    line-height: 32px;
    margin: 0 18px 0 10px
}
.waffle-dbsource-pill-error {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    color: #db4437;
    height: 32px;
    line-height: 32px;
    margin: 0 10px
}
.waffle-dbsource-pill-error .waffle-dbsource-error-icon {
    height: 18px;
    margin-right: 4px;
    position: relative;
    top: 4px;
    width: 18px
}
.docs-gm-dialogs .waffle-dbsource-pill-error-icon .waffle-dataconnector-error-icon {
    line-height: 32px;
    margin-right: 5px;
    vertical-align: middle
}
.waffle-dbsource-pill .docs-material-button {
    font-size: 14px;
    letter-spacing: 0.25px
}
.docs-gm-dialogs .waffle-dbsource-pill-refresh-button {
    color: #188038;
    font-family: 'Google Sans';
    font-weight: 500;
    padding: 0 8px;
    text-transform: none
}
.docs-gm-dialogs .waffle-dbsource-pill-refresh-button.docs-material-button-disabled {
    color: rgba(0, 0, 0, 0.26)
}
.waffle-dbsource-pill-refresh-button.docs-material-button-flat-default.docs-material-button.docs-material-button-hover {
    background-color: #e6f4ea
}
.waffle-dbsource-pill-refresh-button.docs-material-button-flat-default.docs-material-button.docs-material-button-active {
    background-color: #ceead6
}
.docs-gm-dialogs .waffle-dbsource-pill-showerror-button {
    color: #202124;
    text-transform: none
}
.waffle-dbsource-pill-menu-button {
    border: none;
    margin-left: 2px;
    padding: 0 6px
}
.waffle-dbsource-pill-menu-button.docs-material-menu-button-flat-default-hover {
    background-color: #f8f9fa
}
.waffle-dbsource-pill-menu-button.docs-material-menu-button-flat-default-active,
.waffle-dbsource-pill-menu-button.docs-material-menu-button-flat-default-focused {
    background-color: #f1f3f4;
    border: none
}
.waffle-dbsource-menu-icon {
    position: relative;
    top: 3px
}
.waffle-dbsource-pill-menu .goog-menuseparator {
    margin: 0
}
.waffle-dbsource-pill-menu.goog-menu .goog-menuitem {
    padding-left: 15px
}
.waffle-dbsource-pill-menu svg {
    height: 20px;
    margin-right: 13px;
    position: relative;
    width: 20px
}
.waffle-dbsource-pill-menuitem {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    height: 32px;
    line-height: 32px
}
.waffle-dbsource-pill-menuitem-feedback {
    padding-left: 33px
}
.waffle-dbsource-pill-menuitem-accel {
    margin-left: auto;
    padding: 0 20px 0 40px;
    text-align: center;
    color: #9e9e9e
}
.waffle-dbsource-pill-menuitem-refreshquery-info svg {
    margin: 0
}
.waffle-dbsource-pill-menuitem-refreshquery-info-progress {
    font-style: italic
}
.waffle-dbsource-pill-menuitem-refreshquery-info-error-button {
    color: #db4437;
    text-decoration: underline
}
.waffle-filter-filtercard {
    background-color: #f0f0f0;
    border-radius: 8px;
    padding: 8px
}
.waffle-filter-filtercard:not(:last-child) {
    margin-bottom: 8px
}
.waffle-filter-filtercard-top-row {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    padding-bottom: 8px
}
.waffle-filter-filtercard-top-row>div {
    -webkit-flex-shrink: 0;
    -ms-flex-negative: 0;
    flex-shrink: 0
}
.waffle-filter-filtercard-top-row>.waffle-filter-filtercard-label {
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    -webkit-flex-shrink: 1;
    -ms-flex-negative: 1;
    flex-shrink: 1;
    overflow: hidden;
    text-overflow: ellipsis
}
.waffle-filter-filtercard-label {
    color: #424242;
    font-size: 14px;
    padding-left: 8px
}
.waffle-filter-filtercard-delete-button {
    -webkit-transition: background-color 0.2s ease;
    -moz-transition: background-color 0.2s ease;
    -o-transition: background-color 0.2s ease;
    transition: background-color 0.2s ease;
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAyNCAyNCI+ICA8cGF0aCBmaWxsPSIjZjBmMGYwIiBkPSJNMTkgNi40MUwxNy41OSA1IDEyIDEwLjU5IDYuNDEgNSA1IDYuNDEgMTAuNTkgMTIgNSAxNy41OSA2LjQxIDE5IDEyIDEzLjQxIDE3LjU5IDE5IDE5IDE3LjU5IDEzLjQxIDEyeiIvPjwvc3ZnPg==");
    background-color: #bfbfbf;
    border: 0;
    border-radius: 16px;
    cursor: pointer;
    height: 16px;
    margin: 8px;
    width: 16px
}
.waffle-filter-filtercard-delete-button:hover {
    background-color: #aaa
}
.waffle-filter-filtercard .waffle-filter-filtercard-select .jfk-select {
    text-align: left;
    width: 100%
}
.waffle-filterbox-container {
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    line-height: 32px;
    vertical-align: middle
}
.waffle-filterdropdown-filter-color-menu-item {
    display: table
}
.waffle-filterdropdown-filter-color {
    border: 1px solid rgba(0, 0, 0, 0.1);
    border-radius: 50%;
    box-sizing: border-box;
    display: table-cell;
    height: 20px;
    left: -15px;
    margin: 0;
    position: relative;
    vertical-align: middle;
    width: 20px
}
.waffle-filterdropdown-filter-color-text {
    display: table-cell;
    vertical-align: middle
}
.goog-menu.waffle-filterdropdown-filter-colors-menu {
    max-height: 50vh;
    overflow: auto
}
.waffle-filterdropdown-filter-color-checkbox::after {
    content: "\002713";
    left: 6px;
    position: absolute
}
.waffle-types-number-icon {
    background: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz48c3ZnIHdpZHRoPSIxOHB4IiBoZWlnaHQ9IjEwcHgiIHZpZXdCb3g9IjAgMCAxOCAxMCIgdmVyc2lvbj0iMS4xIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIj4gICAgICAgIDx0aXRsZT5udW1iZXI8L3RpdGxlPiAgICA8ZGVzYz5DcmVhdGVkIHdpdGggU2tldGNoLjwvZGVzYz4gICAgPGRlZnM+PC9kZWZzPiAgICA8ZyBpZD0iUGFnZS0xIiBzdHJva2U9Im5vbmUiIHN0cm9rZS13aWR0aD0iMSIgZmlsbD0ibm9uZSIgZmlsbC1ydWxlPSJldmVub2RkIiBvcGFjaXR5PSIwLjU0Ij4gICAgICAgIDxnIGlkPSJudW1iZXIiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDAuMDAwMDAwLCAtNC4wMDAwMDApIj4gICAgICAgICAgICA8cmVjdCBpZD0iUmVjdGFuZ2xlLTE0IiB4PSIwIiB5PSIwIiB3aWR0aD0iMTgiIGhlaWdodD0iMTgiPjwvcmVjdD4gICAgICAgICAgICA8cGF0aCBkPSJNMCw0IEw0LDQgTDQsMTQgTDIsMTQgTDIsNiBMMCw2IEwwLDQgWiBNNSw0IEw5LDQgQzEwLjEwNSw0IDExLDQuODk1IDExLDYgTDExLDggQzExLDkuMTA1IDEwLjEwNSwxMCA5LDEwIEw3LDEwIEw3LDEyIEwxMSwxMiBMMTEsMTQgTDUsMTQgTDUsMTAgQzUsOC44OTUgNS44OTYsOCA3LDggTDksOCBMOSw2IEw1LDYgTDUsNCBaIE0xNiw0IEMxNy4xMDUsNCAxOCw0Ljg5NSAxOCw2IEwxOCw3LjUgQzE4LDguMzI4IDE3LjMyOCw5IDE2LjUsOSBDMTcuMzI4LDkgMTgsOS42NzIgMTgsMTAuNSBMMTgsMTIgQzE4LDEzLjEwNSAxNy4xMDUsMTQgMTYsMTQgTDEyLDE0IEwxMiwxMiBMMTYsMTIgTDE2LDEwIEwxNCwxMCBMMTQsOCBMMTYsOCBMMTYsNiBMMTIsNiBMMTIsNCBMMTYsNCBaIiBpZD0iQ29tYmluZWQtU2hhcGUiIGZpbGw9IiMwMDAwMDAiPjwvcGF0aD4gICAgICAgIDwvZz4gICAgPC9nPjwvc3ZnPg==) no-repeat
}
.waffle-types-text-icon {
    background: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz48c3ZnIHdpZHRoPSIxNnB4IiBoZWlnaHQ9IjEycHgiIHZpZXdCb3g9IjAgMCAxNiAxMiIgdmVyc2lvbj0iMS4xIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIj4gICAgICAgIDx0aXRsZT5pY190ZXh0X2ZpZWxkc19ibGFja18xOGRwPC90aXRsZT4gICAgPGRlc2M+Q3JlYXRlZCB3aXRoIFNrZXRjaC48L2Rlc2M+ICAgIDxkZWZzPiAgICAgICAgPHBvbHlnb24gaWQ9InBhdGgtMSIgcG9pbnRzPSIxOCAxOCAwIDE4IDAgMCAxOCAwIj48L3BvbHlnb24+ICAgIDwvZGVmcz4gICAgPGcgaWQ9IlBhZ2UtMSIgc3Ryb2tlPSJub25lIiBzdHJva2Utd2lkdGg9IjEiIGZpbGw9Im5vbmUiIGZpbGwtcnVsZT0iZXZlbm9kZCIgb3BhY2l0eT0iMC41Mzk5OTk5NjIiPiAgICAgICAgPGcgaWQ9ImljX3RleHRfZmllbGRzX2JsYWNrXzE4ZHAiIHRyYW5zZm9ybT0idHJhbnNsYXRlKC0xLjAwMDAwMCwgLTMuMDAwMDAwKSI+ICAgICAgICAgICAgPG1hc2sgaWQ9Im1hc2stMiIgZmlsbD0id2hpdGUiPiAgICAgICAgICAgICAgICA8dXNlIHhsaW5rOmhyZWY9IiNwYXRoLTEiPjwvdXNlPiAgICAgICAgICAgIDwvbWFzaz4gICAgICAgICAgICA8ZyBpZD0iYSI+PC9nPiAgICAgICAgICAgIDxwYXRoIGQ9Ik0xLjg3NSwzIEwxLjg3NSw1LjI1IEw1LjYyNSw1LjI1IEw1LjYyNSwxNC4yNSBMNy44NzUsMTQuMjUgTDcuODc1LDUuMjUgTDExLjYyNSw1LjI1IEwxMS42MjUsMyBMMS44NzUsMyBaIE0xNi4xMjUsNi43NSBMOS4zNzUsNi43NSBMOS4zNzUsOSBMMTEuNjI1LDkgTDExLjYyNSwxNC4yNSBMMTMuODc1LDE0LjI1IEwxMy44NzUsOSBMMTYuMTI1LDkgTDE2LjEyNSw2Ljc1IFoiIGlkPSJTaGFwZSIgZmlsbD0iIzAwMDAwMCIgZmlsbC1ydWxlPSJub256ZXJvIiBtYXNrPSJ1cmwoI21hc2stMikiPjwvcGF0aD4gICAgICAgIDwvZz4gICAgPC9nPjwvc3ZnPg==) no-repeat
}
.waffle-types-date-icon {
    background: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz48c3ZnIHdpZHRoPSIxNHB4IiBoZWlnaHQ9IjE2cHgiIHZpZXdCb3g9IjAgMCAxNCAxNiIgdmVyc2lvbj0iMS4xIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIj4gICAgICAgIDx0aXRsZT5pY19kYXRlX3JhbmdlXzI0cHg8L3RpdGxlPiAgICA8ZGVzYz5DcmVhdGVkIHdpdGggU2tldGNoLjwvZGVzYz4gICAgPGRlZnM+PC9kZWZzPiAgICA8ZyBpZD0iUGFnZS0xIiBzdHJva2U9Im5vbmUiIHN0cm9rZS13aWR0aD0iMSIgZmlsbD0ibm9uZSIgZmlsbC1ydWxlPSJldmVub2RkIiBvcGFjaXR5PSIwLjU0Ij4gICAgICAgIDxnIGlkPSJHcm91cC1Db3B5IiB0cmFuc2Zvcm09InRyYW5zbGF0ZSgtMi4wMDAwMDAsIC0xLjAwMDAwMCkiPiAgICAgICAgICAgIDxnIGlkPSJpY19kYXRlX3JhbmdlXzI0cHgiPiAgICAgICAgICAgICAgICA8cGF0aCBkPSJNNi43NSw4LjI1IEw1LjI1LDguMjUgTDUuMjUsOS43NSBMNi43NSw5Ljc1IEw2Ljc1LDguMjUgWiBNOS43NSw4LjI1IEw4LjI1LDguMjUgTDguMjUsOS43NSBMOS43NSw5Ljc1IEw5Ljc1LDguMjUgWiBNMTIuNzUsOC4yNSBMMTEuMjUsOC4yNSBMMTEuMjUsOS43NSBMMTIuNzUsOS43NSBMMTIuNzUsOC4yNSBaIE0xNC4yNSwzIEwxNCwzIEwxNCwxIEwxMiwxIEwxMiwzIEw2LDMgTDYsMSBMNCwxIEw0LDMgTDMuNzUsMyBDMi45MTc1LDMgMi4yNTc1LDMuNjc1IDIuMjU3NSw0LjUgTDIuMjUsMTUgQzIuMjUsMTUuODI1IDIuOTE3NSwxNyAzLjc1LDE3IEwxNC4yNSwxNyBDMTUuMDc1LDE3IDE1Ljc1LDE1LjgyNSAxNS43NSwxNSBMMTUuNzUsNC41IEMxNS43NSwzLjY3NSAxNS4wNzUsMyAxNC4yNSwzIFogTTE0LDE1IEw0LDE1IEw0LDcgTDE0LDcgTDE0LDE1IFoiIGlkPSJTaGFwZSIgZmlsbD0iIzAwMDAwMCIgZmlsbC1ydWxlPSJub256ZXJvIj48L3BhdGg+ICAgICAgICAgICAgICAgIDxwb2x5Z29uIGlkPSJTaGFwZSIgcG9pbnRzPSIwIDAgMTggMCAxOCAxOCAwIDE4Ij48L3BvbHlnb24+ICAgICAgICAgICAgPC9nPiAgICAgICAgPC9nPiAgICA8L2c+PC9zdmc+) no-repeat
}
.waffle-types-boolean-icon {
    background: url(data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMTgiIGhlaWdodD0iMTgiIHZpZXdCb3g9IjAgMCAxOCAxOCIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj4gIDxnIGZpbGw9IiM3NzciIHN0cm9rZT0iIzc3NyIgZmlsbC1ydWxlPSJldmVub2RkIj4gICAgPHBhdGggZD0iTTEyLjc3MzY3MzUgOS41Njk1NDM2NWwuMzUzNTUzNC4zNTM1NTMzOSAyLjg2MjQzNjktMi44NjI0MzY4Ny0uMzUzNTUzNC0uMzUzNTUzMzktMi41MDU5MDY2IDIuNTA1OTA2NTgtMS4wNjk1NDM2LTEuMDY5NTQzNjUtLjM1MzU1MzQuMzUzNTUzNCAxLjA2OTU0MzYgMS4wNjk1NDM2NC0uMDAyOTc2OS4wMDI5NzY5ek0yLjA2MDY2MDE3IDYuNzA3MTA2NzhsLS4zNTM1NTMzOS4zNTM1NTMzOSAxLjU5MDk5MDI2IDEuNTkwOTkwMjYtMS41OTA5OTAyNiAxLjU5MDk5MDI2LjM1MzU1MzM5LjM1MzU1MzM5IDEuNTkwOTkwMjYtMS41OTA5OTAyNiAxLjU5MDk5MDI2IDEuNTkwOTkwMjYuMzUzNTUzMzktLjM1MzU1MzM5LTEuNTkwOTkwMjYtMS41OTA5OTAyNiAxLjU5MDk5MDI2LTEuNTkwOTkwMjYtLjM1MzU1MzM5LS4zNTM1NTMzOS0xLjU5MDk5MDI2IDEuNTkwOTkwMjYtMS41OTA5OTAyNi0xLjU5MDk5MDI2ek04LjUgNC41aDF2OWgtMXoiLz4gIDwvZz48L3N2Zz4=) no-repeat
}
.waffle-types-boolean-icon,
.waffle-types-date-icon,
.waffle-types-number-icon,
.waffle-types-text-icon {
    background-position: center;
    height: 18px;
    opacity: .7;
    width: 18px
}
.goog-menu.waffle-dataconnector-tablepicker-filtered-menu {
    border: none;
    border-radius: 0;
    box-shadow: none;
    box-sizing: border-box;
    max-height: auto;
    overflow-x: hidden;
    padding-top: 2px;
    width: 100%
}
.goog-menu.waffle-dataconnector-tablepicker-filtered-menu .goog-menu-filter {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    background-color: #f8f9fa;
    border-radius: 8px;
    height: 40px;
    margin: 0 24px 16px 24px;
    position: relative
}
.goog-menu.waffle-dataconnector-tablepicker-filtered-menu .goog-menu-filter:after {
    background: #e8eaed;
    bottom: -16px;
    content: '';
    display: block;
    height: 1px;
    left: 0;
    position: absolute;
    width: 464px
}
.waffle-dataconnector-tablepicker-filtered-menu-icon-search {
    border-bottom: none;
    padding: 11px 0 11px 13px;
    position: absolute
}
.waffle-dataconnector-tablepicker-filtered-menu-icon-info {
    border-bottom: none;
    padding: 11px 13px 11px 5px;
    position: absolute;
    right: 0
}
.goog-menu.waffle-dataconnector-tablepicker-filtered-menu input {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    background: white;
    border: 0;
    border-radius: 8px;
    box-shadow: 0 1px 3px 1px rgba(60, 64, 67, .15);
    font: 400 14px/20px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    letter-spacing: 0.17px;
    outline: 0;
    padding: 0 37px
}
.goog-menu.waffle-dataconnector-tablepicker-filtered-menu .goog-menu-content {
    max-height: 223px;
    opacity: 0;
    overflow-y: auto;
    padding: 16px 0 0 16px;
    position: relative
}
.waffle-bigquerydbsourcesettingsdialog-project-menu-wrapper .goog-menu.waffle-dataconnector-tablepicker-filtered-menu .goog-menu-content {
    max-height: 261px
}
.waffle-dataconnector-tablepicker-filtered-menu-loading-bar-wrapper {
    height: 4px;
    margin-top: -1px;
    position: absolute;
    width: 100%
}
.waffle-dataconnector-tablepicker-filtered-menu-loading-bar-wrapper .docs-indeterminate-loading-bar {
    background-color: #e6f4ea;
    height: 100%;
    overflow: hidden
}
.waffle-dataconnector-tablepicker-filtered-menu-loading-bar-wrapper .docs-indeterminate-loading-bar>div {
    -webkit-animation: loading-bar-animation 1.3s ease-in-out infinite;
    -moz-animation: loading-bar-animation 1.3s ease-in-out infinite;
    -o-animation: loading-bar-animation 1.3s ease-in-out infinite;
    animation: loading-bar-animation 1.3s ease-in-out infinite;
    background-color: #34a853;
    border-radius: 2px;
    height: 100%;
    left: 0;
    position: absolute;
    right: 0;
    top: 0;
    transform: none
}
@keyframes loading-bar-animation {
    0% {
        transform: translateX(-50%) scaleX(0)
    }
    23%,
    54% {
        transform: translateX(0) scaleX(1)
    }
    77%,
    100% {
        transform: translateX(50%) scaleX(0)
    }
}
.waffle-dataconnector-tablepicker-filtered-menu-error-message {
    color: #5f6368;
    font-size: 14px;
    line-height: 20px;
    margin-left: 8px;
    margin-right: 24px;
    text-align: center
}
.waffle-dataconnector-tablepicker-filtered-menu-info-bubble-title {
    color: #202124;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    line-height: 20px;
    margin-bottom: 8px
}
.waffle-dataconnector-tablepicker-filtered-menu-info-bubble-content {
    color: #3c4043;
    font-size: 12px;
    line-height: 16px;
    max-width: 200px
}
.goog-menu .waffle-dataconnector-tablepicker-menuitem.goog-menuitem {
    border-radius: 24px;
    box-sizing: border-box;
    line-height: 36px;
    padding: 0 16px;
    transition: background-color 100ms linear;
    white-space: nowrap;
    width: 480px
}
.waffle-dataconnector-tablepicker-menuitem.goog-menuitem.goog-menuitem-highlight,
.waffle-dataconnector-tablepicker-menuitem.goog-menuitem:focus {
    border-bottom: none;
    background-color: #e6f4ea;
    border-top: none;
    outline: none
}
.waffle-dataconnector-tablepicker-menuitem.goog-menuitem.goog-menuitem-highlight.goog-menuitem-active {
    background-color: #ceead6;
    border-top: none
}
.waffle-dataconnector-tablepicker-menuitem.goog-menuitem.goog-menuitem-highlight.goog-menuitem-active.goog-option-selected,
.waffle-dataconnector-tablepicker-menuitem.goog-menuitem.goog-option-selected {
    background-color: #e6f4ea;
    background-image: none;
    cursor: auto
}
.waffle-dataconnector-tablepicker-menu-bottom-border .waffle-dataconnector-tablepicker-menuitem.goog-menuitem {
    padding-right: 12px
}
.waffle-dataconnector-tablepicker-menuitem .goog-menuitem-content {
    font-size: 13px
}
.waffle-dataconnector-tablepicker-menuitem-content-wrapper {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    position: relative
}
.waffle-dataconnector-tablepicker-menuitem-content-wrapper .goog-menuitem-checkbox {
    display: none
}
.waffle-dataconnector-tablepicker-menuitem-content-name,
.waffle-dataconnector-tablepicker-menuitem-content-id {
    display: inline-block;
    font: 400 14px/24px Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.waffle-dataconnector-tablepicker-menuitem-content-name {
    color: rgba(0, 0, 0, 0.87);
    line-height: 36px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    width: 100%
}
.waffle-dataconnector-tablepicker-menuitem-content-wrapper-project .waffle-dataconnector-tablepicker-menuitem-content-name {
    padding-right: 22px;
    width: 176px
}
.waffle-dataconnector-tablepicker-menuitem-content-wrapper-dataset .waffle-dataconnector-tablepicker-menuitem-content-name {
    width: 389px
}
.waffle-dataconnector-tablepicker-menuitem-content-id {
    color: rgba(0, 0, 0, 0.54);
    line-height: 36px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    width: 191px
}
.waffle-dataconnector-tablepicker-menuitem-content-schemaicon {
    margin-right: 8px;
    min-width: 18px;
    width: 18px
}
.waffle-dataconnector-tablepicker-menuitem-content-schemaicon svg {
    margin-right: 5px;
    vertical-align: middle
}
.waffle-dataconnector-tablepicker-menuitem-content-schemaicon .waffle-dataconnector-tablepicker-filtered-menu-icon-search {
    padding: 0px
}
.waffle-dataconnector-tablepicker-menuitem-content-nexticon {
    margin-left: auto;
    width: 18px
}
.waffle-dataconnector-tablepicker-menuitem-content-nexticon svg {
    vertical-align: middle
}
.waffle-dataconnector-tablepicker-multilevelmenu {
    position: relative
}
.waffle-dataconnector-tablepicker-multilevelmenu,
.waffle-dataconnector-tablepicker-multilevelmenu .goog-menu.waffle-dataconnector-tablepicker-menu {
    height: 286px
}
.waffle-dataconnector-breadcrumbnavigator {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    overflow: hidden;
    vertical-align: middle
}
.waffle-dataconnector-breadcrumbnavigator-entry {
    border: 1px solid transparent;
    border-radius: 4px;
    box-shadow: none;
    color: #202124;
    cursor: pointer;
    font-size: 22px;
    letter-spacing: .2px;
    line-height: 24px;
    overflow: hidden;
    padding: 4px;
    text-overflow: ellipsis;
    transition: background-color 100ms linear;
    vertical-align: middle;
    white-space: nowrap
}
.waffle-dataconnector-breadcrumbnavigator-entry {
    flex: 0 1 25%;
    min-width: 45px
}
.waffle-dataconnector-breadcrumbnavigator-entry-condensed {
    flex: 0 1 10%
}
.waffle-dataconnector-breadcrumbnavigator-entry:last-of-type {
    flex: none
}
.waffle-dataconnector-breadcrumbnavigator-entry.goog-control-hover,
.waffle-dataconnector-breadcrumbnavigator-entry.goog-control-focused {
    background-color: #f1f3f4;
    outline: none
}
.waffle-dataconnector-breadcrumbnavigator-entry.goog-control-active {
    background-color: #e8eaed;
    outline: none
}
.waffle-dataconnector-breadcrumbnavigator-entry.goog-control-disabled {
    cursor: auto
}
.waffle-dataconnector-breadcrumbnavigator-separator {
    vertical-align: middle
}
.waffle-dataconnector-modal-title .waffle-dataconnector-breadcrumbnavigator-separator svg {
    bottom: unset;
    height: 18px;
    margin-right: 0;
    transform: unset;
    vertical-align: middle;
    width: 18px
}
.waffle-dataconnector-modal-title .waffle-dataconnector-breadcrumbnavigator-separator polygon {
    fill: #5f6368
}
.waffle-dataconnector-prompt {
    background: #fff;
    border-radius: 2px;
    border: none;
    box-shadow: 0px 16px 24px 2px rgba(0, 0, 0, 0.14), 0px 6px 30px 5px rgba(0, 0, 0, 0.12), 0px 8px 10px -5px rgba(0, 0, 0, 0.2);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    position: absolute;
    z-index: 1302
}
.waffle-dataconnector-prompt-bg {
    left: 0;
    position: absolute;
    top: 0;
    z-index: 1300
}
.waffle-dataconnector-prompt:focus {
    outline: none
}
.waffle-dataconnector-prompt-title {
    padding: 24px 24px 20px 24px
}
.waffle-dataconnector-prompt-title-text {
    font: 500 21px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    padding-right: 38px
}
.waffle-dataconnector-prompt-title-close {
    background-size: cover;
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxOCIgaGVpZ2h0PSIxOCIgdmlld0JveD0iMCAwIDE4IDE4Ij4KICA8ZyBmaWxsPSJub25lIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiPgogICAgPHBhdGggZD0iTTAsMCBMMTgsMCBMMTgsMTggTDAsMTggTDAsMCBaIE0wLDAgTDE4LDAgTDE4LDE4IEwwLDE4IEwwLDAgWiIvPgogICAgPHBvbHlnb24gZmlsbD0iIzAwMCIgcG9pbnRzPSIxNC41MyA0LjUzIDEzLjQ3IDMuNDcgOSA3Ljk0IDQuNTMgMy40NyAzLjQ3IDQuNTMgNy45NCA5IDMuNDcgMTMuNDcgNC41MyAxNC41MyA5IDEwLjA2IDEzLjQ3IDE0LjUzIDE0LjUzIDEzLjQ3IDEwLjA2IDkiLz4KICA8L2c+Cjwvc3ZnPgo=") no-repeat;
    display: block;
    height: 20px;
    position: absolute;
    right: 24px;
    top: 26px;
    width: 20px
}
.waffle-dataconnector-prompt-content {
    padding: 0 24px
}
.waffle-dataconnector-prompt-buttons {
    float: right;
    padding: 8px 4px 14px 4px
}
.waffle-dataconnector-prompt-buttons:after {
    clear: both;
    content: "";
    display: block;
    height: 0;
    width: 0
}
.waffle-dataconnector-modal {
    background: #fff;
    border-radius: 2px;
    border: none;
    box-shadow: 0px 16px 24px 2px rgba(0, 0, 0, 0.14), 0px 6px 30px 5px rgba(0, 0, 0, 0.12), 0px 8px 10px -5px rgba(0, 0, 0, 0.2);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    position: absolute;
    z-index: 1003
}
.waffle-dataconnector-modal.docs-material-gm-dialog {
    border-radius: 8px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.waffle-dataconnector-modal-bg {
    background-color: rgba(0, 0, 0, 0.54);
    z-index: 1002
}
.waffle-dataconnector-modal:focus {
    outline: none
}
.waffle-dataconnector-modal-header {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-justify-content: space-between;
    justify-content: space-between;
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    padding: 24px;
    user-select: none
}
.waffle-dataconnector-modal-title {
    font-weight: 500;
    font-size: 18px;
    padding-right: 38px
}
.docs-material-gm-dialog .waffle-dataconnector-modal-title {
    color: #202124;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 400;
    font-size: 22px
}
.waffle-dataconnector-modal-title svg {
    -webkit-transform: scale(1.4, 1.4);
    -moz-transform: scale(1.4, 1.4);
    -ms-transform: scale(1.4, 1.4);
    -o-transform: scale(1.4, 1.4);
    transform: scale(1.4, 1.4);
    bottom: -0.125em;
    font-size: 18px;
    height: 1em;
    margin-right: 8px;
    position: relative;
    width: 1em
}
.docs-material-gm-dialog .waffle-dataconnector-modal-title svg path {
    fill: #5f6368
}
.waffle-dataconnector-modal-close-button {
    background: transparent;
    border-radius: 50%;
    cursor: pointer;
    display: block;
    height: 28px;
    opacity: 0.54;
    position: relative;
    transition: background-color 0.28s ease-out, opacity 0.28s ease-out;
    width: 28px
}
.waffle-dataconnector-modal-close-button svg {
    height: 18px;
    margin: 5px;
    width: 18px
}
.waffle-dataconnector-modal-close-button:focus {
    opacity: 1.0;
    background-color: rgba(0, 0, 0, 0.12);
    outline: none
}
.waffle-dataconnector-modal-close-button:hover {
    opacity: 1.0
}
.waffle-dataconnector-modal-body {
    padding: 24px
}
.waffle-dataconnector-modal-footer {
    border-top: 1px solid rgba(0, 0, 0, 0.12);
    padding: 15px 12px 15px 24px
}
.waffle-dataconnector-bigqueryquerysettingsdialog {
    width: 512px
}
.waffle-dataconnector-bigqueryquerysettingsdialog .waffle-dataconnector-modal-body {
    height: 283px;
    padding: 0
}
.waffle-dataconnector-bigqueryquerysettingsdialog-project-select-wrapper {
    width: 100%
}
.waffle-dataconnector-bigqueryquerysettingsdialog-project-select-header {
    font-weight: 700;
    margin: 16px 0
}
.waffle-dataconnector-bigqueryquerysettingsdialog-project-section {
    padding: 24px
}
.waffle-dataconnector-bigqueryquerysettingsdialog-project-select .docs-material-labeled-select-label {
    color: rgba(0, 0, 0, 0.87);
    font-size: 14px;
    font-weight: 500
}
.waffle-dataconnector-bigqueryquerysettingsdialog-error-caption {
    color: #e06055;
    margin-top: 8px
}
.waffle-dataconnector-bigqueryquerysettingsdialog-project-select .docs-material-labeled-select-outer-box {
    margin-top: 16px
}
.waffle-dataconnector-bigqueryquerysettingsdialog .waffle-dataconnector-modal-footer {
    border-top: none;
    padding: 0
}
.waffle-dataconnector-bigqueryquerysettingsdialog-continue-button-wrapper {
    display: flex
}
.waffle-dataconnector-bigqueryquerysettingsdialog-continue-button-wrapper>p {
    color: rgba(0, 0, 0, 0.54);
    flex: 1;
    margin: 14px 24px
}
.waffle-dataconnector-bigqueryquerysettingsdialog-continue-button {
    margin: 16px 24px
}
.waffle-dataconnector-bigqueryquerysettingsdialog-continue-button-wrapper:after {
    clear: both;
    content: "";
    display: block;
    height: 0;
    width: 0
}
.waffle-dataconnector-footer-sharing-message {
    background-color: #fafafa;
    color: rgba(0, 0, 0, 0.54);
    padding: 16px 24px 24px 60px;
    position: relative
}
.waffle-dataconnector-footer-sharing-message:after {
    background-size: contain;
    background-image: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyNHB4IiBoZWlnaHQ9IjI0cHgiIHZpZXdCb3g9IjAgMCAyNCAyNCIgZmlsbD0iIzAwMDAwMCI+CiAgICA8cGF0aCBkPSJNMCAwaDI0djI0SDB6IiBmaWxsPSJub25lIi8+CiAgICA8cGF0aCBkPSJNMTggOGgtMVY2YzAtMi43Ni0yLjI0LTUtNS01UzcgMy4yNCA3IDZ2Mkg2Yy0xLjEgMC0yIC45LTIgMnYxMGMwIDEuMS45IDIgMiAyaDEyYzEuMSAwIDItLjkgMi0yVjEwYzAtMS4xLS45LTItMi0yem0tNiA5Yy0xLjEgMC0yLS45LTItMnMuOS0yIDItMiAyIC45IDIgMi0uOSAyLTIgMnptMy4xLTlIOC45VjZjMC0xLjcxIDEuMzktMy4xIDMuMS0zLjEgMS43MSAwIDMuMSAxLjM5IDMuMSAzLjF2MnoiLz4KPC9zdmc+Cg==");
    content: "";
    display: block;
    height: 18px;
    left: 27px;
    opacity: 0.54;
    position: absolute;
    top: 23px;
    width: 18px
}
.waffle-dataconnector-dialog {
    background: #fff;
    border-radius: 2px;
    border: none;
    box-shadow: 0px 16px 24px 2px rgba(0, 0, 0, 0.14), 0px 6px 30px 5px rgba(0, 0, 0, 0.12), 0px 8px 10px -5px rgba(0, 0, 0, 0.2);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    position: absolute;
    z-index: 1003
}
.waffle-dataconnector-dialog-bg {
    background-color: #000;
    left: 0;
    position: absolute;
    top: 0;
    z-index: 1002
}
.waffle-dataconnector-dialog:focus {
    outline: none
}
.waffle-dataconnector-dialog-title {
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    padding: 24px
}
.waffle-dataconnector-dialog-title-draggable {
    cursor: move
}
.waffle-dataconnector-dialog-title-text {
    font: 500 21px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    padding-right: 38px
}
.waffle-dataconnector-dialog-title-close {
    border-radius: 50%;
    cursor: pointer;
    display: block;
    height: 28px;
    opacity: 0.54;
    position: absolute;
    right: 18px;
    top: 22px;
    transition: background-color 0.28s ease-out, opacity 0.28s ease-out;
    width: 28px
}
.waffle-dataconnector-dialog-title-close svg {
    -webkit-transform: translate(-50%, -50%);
    -moz-transform: translate(-50%, -50%);
    -ms-transform: translate(-50%, -50%);
    -o-transform: translate(-50%, -50%);
    transform: translate(-50%, -50%);
    position: absolute;
    left: 50%;
    top: 50%
}
.waffle-dataconnector-dialog-title-close:focus {
    opacity: 1.0;
    background-color: rgba(0, 0, 0, 0.12);
    outline: none
}
.waffle-dataconnector-dialog-title-close:hover {
    background-color: rgba(0, 0, 0, 0.26);
    opacity: 1.0
}
.waffle-dataconnector-dialog-content {
    padding: 24px
}
.waffle-dataconnector-dialog-buttons {
    padding: 15px 12px 15px 24px
}
.waffle-dataconnector-dialog-button-wrapper {
    float: right
}
.waffle-dataconnector-dialog-button-wrapper>.docs-material-button {
    float: left
}
.waffle-dataconnector-dialog-buttons:after {
    clear: both;
    content: '';
    display: block;
    height: 0;
    width: 0
}
.waffle-dataconnector-dialog-error-message,
.waffle-dataconnector-dialog-info-message {
    color: rgba(0, 0, 0, 0.87);
    display: block;
    font: 500 13px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    line-height: 18px;
    margin: 7px 0 7px 0px;
    position: relative;
    vertical-align: middle
}
.waffle-dataconnector-dialog-error-message {
    padding-left: 24px;
    color: #db4437
}
.waffle-dataconnector-dialog-error-message:before {
    background-size: cover;
    background: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxOCIgaGVpZ2h0PSIxOCIgdmlld0JveD0iMCAwIDE4IDE4Ij4KICA8ZyBmaWxsPSJub25lIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiPgogICAgPHBvbHlnb24gcG9pbnRzPSIwIDAgMTggMCAxOCAxOCAwIDE4Ii8+CiAgICA8cGF0aCBmaWxsPSIjZGI0NDM3IiBkPSJNMTUuNDk5ODkzOCwxNiBDMTYuNjA0NTIyLDE2IDE3LjA1NDk3MDgsMTUuMjE0NjU0MyAxNi41MTY2MzgyLDE0LjI2NDY1NTcgTDkuOTgzMzYxNzYsMi43MzUzNDQyOCBDOS40NDAyNjYwNiwxLjc3Njk0MDEgOC41NTQ5NzA3OSwxLjc4NTM0NTY2IDguMDE2NjM4MjQsMi43MzUzNDQyOCBMMS40ODMzNjE3NiwxNC4yNjQ2NTU3IEMwLjk0MDI2NjA1NSwxNS4yMjMwNTk5IDEuMzkwMDU4NDEsMTYgMi41MDAxMDYxOCwxNiBMMTUuNDk5ODkzOCwxNiBaIE0xMCwxNCBMOCwxNCBMOCwxMiBMMTAsMTIgTDEwLDE0IEwxMCwxNCBaIE0xMCwxMSBMOCwxMSBMOCw3IEwxMCw3IEwxMCwxMSBMMTAsMTEgWiIvPgogIDwvZz4KPC9zdmc+Cg==") no-repeat;
    content: '';
    display: inline-block;
    height: 18px;
    left: 0px;
    position: absolute;
    top: 0;
    width: 18px
}
.waffle-dataconnector-dialog-message-container {
    float: left;
    min-height: 32px;
    min-width: 200px;
    width: calc(100% - 260px)
}
.waffle-dataconnector-dialog-progress-message {
    margin-left: 20px
}
.waffle-dataconnector-dialog-progress-label {
    font: 13px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    line-height: 18px
}
.waffle-dataconnector-dialog-progress-bar {
    height: 5px;
    width: 450px
}
.waffle-dataconnector-error-popup {
    max-width: 780px;
    min-width: 480px
}
.waffle-dataconnector-error-popup .waffle-dataconnector-prompt-content {
    padding: 0 24px;
    overflow: auto
}
.waffle-dataconnector-error-popup .waffle-dataconnector-error-message-main {
    font: 500 15px Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.waffle-dataconnector-query-parameter-prompt.waffle-dataconnector-modal {
    width: 320px;
    z-index: calc(1003 + 300)
}
.waffle-dataconnector-query-parameter-prompt .waffle-dataconnector-modal-body {
    padding: 0 24px
}
.waffle-dataconnector-query-parameter-prompt-name-field input {
    text-transform: uppercase
}
.waffle-dataconnector-query-parameter-prompt-toggle-row {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    height: 21px;
    margin-top: 16px
}
.waffle-dataconnector-query-parameter-prompt-toggle-label {
    line-height: 21px;
    margin-left: 8px
}
.waffle-dataconnector-query-parameter-prompt .waffle-dataconnector-modal-header {
    border-bottom: none
}
.waffle-dataconnector-query-parameter-prompt .waffle-dataconnector-modal-footer {
    border-top: none;
    float: right
}
.waffle-dataconnector-query-parameter-prompt-rangepicker {
    border-radius: 50%;
    bottom: 6px;
    height: 29px;
    position: relative;
    right: 0;
    width: 29px
}
.waffle-dataconnector-query-parameter-prompt-rangepicker .docs-icon {
    margin: 4px auto 4px 3px
}
.waffle-dataconnector-query-parameter-prompt-rangepicker-focused {
    background: rgba(0, 0, 0, 0.12);
    outline: none
}
.waffle-dataconnector-simple-text-input-prompt-text-field {
    width: 400px
}
.waffle-dataconnector-bigquery-query-settings-widget-project-section-header {
    color: rgba(0, 0, 0, 0.54);
    margin-bottom: 4px;
    whitespace: nowrap
}
.waffle-dataconnector-bigquery-query-settings-widget-alert {
    color: #e06055;
    font-size: 11px;
    font-weight: 500
}
.waffle-dataconnector-bigquery-query-settings-widget-alert .waffle-dataconnector-error-icon {
    bottom: -0.325em;
    height: 1.4em;
    margin-right: 4px;
    position: relative;
    width: 1.4em
}
.waffle-dataconnector-bigquery-query-settings-widget-alert-description {
    color: #e06055;
    margin-top: 4px
}
.waffle-dataconnector-bigquery-query-validation-widget-open-button {
    border-radius: 50%;
    bottom: 8px;
    box-sizing: border-box;
    cursor: pointer;
    height: 20px;
    position: absolute;
    right: 8px;
    width: 20px;
    z-index: 10
}
.waffle-dataconnector-bigquery-query-validation-widget-open-button .waffle-dataconnector-info-icon {
    height: 100%;
    width: 100%
}
.waffle-dataconnector-bigquery-query-validation-widget-open-button-hover,
.waffle-dataconnector-bigquery-query-validation-widget-open-button-focused {
    background: rgba(66, 133, 244, 0.26)
}
.waffle-dataconnector-bigquery-query-validation-widget-bar {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    -webkit-justify-content: space-between;
    justify-content: space-between;
    background: rgba(66, 133, 244, 0.12);
    border-top: 1px solid rgba(0, 0, 0, 0.12);
    bottom: 0;
    box-sizing: border-box;
    color: #4285f4;
    display: none;
    font: inherit;
    font-weight: 500;
    max-height: 60px;
    min-height: 40px;
    padding: 8px;
    padding-left: 16px;
    position: relative;
    right: 0;
    width: 100%
}
.waffle-dataconnector-bigquery-query-validation-widget-message {
    max-height: 44px;
    overflow: hidden;
    text-overflow: ellipsis
}
.waffle-dataconnector-bigquery-query-validation-widget-visible>.waffle-dataconnector-bigquery-query-validation-widget-bar {
    display: flex
}
.waffle-dataconnector-bigquery-query-validation-widget-visible>.waffle-dataconnector-bigquery-query-validation-widget-open-button {
    display: none
}
.waffle-dataconnector-bigquery-query-validation-widget-bar .waffle-dataconnector-error-icon-filled {
    height: 20px;
    margin-right: 8px;
    min-width: 20px;
    width: 20px
}
.waffle-dataconnector-bigquery-query-validation-widget-valid>.waffle-dataconnector-bigquery-query-validation-widget-bar {
    background: rgba(15, 157, 88, 0.12);
    color: #0f9d58
}
.waffle-dataconnector-bigquery-query-validation-widget-bar .waffle-dataconnector-info-icon {
    height: 20px;
    margin-right: 8px;
    min-width: 20px;
    width: 20px
}
.waffle-dataconnector-bigquery-query-validation-widget-valid .waffle-dataconnector-info-icon,
.waffle-dataconnector-bigquery-query-validation-widget-invalid .waffle-dataconnector-info-icon {
    display: none
}
.waffle-dataconnector-bigquery-query-validation-widget .waffle-dataconnector-error-icon-filled {
    display: none
}
.waffle-dataconnector-bigquery-query-validation-widget-bar .waffle-dataconnector-error-icon-filled {
    margin-right: 8px
}
.waffle-dataconnector-bigquery-query-validation-widget .waffle-dataconnector-valid-icon {
    display: none
}
.waffle-dataconnector-bigquery-query-validation-widget-bar .waffle-dataconnector-valid-icon {
    height: 20px;
    margin-right: 8px;
    min-width: 20px;
    width: 20px
}
.waffle-dataconnector-bigquery-query-validation-widget-invalid .waffle-dataconnector-bigquery-query-validation-widget-bar {
    background: rgba(219, 68, 55, 0.12);
    color: #db4437
}
.waffle-dataconnector-bigquery-query-validation-widget-invalid .waffle-dataconnector-error-icon-filled {
    display: block
}
.waffle-dataconnector-bigquery-query-validation-widget-valid .waffle-dataconnector-valid-icon {
    display: block
}
.waffle-dataconnector-bigquery-query-validation-widget-message {
    max-width: calc(100% - 30px);
    overflow: hidden;
    text-overflow: ellipsis
}
.waffle-dataconnector-bigquery-query-validation-widget-close-button {
    border-radius: 50%;
    cursor: pointer;
    height: 24px;
    margin-left: auto;
    width: 24px
}
.waffle-dataconnector-bigquery-query-validation-widget-close-button svg {
    height: 20px;
    margin: 2px;
    width: 20px
}
.waffle-dataconnector-bigquery-query-validation-widget .waffle-dataconnector-close-icon polygon {
    fill: #4285f4
}
.waffle-dataconnector-bigquery-query-validation-widget-close-button-hover,
.waffle-dataconnector-bigquery-query-validation-widget-close-button-focused {
    background: rgba(66, 133, 244, 0.26);
    outline: none
}
.waffle-dataconnector-bigquery-query-validation-widget-invalid .waffle-dataconnector-bigquery-query-validation-widget-close-button-hover,
.waffle-dataconnector-bigquery-query-validation-widget-invalid .waffle-dataconnector-bigquery-query-validation-widget-close-button-focused {
    background: rgba(219, 68, 55, 0.26)
}
.waffle-dataconnector-bigquery-query-validation-widget-valid .waffle-dataconnector-bigquery-query-validation-widget-close-button-hover,
.waffle-dataconnector-bigquery-query-validation-widget-valid .waffle-dataconnector-bigquery-query-validation-widget-close-button-focused {
    background: rgba(15, 157, 88, 0.26)
}
.waffle-dataconnector-bigquery-query-validation-widget-valid .waffle-dataconnector-close-icon polygon {
    fill: #0f9d58
}
.waffle-dataconnector-bigquery-query-validation-widget-invalid .waffle-dataconnector-close-icon polygon {
    fill: #db4437
}
.waffle-dataconnector-codemirrorquerytexteditor {
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    height: 100%;
    position: relative
}
.waffle-dataconnector-codemirrorquerytexteditor,
.waffle-dataconnector-codemirrorquerytexteditor .CodeMirror {
    font-family: 'Roboto Mono', 'Consolas', monospace;
    height: 100%
}
.waffle-dataconnector-codemirrorquerytexteditor .CodeMirror-gutters {
    border-right: 1px solid rgba(0, 0, 0, 0.12)
}
.waffle-dataconnector-codemirrorquerytexteditor>.CodeMirror-focused .CodeMirror-gutters {
    border-right: 1px solid #4285f4
}
.waffle-dataconnector-codemirrorquerytexteditor .CodeMirror-linenumbers {
    background: #f5f5f5
}
.waffle-dataconnector-codemirrorquerytexteditor .CodeMirror-linenumbers {
    color: rgba(0, 0, 0, 0.54);
    font: 500 14px Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.waffle-dataconnector-codemirrorquerytexteditor .CodeMirror-gutter-elt {
    min-width: 0;
    padding-left: 24px;
    padding-right: 16px;
    text-align: center
}
.waffle-dataconnector-codemirrorquerytexteditor .CodeMirror-lines {
    padding: 16px 0
}
.waffle-dataconnector-codemirrorquerytexteditor .CodeMirror-line {
    padding-left: 16px
}
.waffle-dataconnector-queryeditor-collapsible-sidebar-widget {
    border-bottom: 1px solid rgba(0, 0, 0, 0.12)
}
.waffle-dataconnector-queryeditor-collapsible-sidebar-widget .docs-charts-editor-collapsible-header {
    color: rgba(0, 0, 0, 0.87)
}
.waffle-dataconnector-queryeditor-query-settings-icon {
    margin-right: 8px
}
.waffle-dataconnector-queryeditor-collapsible-sidebar-widget .docs-charts-editor-collapsible-title {
    width: calc(100% - 50px)
}
.waffle-dataconnector-queryeditor-collapsible-sidebar-widget .docs-charts-editor-collapsible-summary {
    display: none
}
.waffle-dataconnector-queryeditor-collapsible-sidebar-widget .docs-charts-editor-collapsible-content>div {
    padding: 8px 16px 16px
}
.waffle-dataconnector-queryeditor-collapsible-sidebar-widget .docs-charts-editor-collapsible-header {
    border: 1px solid transparent
}
.waffle-dataconnector-queryeditor-collapsible-sidebar-widget .docs-charts-editor-collapsible-header.goog-control-focused {
    border: 1px solid #4285f4
}
.waffle-dataconnector-dbschematreenode-label {
    cursor: pointer;
    display: flex;
    height: 22px;
    position: relative;
    width: 100%
}
.waffle-dataconnector-dbschematreenode-title {
    height: 22px;
    line-height: 22px;
    max-width: calc(100% - 18px - 10px);
    overflow: hidden;
    text-overflow: ellipsis;
    vertical-align: middle;
    white-space: nowrap
}
.waffle-dataconnector-dbschematreenode .waffle-dataconnector-expand-icon {
    width: 18px;
    height: 18px;
    margin: 2px 10px 2px 2px;
    transform: rotate(-90deg);
    transition: transform .2s cubic-bezier(0.4, 0.0, 1, 1)
}
.waffle-dataconnector-dbschematreenode-rtl .waffle-dataconnector-expand-icon {
    transform: rotate(90deg)
}
.waffle-dataconnector-dbschematreenode .waffle-spinner {
    height: 14px;
    margin: 4px 12px 4px 4px;
    width: 14px
}
.waffle-dataconnector-dbschematreenode .waffle-spinner-circle {
    border-width: 2px
}
.waffle-dataconnector-dbschematreenode>.waffle-dataconnector-dbschematreenode-label>.waffle-dataconnector-dbschematreenode-spinner-container {
    display: none
}
.waffle-dataconnector-dbschematreenode-loading>.waffle-dataconnector-dbschematreenode-label>.waffle-dataconnector-dbschematreenode-spinner-container {
    display: block
}
.waffle-dataconnector-dbschematreenode-loading>.waffle-dataconnector-dbschematreenode-label>.waffle-dataconnector-expand-icon {
    display: none
}
.waffle-dataconnector-dbschematreenode-open>.waffle-dataconnector-dbschematreenode-label>.waffle-dataconnector-expand-icon {
    transform: rotate(0deg)
}
.waffle-dataconnector-dbschematreenode-leaf>.waffle-dataconnector-dbschematreenode-label>.waffle-dataconnector-expand-icon {
    visibility: hidden
}
.waffle-dataconnector-dbschematreenode-label:hover,
.waffle-dataconnector-dbschematreenode-selected>.waffle-dataconnector-dbschematreenode-label {
    color: #4285f4
}
.waffle-dataconnector-dbschematreenode-child-container {
    display: none;
    margin-left: 16px
}
.waffle-dataconnector-dbschematreenode-open>.waffle-dataconnector-dbschematreenode-child-container {
    display: block
}
.waffle-dataconnector-dbschematreenode-error .waffle-dataconnector-dbschematreenode-title {
    color: #e06055;
    font-size: 11px;
    padding-left: 13px
}
.waffle-dataconnector-dbschematreenode-error .waffle-dataconnector-expand-icon {
    display: none
}
.waffle-dataconnector-draggablebar {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    background: rgba(0, 0, 0, 0.12);
    bottom: 0;
    position: absolute
}
.waffle-dataconnector-draggablebar-horizontal {
    width: 100%
}
.waffle-dataconnector-draggablebar-vertical {
    height: 100%
}
.waffle-dataconnector-draggablebar-handle {
    background: #fff;
    border: 1px solid rgba(0, 0, 0, 0.12);
    box-sizing: border-box;
    z-index: 100
}
.waffle-dataconnector-draggablebar-horizontal .waffle-dataconnector-draggablebar-handle {
    cursor: row-resize;
    height: 9px;
    left: calc(50% - 32px/2);
    position: absolute;
    top: calc(50% - 9px/2);
    width: 32px
}
.waffle-dataconnector-draggablebar-vertical .waffle-dataconnector-draggablebar-handle {
    background: transparent;
    border: 1px solid rgba(0, 0, 0, 0.12);
    cursor: col-resize;
    height: 32px;
    left: calc(50% - 9px/2);
    position: absolute;
    top: calc(50% - 32px/2);
    width: 9px
}
.waffle-dataconnector-draggablebar-handle-icon {
    background: rgba(0, 0, 0, 0.12);
    border: 3px solid #fff;
    box-sizing: border-box;
    height: 100%;
    width: 100%
}
.waffle-dataconnector-textarea-editor {
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    height: 100%;
    position: relative
}
.waffle-dataconnector-textarea-editor-textareawrapper {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    border-radius: 0;
    border: none;
    height: 100%;
    margin: 0;
    overflow: hidden;
    position: absolute;
    width: 100%
}
.waffle-dataconnector-textarea-editor-textarea {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    background-color: white;
    border-radius: 0;
    border: none;
    color: #000;
    display: block;
    font-family: 'Roboto Mono', 'Consolas', monospace;
    font-size: 13px;
    height: 100%;
    line-height: 20px;
    margin: 0 0 0 48px;
    outline: none;
    overflow: auto;
    overflow-wrap: normal;
    padding: 8px;
    resize: none;
    white-space: pre;
    width: calc(100% - 48px);
    word-wrap: normal
}
.waffle-dataconnector-textarea-editor-linegutter {
    background: #f5f5f5;
    border-right: 1px solid rgba(0, 0, 0, 0.12);
    height: 100%;
    left: 0;
    position: absolute;
    top: 0;
    width: 48px
}
.waffle-dataconnector-textarea-editor-focused .waffle-dataconnector-textarea-editor-linegutter {
    border-right: 1px solid #4285f4
}
.waffle-dataconnector-textarea-editor-linenumber-container {
    left: 0;
    padding-top: 8px;
    position: absolute;
    width: 100%
}
.waffle-dataconnector-textarea-editor-linenumber {
    height: 20px;
    line-height: 20px;
    text-align: center;
    user-select: none;
    vertical-align: middle
}
.waffle-dataconnector-jdbc-query-settings-widget-connection-name-section {
    font-family: inherit
}
.waffle-dataconnector-jdbc-query-settings-widget-connection-name-section {
    margin-top: 8px
}
.waffle-dataconnector-jdbc-query-settings-widget-connection-name-label {
    color: rgba(0, 0, 0, 0.54)
}
.waffle-dataconnector-jdbc-query-settings-widget-connection-name {
    color: rgba(0, 0, 0, 0.87);
    font-weight: 500;
    margin-top: 8px
}
.waffle-dataconnector-jdbc-query-settings-widget-connection-name-error {
    color: #e06055
}
.waffle-dataconnector-jdbc-query-settings-widget-change-button {
    left: -8px;
    margin: 8px 0;
    position: relative
}
.waffle-dataconnector-plx-query-settings-widget {
    font: inherit
}
.waffle-dataconnector-plx-query-settings-widget-engine-section {
    margin-top: 8px
}
.waffle-dataconnector-plx-query-settings-widget-script-section {
    margin-top: 16px
}
.waffle-dataconnector-plx-query-settings-widget-script-section .waffle-dataconnector-removable-chip {
    margin-top: 8px
}
.waffle-dataconnector-plx-query-settings-widget-script-label {
    font-size: 11px
}
.waffle-dataconnector-plx-query-settings-widget-link-script-button {
    margin: 8px 0 0 0
}
.waffle-dataconnector-modal.waffle-dataconnector-newqueryeditor {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    height: calc(100% - 16px);
    max-height: 640px;
    min-height: 400px;
    width: 832px
}
.waffle-dataconnector-modal.waffle-dataconnector-newqueryeditor.docs-material-gm-dialog {
    width: 880px
}
.waffle-dataconnector-newqueryeditor .waffle-dataconnector-modal-body {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    max-height: 457px;
    padding: 0
}
.waffle-dataconnector-newqueryeditor.docs-material-gm-dialog .waffle-dataconnector-modal-body {
    padding: 0 24px 24px
}
.waffle-dataconnector-newqueryeditor.docs-material-gm-dialog .waffle-dataconnector-modal-header {
    border: none
}
.waffle-dataconnector-newqueryeditor .waffle-dataconnector-newqueryeditor-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row-reverse;
    -webkit-flex-direction: row-reverse;
    flex-direction: row-reverse;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    -webkit-justify-content: space-between;
    justify-content: space-between;
    height: 100%;
    overflow: hidden;
    position: relative
}
.waffle-dataconnector-newqueryeditor.docs-material-gm-dialog .waffle-dataconnector-newqueryeditor-container {
    border: 1px solid rgba(0, 0, 0, 0.12);
    border-radius: 4px
}
.waffle-dataconnector-newqueryeditor-main {
    border-right: 1px solid rgba(0, 0, 0, 0.12);
    overflow: hidden;
    position: relative;
    width: 576px
}
.waffle-dataconnector-newqueryeditor-sidebar {
    box-sizing: border-box;
    overflow-x: hidden;
    overflow-y: auto;
    width: calc(100% - 576px)
}
.waffle-dataconnector-newqueryeditor-preview-pane {
    bottom: 0;
    height: 0;
    position: absolute;
    overflow: hidden;
    width: 100%
}
.waffle-dataconnector-newqueryeditor-info-pane:after {
    clear: both;
    content: "";
    display: block;
    height: 0;
    width: 0
}
.waffle-dataconnector-newqueryeditor .waffle-dataconnector-modal-footer {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    align-items: center;
    border-top: 1px solid rgba(0, 0, 0, 0.12);
    padding: 16px
}
.waffle-dataconnector-newqueryeditor-footer-message-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1;
    align-items: center;
    height: 48px;
    margin: 0 8px;
    overflow: auto
}
.waffle-dataconnector-newqueryeditor-footer-message {
    color: rgba(0, 0, 0, 0.54)
}
.waffle-dataconnector-newqueryeditor-footer-message .waffle-dataconnector-error-message:before {
    content: "";
    display: block;
    height: 20px
}
.waffle-dataconnector-newqueryeditor-footer-message .waffle-dataconnector-error-message:after {
    content: "";
    display: block;
    height: 20px
}
.waffle-dataconnector-newqueryeditor-footer-message-container .waffle-dataconnector-error-icon {
    display: none;
    margin-right: 8px;
    height: 24px;
    min-width: 24px;
    width: 24px
}
.waffle-dataconnector-newqueryeditor-footer-message-container.waffle-dataconnector-newqueryeditor-unhandled-error>.waffle-dataconnector-newqueryeditor-footer-message {
    color: #db4437
}
.waffle-dataconnector-newqueryeditor-footer-message-container.waffle-dataconnector-newqueryeditor-unhandled-error .waffle-dataconnector-error-icon {
    display: block
}
.waffle-dataconnector-newqueryeditor-preview-query-button,
.waffle-dataconnector-newqueryeditor-execute-query-button {
    min-width: 140px;
    white-space: nowrap
}
.waffle-dataconnector-newqueryeditor-preview-query-button .waffle-dataconnector-refresh-icon {
    height: 24px;
    margin: 4px;
    width: 24px
}
.waffle-dataconnector-newqueryeditor-preview-query-button .waffle-dataconnector-refresh-icon path {
    fill: #4285f4
}
.waffle-dataconnector-newqueryeditor-preview-query-button.docs-material-button-disabled .waffle-dataconnector-refresh-icon path {
    fill: rgba(0, 0, 0, 0.26)
}
.waffle-dataconnector-newqueryeditor-editor-pane {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    height: 100%;
    position: relative;
    overflow: hidden
}
.waffle-dataconnector-newqueryeditor-sidebar::-webkit-scrollbar-thumb {
    background: rgba(0, 0, 0, 0.12);
    min-height: 0;
    width: 8px
}
.waffle-dataconnector-newqueryeditor-sidebar::-webkit-scrollbar-track {
    border: none;
    padding: 0;
    width: 8px
}
.waffle-dataconnector-newqueryeditor-sidebar::-webkit-scrollbar {
    width: 8px;
    border-left: 1px solid rgba(0, 0, 0, 0.12)
}
.waffle-dataconnector-queryeditor-queryparameterchip-name {
    font-weight: 700
}
.waffle-dataconnector-queryeditor-removable-chip-error .waffle-dataconnector-queryeditor-queryparameterchip-name {
    color: #db4437
}
.waffle-dataconnector-queryeditor-queryparameterwidget .waffle-dataconnector-queryeditor-removable-chip {
    margin: 8px 0
}
.waffle-dataconnector-queryeditor-queryparameterwidget-header {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    height: 100%
}
.waffle-dataconnector-queryeditor-queryparameterwidget-header .waffle-dataconnector-query-parameters-icon {
    height: 18px;
    margin-right: 8px;
    min-width: 18px;
    width: 18px
}
.waffle-dataconnector-queryeditor-queryparameterwidget .waffle-dataconnector-queryeditor-removable-chip {
    margin-bottom: 0
}
.waffle-dataconnector-queryeditor-queryparameterwidget-add-parameter-button {
    margin: 8px 0 0 0
}
.waffle-dataconnector-querypreviewrenderer {
    height: 100%;
    width: 100%
}
.waffle-dataconnector-querypreviewrenderer-canvas-viewport {
    background: #f3f3f3;
    direction: ltr;
    height: 100%;
    overflow: scroll;
    width: 100%
}
.waffle-dataconnector-querypreviewrenderer-canvas-viewport.native-scrollbar {
    position: static
}
.waffle-dataconnector-querypreviewrenderer-preview-overlay {
    background: rgba(0, 0, 0, 0.12);
    height: 100%;
    left: 0;
    line-height: 80px;
    opacity: 0;
    position: absolute;
    text-align: center;
    top: 0;
    transition: opacity 0.3s ease-in, visibility 0s linear 0.3s;
    vertical-align: middle;
    visibility: hidden;
    width: 100%;
    z-index: 2
}
.waffle-dataconnector-querypreviewrenderer-preview-overlay-text {
    -webkit-transform: translate(-50%, -50%);
    -moz-transform: translate(-50%, -50%);
    -ms-transform: translate(-50%, -50%);
    -o-transform: translate(-50%, -50%);
    transform: translate(-50%, -50%);
    background: rgba(0, 0, 0, 0.54);
    border-radius: 4px;
    box-shadow: 0px 4px 5px 0px rgba(0, 0, 0, 0.14), 0px 1px 10px 0px rgba(0, 0, 0, 0.12), 0px 2px 4px -1px rgba(0, 0, 0, 0.2);
    color: white;
    font: 500 21px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    left: 50%;
    max-width: 80%;
    padding: 20px;
    position: absolute;
    top: 50%
}
.waffle-dataconnector-querypreviewrenderer-preview-overlay.visible {
    opacity: 1;
    transition-delay: 0s;
    visibility: visible
}
.waffle-dataconnector-querypreviewrenderer-preview-inactive>.waffle-dataconnector-querypreviewrenderer-canvas-viewport {
    overflow: hidden
}
.waffle-dataconnector-querypreviewrenderer-canvas-viewport>canvas {
    height: 100%;
    width: 100%
}
.waffle-dataconnector-querypreviewrenderer-a11y-region {
    position: absolute;
    top: -10000px;
    left: -10000px
}
.waffle-dataconnector-queryeditor-query-settings-header .docs-icon {
    margin-right: 8px
}
.waffle-dataconnector-querytexteditor {

    position: relative
}
.waffle-dataconnector-querytexteditor-editor-container {
    height: 100%;
    position: absolute;
    width: 100%
}
.waffle-dataconnector-querytexteditor-overlay {
    background-color: #fff;
    height: 100%;
    left: 0;
    position: absolute;
    top: 0;
    width: 100%;
    width: 100%;
    z-index: 10000
}
.waffle-dataconnector-querytexteditor-overlay-message {
    -webkit-transform: translateY(-50%);
    -moz-transform: translateY(-50%);
    -ms-transform: translateY(-50%);
    -o-transform: translateY(-50%);
    transform: translateY(-50%);
    color: rgba(0, 0, 0, 0.54);
    font: 500 13px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    position: absolute;
    text-align: center;
    top: 50%;
    width: 100%
}
.waffle-dataconnector-querytexteditor-overlay-message a {
    color: inherit;
    text-decoration: underline
}
.waffle-dataconnector-queryeditor-removable-chip-inner {
    display: inline-block;
    max-width: 100%;
    position: relative
}
.waffle-dataconnector-queryeditor-removable-chip-button {
    background: #f0f0f0;
    border-radius: 16px;
    border: 2px solid transparent;
    cursor: pointer;
    display: block;
    height: 32px;
    line-height: 32px;
    padding: 0 32px 0 12px
}
.waffle-dataconnector-queryeditor-removable-chip-chip-content {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.waffle-dataconnector-queryeditor-removable-chip-error .waffle-dataconnector-queryeditor-removable-chip-button {
    background: #fff;
    border: 2px solid #db4437;
    overflow: hidden
}
.waffle-dataconnector-queryeditor-removable-chip-view-only .waffle-dataconnector-queryeditor-removable-chip-button {
    padding-right: 12px
}
.waffle-dataconnector-queryeditor-removable-chip-button-hover {
    background: #e0e0e0
}
.waffle-dataconnector-queryeditor-removable-chip-button-active {
    background: #d0d0d0
}
.waffle-dataconnector-queryeditor-removable-chip-button-focused {
    border: 2px solid #4285f4;
    outline: none
}
.waffle-dataconnector-queryeditor-removable-chip-button a {
    color: inherit
}
.waffle-dataconnector-queryeditor-removable-chip-remove-button {
    -webkit-transform: translateY(-50%);
    -moz-transform: translateY(-50%);
    -ms-transform: translateY(-50%);
    -o-transform: translateY(-50%);
    transform: translateY(-50%);
    background-color: rgba(0, 0, 0, 0.12);
    border-radius: 50%;
    box-sizing: border-box;
    height: 18px;
    position: absolute;
    right: 9px;
    top: 50%;
    width: 18px
}
.waffle-dataconnector-queryeditor-removable-chip-remove-button .waffle-dataconnector-close-icon {
    height: 14px;
    margin: 2px;
    width: 14px
}
.waffle-dataconnector-queryeditor-removable-chip-remove-button .waffle-dataconnector-close-icon polygon {
    fill: #fff
}
.waffle-dataconnector-queryeditor-removable-chip-remove-button-hover {
    background-color: rgba(0, 0, 0, 0.38);
    cursor: pointer
}
.waffle-dataconnector-queryeditor-removable-chip-remove-button-focused {
    background-color: rgba(0, 0, 0, 0.38);
    outline: none
}
.waffle-dataconnector-schema-menu {
    min-height: 30px;
    position: relative
}
.waffle-dataconnector-schema-menu .waffle-dataconnector-schema-menu-spinner {
    left: 50%;
    position: absolute;
    top: 50%;
    transform: translate(-50%, -50%)
}
.waffle-dataconnector-schema-menu-error-message {
    color: rgba(0, 0, 0, 0.54)
}
.waffle-dataconnector-queryeditor-schemamenuwidget-header {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center;
    height: 100%
}
.waffle-dataconnector-queryeditor-schemamenuwidget-header .waffle-dataconnector-database-icon {
    height: 18px;
    margin-right: 8px;
    min-width: 18px;
    width: 18px
}
.waffle-dataconnector-queryeditor-sidebaraccordion {
    box-sizing: border-box;
    display: flex;
    flex-direction: column;
    min-width: 200px
}
.waffle-dataconnector-queryeditor-sidebaraccordion:focus {
    outline-color: #4285f4
}
.trix-data-prep-date-time-input .nfd-inputall .nfd-input {
    width: 300px
}
.trix-data-prep-highlight-styled-rect {
    background-color: #0f9d58;
    opacity: 0.06;
    pointer-events: none
}
.range-border.trix-data-prep-highlight-styled-border {
    border-color: #0f9d58;
    border-style: dashed
}
.trix-data-prep-active-column-label {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
div.trix-data-prep-insights-tab .trix-data-prep-insights-container .docs-charts-editor-material-togglebutton {
    height: inherit;
    width: inherit
}
.waffle-calculated-columns-dialog {
    width: 720px
}
.waffle-calculated-columns-formula-input {
    width: 460px
}
.docs-gm-dialogs .waffle-data-validation-dialog {
    min-width: 672px
}
.docs-gm-dialogs .waffle-data-validation-dialog .waffle-dv-list-options-textarea {
    margin: 0;
    max-width: 251px;
    padding: 7px
}
.docs-gm-dialogs .waffle-data-validation-dialog .waffle-dv-editbox-number {
    margin: 0;
    width: 50px
}
.docs-gm-dialogs .waffle-data-validation-dialog .waffle-dv-editbox-text {
    margin: 0
}
.docs-gm-dialogs .waffle-data-validation-dialog .waffle-dv-editbox-date {
    margin: 0;
    width: 72px
}
.docs-gm-dialogs .waffle-data-validation-dialog .waffle-input-error-butter-container {
    margin-left: 180px;
    margin-top: -50px;
    z-index: 999;
    width: auto
}
.docs-gm-dialogs .waffle-dv-customcheckboxlabel {
    padding-top: 14px
}
.docs-gm-dialogs .waffle-dv-checkbox-label {
    padding-left: 8px
}
.docs-gm-dialogs .waffle-dv-table {
    width: 672px
}
.docs-gm-dialogs .waffle-dv-table .jfk-select {
    margin-right: 8px
}
.docs-gm-dialogs .waffle-dv-table .goog-flat-menu-button {
    margin-left: 0;
    height: 36px
}
.docs-gm-dialogs .waffle-dv-on-invalid-data .jfk-radiobutton-radio {
    left: 2px
}
.docs-gm-dialogs .waffle-dv-on-invalid-data .jfk-radiobutton:not(:last-child) {
    padding-right: 20px
}
.waffle-material-confirm-dialog {
    background: #fff;
    border-radius: 2px;
    border: none;
    box-shadow: 0px 16px 24px 2px rgba(0, 0, 0, 0.14), 0px 6px 30px 5px rgba(0, 0, 0, 0.12), 0px 8px 10px -5px rgba(0, 0, 0, 0.2);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    position: absolute;
    z-index: 1002
}
.waffle-material-confirm-dialog-bg {
    background-color: rgba(0, 0, 0, .6);
    left: 0;
    position: absolute;
    top: 0;
    z-index: 1001
}
.waffle-material-confirm-dialog-header {
    font-size: 18px;
    height: 18px;
    line-height: 18px;
    padding: 24px 24px 20px 24px
}
.waffle-material-confirm-dialog-content {
    padding: 0 24px
}
.waffle-material-confirm-dialog-footer {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-justify-content: flex-end;
    justify-content: flex-end;
    padding: 8px 14px 14px 14px
}
.waffle-source-destination-selection-dialog {
    min-width: 350px;
    border-radius: 10px
}
.waffle-source-destination-selection-dialog .docs-material-dialog-title {
    border-bottom: 0
}
.waffle-source-destination-selection-dialog .docs-material-gm-dialog-title-close {
    cursor: pointer
}
.waffle-sdsd-source-container .waffle-sdsd-rangepicker-container {
    padding: 0 0 16px
}
.waffle-sdsd-destination-container .waffle-sdsd-rangepicker-container {
    padding: 0 0 16px 22px
}
.waffle-sdsd-rangepicker-label {
    color: rgba(0, 0, 0, 0.54)
}
.waffle-sdsd-rangepicker-error-label {
    color: #db4437;
    font-size: 13px
}
.waffle-sdsd-destination-selection {
    padding: 10px 0
}
.waffle-sdsd-destination-selection .jfk-radiobutton {
    padding: 5px 0
}
.waffle-sdsd-destination-selection .jfk-radiobutton-radio {
    left: 0
}
.waffle-range-selection-container {
    display: flex;
    align-items: center
}
.waffle-range-selection-container-focus {
    border: 1px solid #4d90fe;
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    outline: none
}
.waffle-range-selection-input,
.waffle-range-selection-input:focus {
    background: transparent;
    border: none;
    box-sizing: border-box;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    height: 25px;
    font-size: 13px;
    margin: 0;
    outline: none;
    padding: 1px 8px;
    width: calc(100% - 34px)
}
.waffle-range-selection-button-container {
    overflow: hidden;
    padding: 0;
    text-align: right;
    width: 34px
}
.waffle-range-selection-button:hover,
.waffle-range-selection-button:focus {
    opacity: 0.9
}
.docs-gm-dialogs .waffle-range-selection-container {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    color: #3c4043;
    padding: 1px 8px;
    font-size: 14px;
    height: 36px;
    margin: 8px 0;
    margin: 0;
    padding: 1px
}
.docs-gm-dialogs .waffle-range-selection-container-focus {
    border: 2px solid #1a73e8;
    box-shadow: none;
    padding: 0px 7px;
    padding: 0
}
.docs-gm-dialogs .modal-dialog .waffle-range-selection-button,
.docs-gm-dialogs .modal-dialog .waffle-range-selection-button:hover,
.docs-gm-dialogs .modal-dialog .waffle-range-selection-button:focus,
.docs-gm-dialogs .modal-dialog .waffle-range-selection-button:hover:focus,
.docs-gm-dialogs .modal-dialog .waffle-range-selection-button:active,
.waffle-range-selection-button {
    background: transparent!important;
    border: transparent!important;
    cursor: pointer;
    line-height: 34px;
    padding: 0;
    white-space: nowrap
}
.waffle-range-selection-button {
    line-height: 25px;
    margin: 0;
    opacity: .70
}
.docs-gm-dialogs .waffle-range-selection-button {
    line-height: 33px
}
.docs-gm-dialogs .waffle-range-selection-input {
    color: inherit;
    font: inherit
}
.waffle-db-column-insights-menuitem {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    height: 32px;
    line-height: 32px
}
.waffle-db-column-insights-menuitem-accel {
    color: #9e9e9e;
    margin-left: auto;
    padding: 0 20px 0 40px;
    text-align: center
}
.waffle-db-column-insights-menuitem-refreshquery-info-progress {
    font-style: italic
}
.waffle-db-column-insights-menuitem-refreshquery-info-error-button {
    color: #db4437;
    text-decoration: underline
}
.waffle-material-labeledinput {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    position: relative
}
.waffle-material-labeledinput-inputwrapper {
    height: 46px;
    position: relative
}
.waffle-material-labeledinput-inputrow {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    bottom: 6px;
    color: rgba(0, 0, 0, 0.87);
    height: 20px;
    left: 0;
    position: absolute;
    vertical-align: top;
    width: 100%;
    z-index: 100
}
.waffle-material-labeledinput-input {
    -webkit-box-flex: 100;
    box-flex: 100;
    -ms-flex-positive: 100;
    -webkit-flex-grow: 100;
    flex-grow: 100;
    background: transparent;
    border: none;
    color: rgba(0, 0, 0, 0.87);
    display: block;
    font-size: 13px;
    height: 18px;
    line-height: 18px;
    outline: none;
    vertical-align: top
}
.waffle-material-labeledinput-label {
    -webkit-transition: transform 0.2s cubic-bezier(0.4, 0.0, 1, 1);
    -moz-transition: transform 0.2s cubic-bezier(0.4, 0.0, 1, 1);
    -o-transition: transform 0.2s cubic-bezier(0.4, 0.0, 1, 1);
    transition: transform 0.2s cubic-bezier(0.4, 0.0, 1, 1);
    bottom: 6px;
    color: rgba(0, 0, 0, 0.54);
    font-size: 13px;
    position: absolute;
    transform-origin: left bottom;
    width: 100%
}
.waffle-material-labeledinput-errorcontainer {
    font-size: 11px;
    height: 11px;
    line-height: 11px;
    margin-top: 3px;
    text-align: right
}
.waffle-material-labeledinput-underline {
    background: rgba(0, 0, 0, .42);
    bottom: 3px;
    height: 1px;
    padding: 0;
    position: absolute;
    width: 100%
}
.waffle-material-labeledinput-accentunderline {
    -webkit-transition: transform 0.2s cubic-bezier(0.4, 0.0, 1, 1);
    -moz-transition: transform 0.2s cubic-bezier(0.4, 0.0, 1, 1);
    -o-transition: transform 0.2s cubic-bezier(0.4, 0.0, 1, 1);
    transition: transform 0.2s cubic-bezier(0.4, 0.0, 1, 1);
    background: #4285f4;
    bottom: 2px;
    height: 2px;
    padding: 0;
    position: absolute;
    transform: scaleX(.6);
    visibility: hidden;
    width: 100%
}
.waffle-material-labeledinput.waffle-material-labeledinput-focus .waffle-material-labeledinput-accentunderline {
    transform: scaleX(1);
    visibility: visible
}
.waffle-material-labeledinput.waffle-material-labeledinput-focus .waffle-material-labeledinput-label {
    color: #4285f4
}
.waffle-material-labeledinput.waffle-material-labeledinput-float .waffle-material-labeledinput-label {
    transform: translateY(-21px) scale(.846, .846)
}
.waffle-material-labeledinput.waffle-material-labeledinput-error .waffle-material-labeledinput-accentunderline {
    background: #db4437;
    transform: scaleX(1);
    visibility: visible
}
.waffle-material-labeledinput.waffle-material-labeledinput-error .waffle-material-labeledinput-label,
.waffle-material-labeledinput-errormessage {
    color: #db4437
}
.waffle-material-labeledinput-embedded-control {
    position: relative
}
.waffle-material-selectioninput .waffle-range-selection-container {
    border: none;
    color: rgba(0, 0, 0, 0.87);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    height: 33px;
    line-height: 33px;
    outline: none;
    padding: 0;
    position: relative;
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-material-selectioninput .waffle-range-selection-container {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    height: 42px;
    line-height: 100%;
    padding: 8px 0 8px 8px
}
.waffle-material-selectioninput .waffle-range-selection-container:after {
    -webkit-transition: background-color 0.3s ease;
    -moz-transition: background-color 0.3s ease;
    -o-transition: background-color 0.3s ease;
    transition: background-color 0.3s ease;
    background-color: rgba(0, 0, 0, 0.12);
    content: '';
    height: 1px;
    left: 0;
    position: absolute;
    top: 100%;
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-material-selectioninput .waffle-range-selection-container:after {
    height: 0
}
.waffle-material-selectioninput:hover .waffle-range-selection-container:after {
    background-color: rgba(0, 0, 0, 0.38)
}
.waffle-material-selectioninput .waffle-range-selection-container-focus.waffle-range-selection-container:after {
    background-color: #4285f4;
    height: 2px
}
.waffle-material-selectioninput .waffle-range-selection-container.waffle-range-selection-container-focus {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    outline: none
}
.waffle-material-selectioninput .waffle-range-selection-input,
.waffle-material-selectioninput .waffle-range-selection-container-focus .waffle-range-selection-input {
    padding: 0!important
}
.waffle-material-toolbar-menu-button {
    color: rgba(0, 0, 0, 0.87);
    cursor: pointer;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    height: 26px;
    line-height: 26px;
    margin: 4px;
    outline: 0
}
.waffle-material-toolbar-menu-button-disabled {
    color: rgba(0, 0, 0, 0.12);
    cursor: default
}
.waffle-material-toolbar-menu-button-outer-box {
    border-radius: 2px;
    height: 26px;
    line-height: 26px
}
.waffle-material-toolbar-menu-button-inner-box {
    height: 100%;
    opacity: .54;
    width: 100%
}
.waffle-material-toolbar-menu-button-inner-box svg {
    height: 18px;
    margin: 4px 0 4px 4px;
    width: 18px
}
.waffle-material-toolbar-menu-button-dropdown svg {
    margin-left: 0
}
.waffle-material-toolbar-menu-button-caption,
.waffle-material-toolbar-menu-button-dropdown {
    display: inline-block;
    height: 26px;
    line-height: 26px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.waffle-material-toolbar-menu-button-hover .waffle-material-toolbar-menu-button-outer-box,
.waffle-material-toolbar-menu-button-focused .waffle-material-toolbar-menu-button-outer-box {
    background-color: rgba(0, 0, 0, .06)
}
.waffle-material-toolbar-menu-button-active .waffle-material-toolbar-menu-button-outer-box {
    background-color: rgba(0, 0, 0, .12)
}
.waffle-material-toolbar-menu-button-hover .waffle-material-toolbar-menu-button-inner-box,
.waffle-material-toolbar-menu-button-focused .waffle-material-toolbar-menu-button-inner-box,
.waffle-material-toolbar-menu-button-active .waffle-material-toolbar-menu-button-inner-box {
    opacity: 0.87
}
.jfk-bubble.jfk-bubble-promo.waffle-promo-bubble {
    -webkit-box-shadow: 0px 3px 4px 0px rgba(0, 0, 0, 0.14), 0px 3px 3px -2px rgba(0, 0, 0, 0.12), 0px 1px 8px 0px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 3px 4px 0px rgba(0, 0, 0, 0.14), 0px 3px 3px -2px rgba(0, 0, 0, 0.12), 0px 1px 8px 0px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 3px 4px 0px rgba(0, 0, 0, 0.14), 0px 3px 3px -2px rgba(0, 0, 0, 0.12), 0px 1px 8px 0px rgba(0, 0, 0, 0.2);
    background: #eeeeee;
    border: none;
    color: rgba(0, 0, 0, 0.87);
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    max-width: 265px;
    padding: 18px 30px
}
.jfk-bubble.jfk-bubble-promo.waffle-promo-bubble .jfk-bubble-arrowimplbefore {
    border-color: transparent #eeeeee
}
.jfk-bubble.jfk-bubble-promo.waffle-promo-bubble .jfk-bubble-arrowimplafter {
    border-color: transparent #eeeeee
}
.waffle-promo-bubble-icon {
    background: url('data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyNHB4IiBoZWlnaHQ9IjI0cHgiIHZpZXdCb3g9IjAgMCAyNCAyNCIgZmlsbD0iIzAwMDAwMCI+PHBhdGggZD0iTTIzIDEybC0yLjQ0LTIuNzguMzQtMy42OC0zLjYxLS44Mi0xLjg5LTMuMThMMTIgMyA4LjYgMS41NCA2LjcxIDQuNzJsLTMuNjEuODEuMzQgMy42OEwxIDEybDIuNDQgMi43OC0uMzQgMy42OSAzLjYxLjgyIDEuODkgMy4xOEwxMiAyMWwzLjQgMS40NiAxLjg5LTMuMTggMy42MS0uODItLjM0LTMuNjhMMjMgMTJ6bS0xMCA1aC0ydi0yaDJ2MnptMC00aC0yVjdoMnY2eiIvPjwvc3ZnPg==');
    display: inline-block;
    height: 24px;
    margin-right: 8px;
    position: relative;
    top: 6px;
    width: 24px
}
.waffle-promo-bubble-header {
    display: inline-block;
    font-size: 18px;
    font-weight: 500;
    line-height: 14px
}
.waffle-promo-bubble-description {
    font-size: 14px;
    line-height: 22px
}
.waffle-promo-bubble-content .jfk-button {
    -webkit-transition: color 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: color 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: color 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: color 200ms cubic-bezier(0.4, 0.0, 0.2, 1);
    cursor: pointer;
    font-size: 14px;
    letter-spacing: 0.04em;
    padding-right: 15px;
    padding-top: 5px;
    text-transform: uppercase
}
.jfk-button.waffle-promo-bubble-close {
    color: rgba(0, 0, 0, 0.54)
}
.jfk-button-hover.waffle-promo-bubble-close {
    color: rgba(0, 0, 0, 0.87)
}
.jfk-button.waffle-promo-bubble-continue {
    color: rgba(66, 133, 244, 0.87);
    font-weight: 500
}
.jfk-button-hover.waffle-promo-bubble-continue {
    color: rgba(66, 133, 244, 1)
}
.docs-colormenuitems .goog-menuitem.goog-inline-block.waffle-colormenuitems-scheme-header-edit-button {
    border-radius: 4px;
    border-width: 1px 0;
    height: 22px;
    margin-left: 4px;
    padding: 0;
    width: 24px
}
.goog-menuitem.goog-inline-block.waffle-colormenuitems-scheme-header-edit-button.goog-menuitem-highlight {
    border-width: 0
}
.waffle-ui-floating-toast {
    -webkit-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    bottom: 60px;
    color: rgba(255, 255, 255, 0.87);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    left: 15px;
    line-height: 20px;
    padding: 14px 24px
}
.waffle-ui-floating-toast-action {
    -webkit-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    color: #a1c2fa;
    font-weight: 400;
    opacity: 0.87;
    text-transform: uppercase
}
.waffle-ui-floating-toast-action:hover {
    opacity: 1
}
.waffle-insert-function-row>.goog-menuitem-content {
    min-width: 125px
}
.waffle-function-category-row {
    background: #fff;
    color: #333;
    cursor: pointer;
    font-size: 13px;
    font-weight: normal;
    margin: 0;
    padding: 6px 10px;
    text-overflow: ellipsis;
    white-space: nowrap;
    width: 250px
}
.waffle-function-category-row-name,
.waffle-function-category-row-description {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    max-width: 95%
}
.waffle-function-category-row-name {
    overflow: hidden;
    text-overflow: ellipsis
}
.waffle-function-category-row-description {
    color: #666;
    display: none;
    font-size: 11px;
    overflow: hidden;
    padding: 2px 0;
    text-overflow: ellipsis;
    white-space: nowrap
}
.waffle-function-category-active .waffle-function-category-row-description {
    display: block
}
.waffle-function-category-active {
    background: #eee;
    border-top: 1px solid #eee;
    border-bottom: 1px solid #eee;
    padding: 1px 10px;
    overflow: hidden
}
.waffle-info-icon-bubble {
    border-radius: 8px;
    box-shadow: 0 4px 8px 3px rgba(60, 64, 67, .15);
    font-size: 12px;
    max-width: 200px
}
.waffle-legacy-mnemonics-toast {
    background-color: #323232;
    border-radius: 2px;
    bottom: 70px;
    -webkit-box-shadow: 2px 2px 10px 0 rgba(0, 0, 0, 0.4);
    -moz-box-shadow: 2px 2px 10px 0 rgba(0, 0, 0, 0.4);
    box-shadow: 2px 2px 10px 0 rgba(0, 0, 0, 0.4);
    color: white;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 15px;
    left: 60px;
    padding: 17px 24px;
    position: absolute
}
.waffle-legacy-mnemonics-toast-container {
    display: -webkit-inline-box;
    display: -moz-inline-box;
    display: -ms-inline-flexbox;
    display: -webkit-inline-flex;
    display: inline-flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row
}
.waffle-legacy-mnemonics-toast-content {
    display: -webkit-inline-box;
    display: -moz-inline-box;
    display: -ms-inline-flexbox;
    display: -webkit-inline-flex;
    display: inline-flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row
}
.waffle-legacy-mnemonics-toast-text {
    font-weight: bold;
    padding-left: 4px
}
.waffle-legacy-mnemonics-toast-cancel {
    color: #1a73e8;
    cursor: pointer;
    font-weight: bold;
    padding-left: 35px;
    text-transform: uppercase
}
.waffle-progress-bar.progress-bar-horizontal {
    background: #c6dafc;
    height: 100%
}
.waffle-progress-bar>.progress-bar-thumb {
    background: #4285f4;
    height: 100%
}
.waffle-indeterminate-progress-bar>.progress-bar-thumb {
    -webkit-animation: waffle-indeterminate-progress-bar-animation 2s linear infinite;
    -moz-animation: waffle-indeterminate-progress-bar-animation 2s linear infinite;
    -o-animation: waffle-indeterminate-progress-bar-animation 2s linear infinite;
    animation: waffle-indeterminate-progress-bar-animation 2s linear infinite;
    position: relative;
    transition: width .2s cubic-bezier(.4, 0, .2, 1)
}
@keyframes waffle-indeterminate-progress-bar-animation {
    0% {
        left: 0%;
        width: 0
    }
    50% {
        left: 25%;
        width: 75%
    }
    75% {
        left: 100%;
        width: 0%
    }
}
.waffle-printing-select-list {
    background-color: #fafafa;
    box-shadow: 0 0 8px 0 rgba(0, 0, 0, 0.12), 0 8px 8px 0 rgba(0, 0, 0, 0.24);
    border-radius: 0 2px 2px 0 2px 2px;
    left: 0;
    overflow-y: auto;
    padding: 18px 32px;
    position: absolute;
    top: 0;
    width: 204px;
    z-index: 1003
}
.waffle-printing-select-list>div {
    outline: none
}
.waffle-printing-select-list-checkboxes {
    margin-bottom: 10px
}
.waffle-printing-select-list-checkboxes .waffle-printing-checkbox-label {
    line-height: 28px;
    margin-left: 12px
}
.waffle-printing-select-list-cancel {
    margin-left: 0
}
.docs-gm .goog-menu.waffle-sidebar-draglist-menu {
    border: none;
    border-radius: none;
    box-shadow: none;
    height: calc(100% - 13px);
    padding-bottom: 12px;
    padding-top: 0;
    width: 160px;
    z-index: 0
}
.goog-menu.waffle-sidebar-draglist-menu .goog-menu-filter::before {
    margin-left: 2px;
    margin-right: 1px;
    transform: scale(0.75)
}
.goog-menu.waffle-sidebar-draglist-menu .goog-menu-filter {
    padding-bottom: 8px;
    padding-top: 8px
}
.goog-menu.waffle-sidebar-draglist-menu .goog-menu-filter input {
    line-height: 18px
}
.goog-menu.waffle-sidebar-draglist-menu .goog-menu-content {
    margin-top: 8px;
    width: 100%
}
.docs-gm .goog-menu.waffle-sidebar-draglist-menu .goog-menuitem {
    box-sizing: border-box;
    border-radius: 16px;
    cursor: move;
    margin: 0 4px;
    overflow: hidden;
    padding-left: 8px;
    padding-right: 8px;
    margin-bottom: 2px;
    max-width: 160px
}
.waffle-sidebar-draglist-menu .goog-menuitem-highlight {
    background: #f8f9fa;
    border-radius: 16px;
    box-shadow: 0 1px 2px 0px rgba(60, 64, 67, .3), 0 1px 3px 1px rgba(60, 64, 67, .15)
}
.goog-menu.waffle-sidebar-draglist-menu .goog-menuitem-content,
.goog-menu.waffle-sidebar-draglist-menu .goog-menuitem-content span {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    line-height: 18px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.goog-menu.waffle-sidebar-draglist-menu .goog-menuitem-content>div {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-justify-content: flex-start;
    justify-content: flex-start
}
.goog-menu.waffle-sidebar-draglist-menu .goog-menuitem-icon {
    margin: 0 8px 0 0;
    position: relative;
    top: 0
}
.docs-charts-component:focus {
    outline: none
}
.docs-charts-component-canvas {
    direction: ltr
}
.docs-charts-tooltip {
    -webkit-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    background-color: #ffffff;
    border: 1px solid #c1c1c1;
    border-radius: 2px;
    color: rgba(0, 0, 0, 0.87);
    cursor: default;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 500;
    padding: 3px 12px;
    pointer-events: none;
    position: absolute
}
.docs-charts-tooltip-label,
.docs-charts-tooltip-value {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.docs-charts-tooltip-entry {
    margin-bottom: 3px;
    margin-top: 3px
}
.docs-charts-tooltip-entry .docs-charts-tooltip-label {
    color: rgba(0, 0, 0, 0.54)
}
.docs-charts-tooltip-entry .docs-charts-tooltip-symbol {
    margin-right: 6px
}
.docs-charts-tooltip-entry .docs-charts-tooltip-symbol .docs-charts-tooltip-symbol-icon {
    height: 12px;
    stroke: rgba(0, 0, 0, 0.54);
    stroke-width: 1px;
    width: 12px
}
.docs-charts-tooltip-entry-single .docs-charts-tooltip-label {
    margin-bottom: 3px
}
.docs-charts-tooltip-entry-single .docs-charts-tooltip-value {
    font-size: 1.1em;
    font-weight: 700
}
.docs-charts-tooltip-entry-domain .docs-charts-tooltip-value {
    color: rgba(0, 0, 0, 0.54)
}
.docs-charts-tooltip-entry-range .docs-charts-tooltip-value {
    font-weight: 700
}
.docs-charts-tooltip-entry-range .docs-charts-tooltip-symbol .docs-charts-tooltip-symbol-icon {
    margin-bottom: -1px
}
.prof-feedback-bank-xframe-docos-autocomplete-row {
    box-sizing: border-box;
    padding: 8px 4px;
    word-wrap: break-word
}
.docs-ml-icon {
    direction: ltr;
    display: inline-block;
    text-align: left;
    overflow: hidden;
    position: relative;
    vertical-align: middle
}
.docs-ml-img:before {
    content: url("//ssl.gstatic.com/docs/common/mobileweb_sprite1.png")
}
.docs-ml-img-container {
    height: 156px;
    position: absolute;
    width: 36px
}
.docs-ml-docs-logo-icon {
    left: 0;
    top: -36px
}
.docs-ml-sheets-logo-icon {
    left: 0;
    top: 0
}
.docs-ml-slides-logo-icon {
    left: 0;
    top: -96px
}
.docs-ml-arrow-back-icon {
    left: 0;
    top: -132px
}
.docs-ml-edit-icon {
    left: 0;
    top: -72px
}
@media screen and (-webkit-min-device-pixel-ratio:2.0) {
    .docs-ml-img {
        content: url(//ssl.gstatic.com/docs/common/mobileweb_sprite1.png)
    }
    .docs-ml-img-container {
        height: 156px;
        position: absolute;
        width: 36px
    }
    .docs-ml-docs-logo-icon {
        left: 0;
        top: -36px
    }
    .docs-ml-sheets-logo-icon {
        left: 0;
        top: 0
    }
    .docs-ml-slides-logo-icon {
        left: 0;
        top: -96px
    }
    .docs-ml-arrow-back-icon {
        left: 0;
        top: -132px
    }
    .docs-ml-edit-icon {
        left: 0;
        top: -72px
    }
}
.docs-ml-header {
    background: #fafafa;
    border-bottom: 1px solid #cbcbcb;
    box-shadow: 0 1px 1px rgba(0, 0, 0, .1);
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    font-family: Roboto, "Helvetica Neue", Helvetica, Arial, sans-serif;
    padding: 4px 0;
    position: fixed;
    left: 0;
    top: 0;
    width: 100%
}
.docs-ml-header-icon {
    height: 24px;
    opacity: 0.6;
    width: 24px
}
.docs-ml-header-icon-container {
    padding: 12px
}
.docs-ml-header-item {
    display: inline-block;
    vertical-align: middle
}
.docs-ml-header-drive-link {
    padding-left: 4px
}
body[dir="rtl"] .docs-ml-arrow-back-dir {
    -webkit-transform: scaleX(-1);
    -moz-transform: scaleX(-1);
    -ms-transform: scaleX(-1);
    -o-transform: scaleX(-1);
    transform: scaleX(-1)
}
.docs-ml-header-document-title {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    line-height: 24px;
    padding: 0 12px;
    width: 60%;
    width: calc(100% - 104px)
}
.docs-ml-header-document-title-text {
    font-size: 20px;
    font-weight: 500;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.docs-ml-header-edit-button {
    float: right;
    padding-right: 4px
}
.docs-ml-promotion {
    background: #fafafa;
    bottom: 0;
    box-shadow: 0 4px 12px rgba(0, 0, 0, 0.4);
    font-family: Arial, Helvetica, sans-serif;
    left: 0;
    position: fixed;
    width: 100%
}
.docs-ml-promotion-off-screen {
    -webkit-transform: translateY(100%);
    -moz-transform: translateY(100%);
    -ms-transform: translateY(100%);
    -o-transform: translateY(100%);
    transform: translateY(100%)
}
.docs-ml-promotion-shown {
    -webkit-transform: translateY(0);
    -moz-transform: translateY(0);
    -ms-transform: translateY(0);
    -o-transform: translateY(0);
    transform: translateY(0);
    -webkit-transition: -webkit-transform 333ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: transform 333ms cubic-bezier(0.4, 0.0, 0.2, 1)
}
.docs-ml-promotion-dismissed {
    -webkit-transform: translateY(100%);
    -moz-transform: translateY(100%);
    -ms-transform: translateY(100%);
    -o-transform: translateY(100%);
    transform: translateY(100%);
    box-shadow: none
}
.docs-ml-promotion-no-horizontal-scroll {
    overflow-x: hidden
}
.docs-ml-promotion-header {
    display: table;
    padding: 24px 24px 0 24px
}
.docs-ml-promotion-app-icon-container {
    display: table-cell
}
.docs-ml-promotion-app-icon {
    height: 36px;
    width: 36px
}
@media (min-width:600px) {
    .docs-ml-promotion-app-icon {
        -webkit-transform: scale(1.33);
        -moz-transform: scale(1.33);
        -ms-transform: scale(1.33);
        -o-transform: scale(1.33);
        transform: scale(1.33)
    }
}
.docs-ml-promotion-text {
    display: table-cell;
    padding-left: 20px;
    vertical-align: top
}
.docs-ml-promotion-text-heading {
    color: rgba(0, 0, 0, 0.87);
    font-size: 16px;
    font-weight: bold;
    padding-bottom: 7px
}
.docs-ml-promotion-text-body {
    color: rgba(0, 0, 0, 0.87);
    font-size: 14px
}
.docs-ml-promotion-action-row {
    float: right;
    margin-top: 6px;
    padding: 8px 24px
}
.docs-ml-promotion-action-row-desktop {
    margin-top: 6px
}
.docs-ml-promotion-action-container {
    display: inline-block;
    height: 48px;
    margin: 6px 4px;
    vertical-align: middle
}
.docs-ml-promotion-action-button {
    display: inline-block;
    font-size: 14px;
    font-weight: 500;
    padding: 9px 12px;
    vertical-align: middle
}
.docs-ml-promotion-action-button-wrapper:focus {
    outline-color: #d6d6d6
}
.docs-ml-promotion-action-button.docs-ml-promotion-yes-button {
    background-color: #4285f4;
    border-radius: 4px;
    color: #fafafa;
    border: 1px solid transparent
}
.docs-ml-promotion-action-button.docs-ml-promotion-yes-button:active {
    background-color: #1967d2
}
.docs-ml-promotion-action-button.docs-ml-promotion-no-button {
    background-color: #fafafa;
    color: #5f6368;
    border-radius: 4px;
    border: 1px solid #dadce0
}
.docs-ml-promotion-action-button.docs-ml-promotion-no-button:active {
    background-color: #f5f5f5
}
.docs-ml-promotion.desktop {
    text-align: center
}
@media (orientation:portrait) {
    .docs-ml-promotion.desktop {
        padding-top: 56px;
        padding-bottom: 80px
    }
}
@media (orientation:landscape) {
    .docs-ml-promotion.desktop {
        padding-top: 36px;
        padding-bottom: 56px
    }
}
.docs-ml-promotion-heading-desktop {
    font-family: 'Google Sans';
    font-size: 18px;
    font-weight: bold;
    color: #202124;
    padding-top: 32px;
    padding-bottom: 18px;
    line-height: 1.5;
    width: 360px;
    margin: 0px auto
}
.docs-ml-promotion-text-body-desktop {
    font-size: 14px;
    line-height: 2;
    color: #5f6368;
    padding-bottom: 30px
}
.docs-icon.docs-ml-promotion-desktop-icon {
    height: 40px;
    width: 40px;
    -webkit-transform: scale(2.5);
    -moz-transform: scale(2.5);
    -ms-transform: scale(2.5);
    -o-transform: scale(2.5);
    transform: scale(2.5);
    -webkit-transform-origin: top;
    -moz-transform-origin: top;
    -ms-transform-origin: top;
    -o-transform-origin: top;
    transform-origin: top
}
.docs-icon-ml-promotion-icon-container-desktop {
    height: 100px
}
.docs-ml-promotion-action-row-desktop .docs-ml-promotion-action-container {
    margin: 6px 8px;
    font-family: 'Google Sans'
}
.docs-ml-promotion-action-row-desktop .docs-ml-promotion-action-button-wrapper:focus {
    outline: none
}
.docs-ml-promotion-action-button.docs-ml-promotion-yes-button.docs-ml-promotion-app-themed {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff
}
.docs-ml-promotion-action-button.docs-ml-promotion-yes-button.docs-ml-promotion-app-themed:active {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff
}
.docs-ml-promotion-action-button.docs-ml-promotion-no-button.docs-ml-promotion-app-themed {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #dadce0!important;
    color: #188038
}
.docs-ml-promotion-action-button-wrapper:focus .docs-ml-promotion-action-button.docs-ml-promotion-yes-button.docs-ml-promotion-app-themed {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #4f9e67;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-ml-promotion-action-button-wrapper:focus .docs-ml-promotion-action-button.docs-ml-promotion-no-button.docs-ml-promotion-app-themed {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #e7f5eb;
    border: 1px solid #bbe2c6!important
}
.docs-ml-promotion {
    z-index: 1002
}
.docs-ml-header {
    z-index: 1002
}
.ess-button {
    cursor: pointer;
    display: inline-block
}
.ess-disabled-button {
    opacity: 0.25;
    filter: alpha(opacity=25);
    display: inline-block
}
.ess-button,
.ess-disabled-button {
    margin: 6px;
    vertical-align: middle
}
.ess-icon {
    width: 32px;
    height: 32px;
    background-image: url(//ssl.gstatic.com/docs/documents/share/images/ess-icons-4.png);
    background-repeat: no-repeat
}
.ess-gplus-icon {
    background-position: 0 0
}
.ess-gmail-icon {
    background-position: -34px 0
}
.ess-facebook-icon {
    background-position: -68px 0
}
.ess-twitter-icon {
    background-position: -102px 0
}
.scope-icon-default-group {
    background-repeat: no-repeat;
    background-position: 0 -24px
}
.scope-icon-default-user {
    background-repeat: no-repeat;
    background-position: 0 -342px
}
.scope-icon-default {
    display: inline-block
}
.scope-icon-default {
    width: 21px;
    height: 21px;
    opacity: 0.55;
    filter: alpha(opacity=55);
    margin-top: 4px;
    margin-left: 4px
}
.scope-icon-holder {
    display: inline-block
}
.scope-icon-holder {
    background-color: #f5f5f5;
    height: 29px;
    width: 29px;
    vertical-align: middle
}
.scope-icon-invite-holder {
    background-color: #fff
}
.scope-icon-custom {
    width: 29px;
    height: 29px;
    vertical-align: middle
}
.scope-icon-disabled {
    opacity: 0.25;
    filter: alpha(opacity=25)
}
.scope-icon-unused-invite {
    background-position: 0 -770px
}
.scope-icon-used-invite {
    background-position: 0 -417px
}
.scope-icon-unused-invite,
.scope-icon-used-invite {
    width: 29px;
    height: 29px;
    vertical-align: middle;
    margin-top: 0px;
    margin-left: 0px;
    background-repeat: no-repeat;
    opacity: 1;
    filter: alpha(opacity=100)
}
.vo-public-icon,
.vo-unlisted-icon,
.vo-domain-public-icon,
.vo-domain-unlisted-icon,
.vo-privately-shared-icon,
.vo-private-icon {
    width: 21px;
    height: 21px;
    background-repeat: no-repeat;
    margin-right: 4px;
    vertical-align: bottom
}
.vo-public-icon {
    background-position: 0 -671px
}
.vo-unlisted-icon {
    background-position: 0 -294px
}
.vo-domain-public-icon {
    background-position: 0 -850px
}
.vo-domain-unlisted-icon {
    background-position: 0 -551px
}
.vo-privately-shared-icon {
    background-position: 0 -72px
}
.vo-private-icon {
    background-position: 0 -575px
}
.waffle-filterbox-content {
    border: none;
    height: 130px;
    margin: 0px 4px;
    overflow-y: auto
}
.waffle-filterbox-content>.goog-menuitem-content {
    font-size: 12px
}
.waffle-filterbox-content>.goog-menuitem {
    padding: 1px 7em 1px 26px
}
.waffle-filterbox-content>.goog-menuitem-highlight {
    border: 0px;
    background-color: #d0d0d0
}
.waffle-filterbox-action-link,
.waffle-filterbox-dash {
    color: #15c;
    text-decoration: none
}
.waffle-filterbox-action-link:hover {
    text-decoration: underline
}
.waffle-filterbox-input {
    margin-right: -23px;
    padding-right: 23px;
    width: 221px
}
.waffle-filterbox-input-icon {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -205px -62px;
    display: inline-block;
    margin-top: 2px;
    height: 12px;
    width: 12px
}
.waffle-filterbox-label {
    padding-left: 6px
}
div.waffle-filterbox-label-icon {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -283px -73px;
    float: right;
    height: 16px;
    margin-left: 18px;
    width: 16px
}
.waffle-filterbox-label>div,
.waffle-filterbox-label>a {
    display: inline;
    font-size: 12px;
    margin-right: 3px
}
.waffle-filterbox-menu-spinner {
    text-align: center
}
.docs-gm-dialogs .waffle-filterbox-menu .goog-menu-filter input {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #fff;
    border: 1px solid #dadce0!important;
    font-weight: normal
}
.waffle-filterbox-ok-button .goog-imageless-button-content {
    font-weight: 500;
    padding: 0 15px
}
.waffle-autofilter-border {
    border-color: #0f9d58;
    line-height: 0
}
.docs-gm .waffle-autofilter-border {
    border-color: #188038
}
.filtered-incelldropdown-button {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -791px -13px;
    cursor: pointer;
    list-style: none;
    outline: none
}
.filtered-incelldropdown-button-disabled {
    cursor: default;
    filter: alpha(opacity=30);
    opacity: 0.3
}
.filtered-incelldropdown-button-hover,
.filtered-incelldropdown-button-checked,
.filtered-incelldropdown-button-focused {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -137px -46px
}
.waffle-autovis-lightbox {
    background-color: rgba(0, 0, 0, 0.7);
    height: 100%;
    left: 0;
    position: absolute;
    top: 0;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    width: 100%;
    z-index: 1000
}
.waffle-autovis-lightbox-container {
    height: 100%;
    width: 100%
}
.waffle-autovis-lightbox-chart {
    height: 100%;
    width: 100%
}
.waffle-autovis-lightbox-content {
    bottom: 0;
    left: 0;
    margin: auto;
    position: absolute;
    right: 0;
    top: 60px
}
.waffle-autovis-lightbox-content-inner {
    position: relative;
    white-space: nowrap
}
.waffle-autovis-lightbox-previous.jfk-button-disabled,
.waffle-autovis-lightbox-next.jfk-button-disabled {
    color: grey;
    cursor: default
}
.waffle-autovis-lightbox-page-count {
    color: white;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px;
    margin-top: 35px;
    text-align: center;
    width: 100%
}
.waffle-autovis-lightbox-button {
    background-color: transparent;
    background-image: none;
    border: 0;
    color: white;
    cursor: pointer;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    margin: 0;
    outline: 0;
    padding: 0
}
.waffle-autovis-lightbox-button:focus {
    border: none;
    padding: 0
}
.waffle-autovis-lightbox-previous,
.waffle-autovis-lightbox-next {
    bottom: 0;
    color: white;
    cursor: pointer;
    height: 50px;
    line-height: 50px;
    margin: auto;
    position: absolute;
    text-align: center;
    top: 0;
    width: 50px
}
.waffle-autovis-lightbox-previous {
    margin-right: 25px;
    right: 100%
}
.waffle-autovis-lightbox-next {
    left: 100%;
    margin-left: 25px
}
.waffle-autovis-lightbox-readonly .waffle-autovis-lightbox-readonly-hidden {
    display: none
}
.waffle-autovis-lightbox-header {
    background-color: rgba(0, 0, 0, 0.7);
    height: 60px;
    width: 100%
}
.waffle-autovis-lightbox-buttons-wrapper {
    color: white;
    font-weight: 500;
    line-height: 60px;
    margin-left: auto;
    margin-right: auto;
    text-align: center;
    width: 100%
}
.waffle-autovis-lightbox-close {
    cursor: pointer;
    position: absolute;
    right: 20px;
    top: 19px
}
.waffle-date-picker {
    z-index: 10;
    position: absolute
}
.goog-date-picker {
    -moz-user-focus: normal;
    -moz-user-select: none;
    position: relative;
    width: 156px;
    border: 1px solid #fff;
    border-top: 0;
    padding: 2px
}
.goog-date-picker-foot {
    display: none
}
.goog-date-picker table {
    empty-cells: hide
}
.goog-date-picker-wday,
.goog-date-picker table tbody td {
    width: 22px!important;
    height: 17px;
    text-align: center;
    vertical-align: middle;
    font: 11px Verdana;
    padding: 0
}
.goog-date-picker-wday {
    font-weight: 500
}
.goog-date-picker-btn {
    border: 0;
    display: block;
    float: left;
    width: 12px;
    cursor: pointer;
    font: 9px Verdana;
    font-weight: 500;
    text-align: center;
    margin: 0;
    padding: 0
}
.goog-date-picker-monthyear {
    width: 63px;
    font: 11px Verdana;
    font-weight: 500;
    text-align: center
}
* html .goog-date-picker table {
    margin-left: -1px
}
.goog-date-picker-menu {
    position: absolute;
    background: threedface;
    -moz-user-focus: normal;
    border-style: solid;
    border-width: 1px
}
.goog-date-picker-menu ul {
    list-style: none;
    margin: 0;
    padding: 0
}
.goog-date-picker-menu ul li {
    float: none;
    cursor: default
}
.goog-date-picker,
.goog-date-picker table,
.goog-date-picker-wday {
    background-color: #d9e6f7
}
.goog-date-picker-selected {
    background-color: #ae0a84!important;
    color: #fff!important;
    font-weight: 700!important
}
.goog-date-picker-date {
    background-color: #fff
}
.goog-date-picker table,
.goog-date-picker-head td {
    background-color: #d9e6f7
}
.goog-date-picker-btn {
    background-color: transparent;
    color: #069
}
.goog-date-picker-other-month {
    color: #999
}
.goog-date-picker-wkend-start,
.goog-date-picker-wkend-end {
    background-color: #e8eef7
}
#goog-dp-0,
#goog-dp-1,
#goog-dp-2,
#goog-dp-3,
#goog-dp-4,
#goog-dp-5,
#goog-dp-6 {
    border-top: 1px solid #a2bbdd
}
#goog-dp-0,
#goog-dp-7,
#goog-dp-14,
#goog-dp-21,
#goog-dp-28,
#goog-dp-35 {
    border-left: 1px solid #a2bbdd
}
#goog-dp-6,
#goog-dp-13,
#goog-dp-20,
#goog-dp-27,
#goog-dp-34,
#goog-dp-41 {
    border-right: 1px solid #fff
}
.docs-gm-dialogs .waffle-date-picker,
.docs-gm-dialogs .waffle-date-picker * {
    box-sizing: border-box;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 400
}
.docs-gm-dialogs .waffle-date-picker {
    position: absolute;
    width: 188px;
    z-index: 1000
}
.docs-gm-dialogs .goog-date-picker {
    -moz-user-focus: normal;
    background-color: #fff;
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    outline: none;
    padding: 0 10px 8px 10px;
    position: relative;
    user-select: none;
    width: 188px
}
.docs-gm-dialogs .goog-date-picker table {
    empty-cells: hide;
    outline: none;
    width: 100%
}
.docs-gm-dialogs .goog-date-picker table,
.docs-gm-dialogs .goog-date-picker-head td {
    background-color: transparent
}
.docs-gm-dialogs .goog-date-picker table tbody tr th:first-of-type {
    display: none
}
.docs-gm-dialogs .goog-date-picker table tbody:focus {
    outline: none;
    background-color: #e6f4ea
}
.docs-gm-dialogs .goog-date-picker-head {
    color: #80868b;
    font-size: 11px;
    height: 40px
}
.docs-gm-dialogs .goog-date-picker-monthyear {
    letter-spacing: 0.2px;
    padding-left: 7px;
    text-align: left
}
.docs-gm-dialogs .goog-date-picker-button {
    border: 0;
    border-radius: 50%;
    cursor: pointer;
    display: block;
    font-size: 10px;
    height: 20px;
    left: 2px;
    line-height: 20px;
    margin: 0 auto;
    padding-left: 0;
    position: relative;
    text-align: center;
    width: 20px;
    background-color: rgba(0, 0, 0, 0);
    transition: background-color 100ms linear
}
.docs-gm-dialogs .goog-date-picker-button:hover {
    background-color: #f1f3f4;
    transition: background-color 100ms linear
}
.docs-gm-dialogs .goog-date-picker-button:focus {
    outline: none
}
.docs-gm-dialogs .goog-date-picker-button:active {
    background-color: #dadce0;
    transition: background-color 100ms linear
}
.docs-gm-dialogs .goog-date-picker-nextMonth,
.docs-gm-dialogs .goog-date-picker-previousMonth {
    background: url("data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iNiIgaGVpZ2h0PSI4IiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgogICAgPGcgZmlsbD0ibm9uZSIgZmlsbC1ydWxlPSJldmVub2RkIj4KICAgICAgPHBhdGggZmlsbD0iIzc1NzU3NSIgZD0iTS43MjY2NjY2NyA3LjA2TDMuNzggNCAuNzI2NjY2NjcuOTRsLjk0LS45NEw1LjY2NjY2NjcgNCAxLjY2NjY2NjY3IDh6Ii8+CiAgICAgIDxwYXRoIGQ9Ik0tNS00aDE2djE2SC01eiIvPgogICAgPC9nPgogIDwvc3ZnPg==") center no-repeat
}
[dir="rtl"].docs-gm-dialogs .goog-date-picker-nextMonth {
    transform: rotate(180deg)
}
.docs-gm-dialogs .goog-date-picker-previousMonth {
    transform: rotate(180deg)
}
[dir="rtl"].docs-gm-dialogs .goog-date-picker-previousMonth {
    transform: rotate(0deg)
}
.docs-gm-dialogs .goog-date-picker-foot {
    display: none
}
.docs-gm-dialogs .goog-date-picker-wday,
.docs-gm-dialogs .goog-date-picker-date {
    font-size: 10px;
    font-weight: 400;
    height: 20px;
    line-height: 20px;
    margin: auto;
    position: relative;
    text-align: center;
    width: 24px
}
.docs-gm-dialogs .goog-date-picker-wday {
    background-color: transparent;
    color: #80868b
}
.docs-gm-dialogs .goog-date-picker-date {
    color: #202124;
    cursor: pointer;
    background-color: transparent;
    z-index: 1
}
.docs-gm-dialogs .goog-date-picker-date:focus {
    outline: none
}
.docs-gm-dialogs .goog-date-picker-date::before {
    border-radius: 50%;
    content: "";
    display: block;
    height: 20px;
    left: 2px;
    position: absolute;
    top: 0;
    width: 20px;
    z-index: -1;
    background-color: rgba(0, 0, 0, 0);
    transition: background-color 100ms linear
}
.docs-gm-dialogs .goog-date-picker-date::after {
    content: "";
    display: block;
    height: 20px;
    left: 0;
    position: absolute;
    top: 0;
    width: 24px;
    z-index: 2
}
.docs-gm-dialogs .goog-date-picker-date:hover::before {
    background-color: #dadce0;
    transition: background-color 100ms linear
}
.docs-gm-dialogs .goog-date-picker-other-month {
    color: #80868b
}
.docs-gm-dialogs .goog-date-picker-other-month:hover::before {
    background-color: #f1f3f4;
    transition: background-color 100ms linear
}
.docs-gm-dialogs .goog-date-picker-selected {
    background-color: transparent!important;
    font-weight: 400!important
}
.docs-gm-dialogs .goog-date-picker-selected,
.docs-gm-dialogs .goog-date-picker-selected:hover {
    color: #fff
}
.docs-gm-dialogs .goog-date-picker-selected::before,
.docs-gm-dialogs .goog-date-picker-selected:hover::before {
    background-color: #188038;
    transition: background-color 100ms linear
}
.docs-ui-toast {
    bottom: 74px
}
.docs-butterbar-container {
    z-index: 1003
}
.waffle-ellipses {
    display: inline-block;
    height: 12px;
    position: relative;
    width: 25px
}
.waffle-ellipses-message-container {
    height: 0;
    overflow: hidden;
    position: absolute;
    width: 0
}
.waffle-ellipses-container {
    height: 100%;
    overflow: hidden;
    width: 100%
}
.waffle-ellipses-sprite {
    display: block;
    position: relative
}
.waffle-ellipses.waffle-ellipses-active svg.waffle-ellipses-sprite {
    -webkit-animation: waffle-ellipses-sprite-cycle 1000ms steps(5) infinite reverse;
    -moz-animation: waffle-ellipses-sprite-cycle 1000ms steps(5) infinite reverse;
    -o-animation: waffle-ellipses-sprite-cycle 1000ms steps(5) infinite reverse;
    animation: waffle-ellipses-sprite-cycle 1000ms steps(5) infinite reverse
}
@keyframes waffle-ellipses-sprite-cycle {
    from {
        left: 0
    }
    to {
        left: -125px
    }
}
.waffle-filter-menu {
    max-height: 400px;
    overflow: auto
}
.waffle-filter-bar {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    color: #fff;
    margin-left: 35px;
    height: 30px
}
.waffle-filter-bar-header {
    font-weight: 500;
    margin-left: 10px
}
.waffle-filter-bar-name-label,
.waffle-filter-bar-range-label {
    padding: 7px 0
}
.waffle-filter-bar-name-input,
.waffle-filter-bar-range-input {
    background-color: transparent;
    border: 1px solid transparent;
    box-shadow: none;
    color: #fff;
    height: 19px;
    margin-top: 2.5px
}
.waffle-filter-bar-name-input:hover,
.waffle-filter-bar-range-input:hover {
    background-color: #6b6b6b
}
.waffle-filter-bar-name-input:focus,
.waffle-filter-bar-range-input:focus {
    background: #fff;
    border: 1px solid #4d90fe;
    color: black
}
.waffle-filter-bar-range-readonly,
.waffle-filter-bar-name-readonly {
    border: 1px dotted transparent;
    margin: 0 3px 0 6px;
    outline: none;
    overflow: hidden;
    padding: 6px 4px;
    text-overflow: ellipsis;
    white-space: nowrap;
    vertical-align: bottom
}
.waffle-filter-bar-range-readonly:focus,
.waffle-filter-bar-name-readonly:focus {
    border-color: #ccc
}
.waffle-filter-bar-options {
    margin-top: 4px
}
.waffle-filter-bar-close {
    margin-top: 4px
}
.waffle-filter-bar .goog-flat-button {
    background-color: transparent;
    border: none;
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    outline: none
}
.waffle-filter-bar .goog-flat-button:focus,
.waffle-filter-bar .goog-flat-button:hover {
    background-color: #6b6b6b
}
.docs-gm .waffle-filter-bar .goog-flat-button:focus,
.docs-gm .waffle-filter-bar .goog-flat-button:hover {
    background-color: #5f6368
}
.waffle-filter-bar .goog-flat-button.goog-flat-button-open,
.waffle-filter-bar .goog-flat-button:active {
    background-color: #3d3d3d
}
.docs-gm .waffle-filter-bar .goog-flat-button.goog-flat-button-open,
.docs-gm .waffle-filter-bar .goog-flat-button:active {
    background-color: #202124
}
.waffle-slidingdialog-filterbar {
    background-color: #555555;
    border-bottom: 1px solid black;
    border-left: none;
    border-right: none;
    border-top: 1px solid black;
    padding: 4px 12px
}
.docs-gm .waffle-slidingdialog-filterbar {
    background-color: #3c4043
}
.waffle-filter-bar-name-inputbox {
    display: inline
}
.waffle-filter-bar-name-inputbox,
.waffle-filter-bar-name-readonly {
    width: 175px
}
.waffle-filter-bar-promo-container {
    display: inline;
    margin-left: 32px;
    margin-top: 30px;
    position: absolute
}
.waffle-filter-bar-align-right {
    float: right
}
.waffle-filter-bar-promo {
    font-size: 11px;
    width: 200px
}
.waffle-filter-bar-range-filter-pills-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-flex-shrink: 1;
    -ms-flex-negative: 1;
    flex-shrink: 1;
    -moz-flex-wrap: wrap;
    -ms-flex-wrap: wrap;
    -webkit-flex-wrap: wrap;
    flex-wrap: wrap;
    margin: 0 10px;
    overflow-y: scroll
}
.waffle-filter-bar-add-range-filter-button {
    -webkit-border-radius: 25px;
    -moz-border-radius: 25px;
    border-radius: 25px;
    color: white;
    margin-top: 5px;
    white-space: nowrap
}
.waffle-filter-bar-rangepill {
    -webkit-border-radius: 25px;
    -moz-border-radius: 25px;
    border-radius: 25px;
    background-color: white;
    margin-right: 5px;
    margin-top: 2.5px;
    min-width: 100px;
    height: 25px
}
.waffle-filter-bar-rangepill-range {
    background-color: transparent;
    color: black;
    margin-left: 10px;
    min-width: 60px;
    padding: 5px 0
}
.waffle-filter-bar .waffle-filter-bar-rangepill .waffle-filter-bar-rangepill-close:focus,
.waffle-filter-bar .waffle-filter-bar-rangepill .waffle-filter-bar-rangepill-close:hover {
    background: transparent
}
.waffle-filter-bar-rangepill-close {
    margin: 0
}
.waffle-filter-bar-range-pill-input {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    height: 25px
}
.waffle-filter-bar-range-section,
.waffle-filter-bar-range-section-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    overflow: hidden
}
.waffle-filter-bar-range-section-space-eater {
    -webkit-box-flex: 1;
    box-flex: 1;
    -ms-flex-positive: 1;
    -webkit-flex-grow: 1;
    flex-grow: 1
}
.waffle-slidingdialog-formbar {
    background-color: #424242;
    border-left: none;
    border-right: none;
    padding: 4px 16px 4px 55px
}
.waffle-form-bar {
    color: #fff;
    height: 30px
}
.waffle-form-bar-forms-icon {
    position: relative;
    top: 5px
}
.waffle-form-bar-forms-text {
    font-family: Roboto, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    margin-left: 16px;
    padding: 7px 0
}
.waffle-form-bar-right-all-buttons {
    float: right
}
.waffle-form-bar-right-all-buttons button {
    background-color: transparent;
    border-radius: 2px;
    border: 0;
    color: white;
    cursor: pointer;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-weight: 500;
    margin-right: 8px;
    min-width: 88px;
    padding: 3px 8px;
    position: relative;
    text-transform: uppercase;
    top: -7px
}
.waffle-form-bar-right-all-buttons button.goog-button-disabled {
    color: rgba(255, 255, 255, 0.3);
    cursor: default
}
.waffle-form-bar-more-options {
    margin-left: 8px;
    margin-top: 4px
}
.waffle-form-bar .goog-flat-button {
    background-color: transparent;
    border: none;
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    outline: none
}
.waffle-form-bar .goog-flat-button:focus,
.waffle-form-bar .goog-flat-button-hover,
.waffle-form-bar-right-all-buttons button:focus,
.waffle-form-bar-right-all-buttons button:hover {
    background-color: rgba(204, 204, 204, 0.15);
    outline-width: 0
}
.waffle-form-bar .goog-flat-button.goog-flat-button-open,
.waffle-form-bar .goog-flat-button:active,
.waffle-form-bar-right-all-buttons button:active {
    background-color: rgba(204, 204, 204, 0.25);
    outline-width: 0
}
.waffle-arguments-help-popup {
    background-color: white;
    border: 1px solid rgba(0, 0, 0, .2);
    -webkit-box-shadow: 0 2px 4px rgba(0, 0, 0, .2);
    -moz-box-shadow: 0 2px 4px rgba(0, 0, 0, .2);
    box-shadow: 0 2px 4px rgba(0, 0, 0, .2);
    color: #222;
    font-size: 11px;
    position: absolute;
    width: 320px;
    word-wrap: break-word;
    z-index: 1000
}
.waffle-arguments-help-title {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    background-color: #f5f5f5;
    color: #222;
    direction: ltr;
    padding: 1px 0 1px 10px
}
.waffle-arguments-help-function-name {
    text-decoration: inherit
}
.waffle-arguments-help-body {
    border-top: 1px solid #ebebeb
}
.waffle-arguments-help-content {
    padding-bottom: 2px
}
.waffle-arguments-help-section {
    padding: 5px 10px
}
.waffle-arguments-help-section-title {
    font-size: 11px;
    color: #666
}
.waffle-arguments-help-parameter-content {
    font-size: 11px
}
.waffle-arguments-help-argument-info {}
.waffle-arguments-help-formula {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    direction: ltr;
    font-family: Inconsolata, monospace, arial, sans, sans-serif;
    font-size: 14px;
    overflow: hidden;
    padding: 1px 0
}
.waffle-arguments-help-example-holder {
    text-align: left
}
.waffle-arguments-help-footer {
    padding: 0 10px 8px
}
.waffle-arguments-help-parameter {
    border-radius: 4px;
    padding-left: 1px;
    -webkit-transition: 0.218s ease-in;
    -moz-transition: 0.218s ease-in;
    -o-transition: 0.218s ease-in;
    transition: 0.218s ease-in
}
.waffle-arguments-help-parameter-active {
    background-color: #feb
}
#waffle-arguments-help-learn-more {
    color: #15c;
    text-decoration: none
}
#waffle-arguments-help-learn-more:hover {
    text-decoration: underline
}
.waffle-arguments-help-send-feedback {
    color: #c53929;
    float: right;
    text-decoration: none
}
.waffle-arguments-help-send-feedback:hover,
.waffle-arguments-help-send-feedback:focus {
    text-decoration: underline
}
.waffle-arguments-help-code {
    background-color: #f5f5f5;
    font-family: Inconsolata, monospace, arial, sans, sans-serif
}
.waffle-arguments-help-button-container {
    margin-right: 6px
}
.waffle-arguments-help-button {
    -webkit-transform: scale(.75, .75);
    -moz-transform: scale(.75, .75);
    -ms-transform: scale(.75, .75);
    -o-transform: scale(.75, .75);
    transform: scale(.75, .75);
    display: inline-block;
    margin: -4px;
    opacity: .35;
    padding: 2px 3px 0 3px
}
.waffle-arguments-help-button:hover {
    opacity: .7
}
.waffle-arguments-help-arg-suggestions-title-container .waffle-arguments-help-button {
    opacity: 0.7
}
.waffle-arguments-help-arg-suggestions-title-container .waffle-arguments-help-button:hover {
    opacity: 1
}
.waffle-arguments-help-toggle-icon {
    -webkit-transition: 400ms ease-out;
    -moz-transition: 400ms ease-out;
    -o-transition: 400ms ease-out;
    transition: 400ms ease-out;
    -webkit-transform: rotate(180deg);
    -moz-transform: rotate(180deg);
    -ms-transform: rotate(180deg);
    -o-transform: rotate(180deg);
    transform: rotate(180deg)
}
.waffle-arguments-help-toggle-icon-flipped {
    -webkit-transform: rotate(0);
    -moz-transform: rotate(0);
    -ms-transform: rotate(0);
    -o-transform: rotate(0);
    transform: rotate(0)
}
.waffle-arguments-help-pointer {
    border-left: 5px solid #a3a3a3;
    border-top: 4px solid transparent;
    border-bottom: 4px solid transparent;
    margin-top: 8px;
    position: absolute;
    -webkit-transition: 0.218s ease-in-out;
    -moz-transition: 0.218s ease-in-out;
    -o-transition: 0.218s ease-in-out;
    transition: 0.218s ease-in-out
}
.waffle-arguments-help-arg-suggestions-section {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    background: #e6f4ea;
    padding: 10px;
    padding-bottom: 14px;
    padding-right: 0px;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.waffle-arguments-help-arg-suggestions-v1-ui.waffle-arguments-help-arg-suggestions-section {
    background: #0f9d58;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.waffle-arguments-help-arg-suggestions-title-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    color: #188038;
    font-size: 13px
}
.waffle-arguments-help-arg-suggestions-v1-ui .waffle-arguments-help-arg-suggestions-title-container {
    color: #fff
}
.waffle-arguments-help-arg-suggestions-title {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1
}
.waffle-arguments-help-arg-suggestions-title-text {
    font-weight: 500;
    text-transform: capitalize
}
.waffle-arguments-help-arg-suggestions-v1-ui .waffle-arguments-help-arg-suggestions-title-text {
    font-weight: 700;
    text-transform: uppercase
}
.waffle-arguments-help-arg-suggestions-selection-message {
    font-size: 12px;
    font-weight: 400
}
.waffle-arguments-help-arg-suggestions-chips {
    margin-top: 8px;
    margin-right: 10px
}
.waffle-arguments-help-arg-suggestions-chips-container {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-arguments-help-arg-suggestions-chip {
    -webkit-box-shadow: 0 1px 2px 0 rgba(60, 64, 67, 0.30), 0 1px 3px 1px rgba(60, 64, 67, 0.15);
    -moz-box-shadow: 0 1px 2px 0 rgba(60, 64, 67, 0.30), 0 1px 3px 1px rgba(60, 64, 67, 0.15);
    box-shadow: 0 1px 2px 0 rgba(60, 64, 67, 0.30), 0 1px 3px 1px rgba(60, 64, 67, 0.15);
    background: #fff;
    border: 1px solid transparent;
    border-radius: 8px;
    color: #5f6368;
    cursor: pointer;
    font-size: 13px;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    height: 16px;
    line-height: 16px;
    margin-right: 8px;
    max-width: 100px;
    overflow: hidden;
    padding: 7px;
    text-overflow: ellipsis;
    white-space: nowrap
}
.waffle-arguments-help-arg-suggestions-v1-ui .waffle-arguments-help-arg-suggestions-chip {
    -webkit-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    background: #fff;
    border-radius: 4px;
    border: 1px solid #e0e0e0;
    color: rgba(0, 0, 0, 0.87);
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-weight: 400;
    min-width: 60px;
    text-align: center
}
.waffle-arguments-help-arg-suggestions-v2-ui .waffle-arguments-help-arg-suggestions-chip.goog-button-hover,
.waffle-arguments-help-arg-suggestions-v2-ui .waffle-arguments-help-arg-suggestions-chip.goog-button-focused {
    -webkit-box-shadow: 0 1px 1px 0 rgba(52, 168, 83, 0.50), 0 1px 3px 1px rgba(52, 168, 83, 0.50);
    -moz-box-shadow: 0 1px 1px 0 rgba(52, 168, 83, 0.50), 0 1px 3px 1px rgba(52, 168, 83, 0.50);
    box-shadow: 0 1px 1px 0 rgba(52, 168, 83, 0.50), 0 1px 3px 1px rgba(52, 168, 83, 0.50);
    -webkit-transform: scale(1.05);
    -moz-transform: scale(1.05);
    -ms-transform: scale(1.05);
    -o-transform: scale(1.05);
    transform: scale(1.05);
    border: 1px solid #1e8e3e;
    outline: none
}
.waffle-arguments-help-arg-suggestions-v1-ui .waffle-arguments-help-arg-suggestions-chip.goog-button-hover,
.waffle-arguments-help-arg-suggestions-v1-ui .waffle-arguments-help-arg-suggestions-chip.goog-button-focused {
    -webkit-transform: scale(1.05);
    -moz-transform: scale(1.05);
    -ms-transform: scale(1.05);
    -o-transform: scale(1.05);
    transform: scale(1.05);
    outline: none
}
.waffle-arguments-help-arg-suggestions-chip.waffle-suggested-arg-chip-selected {
    -webkit-box-shadow: 0 1px 1px 0 rgba(52, 168, 83, 0.50), 0 1px 3px 1px rgba(52, 168, 83, 0.50);
    -moz-box-shadow: 0 1px 1px 0 rgba(52, 168, 83, 0.50), 0 1px 3px 1px rgba(52, 168, 83, 0.50);
    box-shadow: 0 1px 1px 0 rgba(52, 168, 83, 0.50), 0 1px 3px 1px rgba(52, 168, 83, 0.50);
    background: rgba(52, 168, 83, 0.04);
    border: 1px solid #1e8e3e;
    color: #1e8e3e
}
.waffle-arguments-help-arg-suggestions-v1-ui .waffle-arguments-help-arg-suggestions-chip.waffle-suggested-arg-chip-selected {
    -webkit-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    background: #4285f4;
    border: 1px solid #4285f4;
    font-weight: 700;
    color: #fff
}
.waffle-arguments-help-arg-suggestions-chip-icon {
    display: inline-block;
    float: left;
    margin-right: 7px;
    height: 16px;
    width: 16px
}
.waffle-arguments-help-arg-suggestions-v1-ui .waffle-arguments-help-arg-suggestions-chip-icon,
.waffle-arguments-help-arg-suggestions-v2-ui-no-chip-icon .waffle-arguments-help-arg-suggestions-chip-icon {
    display: none
}
.waffle-arguments-help-arg-suggestions-chip-value {
    line-height: 17px;
    margin-left: -1px
}
.waffle-formula-autocomplete-renderer .waffle-ac-active {
    background: #eeeeee
}
.waffle-function-autocomplete-row {
    text-overflow: ellipsis;
    width: 325px
}
.waffle-function-autocomplete-row-name,
.waffle-function-autocomplete-row-formula {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    color: #222;
    direction: ltr;
    font-size: 13px;
    font-family: Inconsolata, monospace, arial, sans, sans-serif;
    margin: -2px 0
}
.waffle-function-autocomplete-row-name {
    overflow: hidden;
    text-overflow: ellipsis
}
.waffle-formula-autocomplete-row-primary-content .waffle-function-autocomplete-row-formula {
    margin: 0;
    overflow: hidden
}
.waffle-function-autocomplete-row-description {
    color: #666;
    display: none;
    font-size: 11px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.waffle-ac-active .waffle-function-autocomplete-row-description {
    display: block
}
.waffle-function-autocomplete-row-shortcut,
.waffle-function-autocomplete-row-simplified-shortcut {
    color: #666;
    direction: ltr
}
.waffle-actionable-autocomplete-row,
.waffle-contextual-formula-autocomplete-row,
.waffle-named-range-autocomplete-row {
    -webkit-align-items: flex-start;
    align-items: flex-start;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    cursor: pointer;
    direction: ltr
}
.waffle-ac-row.waffle-ac-actionable-row {
    padding: 1px 10px
}
.waffle-ac-row.waffle-ac-named-range-row,
.waffle-ac-row.waffle-ac-contextual-row {
    padding-top: 1px
}
.waffle-ac-actionable-row {
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    border-top: 1px solid rgba(0, 0, 0, 0.12)
}
.waffle-function-autocomplete-row-icon-container,
.waffle-named-range-autocomplete-row-icon-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    margin-right: 3px;
    width: 25px
}
.waffle-ac-actionable-row .waffle-function-autocomplete-row-icon-container {
    opacity: 0.4
}
.waffle-ac-contextual-row .waffle-function-autocomplete-row-icon-container {
    margin: 1px 2px 2px 1px
}
.waffle-actionable-formula-autocomplete-row-content,
.waffle-contextual-formula-autocomplete-row-content,
.waffle-named-range-autocomplete-row-content {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    direction: ltr;
    padding-top: 2px;
    white-space: normal;
    width: calc(325px - 25px)
}
.waffle-actionable-formula-autocomplete-row-content,
.waffle-contextual-formula-autocomplete-row-content {
    word-wrap: break-word
}
.waffle-named-range-autocomplete-row-content {
    word-wrap: ellipsis
}
.waffle-formula-autocomplete-row-primary-content {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    direction: ltr
}
.waffle-contextual-formula-autocomplete-row .waffle-formula-autocomplete-row-primary-content {
    margin: -2px 0
}
.waffle-ac-close-autocomplete-row {
    border: none!important
}
.waffle-ac-close-autocomplete-row {
    cursor: default!important;
    background: rgba(0, 0, 0, 0.15)
}
.waffle-close-autocomplete-row-content {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-justify-content: flex-end;
    justify-content: flex-end;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1
}
.waffle-close-autocomplete-row-close-button {
    cursor: pointer;
    opacity: 0.3
}
.waffle-close-autocomplete-row-close-button:hover,
.waffle-close-autocomplete-row-close-button:focus {
    opacity: 0.5
}
.waffle-close-autocomplete-row-message {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    color: #000;
    font-weight: 500;
    overflow: hidden;
    overflow-wrap: break-word;
    white-space: normal
}
.waffle-sidebar-container.waffle-pivot-sidebar {
    display: block;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif!important;
    width: 300px
}
.waffle-sidebar-container.waffle-pivot-sidebar:focus {
    outline: 1px solid #4285f4
}
body:not(.docs-gm-sidebars) .waffle-sidebar-title-close {
    border: transparent;
    border-radius: 50%
}
body:not(.docs-gm-sidebars) .waffle-sidebar-title-close:focus {
    background-color: rgba(255, 255, 255, .24);
    border: transparent
}
#waffle-pivot-aggr {
    display: inline;
    font-weight: normal;
    margin-right: 5px
}
#waffle-pivot-aggr .docs-material-select-outer-box {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    border-bottom: none
}
#waffle-pivot-aggr-select {
    font-size: 12px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-container {
    border-top: none;
    padding: 12px 16px 0
}
.waffle-pivot-container {
    border: none;
    border-top: 1px solid #e0e0e0;
    padding: 14px 14px 6px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-label,
.docs-gm-sidebars .waffle-gm-sidebar #waffle-pivot-aggr-label {
    color: #3c4043;
    font-size: 14px;
    font-weight: 500;
    letter-spacing: 0.2px;
    padding-bottom: 18px
}
.waffle-pivot-label {
    color: rgba(0, 0, 0, 0.87);
    font-weight: bold;
    padding: 0 0 14px 2px;
    position: relative
}
#waffle-pivot-aggr-label {
    color: rgba(0, 0, 0, 0.87);
    font-size: 13px;
    font-weight: 500;
    text-decoration: none
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-add-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #dadce0!important;
    color: #188038;
    height: 24px;
    padding: 3px 12px 5px;
    color: #188038;
    letter-spacing: .25px;
    padding: 3px 11px 1px 13px;
    text-transform: none
}
.waffle-pivot-add-button {
    border: transparent;
    color: #4285f4;
    cursor: pointer;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    margin: 0;
    padding: 0 3px 0 6px;
    position: absolute;
    right: 0;
    text-transform: uppercase;
    top: -3px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-add-button:hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #f8fcf9;
    border: 1px solid #c8e7d1!important;
    height: 24px;
    padding: 3px 12px 5px;
    padding: 3px 11px 1px 13px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-add-button:focus {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #e7f5eb;
    border: 1px solid #bbe2c6!important;
    height: 24px;
    padding: 3px 12px 5px;
    padding: 3px 11px 1px 13px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-add-button:hover:focus {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    border: 1px solid #b5e0c1!important;
    height: 24px;
    padding: 3px 12px 5px;
    padding: 3px 11px 1px 13px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-add-button:active {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;

    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    border: 1px solid transparent!important;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    height: 24px;
    padding: 3px 12px 5px;
    padding: 3px 11px 1px 13px
}
.waffle-pivot-add-button:focus {
    background-color: rgba(66, 133, 244, .12);
    border: transparent
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-add-button-disabled {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #f1f3f4!important;
    color: #3c4043;
    opacity: 0.38;
    height: 24px;
    padding: 3px 12px 5px;
    padding: 3px 11px 1px 13px
}
.waffle-pivot-add-button-disabled {
    color: rgba(0, 0, 0, .12);
    cursor: default
}
.waffle-pivot-rangepicker-container {
    padding: 8px 16px 8px
}
#waffle-pivot-range-selection {
    padding-bottom: 8px
}
#waffle-pivot-range-selection .waffle-range-selection-button {
    border-radius: 50%;
    margin: 0;
    padding: 4px 2px 4px 0
}
#waffle-pivot-range-selection .waffle-range-selection-button:focus {
    background-color: rgba(0, 0, 0, .12)!important
}
.waffle-pivot-rangepicker-error-label {
    color: #db4437;
    font-size: 13px
}
.waffle-pivot-drop-target {
    height: auto;
    margin-bottom: -22px;
    margin-top: -24px;
    padding-bottom: 24px;
    padding-top: 24px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-pill {
    box-shadow: 0 1px 3px 1px rgba(60, 64, 67, .15);
    margin-bottom: 16px
}
.waffle-pivot-pill {
    -webkit-transition: max-height 0.25s cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: max-height 0.25s cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: max-height 0.25s cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: max-height 0.25s cubic-bezier(0.4, 0.0, 0.2, 1);
    background-color: #fff;
    border: none;
    border-radius: 2px;
    box-shadow: 0px 0px 2px 0px rgba(0, 0, 0, 0.12), 0px 2px 2px 0px rgba(0, 0, 0, 0.24);
    cursor: move;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif!important;
    margin-bottom: 8px
}
.waffle-pivot-pill:focus {
    outline-color: #4285f4
}
.waffle-pivot-pill-disabled {
    cursor: default
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-pill-checkbox-label {
    color: #5f6368;
    font-size: 12px;
    letter-spacing: .13px
}
.waffle-pivot-pill-checkbox-label {
    margin-left: 10px;
    vertical-align: middle
}
.waffle-pivot-pill-align-middle {
    vertical-align: middle
}
.waffle-pivot-pill-close {
    color: #8d8d8d;
    cursor: pointer;
    float: right;
    font-size: 14px;
    transform: translateY(-15%)
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-pill-close .jfk-button {
    font-size: 18px
}
.waffle-pivot-pill-close .jfk-button {
    border: transparent;
    border-radius: 50%;
    outline: none;
    width: 20px
}
.waffle-pivot-pill-close .jfk-button:focus {
    background-color: rgba(0, 0, 0, .12)
}
.waffle-pill-during-dragging {
    height: 33px
}
.waffle-pill-during-dragging .waffle-pivot-pill-section {
    display: none
}
.waffle-pivot-pill-close-disabled {
    color: rgba(0, 0, 0, .12)
}
.waffle-pivot-pill-section {
    box-sizing: border-box;
    display: inline-block;
    margin: 8px 0;
    padding: 0 8px;
    vertical-align: top;
    width: 50%
}
#waffle-pivot-filter .waffle-pivot-pill-section,
.waffle-pill-section-checkbox,
.waffle-pivot-date-grouping-section {
    width: 100%
}
#waffle-pivot-filter .waffle-pivot-filter-pill-select {
    padding-bottom: 2px;
    padding-top: 2px;
    width: 100%
}
#waffle-pivot-filter .waffle-pivot-filter-pill-select .goog-flat-menu-button-caption {
    font-size: 12px
}
.waffle-pivot-date-grouping-section {
    margin-top: 4px
}
.waffle-pill-section-checkbox {
    margin-top: 0
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-pill-main-table {
    background: none;
    border-bottom: none;
    padding: 10px 8px 6px 12px
}
.waffle-pivot-pill-main-table {
    background: #eee;
    border-bottom: 1px solid #eee;
    padding: 8px;
    min-height: 16px
}
.waffle-pivot-pill-main-table-text {
    float: left;
    max-width: 185px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-pill-title {
    color: #202124;
    font-size: 14px;
    letter-spacing: .25px
}
.waffle-pivot-pill-title {
    color: black;
    font-weight: 500;
    overflow: hidden;
    white-space: nowrap
}
.waffle-pivot-pill-nodrag {
    cursor: pointer
}
.waffle-pivot-pill-type-icon {
    float: left;
    margin-right: 8px;
    opacity: 1!important;
    position: relative;
    top: -1px
}
.waffle-pivot-multi-select {
    background: #efefef;
    border: 1px solid #d7d7d7;
    display: block;
    margin: 3px 0 0 0;
    padding: 3px;
    position: relative
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-multi-select {
    background-color: #f1f3f4;
    border-color: transparent;
    border-radius: 4px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-multi-select .docs-material-gm-select {
    margin-bottom: 4px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-multi-select .docs-material-gm-select:last-child {
    margin-bottom: 0
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-multi-select .docs-material-gm-select-outer-box {
    background-color: white
}
body:not(.docs-gm-sidebars) .waffle-pivot-multi-select::before {
    border-color: #d7d7d7 transparent;
    border-width: 0 5px 5px 5px;
    margin: 0 0 0 -5px;
    left: 50%;
    right: auto;
    top: -5px
}
body:not(.docs-gm-sidebars) .waffle-pivot-multi-select::before,
body:not(.docs-gm-sidebars) .waffle-pivot-multi-select::after {
    border-style: solid;
    content: '';
    display: block;
    height: 0;
    position: absolute;
    width: 0
}
body:not(.docs-gm-sidebars) .waffle-pivot-multi-select::after {
    border-color: #efefef transparent;
    border-width: 0 4px 4px 4px;
    margin: 0 0 0 -4px;
    left: 50%;
    right: auto;
    top: -4px
}
.waffle-pivot-pill-sort-by {
    vertical-align: top;
    width: 100%
}
.waffle-pivot-multi-select .waffle-pivot-select-caption {
    color: #555
}
.waffle-pivot-select-divider {
    color: #555;
    margin: 0 3px
}
.waffle-pivot-checkbox {
    vertical-align: middle
}
.waffle-pivot-feedback-section {
    float: right;
    margin-right: 10px;
    margin-top: 5px;
    position: relative
}
#waffle-pivot-feedback {
    padding-left: 10px
}
.waffle-pivot-add-field-menu {
    overflow-y: auto
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-add-field-label {
    display: inline-block;
    letter-spacing: 0.2px;
    padding-top: 2px
}
.waffle-pivot-aggr-select-container {
    display: inline-block;
    height: 20px;
    margin-top: -5px
}
#waffle-pivot-aggr-select {
    border-bottom: 2px solid transparent
}
#waffle-pivot-aggr-select:focus {
    border-color: #4d90fe
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-select-label {
    color: #5f6368;
    padding-bottom: 3px;
    padding-left: 2px
}
.waffle-pivot-select-label {
    color: #616161;
    font-size: 11px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pivot-calculated-input {
    border: 1px solid #dadce0;
    border-radius: 4px;
    color: #3c4043;
    font-size: 12px;
    padding: 4px 0px 4px 8px
}
.waffle-pivot-calculated-input {
    box-sizing: border-box;
    width: 100%
}
.waffle-pivot-calculated-input:focus {
    outline-color: #4d90fe
}
.waffle-pill-section-formula {
    margin-bottom: 0;
    width: 100%

}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-pill-section-formula .waffle-pivot-pill-nodrag {
    padding-top: 0
}
.waffle-pill-section-formula .waffle-pivot-pill-nodrag {
    padding-top: 8px
}
#waffle-pivot-filter {
    min-height: 20px
}
.waffle-pivot-recommendation-header {
    outline: none
}
.waffle-pivot-recommendation-box.legacy .waffle-pivot-container {
    border-top: 1px solid #efefef;
    height: auto;
    padding: 8px 8px 0px;
    padding-bottom: 12px
}
.waffle-pivot-recommendation-box .waffle-pivot-container {
    padding: 14px
}
.waffle-pivot-curr-drag-item {
    max-height: 30px
}
.waffle-pivot-recommendation-box.legacy .waffle-pivot-label {
    font-size: 13px;
    font-weight: 500;
    margin: 0;
    padding-top: 2px;
    padding-bottom: 6px
}
.waffle-pivot-recommendation-header .waffle-pivot-recommendation-toggle-icon {
    float: right;
    -webkit-transition: 200ms ease-out;
    -moz-transition: 200ms ease-out;
    -o-transition: 200ms ease-out;
    transition: 200ms ease-out;
    -webkit-transform: rotate(180deg);
    -moz-transform: rotate(180deg);
    -ms-transform: rotate(180deg);
    -o-transform: rotate(180deg);
    transform: rotate(180deg)
}
.goog-zippy-expanded .waffle-pivot-recommendation-toggle-icon {
    -webkit-transform: rotate(0);
    -moz-transform: rotate(0);
    -ms-transform: rotate(0);
    -o-transform: rotate(0);
    transform: rotate(0);
    border: 1px solid transparent
}
.waffle-pivot-recommendation-header:focus .waffle-pivot-recommendation-toggle-icon {
    border: 1px solid #5e97f6!important;
    outline: none
}
.waffle-pivot-recommendation-toggle-icon-disabled {
    opacity: 0.24
}
.waffle-pivot-recommendation-error {
    margin-left: 2px
}
.waffle-pivot-recommendation-error,
.waffle-pivot-recommendation-container {
    opacity: 0.7
}
.waffle-pivot-recommendation-container {
    -webkit-align-items: flex-start;
    align-items: flex-start;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    background-color: transparent;
    color: black;
    cursor: pointer
}
.waffle-pivot-recommendation-container:hover,
.waffle-pivot-recommendation-container:hover .waffle-pivot-recommendation-icon {
    opacity: 1.0
}
.waffle-pivot-recommendation-body {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column
}
.waffle-pivot-recommendation-content {
    -webkit-align-items: flex-start;
    align-items: flex-start;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    background-color: transparent;
    overflow-wrap: break-word;
    overflow: hidden;
    padding: 4px 0
}
.waffle-pivot-recommendation-text {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    color: rgba(0, 0, 0, 0.87);
    line-height: 21px;
    padding-left: 5px;
    white-space: normal
}
.waffle-pivot-recommendation-preview-btn {
    -webkit-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    background-color: white;
    display: none;
    opacity: 0.7;
    padding: 4px;
    position: absolute;
    right: 0
}
.waffle-pivot-recommendation-preview-btn-visible,
.waffle-pivot-recommendation-container:hover .waffle-pivot-recommendation-preview-btn {
    cursor: pointer;
    display: block;
    opacity: 0.9
}
.waffle-pivot-recommendation-content:focus,
.waffle-pivot-recommendation-content:hover {
    background-color: #f5f5f5;
    outline: none
}
.waffle-recommendation-box-spinner-container {
    -webkit-align-self: center;
    align-self: center;
    height: 40px;
    width: 40px
}
.waffle-recommendation-box-spinner-container .waffle-spinner {
    height: 25px;
    width: 25px
}
.waffle-pivot-recommendation-error-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex
}
.waffle-pivot-recommendation-error-image {
    opacity: 0.5
}
.waffle-pivot-recommendation-error-content {
    margin-left: 10px
}
.waffle-pivot-rangepicker-label {
    color: rgba(0, 0, 0, 0.54)
}
.waffle-pivot-sidebar .docs-material-gm-select-caption {
    color: #3c4043;
    font-size: 12px;
    padding-left: 8px
}
.waffle-pivot-sidebar .docs-material-gm-select-outer-box {
    padding: 0
}
.waffle-pivot-sidebar .docs-material-gm-checkbox {
    display: inline-block
}
.docs-gm-sidebars .waffle-gm-sidebar.waffle-sidebar-container.waffle-pivot-sidebar-column-names-enabled {
    width: 460px
}
.waffle-pivot-sidebar-column-names-enabled .waffle-sidebar-content {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    overflow: hidden
}
.waffle-pivot-sidebar-column-names-enabled #waffle-pivot-pane {
    border-right: 1px solid #dadce0;
    height: 100%;
    overflow-y: auto;
    width: 300px
}
.waffle-pivot-sidebar-column-names-enabled #waffle-pivot-pane .waffle-pivot-container {
    box-sizing: border-box;
    max-width: 284px;
    padding-right: 0
}
.waffle-pivot-sidebar-column-names-enabled .waffle-pivot-recommendation-list {
    position: relative
}
.waffle-pivot-sidebar-column-names-enabled .waffle-pivot-column-names-container {
    display: block;
    height: 100%;
    overflow-y: auto;
    width: 160px
}
.waffle-gm-sidebar.waffle-pivot-sidebar-column-names-enabled .waffle-pivot-pill {
    background: #f1f3f4;
    border-radius: 8px;
    box-shadow: none
}
.waffle-gm-sidebar.waffle-pivot-sidebar-column-names-enabled .waffle-pivot-pill-main-table {
    padding: 6px 8px
}
.waffle-pivot-pill-type-icon {
    top: 1px
}
.waffle-pivot-sidebar-column-names-enabled .waffle-pivot-pill-main-table-text,
.waffle-pivot-sidebar-column-names-enabled .waffle-pivot-pill-title {
    line-height: 20px
}
.waffle-gm-sidebar.waffle-pivot-sidebar-column-names-enabled .waffle-pivot-pill-title {
    color: #3c4043;
    font-weight: 500
}
.waffle-pivot-sidebar-column-names-enabled .waffle-pivot-pill-close {
    transform: initial
}
.waffle-pivot-sidebar-column-names-enabled.waffle-pill-during-dragging {
    background: #f8f9fa;
    border-radius: 16px;
    box-shadow: 0 4px 4px 0px rgba(60, 64, 67, .3), 0 8px 12px 6px rgba(60, 64, 67, .15);
    opacity: 0.9
}
.waffle-pivot-sidebar-column-names-enabled.waffle-pill-during-dragging .waffle-pivot-pill-close {
    display: none
}
.waffle-pivot-sidebar-column-names-enabled .docs-material-gm-select {
    background: white
}
.waffle-pivot-sidebar-column-names-enabled #waffle-pivot-pane .waffle-pivot-pill.waffle-pivot-pill-highlight {
    background: #ceead6;
    border: 1px solid #34a853
}
.waffle-pivot-sidebar-column-names-enabled.waffle-pill-during-dragging.goog-menuitem {
    box-sizing: border-box;
    border-radius: 16px;
    cursor: move;
    margin: 0 4px;
    overflow: hidden;
    padding-left: 8px;
    padding-right: 8px;
    background: #f8f9fa;
    box-shadow: 0 4px 4px 0px rgba(60, 64, 67, .3), 0 8px 12px 6px rgba(60, 64, 67, .15);
    opacity: 0.9
}
.waffle-pivot-sidebar-column-names-enabled.waffle-pill-during-dragging.goog-menuitem .goog-menuitem-content,
.waffle-pivot-sidebar-column-names-enabled.waffle-pill-during-dragging.goog-menuitem .goog-menuitem-content span {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    line-height: 18px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    font-weight: 500
}
.waffle-pivot-sidebar-column-names-enabled.waffle-pill-during-dragging.goog-menuitem .goog-menuitem-content>div {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: row;
    -webkit-flex-direction: row;
    flex-direction: row;
    -webkit-justify-content: flex-start;
    justify-content: flex-start
}
.waffle-pivot-sidebar-column-names-enabled.waffle-pill-during-dragging.goog-menuitem .goog-menuitem-icon {
    margin: 0 8px 0 0;
    position: relative;
    top: 0
}
.waffle-printing-pane {
    left: 0;
    outline: none;
    position: absolute;
    height: 100%;
    top: 0;
    width: 100%
}
.waffle-printing-fullscreen-cover {
    background: rgba(0, 0, 0, .54);
    bottom: 0;
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}
.waffle-printing-loader-message {
    color: #fff;
    font: 13px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    line-height: 60px;
    text-align: center;
    width: 100%
}
.waffle-printing-indeterminate-loader {
    height: 4px;
    left: 0;
    position: absolute;
    right: 0;
    top: 60px
}
.waffle-printing-body-wrapper {
    bottom: 0;
    left: 0;
    position: absolute;
    right: 0;
    top: 60px
}
.waffle-printing-header-bar {
    background-color: #424242;
    height: 60px;
    line-height: 60px;
    width: 100%
}
.waffle-printing-header-bar-left {
    margin-left: 12px
}
.waffle-printing-header-bar-right {
    margin-right: 12px
}
.waffle-printing-header-bar-middle {
    height: 100%;
    line-height: 60px;
    overflow: hidden;
    text-align: center;
    width: auto
}
.waffle-printing-top-level-header-left {
    float: left;
    height: 60px
}
.waffle-printing-top-level-header-left>div {
    vertical-align: middle
}
.waffle-printing-header-title {
    color: white;
    display: inline-block;
    font: 18px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    margin-left: 28px;
    margin-right: 16px
}
.waffle-printing-page-counter {
    color: white;
    display: inline-block;
    font: 13px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500
}
.waffle-printing-header-page-total {
    font-weight: 400
}
.waffle-printing-cancel-button,
.waffle-printing-cancel-button.docs-material-button-focused.docs-material-button-no-focus-border {
    padding-left: 4px
}
.waffle-printing-cancel-button.docs-material-button-focused {
    padding-left: 3px
}
.waffle-printing-cancel-button .docs-icon {
    margin: -4px 8px 0 0
}
.waffle-printing-header-button-set,
.waffle-printing-custom-headers-footers-confirm,
.waffle-printing-custom-page-breaks-confirm {
    float: right
}
.waffle-printing-header-button-set,
.waffle-printing-custom-headers-footers-confirm,
.waffle-printing-custom-page-breaks-confirm,
.waffle-printing-custom-headers-footers-cancel,
.waffle-printing-custom-page-breaks-cancel {
    margin-top: 14px;
    margin-bottom: 14px
}
.waffle-printing-print-button,
.waffle-printing-top-level-cancel-button {
    float: right
}
.waffle-printing-float-clear {
    clear: both
}
.waffle-printing-preview-pane {
    background-color: #d1d1d1;
    height: 100%;
    overflow: hidden;
    position: relative;
    width: auto
}
.waffle-printing-preview-outer {
    height: 100%
}
.waffle-printing-preview-inner {
    height: 100%;
    overflow-x: auto;
    overflow-y: scroll
}
.waffle-printing-preview-card-wrapper {
    margin: 41px 20px 20px 36px
}
.waffle-printing-preview-card {
    background-color: #fff;
    box-shadow: 0 8px 10px 1px rgba(0, 0, 0, 0.14), 0 3px 14px 3px rgba(0, 0, 0, 0.12), 0 4px 5px 0 rgba(0, 0, 0, 0.20);
    margin: auto;
    position: relative;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    width: 100%
}
.waffle-printing-preview-card>canvas {
    height: 100%;
    width: 100%
}
.waffle-printing-preview-spinner {
    position: absolute;
    left: 50%;
    top: 50%;
    transform: translate(-14px, -14px)
}
.waffle-printing-preview-page-counter-outer {
    bottom: 22px;
    margin: 0 10%;
    pointer-events: none;
    position: absolute;
    width: 80%
}
.waffle-printing-preview-page-counter-inner {
    background-color: rgba(0, 0, 0, 0.7);
    border-radius: 12px;
    color: #fff;
    display: table;
    font: 16px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    margin: auto;
    padding: 20px 32px;
    text-align: center
}
.waffle-printing-preview-page-counter-ellipses {
    max-height: 19px
}
.waffle-printing-options-pane {
    background-color: #fff;
    color: #474747;
    float: right;
    height: 100%;
    overflow-y: auto;
    width: 300px
}
.waffle-printing-options-top-section {
    padding: 8px 16px
}
.waffle-printing-options-section {
    border-bottom: 1px solid #d2d2d2
}
.waffle-printing-options-wrapper .docs-charts-editor-collapsible-header {
    font: 16px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500
}
.waffle-printing-options-wrapper .docs-charts-editor-collapsible-title {
    width: auto
}
.waffle-printing-options-wrapper .docs-charts-editor-collapsible-summary {
    display: none
}
.waffle-printing-options-wrapper h2 {
    color: rgba(0, 0, 0, .87);
    font-size: 13px;
    font-weight: normal;
    margin: 20px 0 0
}
.waffle-printing-options-wrapper h3,
.waffle-printing-options-wrapper .docs-material-labeled-select-label {
    color: rgba(0, 0, 0, .54);
    font: 11px Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.waffle-printing-options-wrapper h3,
.waffle-printing-options-wrapper .docs-material-labeled-select {
    margin: 20px 0 0
}
.waffle-printing-options-wrapper .waffle-material-labeledinput {
    margin: 16px 0 0
}
.waffle-printing-options-wrapper .waffle-material-labeledinput-underline,
.waffle-printing-options-wrapper .waffle-material-labeledinput-accentunderline {
    bottom: 0
}
.waffle-printing-options-wrapper .waffle-material-labeledinput-input {
    bottom: 3px
}
.waffle-printing-options-pane .docs-charts-editor-material-menu-button-caption {
    font-size: 16px
}
.waffle-printing-full-size {
    display: block;
    padding: 0
}
.waffle-printing-custom-paper-height-wrapper {
    float: left;
    width: 120px
}
.waffle-printing-custom-paper-width-wrapper {
    float: right;
    width: 120px
}
.waffle-printing-scale .docs-charts-editor-material-text-input {
    margin-top: 12px
}
.waffle-printing-custom-scale {
    float: right;
    margin-left: 20px;
    width: 33%
}
.waffle-printing-scale-wrapper {
    overflow: hidden;
    width: auto
}
.waffle-printing-page-breaks-edit-button {
    float: right;
    margin-right: -8px
}
.waffle-printing-page-breaks-button-and-toggle {
    line-height: 32px;
    margin: 18px 0
}
.waffle-printing-page-breaks-toggle-wrapper {
    color: rgba(0, 0, 0, 0.87);
    vertical-align: middle;
    float: left;
    width: auto
}
.waffle-printing-page-breaks-toggle {
    display: inline-block;
    margin-left: 12px;
    position: relative;
    top: 3px
}
.waffle-printing-page-breaks-toggle-ie {
    top: 5px
}
.waffle-printing-page-breaks-toggle-label {
    display: inline-block
}
.docs-charts-editor-collapsible-content>div.waffle-printing-formatting-section {
    padding-bottom: 16px
}
.waffle-printing-horizontal-alignment,
.waffle-printing-vertical-alignment {
    float: left;
    width: 118px
}
.waffle-printing-horizontal-alignment {
    margin-right: 20px
}
.waffle-printing-options-section.waffle-printing-repeat-header-cells-section {
    border-bottom: none
}
.waffle-printing-options-section.waffle-printing-repeat-header-cells-section h2 {
    margin-bottom: 10px
}
.waffle-printing-options-section.waffle-printing-repeat-header-cells-section h3 {
    margin: 0 0 16px
}
.waffle-printing-rfs-columns,
.waffle-printing-rfs-rows,
.waffle-printing-rfs-columns .docs-charts-editor-labeledcheckbox,
.waffle-printing-rfs-rows .docs-charts-editor-labeledcheckbox {
    display: inline
}
.waffle-printing-zoom-wrapper {
    position: absolute;
    right: 22px;
    bottom: 10px;
    z-index: 1
}
.waffle-printing-zoom-in-button .jfk-button,
.waffle-printing-zoom-out-button .jfk-button {
    background: #fff;
    border-radius: 20px;
    box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12), 0 3px 1px -2px rgba(0, 0, 0, 0.2);
    height: 15px;
    min-width: 0;
    padding: 12.5px;
    position: relative;
    margin: 0 0 12px 0;
    right: -80px;
    transition: .2s right;
    width: 15px
}
.waffle-printing-zoom-in-button .jfk-button .waffle-printing-zoom-icon-wrapper,
.waffle-printing-zoom-out-button .jfk-button .waffle-printing-zoom-icon-wrapper {
    line-height: 0;
    opacity: .54
}
.waffle-printing-zoom-out-button .jfk-button {
    transition-delay: .1s
}
.waffle-printing-preview-pane:hover .waffle-printing-zoom-in-button .jfk-button {
    right: 0
}
.waffle-printing-preview-pane:hover .waffle-printing-zoom-out-button .jfk-button,
.waffle-printing-zoom-out-button .jfk-button-focused {
    right: 0;
    transition-delay: .1s
}
.waffle-printing-zoom-force-visible.jfk-button {
    right: 0;
    transition: none
}
.waffle-printing-zoom-in-button .jfk-button.jfk-button-hover,
.waffle-printing-zoom-in-button .jfk-button.jfk-button-focused,
.waffle-printing-zoom-out-button .jfk-button.jfk-button-hover,
.waffle-printing-zoom-out-button .jfk-button.jfk-button-focused {
    box-shadow: 0 4px 5px 0 rgba(0, 0, 0, 0.14), 0 1px 10px 0 rgba(0, 0, 0, 0.12), 0 2px 4px -1px rgba(0, 0, 0, 0.4)
}
.waffle-printing-zoom-in-button .jfk-button.jfk-button-hover .waffle-printing-zoom-icon-wrapper,
.waffle-printing-zoom-in-button .jfk-button.jfk-button-focused .waffle-printing-zoom-icon-wrapper,
.waffle-printing-zoom-out-button .jfk-button.jfk-button-hover .waffle-printing-zoom-icon-wrapper,
.waffle-printing-zoom-out-button .jfk-button.jfk-button-focused .waffle-printing-zoom-icon-wrapper {
    opacity: .87
}
.waffle-printing-zoom-in-button .jfk-button.jfk-button-active,
.waffle-printing-zoom-in-button .jfk-button:active,
.waffle-printing-zoom-out-button .jfk-button.jfk-button-active,
.waffle-printing-zoom-out-button .jfk-button:active {
    background: #aaa;
    border-color: #aaa
}
.waffle-printing-margins-control {
    outline: none;
    position: absolute;
    top: 0;
    left: 0
}
.waffle-printing-margins-control-top,
.waffle-printing-margins-control-bottom {
    cursor: ns-resize;
    height: 5px;
    left: 0;
    position: absolute;
    right: 0
}
.waffle-printing-margins-control-right,
.waffle-printing-margins-control-left {
    bottom: 0;
    cursor: ew-resize;
    position: absolute;
    top: 0;
    width: 5px
}
.waffle-printing-margins-control-top {
    border-bottom: 2px dashed #4285f4;
    margin-top: -7px
}
.waffle-printing-margins-control-top:hover,
.waffle-printing-margins-control-top.waffle-printing-margins-control-active {
    border-bottom: 2px solid #4285f4
}
.waffle-printing-margins-control-bottom {
    border-top: 2px dashed #4285f4;
    margin-bottom: -7px
}
.waffle-printing-margins-control-bottom:hover,
.waffle-printing-margins-control-bottom.waffle-printing-margins-control-active {
    border-top: 2px solid #4285f4
}
.waffle-printing-margins-control-right {
    border-left: 2px dashed #4285f4;
    margin-right: -7px
}
.waffle-printing-margins-control-right:hover,
.waffle-printing-margins-control-right.waffle-printing-margins-control-active {
    border-left: 2px solid #4285f4
}
.waffle-printing-margins-control-left {
    border-right: 2px dashed #4285f4;
    margin-left: -7px
}
.waffle-printing-margins-control-left:hover,
.waffle-printing-margins-control-left.waffle-printing-margins-control-active {
    border-right: 2px solid #4285f4
}
.waffle-printing-margins-control-top-wrapper,
.waffle-printing-margins-control-bottom-wrapper,
.waffle-printing-margins-control-right-wrapper,
.waffle-printing-margins-control-left-wrapper {
    background: #fff;
    border: 2px dashed #4285f4;
    height: 34px;
    padding: 16px;
    width: 60px
}
.waffle-printing-margins-control-top:hover .waffle-printing-margins-control-top-wrapper,
.waffle-printing-margins-control-active .waffle-printing-margins-control-top-wrapper,
.waffle-printing-margins-control-bottom:hover .waffle-printing-margins-control-bottom-wrapper,
.waffle-printing-margins-control-active .waffle-printing-margins-control-bottom-wrapper,
.waffle-printing-margins-control-right:hover .waffle-printing-margins-control-right-wrapper,
.waffle-printing-margins-control-active .waffle-printing-margins-control-right-wrapper,
.waffle-printing-margins-control-left:hover .waffle-printing-margins-control-left-wrapper,
.waffle-printing-margins-control-active .waffle-printing-margins-control-left-wrapper {
    border: 2px solid #4285f4
}
.waffle-printing-margins-control-top-title,
.waffle-printing-margins-control-bottom-title,
.waffle-printing-margins-control-right-title,
.waffle-printing-margins-control-left-title {
    font: 11px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    color: rgba(0, 0, 0, .54);
    margin-left: -1px
}
.waffle-printing-margins-control-top-wrapper,
.waffle-printing-margins-control-top:hover .waffle-printing-margins-control-top-wrapper,
.waffle-printing-margins-control-active .waffle-printing-margins-control-top-wrapper {
    border-radius: 0 0 2px 2px;
    border-top: none;
    box-shadow: 0 4px 4px 0 rgba(0, 0, 0, 0.25);
    left: 50%;
    position: absolute;
    top: 5px;
    transform: translateX(-50%)
}
.waffle-printing-margins-control-bottom-wrapper,
.waffle-printing-margins-control-bottom:hover .waffle-printing-margins-control-bottom-wrapper,
.waffle-printing-margins-control-active .waffle-printing-margins-control-bottom-wrapper {
    border-bottom: none;
    border-radius: 2px 2px 0 0;
    box-shadow: 0 -4px 4px 0 rgba(0, 0, 0, 0.25);
    bottom: 5px;
    left: 50%;
    position: absolute;
    transform: translateX(-50%)
}
.waffle-printing-margins-control-right-wrapper,
.waffle-printing-margins-control-right:hover .waffle-printing-margins-control-right-wrapper,
.waffle-printing-margins-control-active .waffle-printing-margins-control-right-wrapper {
    border-radius: 2px 0 0 2px;
    border-right: none;
    box-shadow: -4px 0 4px 0 rgba(0, 0, 0, 0.25);
    position: absolute;
    right: 5px;
    top: 50%;
    transform: translateY(-50%)
}
.waffle-printing-margins-control-left-wrapper,
.waffle-printing-margins-control-left:hover .waffle-printing-margins-control-left-wrapper,
.waffle-printing-margins-control-active .waffle-printing-margins-control-left-wrapper {
    border-left: none;
    border-radius: 0 2px 2px 0;
    box-shadow: 4px 0 4px 0 rgba(0, 0, 0, 0.25);
    left: 5px;
    position: absolute;
    top: 50%;
    transform: translateY(-50%)
}
.waffle-printing-radio-button-wrapper {
    float: left;
    margin-top: 6px;
    width: 50%
}
.waffle-printing-radio-button-wrapper .jfk-radiobutton-label {
    color: rgba(0, 0, 0, .87);
    font: 13px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    line-height: 18px;
    margin-left: 23px
}
.waffle-printing-radio-button-wrapper .jfk-radiobutton-label label {
    margin-left: 0
}
.waffle-printing-radio-button-wrapper .jfk-radiobutton-radio,
.waffle-printing-radio-button-wrapper .jfk-radiobutton-hover .jfk-radiobutton-radio {
    border: 2px solid #bebebe;
    height: 16px;
    left: 2px;
    width: 16px
}
.waffle-printing-radio-button-wrapper .jfk-radiobutton-checked .jfk-radiobutton-radio {
    border: 2px solid #4285f4
}
.waffle-printing-radio-button-wrapper .jfk-radiobutton-radio::after {
    background: #4285f4;
    border: none;
    height: 8px;
    left: 2px;
    top: 2px;
    width: 8px
}
.waffle-printing-radio-button-wrapper .jfk-radiobutton-checked.jfk-radiobutton-focused .jfk-radiobutton-radio {
    border: 2px solid #2a56c6
}
.waffle-printing-radio-button-wrapper .jfk-radiobutton-checked.jfk-radiobutton-focused .jfk-radiobutton-radio::after {
    background-color: #2a56c6
}
.waffle-printing-custom-headers-footers-entry-button,
.waffle-printing-page-breaks-entry-button {
    margin-top: 8px;
    margin-left: -8px
}
.waffle-printing-custom-headers-footers-cancel,
.waffle-printing-custom-page-breaks-cancel {
    float: left
}
.waffle-printing-custom-headers-footers-body,
.waffle-printing-custom-page-breaks-body {
    background-color: #d1d1d1;
    bottom: 0;
    left: 0;
    position: absolute;
    overflow: hidden;
    right: 0;
    top: 60px
}
.waffle-printing-custom-headers-footers-overlay {
    background-color: rgba(255, 255, 255, 0.54);
    outline: none;
    position: absolute;
    top: 0;
    left: 0
}
.waffle-printing-custom-headers-footers-content-area {
    color: rgba(0, 0, 0, 0.24);
    font: 36px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    text-align: center;
    overflow: hidden;
    width: 100%
}
.waffle-printing-custom-headers-footers-overlay-group {
    border-spacing: 12px 0;
    direction: ltr;
    position: absolute;
    table-layout: fixed
}
.waffle-printing-custom-headers-footers-section-wrapper {
    width: 33.3333%
}
.waffle-printing-custom-headers-footers-section {
    background-color: white;
    height: 100%;
    overflow: hidden;
    padding: 0 8px;
    -webkit-transition: border-color 0.2s ease;
    -moz-transition: border-color 0.2s ease;
    -o-transition: border-color 0.2s ease;
    transition: border-color 0.2s ease;
    -webkit-user-select: auto;
    -moz-user-select: auto;
    -ms-user-select: auto;
    white-space: nowrap
}
.waffle-printing-custom-headers-footers-section-inactive {
    border: 1px dotted #bdbdbd
}
.waffle-printing-custom-headers-footers-section-inactive:hover {
    border-color: transparent;
    border-bottom: 1px solid rgba(0, 0, 0, .87);
    cursor: pointer
}
.waffle-printing-custom-headers-footers-section-active {
    border-bottom: 2px solid #4285f4
}
.waffle-printing-custom-headers-footers-section-content {
    box-sizing: border-box;
    color: rgba(0, 0, 0, .87);
    height: 100%;
    overflow: hidden
}
.waffle-printing-custom-headers-footers-section-placeholder {
    color: rgba(0, 0, 0, .54)
}
.waffle-printing-custom-header-footer-section-header-left,
.waffle-printing-custom-header-footer-section-footer-left {
    text-align: left
}
.waffle-printing-custom-header-footer-section-header-right,
.waffle-printing-custom-header-footer-section-footer-right {
    text-align: right
}
.waffle-printing-custom-header-footer-section-header-middle,
.waffle-printing-custom-header-footer-section-footer-middle {
    text-align: center
}
.waffle-printing-custom-headers-footers-section:focus,
.waffle-printing-custom-headers-footers-section-content:focus {
    outline: none
}
.waffle-printing-custom-headers-footers-pill {
    -webkit-user-select: all;
    -moz-user-select: all;
    -ms-user-select: all
}
.waffle-printing-custom-headers-footers-pill-select {
    background-color: #fafafa;
    border-radius: 2px;
    box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12), 0 3px 1px -2px rgba(0, 0, 0, 0.2);
    height: 34px;
    min-width: 195px;
    position: absolute;
    z-index: 1003
}
.waffle-printing-custom-headers-footers-pill-select:focus {
    outline: none
}
.waffle-printing-custom-headers-footers-pill-select .goog-toolbar-separator {
    height: 34px;
    margin: 0
}
.waffle-printing-custom-page-breaks-header-middle {
    color: white;
    font: 13px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    margin: 14px 0
}
.waffle-printing-custom-page-breaks-scale {
    display: inline-block;
    margin-right: 8px;
    position: relative;
    top: 1px
}
.waffle-printing-custom-page-breaks-scale .waffle-ellipses {
    padding-left: 4px;
    top: 2px
}
.waffle-printing-custom-page-breaks-scale-label {
    font-weight: 500
}
.waffle-printing-custom-page-breaks-reset {
    margin-left: 8px
}
.waffle-printing-custom-page-breaks-waffle {
    bottom: 0;
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}
.waffle-printing-custom-page-breaks-canvas-wrapper {
    left: 0;
    overflow: hidden;
    position: absolute;
    top: 0;
    z-index: 1
}
.waffle-printing-custom-page-breaks-dragger-container {
    position: absolute
}
.waffle-printing-custom-page-breaks-overlay {
    border: 2px solid #4285f4;
    box-shadow: 0 8px 10px 1px rgba(0, 0, 0, 0.14), 0 3px 14px 3px rgba(0, 0, 0, 0.12), 0 4px 5px 0 rgba(0, 0, 0, 0.20);
    position: absolute
}
.waffle-printing-snapping-dragger,
.waffle-printing-snapping-dragger-handle,
.waffle-printing-snapping-dragger-handle-bar {
    border-width: 0;
    box-sizing: border-box;
    position: absolute
}
.waffle-printing-snapping-dragger-handle-horizontal .waffle-printing-page-breaks-rounded-corner {
    left: -24px;
    top: -11px;
    transform: rotate(-90deg)
}
.waffle-printing-snapping-dragger-rtl .waffle-printing-snapping-dragger-handle-horizontal .waffle-printing-page-breaks-rounded-corner {
    transform: rotate(90deg)
}
.waffle-printing-snapping-dragger-rtl .waffle-printing-snapping-dragger-handle-horizontal .waffle-printing-page-breaks-rounded-corner-ie {
    transform: rotate(-90deg)
}
.waffle-printing-snapping-dragger-handle-vertical .waffle-printing-page-breaks-rounded-corner {
    left: -11px;
    top: -24px
}
.waffle-printing-snapping-dragger-handle-horizontal,
.waffle-printing-snapping-dragger-handle-bar-horizontal {
    height: 5px;
    transform: translateY(-1px)
}
.waffle-printing-snapping-dragger-handle-bar-horizontal {
    border-top: 2px dashed #4285f4;
    cursor: row-resize
}
.waffle-printing-snapping-dragger-handle-vertical,
.waffle-printing-snapping-dragger-handle-bar-vertical {
    transform: translateX(-1px);
    width: 5px
}
.waffle-printing-snapping-dragger-handle-bar-vertical {
    border-left: 2px dashed #4285f4;
    cursor: col-resize
}
.waffle-printing-snapping-dragger-rtl .waffle-printing-snapping-dragger-handle-vertical,
.waffle-printing-snapping-dragger-rtl .waffle-printing-snapping-dragger-handle-bar-vertical {
    transform: translateX(1px)
}
.waffle-printing-hard-break .waffle-printing-snapping-dragger-handle-bar {
    border-style: solid
}
.waffle-printing-snapping-dragger-active .waffle-printing-snapping-dragger-handle-bar,
.waffle-printing-snapping-dragger-highlight .waffle-printing-snapping-dragger-handle-bar {
    border-color: transparent
}
.waffle-printing-page-breaks-rounded-corner,
.waffle-printing-custom-page-breaks-delete {
    display: block;
    position: absolute;
    z-index: 1
}
.waffle-printing-snapping-dragger-hover-bar {
    background: #4285f4;
    border: 1px solid white;
    box-shadow: 0 8px 10px 1px rgba(0, 0, 0, 0.14), 0 3px 14px 3px rgba(0, 0, 0, 0.12), 0 4px 5px 0 rgba(0, 0, 0, 0.20);
    position: absolute;
    display: none
}
.waffle-printing-snapping-dragger-hover .waffle-printing-snapping-dragger-hover-bar,
.waffle-printing-snapping-dragger-active .waffle-printing-snapping-dragger-hover-bar {
    display: block
}
.waffle-printing-snapping-dragger-hover-bar-horizontal {
    border-left: none;
    border-right: none;
    height: 2px;
    left: 0;
    top: -2px;
    width: 100%
}
.waffle-printing-snapping-dragger-hover-bar-vertical {
    border-bottom: none;
    border-top: none;
    height: 100%;
    left: -2px;
    top: 0;
    width: 2px
}
.waffle-printing-custom-page-breaks-delete {
    background-color: transparent;
    border: none;
    box-shadow: none;
    cursor: pointer;
    fill: #4285f4;
    height: 24px;
    margin: 0;
    min-width: 0;
    padding: 0;
    transform: scale(0.4);
    transition: 200ms;
    width: 24px
}
.waffle-printing-custom-page-breaks-delete-horizontal {
    left: -16px;
    top: -13px
}
.waffle-printing-custom-page-breaks-delete-vertical {
    left: -12px;
    top: -17px
}
.waffle-printing-custom-page-breaks-delete .waffle-printing-custom-page-breaks-delete-background {
    fill: #4285f4;
    transition: 200ms
}
.waffle-printing-snapping-dragger-hover .waffle-printing-custom-page-breaks-delete,
.waffle-printing-snapping-dragger-active .waffle-printing-custom-page-breaks-delete {
    fill: #000;
    transform: scale(1.0)
}
.waffle-printing-snapping-dragger-hover .waffle-printing-custom-page-breaks-delete-horizontal,
.waffle-printing-snapping-dragger-active .waffle-printing-custom-page-breaks-delete-horizontal {
    left: -24px;
    top: -12px
}
.waffle-printing-snapping-dragger-hover .waffle-printing-custom-page-breaks-delete-vertical,
.waffle-printing-snapping-dragger-active .waffle-printing-custom-page-breaks-delete-vertical {
    left: -11px;
    top: -24px
}
.waffle-printing-snapping-dragger-hover .waffle-printing-custom-page-breaks-delete-background,
.waffle-printing-snapping-dragger-active .waffle-printing-custom-page-breaks-delete-background {
    opacity: 0.0
}
.waffle-printing-custom-page-breaks-delete-icon {
    background-color: transparent;
    opacity: 0.54;
    transition: 0s
}
.waffle-printing-custom-page-breaks-delete.jfk-button-hover .waffle-printing-custom-page-breaks-delete-icon,
.waffle-printing-custom-page-breaks-delete.jfk-button-focused .waffle-printing-custom-page-breaks-delete-icon {
    opacity: 0.87
}
.waffle-printing-custom-page-breaks-delete.jfk-button-active,
.waffle-printing-custom-page-breaks-delete:active,
.waffle-printing-custom-page-breaks-delete.jfk-button-focused,
.waffle-printing-custom-page-breaks-delete:focus {
    border: none;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    outline: none
}
.waffle-printing-pane .docs-charts-editor-material-menu-button-caption {
    color: rgba(0, 0, 0, .87);
    font-size: 13px
}
.waffle-printing-pane .docs-charts-editor-collapsible-header {
    color: rgba(0, 0, 0, .87);
    font-size: 13px;
    font-weight: normal
}
.waffle-printing-pane .waffle-printing-headers-and-footers-section h2 {
    color: rgba(0, 0, 0, .87);
    font-size: 13px;
    font-weight: normal;
    margin-top: 16px
}
.waffle-printing-pane .waffle-printing-headers-and-footers-section h3 {
    font-weight: normal;
    margin-bottom: 11px;
    margin-top: 9px
}
.waffle-printing-pane-base .docs-material-button-content {
    display: inline-block;
    min-width: 54px
}
.apps-promo {
    z-index: 21
}
.apps-promo-popup {
    width: 300px
}
.apps-promo-buttons {
    display: none
}
#waffle-promo-button .goog-custom-button-inner-box {
    font-weight: 500
}
.waffle-promo {
    background: #188038!important;
    border-radius: 8px!important;
    box-shadow: 0px 2px 6px rgba(60, 64, 67, 0.15), 0px 1px 2px rgba(0, 64, 67, 0.3)!important;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif!important;
    width: 300px!important
}
.waffle-promo .docs-promo-container {
    padding: 24px!important
}
.waffle-promo .docs-promo-text-container {
    width: 252px!important
}
.waffle-promo .docs-promo-header {
    color: #fff!important;
    font-weight: 700
}
.waffle-promo .docs-promo-body {
    color: #fff!important;
    padding-top: 8px
}
.waffle-promo .docs-promo-action-row {
    padding-top: 16px;
    padding-right: 0;
    padding-bottom: 0
}
.waffle-promo .docs-promo-action-container {
    color: #fff!important;
    font-weight: 500;
    text-transform: lowercase;
    display: inline-block
}
.waffle-promo .docs-promo-action-container::first-letter {
    text-transform: uppercase
}
.waffle-promo .jfk-bubble-arrowdown .jfk-bubble-arrowimplbefore,
.waffle-promo .jfk-bubble-arrowdown .jfk-bubble-arrowimplafter,
.waffle-promo .jfk-bubble-arrowup .jfk-bubble-arrowimplbefore,
.waffle-promo .jfk-bubble-arrowup .jfk-bubble-arrowimplafter {
    border-color: #188038 transparent!important
}
.waffle-promo .jfk-bubble-arrowleft .jfk-bubble-arrowimplbefore,
.waffle-promo .jfk-bubble-arrowleft .jfk-bubble-arrowimplafter,
.waffle-promo .jfk-bubble-arrowright .jfk-bubble-arrowimplbefore,
.waffle-promo .jfk-bubble-arrowright .jfk-bubble-arrowimplafter {
    border-color: transparent #188038!important
}
.waffle-shortcut-override-inside-promo {
    border: 240px solid #0f9d58;
    border-radius: 100%;
    bottom: -260px;
    height: 95px;
    position: absolute;
    right: 60px;
    width: 95px;
    background-color: #fff;
    z-index: 500
}
.waffle-legacy-shortcut-override-inside-promo {
    border-radius: 100%;
    bottom: -20px;
    box-shadow: 175px 0 0 190px #0f9d58;
    height: 90px;
    position: absolute;
    right: 435px;
    width: 80px;
    z-index: 500
}
[dir="rtl"] .waffle-legacy-shortcut-override-inside-promo {
    box-shadow: -175px 0 0 190px #0f9d58;
    left: 220px
}
.waffle-shortcut-override-inside-promo-content,
.waffle-legacy-shortcut-override-inside-promo-content {
    color: white;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    left: -100px;
    line-height: 22px;
    position: absolute;
    text-align: left;
    top: -125px;
    width: 275px
}
.waffle-legacy-shortcut-override-inside-promo-content {
    left: 100px
}
.waffle-legacy-shortcut-override-dismiss-button {
    cursor: pointer;
    color: white;
    font: 500 15px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    margin: 25px 0 0 0;
    min-width: 0;
    outline: none;
    padding: 0;
    right: 5px;
    text-transform: uppercase;
    width: 0
}
.waffle-shortcut-override-inside-promo-header {
    font: 500 21px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    line-height: 27px;
    margin-bottom: 16px
}
.waffle-shortcut-override-inside-promo-description {
    font-size: 15px;
    opacity: 0.87
}
.apps-ui-material-slide-toggle-container {
    z-index: 1000
}
.waffle-shortcut-override-outside-promo {
    background-color: #fafafa;
    bottom: 80px;
    box-shadow: rgba(255, 255, 255, .9) 0 1px 0 inset, rgba(0, 0, 0, .03) 0 -1px 0 inset, rgba(0, 0, 0, .15) 0 15px 10px, rgba(0, 0, 0, .3) 0 8px 36px;
    position: absolute;
    right: 40px;
    width: 380px;
    z-index: 1000
}
.waffle-shortcut-override-outside-promo-header {
    font-size: 16px;
    font-weight: 500;
    opacity: 0.87;
    padding: 22px 25px 0 25px
}
.waffle-shortcut-override-outside-promo-description {
    color: #666;
    line-height: 20px;
    padding: 15px 25px
}
.waffle-shortcut-override-outside-promo-button-container {
    padding: 0 24px 16px;
    text-align: right
}
.waffle-shortcut-override-outside-promo-continue-button,
.waffle-shortcut-override-outside-promo-dismiss-button {
    align-items: center;
    cursor: pointer;
    display: inline-flex;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    justify-content: center;
    text-transform: uppercase
}
.waffle-shortcut-override-outside-promo-continue-button {
    background-color: #4285f4;
    color: white;
    padding: 6px 15px
}
.waffle-shortcut-override-outside-promo-dismiss-button {
    color: #4285f4;
    margin-right: 16px
}
.waffle-sidebar-container {
    border-left: 1px solid #d9d9d9;
    outline: none;
    position: absolute;
    right: 0;
    top: 0;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    width: 250px
}
.docs-gm-sidebars .waffle-gm-sidebar.waffle-sidebar-container {
    overflow: hidden;
    box-shadow: -3px 0px 6px -3px rgba(60, 64, 67, .15), 3px 0px 6px -3px rgba(60, 64, 67, .15);
    border-left: 0;
    width: 300px
}
.waffle-sidebar-content {
    background-color: #fff;
    font-size: 100%;
    overflow-x: hidden;
    overflow-y: auto;
    position: relative
}
.waffle-sidebar-footer-container {
    bottom: 0;
    position: absolute;
    width: 100%
}
.waffle-sidebar-header-container {
    width: 100%
}
.waffle-sidebar-spinner-container {
    background-color: #fff;
    height: 100%;
    position: absolute;
    width: 100%
}
.waffle-sidebar-spinner-container>.waffle-spinner {
    left: 50%;
    margin-left: -14px;
    margin-top: -14px;
    position: absolute;
    top: 50%
}
.waffle-sidebar-title {
    background: #616161;
    color: white;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    padding: 10px 12px 10px 12px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-sidebar-title {
    display: flex;
    align-items: center;
    color: #202124;
    background-color: #fff;
    height: 56px;
    padding: 0 16px;
    border-bottom: 1px solid #dadce0;
    border-top: 1px solid #dadce0;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px;
    z-index: 1
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-sidebar-title-text {
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 16px;
    font-weight: 500;
    line-height: 24px;
    position: relative;
    left: auto
}
.waffle-sidebar-title-close.docs-sidebar-close-button {
    cursor: pointer;
    position: absolute;
    right: 5px;
    top: 7px
}
.docs-gm-sidebars .waffle-gm-sidebar .jfk-textinput {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    color: #3c4043;
    padding: 1px 8px;
    font-size: 14px;
    height: 36px;
    margin: 8px 0
}
.docs-gm-sidebars .waffle-gm-sidebar .jfk-textinput:focus {
    border: 2px solid #1a73e8;
    box-shadow: none;
    padding: 0px 7px
}
.docs-gm-sidebars .jfk-select .goog-flat-menu-button-dropdown {
    margin-top: 0px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-range-selection-button {
    line-height: 25px
}
.docs-gm-sidebars .goog-flat-menu-button.jfk-select {
    padding-left: 8px!important
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-range-selection-button,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-range-selection-button:hover,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-range-selection-button:focus {
    opacity: 1
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-range-selection-holder .docs-icon-grid,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-range-selection-holder .docs-icon-grid:before,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-sidebar-title .docs-gm-sidebar-icon .docs-icon-sheets-table-24,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-sidebar-title .docs-gm-sidebar-icon .docs-icon-sheets-table-24:before {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_green.svg)
}
.docs-gm-sidebars .waffle-gm-sidebar .goog-flat-menu-button {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    cursor: pointer;
    padding: 8px 6px 8px 8px;
    width: 100%;
    align-items: center;
    background: none;
    box-sizing: border-box;
    color: #3c4043;
    display: inline-flex;
    justify-content: space-between;
    outline: none;
    position: relative;
    width: auto;
    width: unset
}
.docs-gm-sidebars .waffle-gm-sidebar .goog-flat-menu-button-disabled {
    color: #5f6368;
    opacity: .38;
    cursor: default
}
.docs-gm-sidebars .waffle-gm-sidebar .goog-flat-menu-button:active {
    background-color: #fff;
    border: 1px solid transparent;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.docs-gm-sidebars .waffle-gm-sidebar .goog-flat-menu-button-hover {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid #dadce0;
    box-shadow: none
}
.docs-gm-sidebars .waffle-gm-sidebar .goog-flat-menu-button-focused {
    background-color: rgba(60, 64, 67, 0.06);
    border: 1px solid #dadce0
}
.docs-gm-sidebars .waffle-gm-sidebar .goog-flat-menu-button-open {
    background-color: rgba(60, 64, 67, 0.04);
    border: 1px solid transparent
}
.docs-gm-sidebars .waffle-gm-sidebar .goog-flat-menu-button-hover.goog-flat-menu-button-open {
    background-color: rgba(60, 64, 67, 0.06)
}
.docs-gm-sidebars .waffle-gm-sidebar .goog-flat-menu-button-focused.goog-flat-menu-button-open {
    background-color: rgba(60, 64, 67, 0.08)
}
.docs-gm-sidebars .waffle-gm-sidebar .goog-flat-menu-button-disabled {
    border: 1px solid #dadce0;
    cursor: default
}
.docs-gm-sidebars .waffle-gm-sidebar .goog-flat-menu-button-caption {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    color: #202124;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    height: 20px;
    line-height: 20px;
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.docs-gm-sidebars .waffle-gm-sidebar .goog-flat-menu-button-dropdown {
    background: no-repeat url(//ssl.gstatic.com/docs/common/material_common_sprite134_grey_medium.svg) 0 -1364px;
    height: 18px;
    width: 18px;
    border: none;
    margin-top: 0;
    position: relative;
    right: 0;
    top: 0
}
.docs-gm-sidebars .waffle-gm-sidebar .goog-flat-menu-button-open .goog-flat-menu-button-dropdown {
    -moz-transform: rotate(180deg);
    -webkit-transform: rotate(180deg);
    -ms-transform: rotate(180deg);
    transform: rotate(180deg)
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-flatcolormenubutton .goog-flat-menu-button-caption {
    height: 22px;
    width: 22px;
    border-radius: 50%;
    border: 1px solid #dadce0;
    margin: 0;
    outline: none
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-flatcolormenubutton.goog-flat-menu-button {
    padding: 6px 0 6px 6px
}
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-action {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff
}
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-action.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #2a8947;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-action.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #4f9e67;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-action.jfk-button-hover.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15)
}
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-action.jfk-button-active,
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-action.jfk-button-focus.jfk-button-active {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 2px 6px 2px rgba(52, 168, 83, 0.15)
}
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-action.jfk-button-disabled {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #f1f3f4;
    color: #3c4043;
    opacity: 0.38
}
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-standard {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #dadce0!important;
    color: #188038
}
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-standard.jfk-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #f8fcf9;
    border: 1px solid #c8e7d1!important
}
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-standard.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #e7f5eb;
    border: 1px solid #bbe2c6!important
}
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-standard.jfk-button-hover.jfk-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    border: 1px solid #b5e0c1!important
}
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-standard.jfk-button-active,
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-standard.jfk-button-focus.jfk-button-active {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    border: 1px solid transparent!important;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-standard.jfk-button-disabled {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #f1f3f4!important;
    color: #3c4043;
    opacity: 0.38
}
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-standard.waffle-range-selection-button,
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-standard.jfk-button-hover.waffle-range-selection-button,
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-standard.jfk-button-focused.waffle-range-selection-button,
.docs-gm-sidebars .waffle-gm-sidebar .jfk-button-standard.jfk-button-hover.jfk-button-focused.waffle-range-selection-button {
    border: none!important;
    padding: 8px 0px 0px!important
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-sidebar-toggle-tabs {
    background-color: white;
    border-bottom: 0;
    height: 40px;
    margin-top: 0;
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-sidebar-toggle-tabs .jfk-button.docs-sidebar-toggle-tab>div {
    display: inline-block;
    position: relative
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-sidebar-toggle-tabs .jfk-button.docs-sidebar-toggle-tab-active {
    color: #188038;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    text-transform: none;
    border-bottom: none;
    line-height: calc(40px - 8px);
    height: calc(40px - 8px);
    margin-top: 8px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-sidebar-toggle-tabs .jfk-button.docs-sidebar-toggle-tab-inactive {
    color: #5f6368;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    text-transform: none;
    border-bottom: none;
    line-height: calc(40px - 8px);
    height: calc(40px - 8px);
    margin-top: 8px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-sidebar-toggle-tabs .jfk-button.docs-sidebar-toggle-tab-inactive:hover {
    color: #202124;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    text-transform: none;
    border-bottom: none;
    line-height: calc(40px - 8px);
    height: calc(40px - 8px);
    margin-top: 8px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-sidebar-toggle-tabs .jfk-button.docs-sidebar-toggle-tab-active>div:after {
    border-bottom: 3px solid #188038;
    border-radius: 3px 3px 0 0;
    bottom: 0;
    content: '';
    display: block;
    height: 0;
    left: -4px;
    position: absolute;
    width: calc(100% + 8px)
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-sidebar-toggle-tabs .jfk-button-focused.docs-sidebar-toggle-tab-inactive>div:after {
    border-bottom: 3px dotted #188038;
    border-radius: 3px 3px 0 0;
    bottom: 0;
    content: '';
    display: block;
    height: 0;
    left: -4px;
    position: absolute;
    width: calc(100% + 8px)
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-sidebar-toggle-tabs .jfk-button-active.jfk-button-focused.docs-sidebar-toggle-tab-inactive>div:after {
    border-top: none
}
.waffle-slicer-overlay,
.waffle-embedded-object-container,
.waffle-slicer-container {
    border-radius: 20px
}
.waffle-slicer-container {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    direction: ltr;
    height: inherit;
    min-height: 100%;
    min-width: 100%
}
.waffle-slicer-filter-box-container .goog-menu-filter {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center
}
.waffle-slicer-filter-box-container .waffle-filterbox-input {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    margin-right: 0px!important
}
.waffle-slicer-filter-box-container .waffle-filterbox-input-icon {
    height: 18px;
    margin: 0 5px 0 0;
    position: absolute;
    right: 20px;
    width: 18px
}
.waffle-slicer-filter-box-container .waffle-filterbox-label-icon-jfk {
    display: none
}
.waffle-slicer-filter-box-container .waffle-filterbox-content {
    height: auto!important;
    margin: 3px 0;
    max-height: 320px
}
.waffle-slicer-filter-box-container .goog-menuitem .goog-menuitem-content {
    margin: 0 6px
}
.waffle-slicer-filter-container {
    -webkit-box-shadow: 0px 1px 1px 0px rgba(0, 0, 0, 0.14), 0px 2px 1px -1px rgba(0, 0, 0, 0.12), 0px 1px 3px 0px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 1px 1px 0px rgba(0, 0, 0, 0.14), 0px 2px 1px -1px rgba(0, 0, 0, 0.12), 0px 1px 3px 0px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 1px 1px 0px rgba(0, 0, 0, 0.14), 0px 2px 1px -1px rgba(0, 0, 0, 0.12), 0px 1px 3px 0px rgba(0, 0, 0, 0.2);
    background: white;
    direction: ltr;
    margin-top: 4px;
    overflow-y: auto;
    padding-top: 8px;
    position: absolute;
    right: 0;
    left: 0;
    z-index: 1000
}
.waffle-slicer-filter-container {
    border-radius: 8px
}
.waffle-slicer-icon-container {
    height: 24px;
    padding: 5px
}
.waffle-slicer-icon-filtered {
    border-radius: 50%
}
.waffle-slicer-row {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    margin: 0 30px 0 5px;
    overflow: hidden
}
.waffle-slicer-row-enabled {
    cursor: pointer
}
.waffle-slicer-header {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    max-height: 100%;
    overflow: hidden
}
.waffle-slicer-title-container {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    margin: 0 10px;
    overflow: hidden;
    padding: 2px 0;
    text-overflow: ellipsis;
    white-space: nowrap
}
.waffle-slicer-status-container {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-flex-shrink: 1;
    -ms-flex-negative: 1;
    flex-shrink: 1;
    border-radius: 10%;
    max-width: 100px;
    overflow: hidden;
    padding: 2px 5px 2px 10px;
    text-overflow: ellipsis;
    white-space: nowrap
}
.waffle-slicer-status-icon-container {
    -webkit-align-items: center;
    align-items: center;
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1
}
.waffle-slicer-icon-container:hover {
    border-radius: 50%
}
.waffle-slicer-filter-box-container .waffle-conditionalformat-condition-type-select .goog-flat-menu-button,
.waffle-slicer-filter-box-container .waffle-conditionalformat-condition-date-select .goog-flat-menu-button,
.waffle-slicer-filter-box-container .waffle-conditionalformat-range-args-holder {
    width: 100%
}
.waffle-slicer-filter-box-container .waffle-conditionalformat-range-args-holder .waffle-conditionalformat-arg1 {
    margin-right: 0;
    padding: 10px;
    width: 100%
}
.waffle-slicer-filter-box-container .waffle-conditionalformat-arg-separator {
    margin: 0 5px
}
.waffle-slicer-filter-box-container .waffle-conditionalformat-range-args-holder .waffle-conditionalformat-arg2 {
    padding: 10px
}
.waffle-slicer-help-icon-container {
    margin: 0 3px 0 3px;
    padding: 5px;
    background-color: transparent
}
.waffle-spinner {
    display: inline-block;
    position: relative;
    width: 28px;
    height: 28px
}
.waffle-spinner-message-container {
    position: absolute;
    width: 0;
    height: 0;
    overflow: hidden
}
.waffle-spinner-container {
    width: 100%;
    height: 100%
}
.waffle-spinner.waffle-spinner-active .waffle-spinner-container {
    -webkit-animation: waffle-spinner-container-rotate 1568ms linear infinite;
    animation: waffle-spinner-container-rotate 1568ms linear infinite
}
.waffle-spinner-layer {
    position: absolute;
    width: 100%;
    height: 100%;
    opacity: 0
}
.waffle-spinner-color-one {
    border-color: #4285f4
}
.waffle-spinner-color-two {
    border-color: #db4437
}
.waffle-spinner-color-three {
    border-color: #f4b400
}
.waffle-spinner-color-four {
    border-color: #0f9d58
}
.waffle-spinner.waffle-spinner-active .waffle-spinner-layer.waffle-spinner-color-one {
    -webkit-animation: waffle-spinner-fill-unfill-rotate 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both, waffle-spinner-blue-fade-in-out 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both;
    animation: waffle-spinner-fill-unfill-rotate 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both, waffle-spinner-blue-fade-in-out 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both
}
.waffle-spinner.waffle-spinner-active .waffle-spinner-layer.waffle-spinner-color-two {
    -webkit-animation: waffle-spinner-fill-unfill-rotate 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both, waffle-spinner-red-fade-in-out 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both;
    animation: waffle-spinner-fill-unfill-rotate 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both, waffle-spinner-red-fade-in-out 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both
}
.waffle-spinner.waffle-spinner-active .waffle-spinner-layer.waffle-spinner-color-three {
    -webkit-animation: waffle-spinner-fill-unfill-rotate 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both, waffle-spinner-yellow-fade-in-out 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both;
    animation: waffle-spinner-fill-unfill-rotate 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both, waffle-spinner-yellow-fade-in-out 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both
}
.waffle-spinner.waffle-spinner-active .waffle-spinner-layer.waffle-spinner-color-four {
    -webkit-animation: waffle-spinner-fill-unfill-rotate 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both, waffle-spinner-green-fade-in-out 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both;
    animation: waffle-spinner-fill-unfill-rotate 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both, waffle-spinner-green-fade-in-out 5332ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both
}
.waffle-spinner-gap-patch {
    position: absolute;
    box-sizing: border-box;
    top: 0;
    left: 45%;
    width: 10%;
    height: 100%;
    overflow: hidden;
    border-color: inherit
}
.waffle-spinner-gap-patch .waffle-spinner-circle {
    width: 1000%;
    left: -450%
}
.waffle-spinner-circle-clipper {
    display: inline-block;
    position: relative;
    width: 50%;
    height: 100%;
    overflow: hidden;
    border-color: inherit
}
.waffle-spinner-circle-clipper .waffle-spinner-circle {
    width: 200%
}
.waffle-spinner-circle {
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    box-sizing: border-box;
    height: 100%;
    border-width: 3px;
    border-style: solid;
    border-color: inherit;
    border-bottom-color: transparent;
    border-radius: 50%;
    -webkit-animation: none;
    animation: none
}
.waffle-spinner-circle-clipper.waffle-spinner-left .waffle-spinner-circle {
    border-right-color: transparent;
    -webkit-transform: rotate(129deg);
    transform: rotate(129deg)
}
.waffle-spinner-circle-clipper.waffle-spinner-right .waffle-spinner-circle {
    left: -100%;
    border-left-color: transparent;
    -webkit-transform: rotate(-129deg);
    transform: rotate(-129deg)
}
.waffle-spinner.waffle-spinner-active .waffle-spinner-circle-clipper.waffle-spinner-left .waffle-spinner-circle {
    -webkit-animation: waffle-spinner-left-spin 1333ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both;
    animation: waffle-spinner-left-spin 1333ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both
}
.waffle-spinner.waffle-spinner-active .waffle-spinner-circle-clipper.waffle-spinner-right .waffle-spinner-circle {
    -webkit-animation: waffle-spinner-right-spin 1333ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both;
    animation: waffle-spinner-right-spin 1333ms cubic-bezier(0.4, 0.0, 0.2, 1) infinite both
}
.waffle-spinner.waffle-spinner-isWarmdown .waffle-spinner-container {
    -webkit-animation: waffle-spinner-container-rotate 1568ms linear infinite, waffle-spinner-fade-out 400ms cubic-bezier(0.4, 0.0, 0.2, 1);
    animation: waffle-spinner-container-rotate 1568ms linear infinite, waffle-spinner-fade-out 400ms cubic-bezier(0.4, 0.0, 0.2, 1)
}
@keyframes waffle-spinner-container-rotate {
    to {
        transform: rotate(360deg)
    }
}
@keyframes waffle-spinner-fill-unfill-rotate {
    12.5% {
        transform: rotate(135deg)
    }
    25% {
        transform: rotate(270deg)
    }
    37.5% {
        transform: rotate(405deg)
    }
    50% {
        transform: rotate(540deg)
    }
    62.5% {
        transform: rotate(675deg)
    }
    75% {
        transform: rotate(810deg)
    }
    87.5% {
        transform: rotate(945deg)
    }
    to {
        transform: rotate(1080deg)
    }
}
@keyframes waffle-spinner-blue-fade-in-out {
    from {
        opacity: 0.99
    }
    25% {
        opacity: 0.99
    }
    26% {
        opacity: 0
    }
    89% {
        opacity: 0
    }
    90% {
        opacity: 0.99
    }
    100% {
        opacity: 0.99
    }
}
@keyframes waffle-spinner-red-fade-in-out {
    from {
        opacity: 0
    }
    15% {
        opacity: 0
    }
    25% {
        opacity: 0.99
    }
    50% {
        opacity: 0.99
    }
    51% {
        opacity: 0
    }
}
@keyframes waffle-spinner-yellow-fade-in-out {
    from {
        opacity: 0
    }
    40% {
        opacity: 0
    }
    50% {
        opacity: 0.99
    }
    75% {
        opacity: 0.99
    }
    76% {
        opacity: 0
    }
}
@keyframes waffle-spinner-green-fade-in-out {
    from {
        opacity: 0
    }
    65% {
        opacity: 0
    }
    75% {
        opacity: 0.99
    }
    90% {
        opacity: 0.99
    }
    100% {
        opacity: 0
    }
}
@keyframes waffle-spinner-left-spin {
    from {
        transform: rotate(130deg)
    }
    50% {
        transform: rotate(-5deg)
    }
    to {
        transform: rotate(130deg)
    }
}
@keyframes waffle-spinner-right-spin {
    from {
        transform: rotate(-130deg)
    }
    50% {
        transform: rotate(5deg)
    }
    to {
        transform: rotate(-130deg)
    }
}
@keyframes waffle-spinner-fade-out {
    from {
        opacity: 0.99
    }
    to {
        opacity: 0
    }
}
.row-header-wrapper {
    overflow: hidden;
    border-width: 0;
    margin: 0;
    padding: 0
}
.column-headers-background,
.row-headers-background {
    z-index: 1
}
.selected-row-headers-background {
    position: absolute;
    background-color: #c8c8c8;
    width: 45px;
    z-index: 2
}
.selected-column-headers-background {
    position: absolute;
    background-color: #c8c8c8;
    height: 23px;
    z-index: 2
}
.waffle td,
.grid-fixed-table td {
    overflow: hidden;
    border: 1px #e5e5e5 solid;
    border-color: rgba(0, 0, 0, 0.15);
    border-width: 0 1px 1px 0;
    vertical-align: bottom;
    line-height: inherit;
    background-color: #fff;
    padding: 0 3px
}
.waffle .softmerge {
    overflow: visible
}
.softmerge-inner {
    white-space: nowrap;
    overflow: hidden;
    text-overflow: hidden;
    position: relative
}
.waffle-ltr td,
.grid-fixed-table-ltr td {
    border-width: 0 1px 1px 0
}
.waffle-rtl td,
.grid-fixed-table-rtl td {
    border-width: 0 0 1px 1px
}
.waffle th,
.grid-fixed-table th {
    font-weight: normal;
    background: transparent;
    text-align: center;
    vertical-align: middle;
    font-size: 8pt;
    color: #222;
    height: 23px;
    border: solid 1px #ccc;
    border-width: 0 1px 1px 0;
    overflow: hidden;
    padding: 0
}
.waffle-ltr th,
.grid-fixed-table-ltr th {
    border-width: 0 1px 1px 0
}
.waffle-rtl th,
.grid-fixed-table-rtl th {
    border-width: 0 0 1px 1px
}
.no-grid td {
    border: solid 1px rgb(255, 255, 255);
    border: solid 1px rgba(204, 204, 204, 0);
    border-width: 0 1px 1px 0
}
td.empty {
    font-size: 0!important
}
th.row-header {
    background-color: #eee;
    width: 45px;
    text-align: center;
    vertical-align: middle;
    font-size: 8pt;
    color: #333;
    line-height: inherit;
    overflow: hidden
}
th.tall-row,
td.tall-row {
    vertical-align: top
}
th.row-header-shim,
td.row-header-shim {
    width: 0;
    margin: 0;
    overflow: hidden
}
div.column-headers-background {
    position: absolute;
    height: 23px;
    background: #eee
}
th.column-headers-background {
    background: #eee;
    position: relative
}
div.row-headers-background {
    position: absolute;
    width: 45px;
    background: #eee
}
th.row-headers-background {
    background: #eee;
    position: relative
}
tr.column-header-row {
    height: 23px
}
th.selected,
td.selected {
    background-color: #c8c8c8;
    border-bottom: 1px solid #9fc2fd
}
td.header-shim,
th.header-shim {
    border-width: 0 1px 0 0;
    height: 0;
    margin: 0
}
td.freezebar-cell,
th.freezebar-cell {
    border-color: #dadfe8!important;
    background-color: #dadfe8;
    padding: 0;
    border-width: 0
}
th.freezebar-origin-rtl {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -305px -62px
}
th.freezebar-origin-ltr {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -205px 0
}
th.freezebar-origin-ltr,
th.freezebar-origin-rtl {
    background-color: #eee;
    position: relative
}
th.frozen-column-cell {
    width: 4px
}
td.freezebar-hidden,
th.freezebar-hidden {
    height: 0px;
    width: 0px;
    display: none
}
td.frozen-row-cell,
th.frozen-row-cell {
    height: 4px
}
.grid-fixed-table tr {
    height: 10px
}
.docs-gm .row-header,
.docs-gm .row-header-shim {
    background: #f8f9fa
}
.docs-gm div.column-headers-background,
.docs-gm th.column-headers-background,
.docs-gm div.row-headers-background,
.docs-gm th.row-headers-background {
    background: #f8f9fa;
    color: #5f6368;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.waffle-current-theme {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    line-height: 16px;
    padding-left: 15px
}
.waffle-current-theme-bar {
    background: #fff;
    border-bottom: 1px solid #dadce0;
    z-index: 1
}
.waffle-current-theme-bar-shadow {
    -webkit-box-shadow: 0px 1px 1px 0px rgba(0, 0, 0, 0.14), 0px 2px 1px -1px rgba(0, 0, 0, 0.12), 0px 1px 3px 0px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 1px 1px 0px rgba(0, 0, 0, 0.14), 0px 2px 1px -1px rgba(0, 0, 0, 0.12), 0px 1px 3px 0px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 1px 1px 0px rgba(0, 0, 0, 0.14), 0px 2px 1px -1px rgba(0, 0, 0, 0.12), 0px 1px 3px 0px rgba(0, 0, 0, 0.2)
}
.waffle-current-theme-common-content {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -webkit-align-items: center;
    align-items: center
}
.waffle-current-theme-preview {
    padding-bottom: 20px
}
.waffle-current-theme-title-section {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    margin: 16px 0;
    overflow: hidden
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-current-theme-title-section {
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.waffle-custom-theme-warning-message {
    background: #f4f4f4;
    height: 32px;
    margin: auto;
    padding: 10px
}
.waffle-theme-thumbnail.waffle-theme-active {
    -webkit-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    border: 1px solid #34a853
}
.waffle-theme-button {
    outline: none
}
.waffle-theme-container-element {
    background: #fff;
    padding-top: 16px;
    outline: none
}
.waffle-theme-container-element-focus .waffle-theme-thumbnail {
    border-color: #1a73e8
}
.waffle-theme-editor-content {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex-direction: column;
    -webkit-flex-direction: column;
    flex-direction: column;
    height: 100%
}
.waffle-theme-editor-send-feedback-container {
    text-align: end;
    padding: 10px
}
.waffle-theme-editor-themes-container {
    overflow: auto
}
.waffle-theme-edit-panel-color {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    margin: 5px 0
}
.waffle-theme-edit-panel-color-text {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    line-height: 40px;
    overflow: hidden;
    text-overflow: ellipsis
}
.waffle-theme-edit-panel-font-family {
    margin-top: 5px;
    margin-bottom: 25px
}
.waffle-theme-editor-edit-panel {
    overflow: auto;
    padding: 25px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-theme-editor-edit-panel {
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.waffle-theme-edit-panel-color-picker {
    height: 32px;
    margin: auto
}
.waffle-theme-edit-panel-title {
    font-weight: 500;
    overflow: hidden;
    text-overflow: ellipsis
}
.waffle-theme-title {
    color: #3c4043;
    font-weight: 500;
    line-height: 32px;
    overflow: hidden;
    padding: 0px 15px;
    text-overflow: ellipsis;
    white-space: nowrap
}
.waffle-theme-title.waffle-current-theme-title {
    line-height: 20px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-theme-title {
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.waffle-theme-thumbnail {
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
    cursor: pointer;
    border: 1px solid #dadce0;
    height: 154px;
    margin: auto;
    width: 250px
}
.waffle-filterbox-container {
    padding-top: 4px;
    padding-bottom: 0;
    width: 300px
}
.waffle-filtermenu {
    background-color: #fff;
    padding-left: 17px;
    padding-right: 20px;
    letter-spacing: 0.2px
}
.waffle-filterbox-boolean-condition-picker {
    background-color: #fff;
    padding-left: 17px;
    padding-right: 20px;
    letter-spacing: 0.2px
}
.waffle-filterbox-with-condition:focus {
    outline: none
}
.waffle-autofilter-sort {
    padding-left: 20px;
    margin: 3px 0px 3px 0px
}
.waffle-autofilter-sort.waffle-datasourcesheet-sort-selected {
    background-color: #e8eaed
}
.docs-gm .goog-menu.waffle-datasourcesheet-filterbox-container .goog-menuitem {
    padding-left: 17px
}
.docs-gm .waffle-datasourcesheet-filterbox-container .goog-menuseparator {
    margin-left: 17px;
    margin-right: 20px
}
.docs-gm-dialogs .waffle-filterbox-container.waffle-datasourcesheet-filterbox-container .waffle-conditionalformat-condition-type-select .goog-flat-menu-button {
    width: 100%
}
.waffle-filterbox-content {
    padding: 3px 8px 2px 8px
}
.waffle-filterbox-content>.goog-menuitem {
    padding: 6px 0px 6px 22px
}
.waffle-filterbox-label {
    margin-top: 15px;
    margin-bottom: 13px
}
.waffle-filterbox-with-condition .waffle-filterbox-label {
    margin-top: 0
}
.waffle-filterbox-label-icon-jfk {
    background: none;
    float: right
}
.waffle-filterbox-button-container {
    padding: 14px 0 14px 20px
}
.docs-gm-dialogs .waffle-filterbox-button-container {
    text-align: right
}
.waffle-filterbox-with-condition {
    overflow-y: auto
}
.waffle-filterbox-input-icon {
    background: none
}
.waffle-action-menu {
    max-height: 400px;
    overflow: auto
}
.waffle-recording-toast {
    background-color: #fff;
    border-bottom: 1px solid rgba(0, 0, 0, 0.14);
    border-radius: 2px;
    bottom: 52px;
    -webkit-box-shadow: 1px 1px 8px 0 rgba(0, 0, 0, 0.4);
    -moz-box-shadow: 1px 1px 8px 0 rgba(0, 0, 0, 0.4);
    box-shadow: 1px 1px 8px 0 rgba(0, 0, 0, 0.4);
    color: #3c4043;
    font: 14px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    outline: none;
    position: absolute
}
.docs-gm-dialogs .waffle-recording-toast {
    border-radius: 8px;
    box-shadow: 0 4px 8px 3px rgba(60, 64, 67, .15)
}
.waffle-recording-toast-top {
    height: 64px;
    min-width: 454px;
    overflow: hidden;
    position: relative
}
.waffle-recording-toast-bottom {
    background-color: #f8f9fa;
    border-top: 1px solid rgba(0, 0, 0, 0.14);
    color: #3c4043;
    box-sizing: border-box;
    font-size: 14px;
    font-weight: 500;
    width: 100%
}
.docs-gm-dialogs .waffle-recording-toast-bottom {
    background-color: #fff;
    border-radius: 0 0 8px 8px
}
.docs-gm-dialogs .waffle-recording-toast-relativity-split .jfk-radiobutton {
    max-width: 232px;
    padding: 12px 12px
}
.waffle-recording-toast-new-content.waffle-recording-toast-slide-in {
    -webkit-animation: waffle-recording-toast-new-message 2.1s cubic-bezier(0.4, 0, 0.2, 1) forwards;
    -moz-animation: waffle-recording-toast-new-message 2.1s cubic-bezier(0.4, 0, 0.2, 1) forwards;
    -o-animation: waffle-recording-toast-new-message 2.1s cubic-bezier(0.4, 0, 0.2, 1) forwards;
    animation: waffle-recording-toast-new-message 2.1s cubic-bezier(0.4, 0, 0.2, 1) forwards;
    opacity: 1
}
.waffle-recording-toast-new-content {
    overflow: hidden;
    position: absolute;
    text-overflow: ellipsis;
    top: -42px;
    white-space: nowrap
}
@keyframes waffle-recording-toast-new-message {
    0% {
        top: -42px
    }
    14%,
    86% {
        top: 0
    }
    100% {
        top: 42px
    }
}
.waffle-recording-toast-content {
    display: inline-block;
    height: 64px;
    line-height: 64px;
    margin: 0 4px 0 16px
}
.waffle-recording-toast-content,
.waffle-recording-toast-new-content,
.waffle-recording-toast-default-content {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    width: 205px
}
.waffle-recording-toast-default-content {
    opacity: 1;
    -webkit-transition: opacity 0.3s cubic-bezier(0.4, 0, 0.2, 1);
    -moz-transition: opacity 0.3s cubic-bezier(0.4, 0, 0.2, 1);
    -o-transition: opacity 0.3s cubic-bezier(0.4, 0, 0.2, 1);
    transition: opacity 0.3s cubic-bezier(0.4, 0, 0.2, 1)
}
.waffle-recording-toast-relativity-split {
    width: 50%;
    display: inline-block;
    vertical-align: top
}
.waffle-recording-toast-relativity-split .jfk-radiobutton {
    max-width: 200px;
    padding: 12px 8px
}
.waffle-recording-toast-label-description {
    color: #3c4043;
    font-size: 12px;
    font-weight: normal;
    margin-top: 4px
}
.waffle-recording-toast-right {
    float: right
}
.waffle-recording-toast-expand-section {
    display: inline-block;
    border-left: 1px solid rgba(0, 0, 0, 0.14);
    box-sizing: border-box;
    height: 64px;
    padding: 20px 5px;
    vertical-align: bottom
}
.waffle-recording-toast-expand {
    border: none;
    border-radius: 2px;
    display: inline-block;
    outline: none;
    padding: 3px
}
.waffle-recording-toast .goog-flat-button {
    background-color: transparent;
    border: none;
    border-radius: 2px;
    color: #5f6368;
    display: inline-block;
    font: 14px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    height: 16px;
    margin: 14px 0;
    padding: 10px
}
.waffle-recording-toast-cancel,
.waffle-recording-toast-stop {
    text-transform: uppercase
}
.docs-gm-dialogs .waffle-recording-toast-cancel,
.docs-gm-dialogs .waffle-recording-toast-stop {
    text-transform: none
}
.waffle-recording-toast .waffle-recording-toast-stop {
    margin: 14px 16px
}
.waffle-recording-toast-close-button {
    background-color: transparent;
    border: none;
    cursor: pointer;
    display: inline-block;
    margin: 0;
    padding: 0
}
.waffle-recording-toast-relativity {
    display: inline-block;
    padding-left: 12px
}
.waffle-recording-toast-relativity-label {
    display: inline-block;
    padding-left: 24px
}
.waffle-edit-actions-dialog,
.waffle-import-custom-function-actions-dialog,
.waffle-record-script-dialog {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif
}
.waffle-record-script-dialog-gm.modal-dialog {
    width: 286px
}
.waffle-record-script-dialog.modal-dialog {
    border: none;
    -webkit-box-shadow: 0 4px 16px 0 rgba(0, 0, 0, .4);
    -moz-box-shadow: 0 4px 16px 0 rgba(0, 0, 0, .4);
    box-shadow: 0 4px 16px 0 rgba(0, 0, 0, .4);
    min-height: 239px;
    padding: 0;
    width: 334px
}
.waffle-record-script-dialog .modal-dialog-content {
    line-height: 1em;
    padding: 0 24px
}
.waffle-record-script-dialog .modal-dialog-title {
    color: rgba(0, 0, 0, 0.87);
    font-size: 19px;
    font-weight: 500;
    margin: 0;
    padding: 21px 24px 16px 24px
}
.waffle-record-script-dialog .modal-dialog-buttons {
    float: right;
    margin: 33px 0 14px 0
}
.waffle-record-script-dialog-label {
    color: rgba(0, 0, 0, 0.54);
    font-size: 11px;
    padding-top: 3px
}
.waffle-record-script-dialog-gm .waffle-record-script-dialog-label {
    color: #3c4043;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    padding: 0 0 4px 0
}
.waffle-record-script-dialog-name-section {
    margin-bottom: 16px
}
.waffle-record-script-dialog .docs-charts-editor-material-text-input,
.waffle-record-script-dialog .docs-charts-editor-material-text-input input {
    font-size: 13px
}
.waffle-record-script-dialog-gm .waffle-record-script-name-input {
    width: 100%
}
.waffle-record-script-shortcut input {
    margin-left: 8px;
    text-align: center;
    width: 60px
}
.waffle-record-script-dialog-gm .waffle-record-script-shortcut label {
    margin-right: 8px
}
.waffle-record-script-dialog-gm .waffle-record-script-shortcut input {
    width: 74px
}
.waffle-recording-toast .jfk-radiobutton-label {
    margin-left: 28px
}
.waffle-recording-toast .jfk-radiobutton-radio,
.waffle-recording-toast .jfk-radiobutton-hover .jfk-radiobutton-radio {
    border: 2px solid #bebebe;
    height: 16px;
    left: 8px;
    top: 12px;
    width: 16px
}
.waffle-recording-toast .jfk-radiobutton-radio::after {
    background: #4285f4;
    border: 4px solid #4285f4;
    box-sizing: border-box;
    height: 8px;
    left: 2px;
    top: 2px;
    width: 8px
}
.waffle-recording-toast .jfk-radiobutton-checked .jfk-radiobutton-radio {
    border: 2px solid #4285f4
}
.waffle-recording-toast-relativity-split .jfk-radiobutton-checked.jfk-radiobutton-focused .jfk-radiobutton-radio {
    border: 2px solid #2a56c6
}
.waffle-recording-toast-relativity-split .jfk-radiobutton-checked.jfk-radiobutton-focused .jfk-radiobutton-radio::after {
    background-color: #2a56c6;
    border: 4px solid #2a56c6
}
.docs-gm-dialogs .waffle-recording-toast .jfk-radiobutton-radio::after {
    background: #188038;
    border: 4px solid #188038
}
.docs-gm-dialogs .waffle-recording-toast .jfk-radiobutton-checked .jfk-radiobutton-radio {
    border: 2px solid #188038
}
.docs-gm-dialogs .waffle-recording-toast-relativity-split .jfk-radiobutton-focused .jfk-radiobutton-radio {
    border: 2px solid #188038
}
.docs-gm-dialogs .waffle-recording-toast-relativity-split .jfk-radiobutton-checked.jfk-radiobutton-focused .jfk-radiobutton-radio {
    border: 2px solid #0d652d
}
.docs-gm-dialogs .waffle-recording-toast-relativity-split .jfk-radiobutton-checked.jfk-radiobutton-focused .jfk-radiobutton-radio::after {
    background-color: #0d652d;
    border: 4px solid #0d652d
}
.waffle-recording-toast-icon {
    color: #ea4335;
    display: inline-block;
    height: 16px;
    margin-bottom: 24px;
    margin-left: 16px;
    margin-top: 24px;
    width: 16px
}
.waffle-recording-toast-outer-circle {
    border: 2px solid #ff5959;
    border-radius: 50%;
    box-sizing: border-box;
    height: 16px;
    position: relative;
    width: 16px
}
.waffle-recording-toast-inner-circle {
    -webkit-animation: waffle-recording-toast-recording-cycle 1333ms steps(1) infinite;
    -moz-animation: waffle-recording-toast-recording-cycle 1333ms steps(1) infinite;
    -o-animation: waffle-recording-toast-recording-cycle 1333ms steps(1) infinite;
    animation: waffle-recording-toast-recording-cycle 1333ms steps(1) infinite;
    border: 4px solid #ff5959;
    border-radius: 50%;
    box-sizing: border-box;
    height: 8px;
    left: 2px;
    position: relative;
    top: 2px;
    width: 8px
}
@keyframes waffle-recording-toast-recording-cycle {
    0% {
        border: 4px solid #ff5959
    }
    50% {
        border: 0
    }
    100% {
        border: 4px solid #ff5959
    }
}
.waffle-recording-toast-expand-icon {
    height: 18px;
    width: 18px
}
.waffle-recording-toast-expand-icon::after {
    content: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxOCIgaGVpZ2h0PSIxOCIgdmlld0JveD0iMCAwIDE4IDE4Ij48ZyBzdHlsZT0iZmlsbDpub25lO3N0cm9rZS13aWR0aDoxO3N0cm9rZTpub25lIj48ZyB0cmFuc2Zvcm09InRyYW5zbGF0ZSg5IDkpc2NhbGUoMSAtMSl0cmFuc2xhdGUoLTkgLTkpIj48cmVjdCB3aWR0aD0iMTgiIGhlaWdodD0iMTgiLz48cG9seWdvbiBwb2ludHM9IjkgNSAzIDExIDQuNCAxMi40IDkgNy44IDEzLjYgMTIuNCAxNSAxMSIgZmlsbD0iIzVmNjM2OCIvPjwvZz48L2c+PC9zdmc+")
}
.goog-zippy-collapsed .waffle-recording-toast-expand-icon {
    transform: rotate(-180deg)
}
.waffle-recording-toast-relativity-info {
    color: white;
    display: inline-block;
    float: right;
    font-weight: 500;
    height: 20px;
    text-align: center;
    width: 20px
}
.waffle-recording-toast-info-circle {
    border: 2px solid white;
    border-radius: 50%;
    height: 16px;
    left: -2px;
    position: relative;
    top: -2px;
    width: 16px
}
.waffle-edit-actions-dialog.modal-dialog {
    -webkit-box-shadow: 0 4px 16px 0 rgba(0, 0, 0, .4);
    -moz-box-shadow: 0 4px 16px 0 rgba(0, 0, 0, .4);
    box-shadow: 0 4px 16px 0 rgba(0, 0, 0, .4);
    border: none;
    padding: 0px;
    width: 441px
}
.waffle-edit-actions-dialog .modal-dialog-title {
    color: rgba(0, 0, 0, 0.87);
    font-size: 18px;
    font-weight: 500;
    margin-bottom: 16px;
    padding: 24px 24px 0 24px
}
.waffle-import-custom-function-actions-dialog .modal-dialog-title .title-action-number {
    color: rgba(0, 0, 0, 0.54);
    font-size: 18px;
    font-weight: 400;
    margin-left: 5px
}
.waffle-edit-actions-dialog .modal-dialog-buttons {
    float: right;
    margin-bottom: 14px;
    margin-top: 8px
}
.waffle-edit-actions-dialog .modal-dialog-buttons button,
.waffle-record-script-dialog .modal-dialog-buttons button {
    background-color: white;
    background-image: none;
    border: none;
    border-radius: 2px;
    color: rgba(0, 0, 0, 0.54);
    font-size: 13px;
    font-weight: 500;
    height: 32px;
    margin-right: 8px;
    min-width: 64px;
    padding-left: 8px;
    padding-right: 8px;
    text-transform: uppercase
}
.waffle-edit-actions-dialog .modal-dialog-buttons .goog-buttonset-default,
.waffle-record-script-dialog .modal-dialog-buttons .goog-buttonset-default,
.waffle-recording-toast .waffle-recording-toast-stop {
    color: #4285f4
}
.waffle-edit-actions-dialog .modal-dialog-buttons button:hover:enabled,
.waffle-record-script-dialog .modal-dialog-buttons button:hover:enabled,
.waffle-recording-toast .goog-flat-button-hover,
.waffle-recording-toast-expand:hover {
    background-color: rgba(0, 0, 0, 0.12)
}
.waffle-edit-actions-dialog .modal-dialog-buttons button:focus,
.waffle-record-script-dialog .modal-dialog-buttons button:focus,
.waffle-recording-toast .goog-flat-button-focused,
.waffle-recording-toast-expand:focus {
    background-color: #ddd;
    background-image: none;
    border: none
}
.waffle-edit-actions-dialog .modal-dialog-buttons button:active:enabled,
.waffle-record-script-dialog .modal-dialog-buttons button:active:enabled,
.waffle-recording-toast .goog-flat-button-active,
.waffle-recording-toast-expand:active {
    background-color: rgba(0, 0, 0, 0.12);
    color: rgba(0, 0, 0, 0.87)
}
.waffle-edit-actions-dialog .modal-dialog-buttons button.goog-buttonset-default:hover:enabled,
.waffle-record-script-dialog .modal-dialog-buttons button.goog-buttonset-default:hover:enabled,
.waffle-recording-toast .waffle-recording-toast-stop.goog-flat-button-hover {
    background-color: rgba(66, 133, 244, 0.12)
}
.waffle-edit-actions-dialog .modal-dialog-buttons button.goog-buttonset-default:active:enabled,
.waffle-record-script-dialog .modal-dialog-buttons button.goog-buttonset-default:active:enabled,
.waffle-recording-toast .waffle-recording-toast-stop.goog-flat-button-active,
.waffle-recording-toast .waffle-recording-toast-stop.goog-flat-button-enabled {
    background-color: rgba(66, 133, 244, 0.32);
    color: #3367d6
}
.docs-gm-dialogs .waffle-import-custom-function-add-function .goog-flat-button,
.docs-gm-dialogs .waffle-recording-toast-stop.goog-flat-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    color: #188038;
    outline: none;
    text-transform: none
}
.docs-gm-dialogs .waffle-import-custom-function-add-function .goog-flat-button-hover,
.docs-gm-dialogs .waffle-recording-toast-stop.goog-flat-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #f8fcf9;
    color: #188038
}
.docs-gm-dialogs .waffle-import-custom-function-add-function .goog-flat-button-focused,
.docs-gm-dialogs .waffle-recording-toast-stop.goog-flat-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #e7f5eb;
    color: #188038
}
.docs-gm-dialogs .waffle-import-custom-function-add-function .goog-flat-button-active,
.docs-gm-dialogs .waffle-recording-toast-stop.goog-flat-button-active {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    color: #188038;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.docs-gm-dialogs .waffle-import-custom-function-view-script .goog-flat-button,
.docs-gm-dialogs .waffle-recording-toast-cancel.goog-flat-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    color: #5f6368;
    outline: none;
    text-transform: none
}
.docs-gm-dialogs .waffle-import-custom-function-view-script .goog-flat-button-hover,
.docs-gm-dialogs .waffle-recording-toast-cancel.goog-flat-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #f8fcf9;
    color: #5f6368
}
.docs-gm-dialogs .waffle-import-custom-function-view-script .goog-flat-button-focused,
.docs-gm-dialogs .waffle-recording-toast-cancel.goog-flat-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #e7f5eb;
    color: #5f6368
}
.docs-gm-dialogs .waffle-import-custom-function-view-script .goog-flat-button-active,
.docs-gm-dialogs .waffle-recording-toast-cancel.goog-flat-button-active {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    color: #5f6368;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.docs-gm-dialogs .waffle-recording-toast-expand:hover {
    background-color: #f8fcf9
}
.docs-gm-dialogs .waffle-recording-toast-expand:focus {
    background-color: #e7f5eb
}
.docs-gm-dialogs .waffle-recording-toast-expand:focus:hover {
    background-color: #dff2e4
}
.docs-gm-dialogs .waffle-recording-toast-expand:active {
    background-color: #dff2e4;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.waffle-edit-actions-dialog .waffle-edit-actions-row {
    padding-bottom: 10px;
    padding-top: 10px
}
.waffle-edit-actions-row {
    color: rgba(0, 0, 0, 0.87);
    font-size: 13px;
    font-weight: 400;
    height: 30px
}
.waffle-edit-actions-row-name {
    float: left;
    margin-right: 10px;
    width: 175px
}
.waffle-edit-actions-row-shortcut-prefix {
    display: inline-block;
    margin-right: 5px;
    padding-top: 4px
}
.waffle-edit-actions-row-shortcut {
    display: inline-block;
    width: 32px
}
.waffle-edit-actions-row-shortcut-input {
    max-width: 100%;
    text-align: center
}
.waffle-edit-actions-row-name input:disabled {
    color: rgba(0, 0, 0, 0.87);
    border: none
}
.waffle-edit-actions-row-name input {
    max-width: 100%
}
.waffle-edit-actions-dialog .modal-dialog-title-close {
    margin-right: 7px;
    padding: 24px 17px 24px 24px
}
.waffle-edit-actions-dialog-scroll {
    max-height: 346px;
    min-height: 160px;
    overflow-y: auto;
    padding: 10px 24px 10px 24px
}
.waffle-edit-actions-dialog-gm .waffle-edit-actions-dialog-scroll {
    padding: 0 4px
}
.waffle-edit-actions-options {
    float: right
}
.waffle-edit-actions-row-menu {
    display: inline-block;
    margin-left: 10px
}
.waffle-edit-actions-options .goog-menuitem {
    padding-right: 30px
}
.waffle-edit-actions-row .goog-menu {
    display: inline-block;
    overflow: hidden
}
.waffle-edit-actions-shortcut-conflict-message {
    clear: left;
    color: #db4437;
    font-size: 11px
}
.waffle-edit-actions-undo-remove-toast {
    z-index: 1003
}
.waffle-edit-actions-dialog .modal-dialog-buttons button:disabled {
    opacity: 0.38
}
.waffle-import-custom-function-actions-dialog.modal-dialog {
    -webkit-box-shadow: 0 4px 16px 0 rgba(0, 0, 0, .4);
    -moz-box-shadow: 0 4px 16px 0 rgba(0, 0, 0, .4);
    box-shadow: 0 4px 16px 0 rgba(0, 0, 0, .4);
    border: none;
    padding: 0px;
    width: 451px
}
.waffle-import-custom-function-actions-dialog .modal-dialog-title {
    color: rgba(0, 0, 0, 0.87);
    font-size: 18px;
    font-weight: 500;
    margin-bottom: 16px;
    padding: 24px 24px 0 24px
}
.waffle-import-custom-function-title-description {
    color: rgba(0, 0, 0, 0.54);
    font-size: 11px;
    font-weight: 400
}
.waffle-import-custom-function-actions-title-separator {
    border-bottom: 1px solid rgba(0, 0, 0, 0.12);
    margin: 0 24px
}
.waffle-import-custom-functions-row-container {
    padding-top: 8px
}
.waffle-import-custom-function-row {
    margin-top: 8px;
    padding-left: 8px
}
.docs-gm-dialogs .waffle-import-custom-function-actions-dialog.modal-dialog {
    padding: 24px 12px
}
.docs-gm-dialogs .waffle-import-custom-function-actions-dialog .modal-dialog-title {
    padding: 0 12px
}
.docs-gm-dialogs .waffle-import-custom-function-actions-title-separator {
    margin: 0 12px
}
.docs-gm-dialogs .waffle-import-custom-function-actions-dialog-scroll {
    padding: 0 1px 10px 2px
}
.docs-gm-dialogs .waffle-import-custom-function-row {
    margin-top: 8px;
    padding-left: 10px
}
.waffle-import-custom-function-add-function {
    display: inline-block;
    float: right
}
.waffle-import-custom-function-add-function button {
    background-color: white;
    border: none;
    border-radius: 2px;
    color: #4285f4;
    font: 500 15px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    height: 32px;
    padding: 8px;
    text-transform: uppercase
}
.waffle-import-custom-function-add-function button:hover {
    background-color: rgba(66, 133, 244, 0.12)
}
.waffle-import-custom-function-add-function button:active {
    background-color: rgba(66, 133, 244, 0.32);
    color: #3367d6
}
.waffle-import-custom-function-name {
    color: rgba(0, 0, 0, 0.87);
    font-weight: 500;
    font-size: 13px
}
.waffle-import-custom-function-metadata {
    color: rgba(0, 0, 0, 0.54);
    font-size: 11px;
    font-weight: 400;
    margin-top: 6px
}
.waffle-import-custom-function-description-label {
    font-weight: 500
}
.waffle-import-custom-function-project-name {
    display: inline-block
}
.waffle-import-custom-function-file-name {
    display: inline-block;
    margin-left: 16px
}
.waffle-import-custom-function-view-script {
    display: inline-block
}
.waffle-import-custom-function-view-script button {
    background-color: white;
    background-image: none;
    border: none;
    border-radius: 2px;
    color: rgba(0, 0, 0, 0.6);
    font: 500 15px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    height: 32px;
    margin-left: -8px;
    text-transform: uppercase;
    padding: 8px;
    line-height: 1em
}
.waffle-import-custom-function-view-script button:hover {
    background-color: rgba(0, 0, 0, 0.12)
}
.waffle-import-custom-function-view-script button:active {
    background-color: rgba(0, 0, 0, 0.12);
    color: rgba(0, 0, 0, 0.87)
}
.function-description-seperator {
    padding-left: 5px
}
.waffle-import-custom-function-actions-dialog-scroll {
    max-height: 381px;
    min-height: 185px;
    overflow-y: scroll;
    padding: 0 1px 10px 16px
}
.waffle-import-custom-function-actions-status-toast {
    z-index: 1003
}
.waffle-import-custom-function-actions-checkmark {
    height: 24px;
    width: 24px
}
.waffle-import-custom-function-actions-checkmark::after {
    content: url("data:image/svg+xml;base64,PHN2ZyB4bWxuczp4bGluaz0naHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluaycgeG1sbnM9J2h0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnJyB2ZXJzaW9uPScxLjEnIHdpZHRoPScyNHB4JyBoZWlnaHQ9JzI0cHgnIHZpZXdCb3g9JzAgMCAxNSAxNSc+PHBhdGggZmlsbD0nZ3JleScgZmlsbC1ydWxlPSdldmVub2RkJyBkPSdNNywxNCBDMTAuODY1OTkzMiwxNCAxNCwxMC44NjU5OTMyIDE0LDcgQzE0LDMuMTM0MDA2NzUgMTAuODY1OTkzMiwwIDcsMCBDMy4xMzQwMDY3NSwwIDAsMy4xMzQwMDY3NSAwLDcgQzAsMTAuODY1OTkzMiAzLjEzNDAwNjc1LDE0IDcsMTQgWiBNMi4yNSw3LjUgTDMuMzA3NSw2LjQ0MjUgTDUuNSw4LjYyNzUgTDEwLjY5MjUsMy40MzUgTDExLjc1LDQuNSBMNS41LDEwLjc1IEwyLjI1LDcuNSBaJz48L3BhdGg+PC9zdmc+")
}
.waffle-edit-actions-empty {
    color: rgba(0, 0, 0, 0.54);
    font-size: 15px;
    font-weight: 400;
    line-height: 160px;
    text-align: center
}
.docs-ui-toast-content .waffle-ellipses {
    left: 4px;
    top: 3px
}
.grid-shim-bottom {
    border-top: 1px solid #d9d9d9
}
.grid-shim-end-ltr {
    border-left: 1px solid #d9d9d9
}
.grid-shim-end-rtl {
    border-right: 1px solid #d9d9d9
}
.row-freezebar-extension {
    background-color: #dadfe8;
    border-top: 1px solid #d9d9d9;
    border-bottom: 1px solid #dbdbdb;
    position: relative
}
.grid-bottom-bar {
    border-top: 1px solid #d9d9d9
}
.grid-bottom-bar {
    border-top: 1px solid #aaa
}
.column-freezebar-extension {
    height: 100%;
    background-color: #dadfe8;
    border-left: 1px solid #d9d9d9;
    border-right: 1px solid #dbdbdb;
    position: relative
}
.mimic-overlay::-webkit-scrollbar {
    background-color: rgba(255, 255, 255, 1.0)
}
.mimic-overlay::-webkit-scrollbar-corner {
    background-color: rgba(255, 255, 255, 1.0)
}
.scroll-container::-webkit-scrollbar:vertical {
    width: 12px
}
.scroll-container::-webkit-scrollbar:horizontal {
    height: 12px
}
.scroll-container::-webkit-scrollbar-button:start {
    display: none
}
.scroll-container::-webkit-scrollbar-button:end {
    display: block
}
.scroll-container::-webkit-scrollbar-button {
    border: 1px solid #d9d9d9
}
.scroll-container::-webkit-scrollbar-button:horizontal {
    border-width: 1px 0 0 0
}
.scroll-container-ltr::-webkit-scrollbar-button:vertical {
    border-width: 0 0 0 1px
}
.scroll-container-rtl::-webkit-scrollbar-button:vertical {
    border-width: 0 1px 0 0
}
.scroll-container::-webkit-scrollbar-button:horizontal:increment {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -663px -13px;
    width: 15px;
    padding-left: 1px;
    background-clip: border-box;
    border: 1px solid #d9d9d9;
    border-width: 1px 0 0 0;
    box-shadow: none;
    background-color: #f8f8f8
}
.scroll-container::-webkit-scrollbar-button:horizontal:increment:hover {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -395px -62px
}
.scroll-container::-webkit-scrollbar-button:horizontal:increment:active {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -679px -13px
}
.scroll-container::-webkit-scrollbar-button:horizontal:decrement {
    border-left: 1px solid #d9d9d9;
    border-right: 1px solid #d9d9d9;
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -283px -62px;
    width: 17px
}
.scroll-container::-webkit-scrollbar-button:horizontal:hover {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -145px -70px
}
.scroll-container::-webkit-scrollbar-button:horizontal:active {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -552px 0
}
.scroll-container::-webkit-scrollbar-button:vertical:increment {
    padding-top: 1px;
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -531px -24px;
    height: 15px
}
.scroll-container::-webkit-scrollbar-button:vertical:increment:hover {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -570px -42px
}
.scroll-container::-webkit-scrollbar-button:vertical:increment:active {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -83px -46px
}
.scroll-container::-webkit-scrollbar-button:vertical:decrement {
    border-top: 1px solid #d9d9d9;
    border-bottom: 1px solid #d9d9d9;
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -631px -27px;
    height: 17px
}
.scroll-container::-webkit-scrollbar-button:vertical:decrement:hover {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -180px -58px
}
.scroll-container::-webkit-scrollbar-button:vertical:decrement:active {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -776px -28px
}
.scroll-container::-webkit-scrollbar-track:vertical {
    background-clip: border-box;
    border: 1px solid #d9d9d9;
    box-shadow: none;
    background-color: #f8f8f8
}
.scroll-container-ltr::-webkit-scrollbar-track:vertical {
    border-width: 0 0 0 1px
}
.scroll-container-rtl::-webkit-scrollbar-track:vertical {
    border-width: 0 1px 0 0
}
.scroll-container::-webkit-scrollbar-track:horizontal {
    background-clip: border-box;
    border: 1px solid #d9d9d9;
    border-width: 1px 0 0 0;
    box-shadow: none;
    background-color: #f8f8f8
}
.scroll-container::-webkit-scrollbar-track:hover {
    background: none;
    box-shadow: none
}
.docs-gm-sidebars .native-scrollbar::-webkit-scrollbar-track:hover {
    border-width: 0;
    background: none
}
.scroll-container::-webkit-scrollbar-track:horizontal:hover,
.scroll-container::-webkit-scrollbar-track:vertical:hover {
    box-shadow: none;
    background-clip: border-box;
    border: 1px solid #d9d9d9;
    border-width: 1px 0 0 0;
    box-shadow: none;
    background-color: #f8f8f8
}
.scroll-container::-webkit-scrollbar-track:horizontal:hover {
    border-width: 1px 0 0 0
}
.scroll-container::-webkit-scrollbar-track:vertical:hover {
    border-width: 0 1px 0 1px
}
.scroll-container::-webkit-scrollbar-thumb {
    background-color: rgba(0, 0, 0, .2);
    background-clip: padding-box;
    border: solid transparent;
    min-height: 28px;
    padding: none;
    box-shadow: none;
    border-width: 1px 1px 1px 1px
}
.scroll-container::-webkit-scrollbar-thumb:horizontal {
    box-shadow: none;
    border-width: 2px 1px 1px 1px
}
.scroll-container::-webkit-scrollbar-thumb:vertical {
    padding: 1px 1px 1px 1px;
    box-shadow: none
}
.scroll-container-ltr::-webkit-scrollbar-thumb:vertical {
    border-width: 1px 1px 1px 2px
}
.scroll-container-rtl::-webkit-scrollbar-thumb:vertical {
    border-width: 1px 2px 1px 1px
}
.scroll-container::-webkit-scrollbar-thumb:hover {
    box-shadow: none
}
.docs-gm-sidebars .native-scrollbar::-webkit-scrollbar-thumb:hover {
    background-color: #bdc1c6
}
.docs-gm-sidebars .native-scrollbar::-webkit-scrollbar-thumb:active {
    background-color: #80868b
}
.docs-gm-sidebars .native-scrollbar::-webkit-scrollbar-track:vertical,
.docs-gm-sidebars .native-scrollbar::-webkit-scrollbar-track:horizontal,
.docs-gm-sidebars .native-scrollbar::-webkit-scrollbar-track:horizontal:hover,
.docs-gm-sidebars .native-scrollbar::-webkit-scrollbar-track:vertical:hover {
    background-color: #fff
}
.scroll-container::-webkit-scrollbar-corner {
    border: 1px solid #d9d9d9
}
.scroll-container-rtl::-webkit-scrollbar-corner {
    border-width: 1px 1px 0 0
}
.scroll-container-ltr::-webkit-scrollbar-corner {
    border-width: 1px 0 0 1px
}
.native-scrollbar::-webkit-scrollbar:vertical {
    width: 12px
}
.native-scrollbar::-webkit-scrollbar:horizontal {
    height: 12px
}
.native-scrollbar::-webkit-scrollbar-button:start {
    display: none
}
.native-scrollbar::-webkit-scrollbar-button:end {
    display: block
}
.native-scrollbar::-webkit-scrollbar-button {
    border: 1px solid #d9d9d9
}
.native-scrollbar::-webkit-scrollbar-button:horizontal {
    border-width: 1px 0 0 0
}
.native-scrollbar-ltr::-webkit-scrollbar-button:vertical {
    border-width: 0 0 0 1px
}
.native-scrollbar-rtl::-webkit-scrollbar-button:vertical {
    border-width: 0 1px 0 0
}
.native-scrollbar::-webkit-scrollbar-button:horizontal:increment {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -663px -13px;
    width: 15px;
    padding-left: 1px;
    background-clip: border-box;
    border: 1px solid #d9d9d9;
    border-width: 1px 0 0 0;
    box-shadow: none;
    background-color: #f8f8f8
}
.native-scrollbar::-webkit-scrollbar-button:horizontal:increment:hover {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -395px -62px
}
.native-scrollbar::-webkit-scrollbar-button:horizontal:increment:active {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -679px -13px
}
.native-scrollbar::-webkit-scrollbar-button:horizontal:decrement {
    border-left: 1px solid #d9d9d9;
    border-right: 1px solid #d9d9d9;
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -283px -62px;
    width: 17px
}
.native-scrollbar::-webkit-scrollbar-button:horizontal:hover {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -145px -70px
}
.native-scrollbar::-webkit-scrollbar-button:horizontal:active {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -552px 0
}
.native-scrollbar::-webkit-scrollbar-button:vertical:increment {
    padding-top: 1px;
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -531px -24px;
    height: 15px
}
.native-scrollbar::-webkit-scrollbar-button:vertical:increment:hover {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -570px -42px
}
.native-scrollbar::-webkit-scrollbar-button:vertical:increment:active {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -83px -46px
}
.native-scrollbar::-webkit-scrollbar-button:vertical:decrement {
    border-top: 1px solid #d9d9d9;
    border-bottom: 1px solid #d9d9d9;
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -631px -27px;
    height: 17px
}
.native-scrollbar::-webkit-scrollbar-button:vertical:decrement:hover {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -180px -58px
}
.native-scrollbar::-webkit-scrollbar-button:vertical:decrement:active {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -776px -28px
}
.docs-gm-sidebars .native-scrollbar::-webkit-scrollbar-track {
    margin: 0px
}
.native-scrollbar::-webkit-scrollbar-track:vertical {
    background-clip: border-box;
    border: 1px solid #d9d9d9;
    box-shadow: none;
    background-color: #f8f8f8
}
.native-scrollbar-ltr::-webkit-scrollbar-track:vertical {
    border-width: 0 0 0 1px
}
.native-scrollbar-rtl::-webkit-scrollbar-track:vertical {
    border-width: 0 1px 0 0
}
.native-scrollbar::-webkit-scrollbar-track:horizontal {
    background-clip: border-box;
    border: 1px solid #d9d9d9;
    border-width: 1px 0 0 0;
    box-shadow: none;
    background-color: #f8f8f8
}
.native-scrollbar::-webkit-scrollbar-track:hover {
    background: none;
    box-shadow: none
}
.native-scrollbar::-webkit-scrollbar-track:horizontal:hover,
.native-scrollbar::-webkit-scrollbar-track:vertical:hover {
    box-shadow: none;
    background-clip: border-box;
    border: 1px solid #d9d9d9;
    border-width: 1px 0 0 0;
    box-shadow: none;
    background-color: #f8f8f8
}
.native-scrollbar::-webkit-scrollbar-track:horizontal:hover {
    border-width: 1px 0 0 0
}
.native-scrollbar::-webkit-scrollbar-track:vertical:hover {
    border-width: 0 1px 0 1px
}
.native-scrollbar::-webkit-scrollbar-thumb {
    background-color: rgba(0, 0, 0, .2);
    background-clip: padding-box;
    border: solid transparent;
    min-height: 28px;
    padding: none;
    box-shadow: none;
    border-width: 1px 1px 1px 1px
}
.native-scrollbar::-webkit-scrollbar-thumb:horizontal {
    box-shadow: none;
    border-width: 2px 1px 1px 1px
}
.native-scrollbar::-webkit-scrollbar-thumb:vertical {
    padding: 1px 1px 1px 1px;
    box-shadow: none
}
.native-scrollbar-ltr::-webkit-scrollbar-thumb:vertical {
    border-width: 1px 1px 1px 2px
}
.native-scrollbar-rtl::-webkit-scrollbar-thumb:vertical {
    border-width: 1px 2px 1px 1px
}
.docs-gm-sidebars .native-scrollbar::-webkit-scrollbar-thumb {
    background-color: #dadce0
}
.native-scrollbar::-webkit-scrollbar-thumb:hover {
    box-shadow: none
}
.native-scrollbar::-webkit-scrollbar-corner {
    border: 1px solid #d9d9d9
}
.native-scrollbar-rtl::-webkit-scrollbar-corner {
    border-width: 1px 1px 0 0
}
.native-scrollbar-ltr::-webkit-scrollbar-corner {
    border-width: 1px 0 0 1px
}
.native-scrollbar-x {
    overflow-x: scroll;
    overflow-y: hidden;
    border: 1px solid #d9d9d9;
    border-width: 0 1px 0 0
}
.native-scrollbar-y {
    overflow-x: hidden;
    overflow-y: scroll;
    border: 1px solid #d9d9d9;
    border-width: 0 0 1px 0
}
.waffle-verbal-title {
    text-align: center
}
.waffle-verbal-wrapper {
    height: 0;
    overflow: hidden;
    position: absolute;
    width: 0
}
.waffle-verbal-highlights-container {
    background-color: white;
    border: 1px solid #9e9e9e;
    border-left: 4px solid #009e55;
    font-family: Roboto, Arial, sans-serif;
    font-size: 13px;
    margin: 3px -1px 0 -1px;
    min-width: 400px;
    padding: 20px 20px 15px 20px;
    white-space: normal
}
.waffle-verbal-highlights-icon {
    margin-right: 4px
}
.waffle-verbal-highlights-header {
    color: #009e55;
    font-weight: 500;
    margin-bottom: 10px
}
.waffle-verbal-highlights-header-left {
    float: left
}
.waffle-verbal-highlights-title-icon {
    display: inline-block;
    padding-bottom: 2px;
    padding-right: 4px;
    margin-left: -2px
}
.waffle-verbal-highlights-title {
    display: inline-block;
    vertical-align: bottom
}
.waffle-verbal-highlights-close {
    float: right;
    opacity: 0.46
}
.waffle-verbal-highlights-close.goog-flat-button {
    position: static;
    border: none;
    margin: -4px -4px 0 0;
    padding: 0;
    background-color: transparent
}
.waffle-verbal-highlights-bullet {
    color: #515151;
    font-family: Roboto, Arial, sans-serif;
    font-size: 13px;
    margin-top: 10px;
    white-space: pre-wrap
}
.waffle-verbal-highlights-empty-notice {
    color: #9e9e9e;
    margin-bottom: 25px;
    text-align: center
}
.waffle-verbal-highlights-pager {
    float: right
}
.waffle-verbal-highlights-viewall.goog-flat-button {
    color: #009e55;
    background-color: transparent;
    border: none;
    display: inline-block;
    float: left;
    font-family: Roboto, Arial, sans-serif;
    font-size: 13px;
    padding: 0
}
.waffle-verbal-highlights-previous.goog-flat-button,
.waffle-verbal-highlights-next.goog-flat-button {
    color: #009e55;
    background-color: transparent;
    border: none;
    display: inline-block;
    font-family: Roboto, Arial, sans-serif;
    font-size: 13px;
    padding: 0
}
.waffle-verbal-highlights-previous.goog-flat-button-disabled,
.waffle-verbal-highlights-next.goog-flat-button-disabled {
    color: #ccc
}
.waffle-verbal-highlights-counter {
    color: #9e9e9e;
    display: inline-block;
    font-family: Roboto, Arial, sans-serif;
    font-size: 13px;
    text-align: center;
    width: 70px
}
.waffle-verbal-highlights-floatclear {
    clear: both
}
.waffle-verbal-highlights-one-option-footer {
    margin: 15px 0
}
.waffle-verbal-highlights-footer {
    margin: 15px 0 0 0
}
.waffle-verbal-highlights-viewall-footer.goog-flat-button {
    background-color: transparent;
    border: none;
    margin: 15px 0 0 -5px;
    padding: 0
}
.waffle-verbal-highlights-viewall-back-label {
    color: #009e55;
    display: inline-block;
    font-family: Roboto, Arial, sans-serif;
    font-size: 13px;
    margin-left: 5px;
    vertical-align: middle
}
.waffle-overflow-menu-material {
    -webkit-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    cursor: pointer;
    height: 18px;
    opacity: 0.54;
    width: 18px
}
.waffle-overflow-menu-material::after {
    content: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyMCIgdmlld2JveD0iMCAwIDIwIDIwIiBoZWlnaHQ9IjIwIj48cGF0aCBkPSJtMTAgNmMxLjEgMCAyLTAuOSAyLTJzLTAuOS0yLTItMi0yIDAuOS0yIDIgMC45IDIgMiAyem0wIDJjLTEuMSAwLTIgMC45LTIgMnMwLjkgMiAyIDIgMi0wLjkgMi0yLTAuOS0yLTItMnptMCA2Yy0xLjEgMC0yIDAuOS0yIDJzMC45IDIgMiAyIDItMC45IDItMi0wLjktMi0yLTJ6Ii8+PC9zdmc+")
}
.waffle-overflow-menu-material.waffle-overflow-menu-material-white::after {
    content: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyMCIgaGVpZ2h0PSIyMCIgdmlld2JveD0iMCAwIDIwIDIwIj48cGF0aCBkPSJNMTAgNmMxLjEgMCAyLTAuOSAyLTJzLTAuOS0yLTItMlM4IDIuOSA4IDQgOC45IDYgMTAgNnpNMTAgOGMtMS4xIDAtMiAwLjktMiAyczAuOSAyIDIgMiAyLTAuOSAyLTJTMTEuMSA4IDEwIDh6TTEwIDE0Yy0xLjEgMC0yIDAuOS0yIDJzMC45IDIgMiAyIDItMC45IDItMlMxMS4xIDE0IDEwIDE0eiIgZmlsbD0iI2ZmZiIvPjwvc3ZnPg==")
}
.waffle-overflow-menu-material:hover {
    opacity: 0.70
}
.goog-modalpopup-bg,
.modal-dialog-bg {
    z-index: 1002
}
.goog-modalpopup,
.modal-dialog {
    z-index: 1003
}
.waffle-dialog-header {
    font-weight: 500;
    font-size: 14px;
    line-height: 2.25em
}
.menuMainLink {
    border-style: none;
    border-width: 0px;
    font-size: 12px;
    color: #15c;
    text-decoration: underline;
    cursor: pointer;
    padding: 2px 0 0 6px;
    vertical-align: middle
}
.dlgImportDisabled {
    color: #666
}
div.uploadBox {
    margin-top: 8px
}
div.dlgImportClear {
    width: 100%;
    height: 1px;
    clear: both
}
div.dlgImportButterPane,
div.dlgRitzImportButterPane {
    background-color: #ffd969;
    padding: 8px;
    margin: 8px -8px 0 -8px
}
span.dlgImportButterPane {
    padding-left: 20px
}
span.dlgRitzImportButterPane {
    display: block;
    padding-top: 10px
}
div.dlgImportHeader {
    font-weight: 500;
    margin-top: 10px
}
.dlgImportError {
    font-weight: 500;
    color: red
}
span.waitSpinner {
    padding-left: 5px
}
#dlgImportCustomOption {
    display: inline-block
}
div.dlgImport {
    width: 730px;
    font-size: 10pt;
    line-height: 130%
}
div.dlgRitzImport {
    width: 310px;
    font-size: 10pt;
    line-height: 130%
}
#customDelimiter {
    width: 20px
}
.docs-gm-sidebars #customDelimiter {
    width: 40px
}
.dlgImport .jfk-radiobutton,
.dlgRitzImport .jfk-radiobutton {
    display: block
}
.dlgImportPreview {
    background-color: #eee;
    height: 300px;
    width: 360px;
    border: 1px solid #ccc;
    display: table-cell;
    text-align: center;
    vertical-align: middle;
    overflow: scroll
}
div.dlgImportPreviewMessage {
    color: gray
}
table.dlgImport {
    width: 376px;
    border: 0px;
    padding: 0px
}
.waffle-alert-dialog-inner {
    width: 376px;
    font-size: 10pt
}
.pub-dialog-wrap {
    width: 500px
}
.pub-dialog-txt {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 500
}
.pub-dialog-content-div {
    padding: 0px 0px 10px 30px
}
.pub-dialog-checkbox-label {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px
}
.pub-dialog-url-box {
    width: 450px;
    font-family: monospace;
    padding: 5px
}
.pub-dialog-input {
    width: 220px
}
.pub-dialog-date-label {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    color: #afafaf;
    padding: 0px 0px 0px 3px
}
.pub-dialog-input-div {
    padding: 0px 0px 6px 0px
}
.pub-dialog-helpertext {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    color: #afafaf
}
.pub-dialog-hr {
    background-color: #bfbfbf;
    color: #bfbfbf;
    height: 1px;
    width: 96%
}
.pub-dialog-hr-div {
    padding: 2px 0 2px 0
}
.pub-dialog-stjw-infotext-span {
    font-size: 11px;
    padding-left: 5px
}
.pub-dialog-link-options-document-part-menu-button,
.pub-dialog-published-content-menu-button {
    margin-left: 0;
    max-width: 150px
}
.pub-dialog-link-options-document-part-menu-button-content,
.pub-dialog-published-content-menu-button-content {
    overflow: hidden;
    text-overflow: ellipsis;
    width: 100%
}
.pub-dialog-link-options-container,
.pub-dialog-published-content-container {
    margin-top: 20px
}
.pub-dialog-link-options-menu,
.pub-dialog-published-content-menu {
    overflow: auto
}
.pub-dialog-link-options-chart-menu-item,
.pub-dialog-published-content-chart-menu-item {
    max-width: 340px;
    overflow: hidden;
    padding-left: 15px;
    text-overflow: ellipsis
}
.pub-dialog-chart-notice {
    color: #999;
    font-size: 11px;
    margin-top: 5px
}
.pub-dialog-chart-notice-emphasis {
    color: #666;
    font-weight: 500
}
.dialog-publishobject-div {
    border: 1px solid #ccc;
    background-color: #efefef;
    font-family: inherit;
    font-size: 12px;
    max-height: 500px;
    overflow: auto;
    padding: 15px;
    width: 350px
}
.dialog-publishobject-msg {
    font-size: 12px
}
.waffle-selection-dialog-content {
    overflow: auto;
    margin-right: -30px;
    max-height: 200px;
    width: 280px
}
.waffle-selection-dialog-editbox {
    margin: 5px 0;
    width: 200px
}
.docs-gm-dialogs .waffle-selection-dialog-content {
    margin-right: 0px;
    width: 314px;
    overflow-y: overlay
}
.docs-gm-dialogs .waffle-selection-dialog-editbox {
    width: 260px
}
div>.waffle-selection-dialog-active-editbox,
div>.waffle-flat-multi-range-active-editbox {
    border: 1px solid #4d90fe;
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    -moz-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.3)
}
.docs-gm-dialogs .waffle-selection-dialog-active-editbox,
.docs-gm-dialogs .waffle-flat-multi-range-active-editbox {
    border: none;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none
}
.waffle-selection-dialog-remove,
.waffle-flat-multi-range-remove {
    display: inline;
    margin: 0 5px 0 20px;
    color: #999;
    cursor: pointer
}
.docs-material .waffle-selection-dialog-remove,
.docs-material .waffle-flat-multi-range-remove {
    margin: 0 0 0 8px
}
.docs-material .waffle-selection-dialog-remove .docs-icon {
    width: 24px;
    height: 24px;
    margin: 0px
}
.waffle-flat-multi-range-remove-table {
    display: inline-block
}
.waffle-selection-dialog-error {
    color: #212121;
    font-size: 13px
}
.waffle-range-selection-container {
    background: #fff;
    border: 1px solid #d9d9d9;
    border-top: 1px solid #c0c0c0;
    min-width: 20px;
    width: 100%
}
.waffle-dv-trrules .waffle-range-selection-container {
    width: 160px
}
.waffle-dv-recs-title-bar {
    font-size: 13px;
    margin: 25px 0 9px 3px
}
.waffle-dv-rec-wrapper {
    background-color: #eee;
    margin: 0 -42px;
    min-height: 42px;
    overflow: hidden;
    padding: 5px 38px;
    position: relative;
    white-space: nowrap;
    width: 570px
}
.waffle-dv-rec-description {
    color: #404040;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.waffle-dv-rec-range {
    color: #3b80f4;
    float: right;
    margin-left: 6px
}
.waffle-dv-rec-chip {
    background-color: #fff;
    border: 1px solid #e0e0e0;
    border-radius: 8px;
    float: left;
    font-size: 13px;
    font-weight: normal;
    height: auto;
    line-height: 21px;
    margin: 5px;
    max-width: 241px;
    padding: 3px 16px 5px
}
.waffle-dv-rec-chip.jfk-button-focused {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    border: 1px solid rgba(0, 0, 0, .4)
}
.waffle-dv-rec-chip.jfk-button-hover {
    -webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, .25);
    -moz-box-shadow: 0 1px 2px rgba(0, 0, 0, .25);
    box-shadow: 0 1px 2px rgba(0, 0, 0, .25)
}
.waffle-dv-rec-chip.waffle-dv-rec-chip-selected {
    -webkit-box-shadow: 0 2px 2px rgba(0, 0, 0, .2);
    -moz-box-shadow: 0 2px 2px rgba(0, 0, 0, .2);
    box-shadow: 0 2px 2px rgba(0, 0, 0, .2);
    border: 1px solid #3b80f4
}
@media screen and (-ms-high-contrast:active) {
    .waffle-dv-rec-chip.waffle-dv-rec-chip-selected {
        border: 2px solid #3b80f4
    }
}
.waffle-dv-no-suggestions {
    color: #757575;
    font-style: italic;
    padding-left: 10px;
    position: absolute;
    top: 50%;
    transform: translateY(-50%)
}
.waffle-dv-rec-spinner-container {
    height: 100%;
    text-align: center
}
.waffle-dv-rec-spinner-container .waffle-spinner {
    top: 7px
}
.waffle-dv-table-with-suggestions {
    padding-top: 10px
}
.waffle-dv-feedback-link {
    float: right;
    font-family: 'Google Sans', Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    text-decoration: none;
    text-transform: uppercase
}
.waffle-range-selection-error {
    border: 1px solid #dd4b39
}
.input-selection-button-div {
    margin-top: -1px;
    margin-left: 4px
}
.waffle-flat-range-select-done {
    margin-top: 3px
}
.waffle-flat-multi-range-row .waffle-range-selection-holder {
    width: 168px;
    display: inline-block
}
.waffle-flat-multi-range-select-done {
    margin-top: 10px
}
.waffle-flat-range-select-message,
.waffle-flat-multi-range-select-message {
    display: none;
    margin-top: 3px;
    width: 110px
}
.waffle-flat-range-select-listening .waffle-flat-range-select-message,
.waffle-flat-multi-range-select-listening .waffle-flat-multi-range-select-message {
    display: inline-block
}
.waffle-flat-range-select-listening,
.waffle-flat-multi-range-select-listening {
    background-color: #fbf2cd;
    margin: 0 -20px 0;
    padding: 10px 20px
}
.waffle-flat-multi-range-add-another {
    display: block
}
.waffle-notification-listrule-container {
    padding: 5px
}
.waffle-notification-rule-row {
    display: inline-block;
    margin-bottom: 10px;
    width: 100%
}
.waffle-notification-rule-text {
    font-size: 10pt
}
.waffle-notification-rule-description {
    float: left
}
.waffle-notification-rulerow-buttons-container {
    float: right
}
.waffle-notification-rulerow-edit-container {
    float: left
}
.waffle-notification-rulerow-delete-container {
    float: right
}
.waffle-notification-rule-disabled {
    font-size: 8pt;
    color: lightgray!important
}
.waffle-dialog-notifications-bounds {
    width: 512px;
    height: 250px;
    border: 1px solid #999;
    overflow: auto;
    vertical-align: top;
    padding: 0 0 0 4px;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    box-sizing: border-box
}
.waffle-dialog-notifications-list {
    width: 100%;
    vertical-align: top
}
.waffle-dialog-notifications {
    width: 100%;
    padding: 6px 8px 8px 2px;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
    vertical-align: top
}
.waffle-dialog-notifications-label {
    font-weight: 500
}
.waffle-dialog-notifications-gap {
    padding-left: 25px
}
.waffle-dialog-notifications-toplabel {
    font-weight: 500
}
.waffle-dialog-notifications-input {
    vertical-align: top;
    padding-left: 25px
}
.waffle-dialog-notifications-input .disabled {
    color: lightgray!important
}
.waffle-dialog-notifications-label .disabled {
    color: lightgray!important
}
.waffle-dialog-notifications-text {
    vertical-align: top;
    padding-left: 20px;
    color: #676767;
    font-size: 8pt;
    width: 150px
}
.waffle-notifications-add {
    font-weight: 500;
    display: block
}
.waffle-notification-rule-area-separator {
    padding: 5px
}
.waffle-notification-addbutton-container {
    align-self: flex-end;
    border: none
}
.docs-gm-dialogs .waffle-notification-listrule-container {
    padding: 0px!important
}
.docs-gm-dialogs .waffle-dialog-notifications-bounds {
    border-color: #dadce0;
    border-radius: 8px;
    max-width: 672px;
    min-width: 464px;
    padding: 10px;
    width: auto;
    width: unset
}
.docs-gm-dialogs .waffle-notification-buttons-container {
    text-align: right
}
.docs-gm-dialogs .waffle-notification-addbutton-container {
    padding-bottom: 6px
}
.docs-gm-dialogs .waffle-notifications-dialog .goog-link-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    color: #188038;
    height: 24px;
    padding: 3px 12px 5px;
    text-decoration: none
}
.docs-gm-dialogs .waffle-dialog-notifications-input {
    padding-left: 0px
}
.docs-gm-dialogs .waffle-notifications-dialog .jfk-radiobutton {
    left: -7px
}
.docs-gm-dialogs .waffle-dialog-notifications-toplabel {
    padding-bottom: 5px
}
.docs-gm-dialogs .waffle-dialog-notifications-label {
    padding-bottom: 5px
}
.docs-gm-dialogs .waffle-notifications-dialog .modal-dialog-buttons {
    justify-content: space-between
}
.docs-gm-dialogs .waffle-notifications-dialog .waffle-notification-addbutton-container .goog-link-button {
    padding-left: 0px
}
.docs-gm-dialogs .waffle-notification-rule-separator {
    border-bottom: 1px solid #dadce0;
    clear: both;
    padding-top: 10px
}
.docs-gm-dialogs .waffle-notification-helpbutton-container {
    float: right;
    margin-right: 34px
}
.docs-gm-dialogs .waffle-notification-helpbutton-container .goog-link-button {
    color: #1a73e8
}
.docs-gm-dialogs .waffle-notification-bottom-group {
    padding-bottom: 2px
}
.docs-gm-dialogs .waffle-notification-end-button {
    margin-right: 0
}
.sketchy-dialog,
.sketchy-dialog-fg {
    z-index: 1003
}
.waffle-find-replace-dialog-label {
    padding-right: 8px
}
.waffle-find-replace-find-scope-select {
    margin: 0 5px 0 0
}
.waffle-findandreplacedialog-checkbox {
    display: inline-block
}
.waffle-findandreplacedialog-checkbox-label {
    vertical-align: middle
}
.waffle-find-replace-selection-input {
    vertical-align: top;
    width: 172px
}
.waffle-find-replace-dialog-border {
    border-color: #8cc474;
    border-style: solid;
    line-height: 0
}
.waffle-find-replace-dialog-display-message {
    display: inline-block;
    max-width: 512px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.docs-gm-dialogs .waffle-findandreplacedialog-checkbox-label {
    vertical-align: bottom;
    padding-left: 8px
}
.docs-gm-dialogs .waffle-find-replace-find-scope-select {
    margin-top: 8px;
    margin-right: 8px;
    margin-bottom: 8px;
    width: 126px
}
.docs-gm-dialogs .waffle-find-replace-selection-input {
    margin-top: 8px;
    width: 150px
}
.docs-gm-dialogs .waffle-find-replace-dialog {
    min-width: 464px
}
.docs-gm-dialogs .waffle-find-replace-dialog .modal-dialog-buttons {
    margin-top: 7px
}
.waffle-find-replace-dialog .find-replace-regex-help {
    display: inline-block;
    font: 14px Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    line-height: 16px;
    margin-left: 8px;
    vertical-align: middle;
    width: auto
}
.waffle-dv-trrules .waffle-range-selection-container {
    width: 160px
}
.waffle-dv-table {
    border-spacing: 3px;
    width: 562px
}
.waffle-dv-table .jfk-checkbox {
    margin-bottom: 1px;
    margin-left: 7px
}
.waffle-dv-table td {
    white-space: nowrap
}
.waffle-dv-helptext {
    width: 310px;
    margin-left: 5px
}
.waffle-dv-errortext {
    color: red;
    font-weight: 500
}
.waffle-dv-smalltext {
    font-size: 10px
}
.waffle-dv-checkbox-label {
    cursor: default
}
.docs-gm-dialogs .waffle-dv-checkbox-label {
    vertical-align: bottom
}
.waffle-dv-editbox-number {
    text-align: right;
    width: 60px
}
.waffle-dv-editbox-text {
    width: 150px
}
.waffle-dv-editbox-date {
    text-align: right;
    width: 100px
}
.waffle-dv-list-options-textarea {
    padding-top: 5px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    -webkit-appearance: textfield;
    width: 180px
}
.waffle-dv-table .jfk-select {
    float: left;
    margin-right: 10px
}
.waffle-dv-trrules {
    height: 41px
}
.waffle-dv-trrules-appearance,
.waffle-dv-trrules-showitems {
    height: 26px
}
.waffle-dv-trrules>td,
.waffle-table-dialog-trrules>td {
    padding-bottom: 7px;
    vertical-align: top
}
.waffle-dv-trrules>td .input-selection,
.waffle-table-dialog-trrules>td .input-selection {
    margin-left: 2px
}
.waffle-cf-tr-rules .jfk-checkbox {
    margin-bottom: 1px
}
.waffle-dv-show-dropdown {
    padding-top: 5px;
    padding-bottom: 1px
}
.waffle-dv-customcheckboxlabel {
    width: 80px;
    padding-top: 11px
}
.waffle-dv-label {
    padding-top: 5px;
    padding-left: 2px;
    width: 96px;
    white-space: nowrap
}
.waffle-dv-label-disabled {
    color: #d3d3d3
}
.waffle-dv-separator {
    margin-left: 5px;
    margin-right: 5px
}
.waffle-dv-highlight-styled-rect {
    background-color: #0f9d58;
    opacity: 0.06;
    pointer-events: none
}
.range-border.waffle-dv-highlight-styled-border {
    border-color: #0f9d58;
    border-style: dashed
}
.waffle-sd-tr-rules {
    padding-top: 7px
}
.waffle-sd-td-rules {
    white-space: nowrap;
    width: 50px
}
.waffle-sd-td-ascending {
    white-space: nowrap
}
.waffle-sd-column-selector {
    width: 120px
}
.waffle-sd-delete {
    color: #999;
    cursor: pointer;
    margin-right: 5px;
    width: 10px;
    text-decoration: none
}
.waffle-sd-row-separator {
    border-bottom: 1px solid #c1d9ff;
    margin-bottom: 4px;
    margin-top: 4px
}
.docs-gm-dialogs .waffle-sd-row-separator {
    border-bottom: 1px solid #dadce0
}
.waffle-sd-add {
    padding-top: 12px;
    font-weight: 500;
    display: block
}
.waffle-sd-menu-item {
    padding-right: 30px
}
.script-gui-dialog-content {
    padding: 0px
}
.waffle-custom-decimals-error-div {
    padding-left: .7em;
    color: #dd4b39
}
textarea.waffle-input-error:focus,
input.waffle-input-error:focus,
.waffle-input-error {
    border: 1px solid #dd4b39
}
.waffle-input-error-butter-container {
    width: 100%;
    position: absolute;
    margin-top: -25px;
    left: 0;
    text-align: center
}
.waffle-input-error-butter-wrap {
    display: inline-block;
    line-height: normal
}
.dialog-settings-text {
    max-width: 300px;
    padding-left: 25px
}
.dialog-settings-sep-td {
    padding: 5px 0 5px 0
}
.docs-gm-dialogs .dialog-settings-sep-td {
    padding: 14px 0 9px 0
}
.docs-gm-dialogs .dialog-settings-sep {
    border-top-color: #e8eaed
}
.docs-gm-dialogs .jfk-radiobutton-radio::after {
    background: #188038;
    border: 4px solid #188038;
    height: 8px;
    left: 0;
    margin: 2px;
    top: 0;
    width: 8px
}
.docs-gm-dialogs .jfk-radiobutton-radio {
    height: 16px;
    width: 16px
}
.docs-gm-dialogs .jfk-radiobutton-checked .jfk-radiobutton-radio {
    border: 2px solid #188038
}
.docs-gm-dialogs .jfk-radiobutton-focused .jfk-radiobutton-radio {
    border: 2px solid #188038
}
.docs-gm-dialogs .jfk-radiobutton-checked.jfk-radiobutton-focused .jfk-radiobutton-radio {
    border: 2px solid #0d652d
}
.docs-gm-dialogs .jfk-radiobutton-checked.jfk-radiobutton-focused .jfk-radiobutton-radio::after {
    background-color: #0d652d;
    border: 4px solid #0d652d
}
.dialog-settings-sep {
    border-top-color: #e1e1e1;
    border-top-style: solid;
    border-width: 1px 0 0 0;
    color: #bfbfbf;
    height: 0
}
.dialog-settings-general-settings-div {
    padding: 10px 0 18px 0
}
.dialog-settings-english-name-div {
    padding-top: 10px
}
#waffle-settings-dialog-english-name-checkbox-label {
    padding-left: 3px
}
.waffle-prompt-dialog {
    width: 340px
}
.waffle-prompt-dialog .modal-dialog-userInput {
    width: 300px;
    margin: 4px
}
.waffle-spellcheck-cell-display {
    font-weight: 500
}
.waffle-resize-option {
    margin: 7px
}
.waffle-resize-inset-input {
    margin-left: 30px
}
.waffle-resize-row-input-container {
    margin-left: 30px
}
.waffle-resize-row-input {
    width: 70px
}
.waffle-resize-row-input-label {
    margin-left: 10px
}
#waffle-resize-input-error-butter-container {
    margin-top: -15px
}
.waffle-confirm-suppress-checkbox {
    margin-top: 15px
}
.waffle-slidingdialogbar-wrapper {
    outline: none;
    overflow: hidden;
    width: 100%
}
.waffle-pivot-histogram-errorable-input {
    display: inline-block;
    margin: 4px;
    vertical-align: top;
    width: 120px
}
.waffle-pivot-histogram-dialog-caption {
    color: rgba(0, 0, 0, 0.54);
    font-size: 11px;
    padding-top: 3px
}
.waffle-pivot-histogram-dialog-error {
    color: #db4437;
    height: 15px;
    margin-top: 6px
}
.waffle-rd-section {
    padding: 8px 0
}
.waffle-rd-section-title {
    font-weight: 500
}
.waffle-rd-columns-container {
    max-height: 300px;
    overflow-x: hidden;
    overflow-y: auto;
    padding-top: 6px
}
.waffle-rd-expand-to-range {
    color: #188038;
    cursor: pointer;
    padding-top: 2px;
    text-decoration: underline
}
.docs-gm-dialogs .waffle-rd-dialog-gm {
    min-width: 312px
}
.waffle-rd-ignore-headers {
    padding-top: 6px
}
.waffle-rd-ignore-headers .docs-material-gm-labeled-checkbox,
.waffle-rd-columns-checkbox .docs-material-gm-labeled-checkbox {
    padding: 6px 0
}
.waffle-rd-checkbox-label {
    display: inline-block;
    padding-left: 5px
}
.docs-gm-dialogs .waffle-sort-dialog-gm {
    min-width: 464px
}
.waffle-sort-dialog-radio-option {
    display: inline-block;
    padding-left: 8px
}
.docs-gm-dialogs .waffle-sd-delete .docs-icon {
    width: 24px;
    height: 24px;
    margin: 0 4px 0 0
}
.docs-gm-dialogs .waffle-sd-row-separator {
    margin-top: 16px;
    margin-bottom: 16px
}
.waffle-sort-dialog-data-header {
    overflow: hidden
}
.docs-gm-dialogs .waffle-sort-dialog-data-header {
    margin-bottom: 25px
}
.waffle-sort-dialog-data-header .docs-material-gm-labeled-checkbox {
    padding: 0
}
.docs-gm-dialogs .docs-dialog .modal-dialog-title-close {
    top: -1px
}
.docs-gm-dialogs .docs-dialog .goog-flat-menu-button {
    padding-top: 7px;
    padding-bottom: 7px
}
.importThemeLabel {
    padding: 0px 3px
}
.importThemeOption {
    padding: 5px 7px
}
.importThemeWarningMessage {
    color: #9e9e9e;
    padding: 0px 25px
}
.goog-palette-cell-selected .goog-palette-colorswatch {
    background: url("//ssl.gstatic.com/docs/spreadsheets/MainMenuVerSprite007.png") transparent no-repeat;
    background-position: 0px -15px
}
.goog-palette-cell {
    border: 1px #666 solid
}
.trix-palette .toolbar-icon,
.trix-palette .docs-common-icon {
    margin: 3px 5px 4px 2px
}
.trix-palette .goog-palette-cell {
    border: 0
}
.trix-palette .goog-palette-table {
    margin: 0 4px;
    border: 0
}
.docs-gm .trix-palette .goog-palette-table {
    border-spacing: 2px;
    border-collapse: separate
}
.trix-palette .goog-palette-cell-hover {
    background: #eee
}
.docs-gm .trix-palette .toolbar-icon,
.docs-gm .trix-palette .docs-common-icon {
    margin: 0
}
.docs-toolbar-menu-button .goog-toolbar-menu-button-caption {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}
.docs-toolbar-menu-button .goog-toolbar-menu-button-icon {
    margin-left: 3px;
    margin-right: 6px;
    opacity: 1
}
.docs-toolbar-menu-button .goog-toolbar-menu-button-inner-box {
    text-align: left
}
.docs-bgcolor-toolbar-menu-button {
    color: #fff!important;
    border: 1px solid rgba(0, 0, 0, 0.09)!important;
    background-image: none;
    overflow: hidden
}
.docs-bgcolor-toolbar-menu-button .goog-toolbar-menu-button-outer-box {
    z-index: 1
}
.docs-bgcolor-toolbar-menu-button:after {
    content: "";
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background-image: linear-gradient(rgba(0, 0, 0, 0), rgba(0, 0, 0, 0.08))
}
.docs-bgcolor-toolbar-menu-button.goog-toolbar-menu-button-hover:hover {
    border: 1px solid rgba(0, 0, 0, 0.18)!important
}
.docs-bgcolor-toolbar-menu-button.goog-toolbar-menu-button-hover:hover:after {
    background-image: linear-gradient(rgba(0, 0, 0, 0), rgba(0, 0, 0, 0.12))
}
.docs-bgcolor-toolbar-menu-button.goog-toolbar-menu-button-hover:not(:hover) {
    -webkit-box-shadow: inset 0 0 0 1px #fff;
    -moz-box-shadow: inset 0 0 0 1px #fff;
    box-shadow: inset 0 0 0 1px #fff;
    border: 1px solid #fff;
    border: rgba(0, 0, 0, 0) solid 1px;
    outline: 1px solid #4d90fe;
    outline: rgba(0, 0, 0, 0) 0
}
.docs-bgcolor-toolbar-menu-button .goog-toolbar-menu-button-dropdown {
    background: no-repeat url(//ssl.gstatic.com/docs/common/jfk_sprite186.png) 0 -1581px;
    height: 12px;
    width: 6px;
    margin-top: 2px
}
#docs-access-level-indicator.docs-acl-indicator-visual-update.goog-flat-menu-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    cursor: pointer;
    height: 24px;
    line-height: 20px;
    margin: 6px 0 6px 8px;
    padding: 0 1px;
    user-select: none
}
#docs-access-level-indicator.docs-acl-indicator-visual-update.goog-flat-menu-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #2a8947;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15);
    cursor: pointer;
    height: 24px;
    line-height: 20px;
    margin: 6px 0 6px 8px;
    padding: 0 1px;
    user-select: none
}
#docs-access-level-indicator.docs-acl-indicator-visual-update.goog-flat-menu-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #4f9e67;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15);
    cursor: pointer;
    height: 24px;
    line-height: 20px;
    margin: 6px 0 6px 8px;
    padding: 0 1px;
    user-select: none
}
#docs-access-level-indicator.docs-acl-indicator-visual-update.goog-flat-menu-button-hover.goog-flat-menu-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 1px 3px 1px rgba(52, 168, 83, 0.15);
    cursor: pointer;
    height: 24px;
    line-height: 20px;
    margin: 6px 0 6px 8px;
    padding: 0 1px;
    user-select: none
}
#docs-access-level-indicator.docs-acl-indicator-visual-update.goog-flat-menu-button-disabled {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    cursor: pointer;
    height: 24px;
    line-height: 20px;
    margin: 6px 0 6px 8px;
    padding: 0 1px;
    user-select: none;
    cursor: default;
    opacity: .38
}
#docs-access-level-indicator.docs-acl-indicator-visual-update.goog-flat-menu-button-pressed,
#docs-access-level-indicator.docs-acl-indicator-visual-update.goog-flat-menu-button:active,
#docs-access-level-indicator.docs-acl-indicator-visual-update.goog-flat-menu-button-open,
#docs-access-level-indicator.docs-acl-indicator-visual-update.goog-flat-menu-button-hover.goog-flat-menu-button-open,
#docs-access-level-indicator.docs-acl-indicator-visual-update.goog-flat-menu-button-focused.goog-flat-menu-button-open {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #188038;
    color: #fff;
    background: #62a877;
    box-shadow: 0 2px 6px 2px rgba(52, 168, 83, 0.15);
    cursor: pointer;
    height: 24px;
    line-height: 20px;
    margin: 6px 0 6px 8px;
    padding: 0 1px;
    user-select: none
}
#docs-access-level-indicator.docs-acl-indicator-visual-update .docs-access-level-indicator-icon-container {
    margin: 2px 4px 4px 6px
}
#docs-access-level-indicator.docs-acl-indicator-visual-update .goog-flat-menu-button-caption {
    margin-right: 20px;
    font-size: 12px;
    font-weight: 500;
    line-height: 21px
}
#docs-access-level-indicator.docs-acl-indicator-visual-update .goog-flat-menu-button-dropdown {
    border-bottom-color: #fff;
    border-top-color: #fff;
    right: 7px;
    top: 10px
}
#docs-access-level-indicator {
    margin-left: 12px
}
.docs-access-level-indicator-view {
    background-color: #4d90fe
}
.docs-access-level-indicator-comment {
    background-color: #1aa863
}
.docs-access-level-indicator-view .goog-toolbar-menu-button-caption,
.docs-access-level-indicator-comment .goog-toolbar-menu-button-caption {
    min-width: 93px
}
.goog-toolbar .docs-access-level-indicator-locked {
    color: #757575
}
.docs-access-level-indicator-locked .goog-toolbar-menu-button-caption {
    min-width: unset
}
.docs-access-level-indicator-locked .goog-toolbar-menu-button-outer-box {
    background-color: #ffffff
}
.docs-access-level-indicator-locked .goog-toolbar-menu-button-dropdown {
    height: 12px;
    margin-left: 10px;
    margin-top: 6px;
    width: 6px
}
.docs-access-level-indicator-no-icon-label {
    margin-left: 9px
}
.docs-access-level-indicator-menu.docs-acl-indicator-visual-update {
    border-radius: 8px;
    max-width: 272px;
    padding: 22px 24px 24px 24px
}
.docs-access-level-indicator-menu.docs-acl-indicator-visual-update .docs-access-level-indicator-menu-text {
    padding: 0;
    font-size: 14px;
    color: #3c4043
}
.docs-access-level-indicator-menu.docs-acl-indicator-visual-update .docs-access-level-indicator-request-access-button {
    height: 24px;
    margin: 16px 0 0 0;
    padding: 4px 12px;
    text-transform: none
}
.docs-access-level-indicator-menu-text {
    color: rgba(0, 0, 0, .67);
    font-size: 13px;
    line-height: 20px;
    padding: 10px 20px 7px;
    width: 196px
}
.docs-access-level-indicator-button-area {
    text-align: left;
    padding: 6px 20px 6px 13px
}
.docs-access-level-indicator-request-access-button.jfk-button {
    cursor: pointer;
    border-radius: 2px;
    font-size: 12px;
    font-weight: 500;
    padding: 6px 6px 5px;
    text-transform: uppercase
}
.docs-access-level-indicator-request-access-button-locked,
.docs-access-level-indicator-request-access-button-view {
    color: #4285f4
}
.docs-access-level-indicator-request-access-button-comment {
    color: #0f9d58
}
.docs-access-level-indicator-request-access-button.jfk-button-disabled {
    cursor: default
}
.docs-access-level-indicator-request-access-button.jfk-button-hover,
.docs-access-level-indicator-request-access-button:focus {
    background-color: rgba(153, 153, 153, .2)
}
.docs-access-level-indicator-request-access-button.jfk-button-selected,
.docs-access-level-indicator-request-access-button.jfk-button-active {
    background-color: rgba(153, 153, 153, .4)
}
#docs-approvals-status-indicator-toolbar-separator {
    margin-right: 0px
}
.docs-gm #docs-primary-toolbars #docs-approvals-locked-menu-button.goog-toolbar-menu-button {
    cursor: pointer;
    height: 24px;
    line-height: 24px;
    margin: 6px 0 6px 4px;
    padding: 0 4px;
    user-select: none
}
#docs-approvals-locked-menu-button .goog-toolbar-menu-button-dropdown {
    margin-left: 2px
}
.docs-gm #docs-primary-toolbars .docs-approval-status-indicator {
    cursor: pointer;
    color: #188038;
    font-size: 14px;
    font-weight: 500;
    height: 26px;
    letter-spacing: .25px;
    margin: 5px 0px 5px 4px;
    min-width: unset;
    padding: 0px 12px 0px 9px;
    user-select: none
}
.docs-gm #docs-primary-toolbars .docs-approval-status-indicator .docs-icon-img {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_green.svg);
    cursor: default;
    margin: -1px 2px 4px 0px
}
.docs-approval-status-indicator-text {
    line-height: 23px
}
.docs-icon-inputtools-button-inner {
    margin: 2px 0
}
.docs-icon-inputtools-menuitem-inner {
    margin: 1px 0;
    opacity: .70
}
.docs-icon.docs-icon-inputtools-menuitem-outter,
.docs-material .docs-icon.docs-icon-inputtools-menuitem-outter {
    margin: 0 10px 0 12px
}
.docs-material .docs-icon.docs-icon-inputtools-menuitem-outter,
.docs-material #inputToolsToggleButton .docs-icon {
    width: 21px;
    height: 21px
}
@media print {
    .docs-ui-unprintable {
        display: none!important
    }
}
.docs-fontmenu-icon {
    left: 16px
}
.docs-fontmenu-text {
    padding-left: 23px
}
.docs-fontmenu-newlyadded {
    background-color: #fffecc
}
.goog-menuitem-highlight.docs-menuitem-add-fonts {
    border: none;
    padding-top: 6px;
    padding-bottom: 6px
}
.goog-menuitem-highlight.docs-fontmenu-newlyadded,
.goog-menuitem-hover.docs-fontmenu-newlyadded {
    background-color: #eee
}
#docs-font-family .goog-toolbar-menu-button-caption {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    width: 70px
}
.docs-fontmenu .docs-submenuitem {
    border: none;
    height: 18px;
    padding: 6px 8em 6px 30px
}
.docs-fontmenu .docs-submenuitem-splitbutton {
    height: 28px;
    line-height: 28px
}
.docs-fontmenu .docs-submenuitem .goog-menuitem-content {
    height: 17px;
    line-height: normal
}
.docs-fontmenu .docs-submenuitem .goog-menuitem-checkbox {
    height: 21px;
    top: 3px
}
.docs-fontmenu .docs-submenuitem::before {
    content: '\0025ba';
    position: absolute;
    right: 0;
    color: #6e6e6e;
    width: 34px;
    text-align: center;
    font-size: 70%;
    line-height: 30px;
    top: 0
}
body[dir="rtl"] .docs-fontmenu .docs-submenuitem::before {
    content: '\0025c4'
}
.docs-fontmenu .docs-halfhovermenuitem .goog-submenu-arrow {
    display: none
}
#contain-402 {
    bottom: 10px;
    position: fixed;
    right: 50px;
    z-index: 1002
}
.sketchy-dialog.modal-dialog {
    padding: 0
}
.sketchy-dialog .modal-dialog-title {
    margin: 24px 44px 14px 44px;
    position: relative
}
.docs-gm-dialogs .sketchy-dialog .modal-dialog-title {
    margin: 24px
}
.sketchy-dialog-title-close {
    margin-right: 0;
    position: absolute;
    right: 0;
    top: -8px
}
.docs-gm-dialogs .sketchy-dialog-title-close {
    top: -5px
}
.sketchy-dialog-title-autosave {
    color: #999;
    font-weight: normal;
    font-size: 12px;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    margin-left: 24px
}
.docs-gm-dialogs .sketchy-dialog-title-autosave {
    color: #80868b
}
.waffle-comment-anchor {
    width: 240px
}
.docs-gm-sidebars .waffle-comment-anchor {
    width: 282px
}
.docos-mole {
    bottom: 28px
}
.waffle-docos-target-cell-border {
    border-color: #f4b400
}
.waffle-docos-target-cell-rect {
    background-color: #ffe168;
    opacity: .5;
    pointer-events: none
}
.waffle-docos-target-cell-resolved-rect {
    background-color: #d9d9d9;
    opacity: .5;
    pointer-events: none
}
th.waffle-docos-target-cell-header {
    background-color: #fcfac6
}
.waffle-objwrap-gvizchart {
    background-color: white;
    height: 100%;
    z-index: 18
}
.waffle-embedded-object-overlay {
    outline: 0;
    position: absolute;
    z-index: 10
}
.waffle-obj-menu-open {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -763px -13px;
    border: none;
    color: #15c;
    float: right;
    height: 13px;
    margin: 10px;
    padding: 0;
    text-decoration: none;
    width: 13px
}
.waffle-obj-menu-open-active,
.waffle-obj-menu-open:hover {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -618px -27px
}
.waffle-obj-message-div {
    padding: 15px 0 15px 15px;
    font-size: 12pt
}
.waffle-borderless-embedded-object-overlay {
    border: 1px solid #999;
    margin: 0;
    outline: none;
    position: absolute;
    z-index: 10;
    user-select: none;
    pointer-events: all
}
.waffle-borderless-embedded-object-container {
    position: relative
}
.waffle-borderless-embedded-object-container .waffle-objwrap-gvizchart {
    background-color: transparent;
    z-index: 15
}
.waffle-obj-control {
    position: absolute;
    z-index: 18
}
.waffle-obj-glasspane-control.waffle-obj-control {
    z-index: 17
}
.waffle-obj-glasspane-control {
    left: 0;
    position: absolute;
    top: 0
}
.waffle-obj-gviz-control {
    border: 1px solid #999;
    position: absolute;
    right: -48px;
    top: -1px
}
.waffle-obj-drag-component {
    position: absolute;
    border: none;
    background-color: #0096fd
}
.waffle-selectionbox-background {
    display: none
}
.docs-charts-tooltip {
    z-index: 3
}
.waffle-charts-alert {
    -webkit-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    -moz-box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    box-shadow: 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 3px 1px -2px rgba(0, 0, 0, 0.12), 0px 1px 5px 0px rgba(0, 0, 0, 0.2);
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    background: rgba(0, 0, 0, 0.87);
    border-radius: 2px;
    bottom: 0;
    line-height: 16px;
    margin: 4px;
    max-height: 93%;
    max-width: 99%;
    padding: 10px 14px;
    position: absolute;
    white-space: nowrap;
    z-index: 1000
}
.waffle-charts-alert-text {
    color: #fff;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    white-space: normal
}
.waffle-charts-alert-link-div {
    float: right;
    padding-left: 35px
}
a.waffle-charts-alert-link {
    -webkit-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -moz-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    -o-transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    transition: opacity 250ms cubic-bezier(0.4, 0.0, 0.2, 1);
    color: #a1c2fa;
    cursor: pointer;
    text-decoration: none;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    opacity: 0.87;
    text-transform: uppercase
}
a.waffle-charts-alert-link:hover {
    opacity: 1
}
a.waffle-charts-alert-link-close {
    color: white;
    margin-left: 15px
}
.waffle-charts-overflow-legend {
    background-color: #ffffff;
    border: 1px solid #999;
    position: absolute
}
.waffle-charts-overflow-legend-scrollbar {
    position: absolute;
    top: 0;
    width: 10px
}
.waffle-obj-menu-control {
    right: 5px;
    top: 5px
}
.waffle-obj-menu-button {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -763px -13px;
    cursor: pointer;
    height: 13px;
    width: 13px
}
.waffle-obj-menu-button.waffle-obj-menu-control-active,
.waffle-obj-menu-button:hover {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -618px -27px
}
.waffle-obj-menu-control-material {
    right: 6px;
    top: 6px
}
.waffle-obj-menu-control-table-chart {
    right: 20px
}
.waffle-chart-filter-indicator-control {
    right: 6px;
    top: 6px
}
.waffle-borderless-embedded-object-overlay-focused .waffle-chart-filter-indicator-control {
    right: 24px
}
.waffle-chart-filter-indicator-control-table-chart {
    right: 20px
}
.waffle-borderless-embedded-object-overlay-focused .waffle-chart-filter-indicator-control-table-chart {
    right: 38px
}
.waffle-objwrap-gvizchart div[id^='google-visualization-errors-all-'] {
    background-image: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyNCIgaGVpZ2h0PSIyNCIgdmlld0JveD0iMCAwIDI0IDI0IiBmaWxsPSIjRTBFMEUwIj48cGF0aCBkPSJNOSAxN0g3di03aDJ2N3ptNCAwaC0yVjdoMnYxMHptNCAwaC0ydi00aDJ2NHptMi41IDJoLTE1VjVoMTV2MTR6bTAtMTZoLTE1Yy0xIDAtMiAxLTIgMnYxNGMwIDEgMSAyIDIgMmgxNWMxIDAgMi0xIDItMlY1YzAtMS0xLTItMi0yeiIvPjxwYXRoIGZpbGw9Im5vbmUiIGQ9Ik0wIDBoMjR2MjRIMHoiLz48L3N2Zz4="), url("data:image/svg+xml;base64,PHN2ZyB2aWV3Qm94PSIwIDAgNjAwIDM3MSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj48cGF0aCBkPSJNMCAxdjFoNjAwVjF6bTAgOTB2MWg2MDB2LTF6bTAgOTF2MWg2MDB2LTF6bTAgOTF2MWg2MDB2LTF6IiBmaWxsPSIjZWVlIi8+PHBhdGggZD0iTTAgMzY2djJoNjAwdi0yeiIgZmlsbD0iI2NmY2ZjZiIvPjwvc3ZnPgo=");
    background-position: center, 0 0;
    background-repeat: no-repeat, repeat-x;
    background-size: 100px 100px, auto 100%;
    height: 100%;
    width: 100%;
    white-space: normal
}
.waffle-objwrap-gvizchart div[id^='google-visualization-errors-all-']>div {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif!important;
    font-size: 14px!important;
    padding-top: 15px;
    text-align: center
}
.waffle-objwrap-gvizchart div[id^='google-visualization-errors-all-']>div>span {
    background-color: transparent!important;
    color: #db4437!important;
    display: block
}
.waffle-objwrap-gvizchart div[id^='google-visualization-errors-all-']>div>span:before {
    background-image: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAxNiAxNiI+PHBhdGggZmlsbD0iI0RCNDQzNyIgZD0iTTggMEMzLjYgMCAwIDMuNiAwIDhzMy42IDggOCA4IDgtMy42IDgtOC0zLjYtOC04LTh6bS44IDEySDcuMnYtMS42aDEuNlYxMnptMC0zLjJINy4yVjRoMS42djQuOHoiLz48L3N2Zz4K");
    background-position: 0 0;
    background-repeat: no-repeat;
    background-size: 16px 16px;
    content: '';
    display: inline-block;
    height: 16px;
    margin-right: 10px;
    vertical-align: sub;
    width: 16px
}
div.ac-datavalidation-renderer {
    z-index: 1001;
    overflow: auto;
    box-shadow: 1px 2px 5px rgba(0, 0, 0, 0.4)
}
div.ac-datavalidation-renderer-upside-down {
    z-index: 1001;
    overflow: auto;
    box-shadow: 1px 0 5px rgba(0, 0, 0, 0.4)
}
.waffle-ac-renderer {
    margin: 0px 0px;
    padding: 0;
    z-index: 85;
    overflow: visible;
    position: absolute;
    white-space: nowrap;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-weight: normal;
    line-height: 22px;
    border: 1px solid rgba(0, 0, 0, 0.2);
    background: #fff;
    -webkit-box-shadow: 0 2px 4px rgba(0, 0, 0, .2);
    -moz-box-shadow: 0 2px 4px rgba(0, 0, 0, .2);
    box-shadow: 0 2px 4px rgba(0, 0, 0, .2)
}
.waffle-ac-row {
    margin: 0;
    cursor: pointer;
    padding: 2px 10px;
    color: #666666
}
.waffle-ac-active {
    background: #f5f5f5;
    color: #000;
    border-top: 1px solid #ebebeb;
    border-bottom: 1px solid #ebebeb;
    padding: 1px 10px
}
.waffle-ac-highlighted {
    font-weight: 500
}
#docs-chrome {
    zoom: 1
}
.docs-toolbar .goog-menuitem-highlight {
    background-color: #e0edfe
}
.ie8 .goog-toolbar-button-disabled .toolbar-icon,
.ie8 .goog-toolbar-button-disabled .docs-icon-img,
.ie8 .goog-toolbar-button-disabled .goog-toolbar-button-inner-box,
.ie8 .goog-toolbar-menu-button-disabled .toolbar-icon,
.ie8 .goog-toolbar-menu-button-disabled .docs-icon-img,
.ie8 .goog-toolbar-menu-button-disabled .goog-toolbar-menu-button-caption,
.ie8 .goog-toolbar-menu-button-disabled .goog-color-menu-button-indicator,
.ie8 .goog-toolbar-menu-button-disabled .goog-toolbar-menu-button-dropdown {
    filter: alpha(opacity=30)
}
.close-icon-small {
    width: 12px;
    background-position: -720px 2px
}
.docs-icon.goog-menuitem-icon {
    position: absolute
}
.goog-clipboard {
    width: 16px
}
#chart-toolbar-container {
    width: 100%
}
.chart-toolbar-container-with-omnibox {
    display: inline-block
}
#chart-toolbar {
    border: none;
    padding: 0 30px 0 0;
    position: absolute;
    right: 0;
    top: 0
}
#datasheet-toolbar {
    background: none;
    border-width: 0!important;
    display: inline;
    min-height: 35px;
    padding: 0
}
.chart-toolbar-with-omnibox#chart-toolbar {
    right: 40px
}
.docs-material .chart-toolbar-with-omnibox {
    background: none
}
#chart-toolbar-title {
    padding-top: 3px
}
.chart-toolbar-title-with-omnibox {
    display: inline-block;
    vertical-align: middle
}
#chart-toolbar-title.sheet-toolbar-title {
    line-height: normal
}
.sheet-toolbar {
    min-height: 22px
}
.object-toolbar-secondary {
    margin-right: 13px!important
}
.sheet-toolbar-title {
    font-weight: 500;
    vertical-align: middle;
    line-height: 20px;
    padding: 0 6px 0 4px
}
.goog-color-menu-button-indicator {
    border-bottom: 4px solid #f0f0f0
}
#num-fmt-currency {
    margin-top: -250px
}
#num-fmt-date {
    margin-top: -100px
}
.num-fmt {
    clear: both;
    height: 1em;
    width: 180px
}
.num-fmt b {
    display: block;
    font-weight: normal;
    float: left
}
.num-fmt span {
    display: block;
    float: right;
    color: #666;
    font-size: 85%
}
.currency-fmt {
    width: 120px;
    font-size: 92%;
    height: 0.9em
}
.date-fmt {
    width: 140px;
    font-size: 92%;
    height: 0.9em
}
.cond-fmt .goog-color-menu-button-indicator {
    border-bottom-style: double
}
#formula-bar {
    padding: 4px 0;
    background: #e5e5e5;
    margin-right: auto
}
#formula-bar table {
    width: 100%;
    border-spacing: 0
}
#t-formula-bar-label {
    vertical-align: middle;
    color: #444;
    padding: 0 8px
}
#t-formula-bar-label.waffle-formulabar-label-disabled {
    color: #9fa4b3
}
#t-formula-bar-input-container {
    width: 100%;
    padding: 0
}
#t-formula-bar-input {
    resize: none;
    border: 1px #7f9db9 solid;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    background-color: #ffffff
}
#t-formula-bar-input.waffle-formulabar-input-disabled {
    background-color: #eee;
    border-color: #c0c0c0
}
#t-formula-bar-input .cell-input {
    word-wrap: break-word;
    -webkit-nbsp-mode: space;
    -webkit-line-break: after-white-space
}
.ie8 .goog-toolbar-button-disabled .toolbar-icon,
.ie8 .goog-toolbar-button-disabled .docs-icon-img,
.ie8 .goog-toolbar-button-disabled .goog-toolbar-button-inner-box,
.ie8 .goog-toolbar-menu-button-disabled .toolbar-icon,
.ie8 .goog-toolbar-menu-button-disabled .docs-icon-img,
.ie8 .goog-toolbar-menu-button-disabled .goog-toolbar-menu-button-caption,
.ie8 .goog-toolbar-menu-button-disabled .goog-color-menu-button-indicator,
.ie8 .goog-toolbar-menu-button-disabled .goog-toolbar-menu-button-dropdown {
    filter: alpha(opacity=30)
}
.docs-toolbar-small-separator+div.goog-toolbar-select {
    margin-left: -4px
}
#t-text-rotation-palette .goog-palette-table {
    border-right: 1px solid #eee
}
.docs-gm #t-text-rotation-palette .goog-palette-table {
    border-right: 1px solid #dadce0
}
body:not(.docs-gm) #t-text-rotation-palette .goog-palette-cell-selected,
.waffle-combobox-menuitem-selected {
    background-color: #e1e1e1
}
.waffle-text-rotation-combobox {
    border-color: transparent
}
body:not(.docs-gm) .waffle-text-rotation-combobox {
    margin-top: -3px!important
}
.docs-gm .goog-toolbar-combo-button.waffle-text-rotation-combobox {
    margin: 1px
}
.waffle-text-rotation-combobox.goog-toolbar-combo-button-hover {
    background: transparent
}
.docs-material .waffle-text-rotation-combobox.goog-toolbar-combo-button-hover {
    background: rgba(0, 0, 0, .06)
}
.waffle-text-rotation-combobox .goog-toolbar-combo-button-input {
    height: 28px;
    width: 25px
}
.waffle-revisions-frame {
    border-style: none
}
.waffle-revisions-older-text {
    color: #676767
}
.waffle-revisions-container {
    background-color: #fff;
    z-index: 15;
    overflow: hidden;
    position: absolute;
    left: 0
}
#revisions-toolbar {
    padding: 2px 0
}
#t-revisions-back {
    margin-left: 6px
}
#t-revisions-revert,
#t-revisions-label {
    margin: 0 8px;
    font-weight: 500
}
#t-revisions-label {
    line-height: 180%
}
#t-revisions-highlighted-label {
    position: absolute;
    right: 6px;
    top: 0;
    line-height: 217%
}
#t-revisions-highlighted {
    border: 2px solid #ffa82d;
    background-color: #ffd396;
    padding: 2px
}
#t-revisions-menu {
    overflow-y: auto;
    max-height: 75%;
    width: 290px
}
#t-revisions-menu .goog-menuitem {
    padding: 4px 0px;
    width: 268px;
    clear: both;
    height: 1em
}
#t-revisions-menu em {
    display: block;
    float: left;
    white-space: nowrap;
    text-align: right;
    font-style: normal;
    width: 134px
}
#t-revisions-menu span {
    display: block;
    float: left;
    white-space: nowrap;
    color: #666;
    width: 134px
}
.waffle-spellcheck-target-cell-rect {
    background-color: #f8b39b;
    opacity: .5;
    pointer-events: none
}
div.sheet-toolbar {
    width: 100%;
    background-image: none;
    min-height: 35px;
    border-bottom: 1px solid #d9d9d9;
    padding: 0
}
.sheet-toolbar-button {
    margin: 3px 2px 0 0
}
.sheet-toolbar-title {
    line-height: 35px;
    padding: 0 44px 0 44px
}
.toolbar-decimal-icon {
    margin-bottom: -7px
}
.docs-material .docs-icon.toolbar-decimal-icon {
    margin-bottom: -4px
}
.docs-material #t-num-fmt-currency,
.docs-material #t-num-fmt-percent {
    font-size: 13px
}
#formula-bar {
    background: #fff;
    border-bottom: 1px solid #c0c0c0;
    height: 23px;
    padding: 0;
    position: relative
}
#t-formula-bar-input {
    border: none;
    bottom: 4px;
    left: 0;
    line-height: 13px;
    position: absolute;
    right: 0;
    top: 4px
}
#t-formula-bar-input.waffle-formulabar-input-disabled {
    background-color: #fff;
    border: none
}
#t-formula-bar-label {
    float: left;
    opacity: .55;
    padding: 0;
    position: relative;
    text-align: center;
    top: 50%;
    transform: translateY(-50%);
    width: 45px
}
.docs-icon-insert-formula {
    margin-top: -1px
}
.docs-material .docs-icon-insert-formula {
    margin-top: 0;
    opacity: .70
}
.formulabar-disabled#formula-bar {
    background-color: #f8f8f8
}
.formulabar-disabled #t-formula-bar-label {
    color: #9fa4b3;
    opacity: .4
}
.formulabar-disabled #t-formula-bar-input {
    background-color: #f8f8f8!important
}
.formulabar-disabled .default-formula-text-color {
    color: #777
}
#t-formula-bar-input-container {
    height: 100%;
    padding: 0 10px;
    overflow: hidden;
    width: auto
}
#t-formula-bar-input-container>div {
    height: 100%;
    overflow-x: hidden;
    overflow-y: auto;
    position: relative
}
#t-formula-bar-progress-bar {
    float: right;
    margin-top: 7px;
    padding: 0;
    width: 161px
}
#t-formula-bar-progress-bar .progress-bar-horizontal {
    width: 146px;
    height: 5px;
    border: 1px solid #999;
    padding: 1px;
    background-color: #fff
}
#t-formula-bar-progress-bar .progress-bar-thumb {
    background-color: #ccc
}
.formula-bar-separator {
    float: left;
    width: 1px;
    height: 100%;
    position: relative
}
.formula-bar-separator>div {
    background-color: #ccc;
    bottom: 3px;
    left: 0;
    position: absolute;
    right: 0;
    top: 3px;
    width: 1px
}
#formula-bar-dragger {
    border-bottom: 1px solid #c0c0c0;
    height: 4px;
    margin-top: -5px;
    position: absolute;
    width: 100%
}
#formula-bar-dragger.formula-bar-hoverable {
    cursor: ns-resize
}
#formula-bar-dragger.formula-bar-hoverable:hover {
    border-bottom: 1px solid #a0a0a0
}
div.formula-bar-disabled {
    background-color: #ccc
}
.waffle-formulabar-cellinput-disabled {
    background-color: #ccc
}
#t-merge-menu {
    margin-right: 2px
}
.docs-material #t-merge-menu {
    margin-right: 1px
}
.goog-toolbar-color-menu-button .goog-toolbar-menu-button-dropdown {
    margin-top: 9px
}
.goog-menuitem-mnemonic-separator {
    font-weight: normal
}
.waffle-banding-pane-sidebar-content {
    overflow-y: hidden
}
.waffle-banding-pane {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    height: 100%;
    overflow-y: auto
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane {
    height: calc(100% - 36px)
}
.waffle-banding-range-picker {
    border-bottom: 1px solid lightgrey;
    padding: 15px 10px
}
.waffle-banding-range-label {
    padding-bottom: 5px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-range-label {
    color: #3c4043;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    line-height: 20px;
    padding-bottom: 10px
}
.waffle-banding-header-footer-checkbox-wrapper {
    border-bottom: 1px solid lightgrey;
    padding: 10px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-header-footer-checkbox-wrapper {
    padding-bottom: 0
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-range-picker,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-header-footer-checkbox-wrapper {
    border-bottom: 0
}
.waffle-banding-checkbox-wrapper {
    padding: 5px 0
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-checkbox-wrapper {
    display: inline;
    padding-right: 20px
}
.waffle-banding-checkbox-wrapper .docs-material-gm-labeled-checkbox {
    display: inline;
    max-width: none;
    width: auto
}
.waffle-banding-pane-color-picker {
    padding: 15px 10px
}
.waffle-banding-pane-color-picker-label {
    padding: 5px 0
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane-color-picker-label {
    color: #3c4043;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-weight: 500;
    line-height: 12px
}
.waffle-banding-color-picker-table,
.waffle-banding-color-picker-focused,
.waffle-banding-color-picker-hover {
    border: 0;
    margin: 0;
    outline: none;
    padding: 0;
    width: 0
}
.waffle-banding-color-picker-table {
    border-spacing: 5px;
    border-collapse: separate
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-color-picker-table {
    border-spacing: 4px
}
.waffle-banding-color-picker-cell {
    border-width: 0
}
.waffle-banding-color-picker-cell:focus {
    outline: 1px solid #5e97f6
}
.waffle-banding-pane-color-tile-wrapper {
    border: 1px solid transparent
}
.waffle-banding-color-picker-cell-selected .waffle-banding-pane-color-tile-wrapper {
    border: 1px solid #4d90fe
}
.waffle-banding-color-picker-cell-hover .waffle-banding-pane-color-tile {
    border-color: darkgrey
}
.waffle-banding-pane-color-tile {
    border: 1px solid lightgrey;
    cursor: pointer;
    height: 35px;
    line-height: 35px;
    margin: 1px;
    vertical-align: middle;
    width: 26px
}
.docs-gm-sidebars .waffle-banding-pane-color-tile {
    width: 33px
}
.docs-gm-sidebars .waffle-assistant-banding-recommendation .waffle-banding-pane-color-tile {
    width: 26px
}
.waffle-banding-pane-color-tile-wrapper .docs-sheet-add .docs-icon {
    margin-left: 4px
}
.docs-gm-sidebars .waffle-banding-pane-color-tile-wrapper .docs-sheet-add .docs-icon {
    margin-left: 7px
}
.docs-gm-sidebars .waffle-gm-sidebar .docs-sheet-add .docs-icon-img {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_green.svg)
}
.waffle-banding-pane-color-tile-band {
    border-bottom: 1px solid lightgrey;
    height: 8px;
    width: 100%
}
.waffle-banding-pane-color-tile-band:last-child {
    border-bottom-width: 0
}
.waffle-banding-pane-color-picker-preview {
    padding-top: 10px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane-color-picker-preview {
    padding: 5px
}
.waffle-banding-pane-color-preview {
    padding: 5px 0
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane-color-preview {
    display: flex
}
.docs-material.waffle-banding-pane-color-preview .goog-toolbar-menu-button {
    margin: 0
}
.waffle-banding-pane-color-preview-label {
    border: 1px solid lightgrey;
    display: inline-block;
    height: 24px;
    line-height: 24px;
    margin-right: 5px;
    text-align: center;
    vertical-align: middle;
    width: 170px
}
.docs-material .waffle-banding-pane-color-preview-label {
    height: 26px;
    line-height: 26px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane-color-preview-label {
    border-radius: 4px;
    box-sizing: border-box;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 400;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane-color-picker-container {
    border: 1px solid #dadce0;
    border-radius: 4px;
    margin-top: 5px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane-custom-color-wrapper {
    border-bottom: 1px solid #dadce0
}
.waffle-banding-pane-color-preview-picker {
    background-color: #f8f8f8;
    border-color: #c6c6c6;
    display: inline-block;
    margin: 0
}
.docs-gm-sidebars .waffle-banding-pane-color-preview-picker.goog-flat-menu-button-active {
    background-color: #fff!important
}
.waffle-banding-pane-buttons {
    margin-bottom: 24px;
    padding: 0 10px 10px 10px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane-buttons {
    margin-bottom: 0;
    text-align: right
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane-buttons .jfk-button {
    margin-left: 16px;
    margin-right: 0px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-named-ranges-edit-buttons {
    text-align: right
}
.waffle-banding-pane-clear-container {
    border-top: 1px solid lightgrey;
    bottom: 0;
    left: 0;
    position: absolute;
    text-align: center;
    vertical-align: bottom;
    width: 100%
}
.waffle-banding-pane-clear {
    background-color: #fff;
    color: #424242;
    cursor: pointer;
    line-height: 24px;
    padding: 5px 0
}
.waffle-banding-pane-clear .docs-icon {
    opacity: 0.59
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane-clear .docs-icon {
    opacity: 1;
    opacity: unset
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane-clear .docs-icon-img {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_green.svg)
}
.waffle-banding-pane-clear:hover {
    background-color: #eee;
    border-color: darkgrey;
    color: #424242
}
.waffle-banding-pane-clear-label {
    padding-left: 3px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane-color-wrapper {
    margin-bottom: 3px;
    margin-left: 1px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane-clear {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    color: #188038;
    border-radius: 0!important;
    outline: none
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane-clear.goog-button-hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #f8fcf9;
    color: #188038
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane-clear.goog-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #e7f5eb;
    color: #188038
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane-clear.goog-button-hover.goog-button-focused {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    color: #188038
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-banding-pane-clear.goog-button-active {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    color: #188038;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15)
}
.waffle-conditionalformat-warning {
    background: #fff;
    border-bottom: 1px solid #bdbdbd;
    border-left: 8px solid #f4b400;
    box-sizing: border-box;
    box-shadow: 0 1px 4px 0 rgba(0, 0, 0, 0.22);
    color: #424242;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    line-height: 16px;
    padding: 14px 14px 14px 16px;
    z-index: 2
}
.waffle-conditionalformat-dismiss-warning-button-holder {
    height: 14px;
    margin-top: 6px;
    width: 212px
}
.waffle-conditionalformat-dismiss-warning-button {
    color: #3367d6;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    height: 14px;
    line-height: 14px;
    position: absolute;
    right: 14px
}
.waffle-conditionalformat-scroll-pane {
    overflow-x: hidden;
    overflow-y: auto
}
.waffle-conditionalformat-add-rule-button {
    background-color: #fafafa;
    border: 1px solid #bdbdbd;
    color: #3367d6;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 500;
    height: 15px;
    line-height: 15px;
    padding: 15px;
    text-align: left;
    width: 218px
}
.jfk-button-clear-outline.waffle-conditionalformat-add-rule-button {
    border: 1px solid #bdbdbd
}
.waffle-conditionalformat-add-rule-button:focus,
.waffle-conditionalformat-add-rule-button:hover {
    background-color: #f0f0f0;
    cursor: pointer
}
.waffle-conditionalformat-add-another-rule-button {
    background-color: #fff;
    border: 1px solid #eee;
    color: #3367d6;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    font-weight: 500;
    height: 14px;
    line-height: 14px;
    padding: 14px 17px;
    text-align: left;
    width: 214px
}
.jfk-button-clear-outline.waffle-conditionalformat-add-another-rule-button {
    border: 1px solid #eee
}
.waffle-conditionalformat-add-another-rule-button:focus,
.waffle-conditionalformat-add-another-rule-button:hover {
    background-color: #fafafa;
    cursor: pointer
}
.docs-gm-dialogs .waffle-filterbox-container .waffle-conditionalformat-condition-type-select .goog-flat-menu-button,
.docs-gm-dialogs .waffle-filterbox-container .waffle-conditionalformat-condition-date-select .goog-flat-menu-button,
.docs-gm-dialogs .waffle-filterbox-container .waffle-conditionalformat-arg1,
.docs-gm-dialogs .waffle-filterbox-container .waffle-conditionalformat-arg2,
.docs-gm-dialogs .waffle-filterbox-container .waffle-filterbox-input {
    width: 252px
}
.docs-gm-dialogs .waffle-conditionalformat-condition-type-select .goog-flat-menu-button,
.docs-gm-dialogs .waffle-conditionalformat-condition-date-select .goog-flat-menu-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #fff;
    border: 1px solid #dadce0!important;
    font-weight: normal
}
.docs-gm-dialogs .waffle-filterbox-boolean-condition-picker-body input {
    border: 1px solid #dadce0;
    border-radius: 4px;
    box-sizing: border-box;
    color: #3c4043;
    padding: 1px 8px;
    font-size: 14px;
    height: 36px;
    margin: 8px 0
}
.docs-gm-dialogs .waffle-filterbox-boolean-condition-picker-body input:focus {
    border: 2px solid #1a73e8;
    box-shadow: none;
    padding: 0px 7px
}
.waffle-conditionalformat-condition-type-select .goog-flat-menu-button,
.waffle-conditionalformat-condition-date-select .goog-flat-menu-button {
    text-align: left
}
.docs-gm-dialogs .waffle-conditionalformat-condition-type-select .goog-flat-menu-button,
.docs-gm-dialogs .waffle-conditionalformat-condition-date-select .goog-flat-menu-button {
    padding-right: 8px
}
.waffle-filterbox-boolean-condition-picker-body {
    margin: 6px 0 8px 0
}
.waffle-conditionalformat-add-rule-icon {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -83px -24px;
    height: 10px;
    position: absolute;
    right: 15px;
    top: 18px;
    width: 10px
}
.waffle-conditionalformat-add-another-rule-icon {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -552px -42px;
    height: 18px;
    position: absolute;
    right: 18px;
    top: 13px;
    width: 18px
}
.waffle-conditionalformat-view-pill {
    background-color: #fff;
    border-bottom: 1px solid #ccc;
    cursor: pointer;
    height: 56px;
    padding: 10px;
    position: relative
}
.waffle-conditionalformat-view-pill.waffle-conditionalformat-filter-border {
    border-left: 4px solid #f4b400;
    padding-left: 6px
}
.waffle-conditionalformat-view-pill:focus,
.waffle-conditionalformat-view-pill:hover {
    background-color: #f3f3f3;
    outline: none
}
.waffle-conditionalformat-drag-handle {
    cursor: move;
    height: 76px;
    line-height: 76px;
    left: 0;
    position: absolute;
    top: 0;
    visibility: hidden;
    width: 10px
}
.waffle-conditionalformat-view-pill:hover .waffle-conditionalformat-drag-handle {
    visibility: visible
}
.waffle-conditionalformat-view-pill.waffle-conditionalformat-filter-border .waffle-conditionalformat-drag-handle {
    left: -4px
}
.waffle-conditionalformat-drag-handle-icon {
    background: no-repeat url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png") -716px -17px;
    height: 18px;
    left: 4px;
    position: absolute;
    top: 29px;
    width: 3px
}
.waffle-conditionalformat-format-preview {
    height: 54px;
    line-height: 54px;
    margin-right: 10px;
    position: absolute;
    text-align: center;
    width: 44px
}
.waffle-conditionalformat-view-pill-summary {
    left: 56px;
    margin-right: 8px;
    position: relative;
    width: 142px
}
.waffle-conditionalformat-condition {
    color: #333;
    font-size: 13px;
    font-weight: 500;
    line-height: 15px;
    max-height: 30px;
    margin-bottom: 4px;
    overflow: hidden;
    text-overflow: ellipsis;
    width: 142px
}
.waffle-conditionalformat-range {
    color: #555;
    height: 14px;
    font-size: 12px;
    line-height: 14px;
    overflow: hidden;
    text-overflow: ellipsis;
    width: 142px
}
.waffle-conditionalformat-delete-button-holder {
    height: 56px;
    line-height: 56px;
    position: absolute;
    left: 216px
}
.waffle-conditionalformat-view-pill.waffle-conditionalformat-filter-border .waffle-conditionalformat-delete-button-holder {
    left: 212px
}
.waffle-conditionalformat-delete-button-holder .waffle-conditionalformat-delete-rule {
    opacity: 0.5
}
.waffle-conditionalformat-delete-button-holder .waffle-conditionalformat-delete-rule:hover {
    opacity: 1
}
.waffle-conditionalformat-drag-item {
    border: 1px solid #ccc;
    width: 228px
}
.waffle-conditionalformat-range-border {
    border-color: #8cc474;
    border-style: solid;
    line-height: 0
}
.waffle-conditionalformat-range-picker {
    border-bottom: 1px solid #d6d6d6;
    padding: 0 18px 18px 18px
}
.waffle-conditionalformat-range-wrapper {
    color: #444;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px
}
.waffle-conditionalformat-slide-frame,
.waffle-conditionalformat-slide-pane {
    position: absolute
}
.waffle-conditionalformat-boolean-condition-picker,
.waffle-conditionalformat-gradient-format-picker {
    border-top: 1px solid #f5f5f5;
    padding: 0 18px
}
.waffle-conditionalformat-boolean-format-picker {
    padding: 0 18px
}
.waffle-conditionalformat-edit-pill-section-label {
    color: #646464;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 12px;
    line-height: 14px;
    margin-bottom: 6px;
    margin-top: 18px
}
.waffle-conditionalformat-edit-pill-button-bar {
    padding: 18px;
    position: relative
}
.waffle-conditionalformat-cancel-button,
.waffle-conditionalformat-done-button {
    cursor: pointer
}
.waffle-conditionalformat-format-button {
    background-clip: padding-box;
    border-color: transparent;
    cursor: pointer;
    height: 32px;
    left: -1px;
    margin: 0;
    padding: 0;
    position: relative;
    width: 214px
}
.waffle-conditionalformat-format-button-inner {
    font-size: 13px;
    font-weight: normal;
    height: 30px;
    line-height: 30px;
    padding-left: 6px;
    text-align: left;
    width: 206px
}
.waffle-conditionalformat-default-style-button,
.waffle-conditionalformat-custom-style-button {
    background: #fff;
    background-clip: padding-box;
    cursor: pointer;
    height: 26px;
    line-height: 26px;
    margin: 3px
}
.waffle-conditionalformat-default-style-button {
    width: 60px
}
.waffle-conditionalformat-custom-style-button {
    text-align: left;
    padding: 0 6px;
    width: 184px
}
.waffle-conditionalformat-active-style-check {
    color: #000;
    font-weight: 500
}
.waffle-conditionalformat-condition-type-select .jfk-select,
.waffle-conditionalformat-condition-date-select .jfk-select {
    margin: 0;
    width: 188px
}
.waffle-conditionalformat-condition-date-select .jfk-select {
    margin-top: 6px
}
.waffle-conditionalformat-arg1 {
    margin: 6px 6px 0 0;
    width: 196px
}
.waffle-conditionalformat-arg1-short {
    width: 162px
}
.waffle-conditionalformat-arg2 {
    margin: 6px 6px 0 0;
    width: 162px
}
.waffle-conditionalformat-arg-separator {
    color: #424242;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 11px;
    font-weight: 500
}
.waffle-conditionalformat-multi-arg-content {
    max-height: 135px;
    overflow: auto
}
.waffle-conditionalformat-remove {
    color: #999;
    cursor: pointer;
    display: inline;
    margin: 0 0 0 8px
}
.waffle-conditionalformat-remove .docs-icon {
    height: 24px;
    margin: 0;
    width: 24px
}
.waffle-conditionalformat-editbox {
    margin: 5px 0;
    width: 162px
}
.waffle-conditionalformat-custom-toolbar {
    border: 1px solid #d8d8d8;
    border-radius: 1px;
    margin: 6px 0;
    padding: 0px 5px;
    width: 186px
}
.docs-material.waffle-conditionalformat-custom-toolbar {
    background-color: #fff;
    padding: 0 2px;
    width: 208px;
    border-radius: 0 0 4px 4px!important
}
.waffle-conditionalformat-gradient-point-holder {
    margin-bottom: 18px
}
.docs-material .waffle-conditionalformat-gradient-point-holder-last {
    margin-bottom: 0
}
.waffle-conditionalformat-gradient-min-select .jfk-select,
.waffle-conditionalformat-gradient-mid-select .jfk-select,
.waffle-conditionalformat-gradient-max-select .jfk-select {
    margin: 0 6px 0 0;
    text-align: left;
    width: 55px
}
.waffle-conditionalformat-gradient-input-holder {
    margin-right: 7px;
    top: 1px;
    width: 84px
}
.docs-material .waffle-conditionalformat-gradient-input-holder {
    margin-right: 6px
}
.waffle-conditionalformat-gradient-min-input,
.waffle-conditionalformat-gradient-mid-input,
.waffle-conditionalformat-gradient-max-input {
    width: 66px
}
.waffle-conditionalformat-gradient-min-input.label-input-label-disabled,
.waffle-conditionalformat-gradient-mid-input.label-input-label-disabled,
.waffle-conditionalformat-gradient-max-input.label-input-label-disabled {
    background-color: #ebebe4
}
.waffle-conditionalformat-gradient-min-color,
.waffle-conditionalformat-gradient-mid-color,
.waffle-conditionalformat-gradient-max-color {
    background-color: #f8f8f8;
    border-color: #c6c6c6;
    height: 27px;
    margin-top: 0
}
.waffle-conditionalformat-gradient-min-color:focus,
.waffle-conditionalformat-gradient-mid-color:focus,
.waffle-conditionalformat-gradient-max-color:focus {
    border-color: #4d90fe
}
.docs-material .waffle-conditionalformat-gradient-min-color,
.docs-material .waffle-conditionalformat-gradient-mid-color,
.docs-material .waffle-conditionalformat-gradient-max-color {
    height: 27px;
    margin: 0
}
.jfk-bubble.waffle-error-bubble.waffle-conditionalformat-error-bubble {
    z-index: 1!important
}
.waffle-conditionalformat-no-suggestions {
    color: #757575;
    font-size: 12px;
    font-style: italic;
    padding-top: 12px
}
.waffle-conditionalformat-suggestion {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    background-clip: content-box;
    height: 24px;
    line-height: 24px;
    padding: 1px;
    text-align: center
}
.waffle-conditionalformat-suggestion-chip {
    padding-top: 14px
}
.waffle-conditionalformat-suggestion-group {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -moz-flex-wrap: wrap;
    -ms-flex-wrap: wrap;
    -webkit-flex-wrap: wrap;
    flex-wrap: wrap;
    border: 1px solid #d0d0d0;
    padding: 1px
}
.waffle-conditionalformat-suggestion-range {
    font-weight: 500
}
.waffle-conditionalformat-collapsible-suggestions {
    border-bottom: 1px solid #d6d6d6
}
.waffle-conditionalformat-suggestions-section {
    padding: 18px
}
.waffle-conditionalformat-suggestion-text {
    color: #646464;
    font-size: 12px;
    padding-top: 6px
}
.waffle-conditionalformat-suggestions-title {
    color: #646464;
    font-weight: 500
}
.waffle-conditionalformat-suggestions-spinner-container {
    padding-top: 14px;
    text-align: center
}
.docs-gm-sidebars .waffle-conditionalformat-edit-pill-section-header {
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    margin-bottom: 18px;
    margin-top: 25px
}
.docs-gm-sidebars .waffle-conditionalformat-range-picker {
    border-bottom: none
}
.docs-gm-sidebars .waffle-conditionalformat-boolean-condition-picker,
.docs-gm-sidebars .waffle-conditionalformat-gradient-format-picker {
    border-top: none
}
.docs-gm-sidebars .waffle-conditionalformat-slide-pane .waffle-conditionalformat-edit-pill-section-header {
    margin-top: 10px;
    padding: 0 18px
}
.docs-gm-sidebars .waffle-conditionalformat-slide-pane .waffle-conditionalformat-edit-pill-button-bar {
    padding: 12px 18px 18px 24px
}
.docs-gm-sidebars .waffle-conditionalformat-slide-frame,
.docs-gm-sidebars .waffle-conditionalformat-slide-pane {
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-conditionalformat-condition-type-select .jfk-select,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-conditionalformat-condition-date-select .jfk-select {
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-conditionalformat-default-boolean-picker {
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-conditionalformat-arg1-holder,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-conditionalformat-arg2,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-conditionalformat-arg1 {
    width: 100%
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-conditionalformat-arg2,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-conditionalformat-arg1 {
    padding-left: 8px;
    padding-right: 8px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-conditionalformat-arg-separator {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    margin: 0 7px
}
.waffle-conditionalformat-twoArgs-holder {
    align-items: center;
    display: flex;
    justify-content: space-evenly
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-conditionalformat-format-button {
    border-radius: 4px 4px 0px 0px!important;
    font-size: 14px;
    height: 36px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-conditionalformat-format-button,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-conditionalformat-format-button .goog-flat-menu-button-caption,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-conditionalformat-format-button-inner {
    width: 100%
}
.docs-gm-sidebars .waffle-conditionalformat-default-menu .goog-palette-table {
    width: 100%
}
.docs-gm-sidebars .waffle-conditionalformat-custom-toolbar {
    box-sizing: border-box;
    border-top: none;
    margin-left: -1px;
    margin-top: 0px;
    width: 100%
}
.docs-gm-sidebars .waffle-conditionalformat-default-menu {
    border-radius: 4px;
    width: 262px
}
.docs-gm-sidebars .waffle-conditionalformat-custom-style-button {
    width: auto
}
.docs-gm-sidebars .waffle-conditionalformat-default-style-button {
    height: 31px;
    line-height: 30px;
    margin-left: 1px;
    margin-right: 0;
    width: 69px
}
.docs-gm-sidebars .waffle-conditionalformat-default-menu .trix-palette .goog-palette-table {
    margin: 0px
}
.docs-gm-sidebars .waffle-conditionalformat-default-menu .goog-palette.trix-palette {
    padding: 5px
}
.docs-gm-sidebars .waffle-conditionalformat-default-menu .trix-palette .goog-palette-cell {
    padding: 5px
}
.docs-gm-sidebars .waffle-conditionalformat-edit-pill-button-bar {
    text-align: right;
    padding: 0 18px 24px 18px;
    border-bottom: 1px solid #dadce0
}
.docs-gm-sidebars .waffle-conditionalformat-done-button {
    margin-right: 0px
}
.docs-gm-sidebars .waffle-conditionalformat-add-another-rule-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    color: #188038;
    padding: 16px 24px;
    width: 100%
}
.waffle-conditionalformat-add-another-rule-plus,
.waffle-conditionalformat-add-rule-plus {
    font-size: 24px;
    font-weight: 100;
    margin-right: 13px;
    vertical-align: text-bottom
}
.docs-gm-sidebars .waffle-conditionalformat-add-another-rule-plus,
.docs-gm-sidebars .waffle-conditionalformat-add-rule-plus {
    font-size: 24px;
    font-weight: 100;
    line-height: 21px;
    margin-right: 8px;
    vertical-align: text-bottom
}
.docs-gm-sidebars .waffle-conditionalformat-default-gradient-picker {
    width: 100%
}
.docs-gm-sidebars .waffle-conditionalformat-gradient-min-color .goog-toolbar-menu-button-inner-box,
.docs-gm-sidebars .waffle-conditionalformat-gradient-mid-color .goog-toolbar-menu-button-inner-box,
.docs-gm-sidebars .waffle-conditionalformat-gradient-max-color .goog-toolbar-menu-button-inner-box {
    min-width: 30px
}
.docs-gm-sidebars .waffle-conditionalformat-gradient-min-select .jfk-select,
.docs-gm-sidebars .waffle-conditionalformat-gradient-mid-select .jfk-select,
.docs-gm-sidebars .waffle-conditionalformat-gradient-max-select .jfk-select {
    width: 123px
}
.docs-gm-sidebars .waffle-conditionalformat-gradient-input-holder {
    width: 90px
}
.docs-gm-sidebars .waffle-conditionalformat-gradient-input-holder input {
    width: 100%
}
.docs-gm-sidebars .waffle-conditionalformat-gradient-point {
    align-items: center;
    display: flex;
    justify-content: flex-start
}
.docs-gm-sidebars .waffle-conditionalformat-gradient-point .jfk-select {
    height: 36px;
    margin-top: 1px;
    width: 123px
}
.docs-gm-sidebars .waffle-conditionalformat-delete-button-holder {
    left: 250px!important
}
.docs-gm-sidebars .waffle-conditionalformat-delete-button-holder .docs-icon {
    width: 21px;
    height: 21px
}
.docs-gm-sidebars .waffle-conditionalformat-view-pill {
    display: flex
}
.docs-gm-sidebars .waffle-conditionalformat-view-pill-summary {
    margin-bottom: auto;
    margin-top: auto
}
.docs-gm-sidebars .waffle-conditionalformat-add-rule-button {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    color: #188038;
    height: 44px;
    padding-top: 17px;
    width: 100%
}
.docs-gm-sidebars .waffle-conditionalformat-drag-item {
    width: 280px
}
.waffle-conditionalformat-range-args-holder .waffle-conditionalformat-arg1-holder,
.waffle-conditionalformat-range-args-holder .waffle-conditionalformat-arg2-holder,
.waffle-conditionalformat-range-args-holder .waffle-conditionalformat-arg1 {
    display: -webkit-box;
    display: -moz-box;
    display: -ms-flexbox;
    display: -webkit-flex;
    display: flex;
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    overflow: hidden
}
.waffle-conditionalformat-range-args-holder .waffle-conditionalformat-arg2 {
    -ms-flex: 1;
    -webkit-flex: 1;
    flex: 1;
    margin-right: 0;
    overflow: hidden
}
.waffle-conditionalformat-range-slider {
    margin-top: 10px
}
.waffle-find-replace-active-cell-rect {
    -webkit-animation-name: waffle-find-replace-pulse;
    -moz-animation-name: waffle-find-replace-pulse;
    -o-animation-name: waffle-find-replace-pulse;
    animation-name: waffle-find-replace-pulse;
    -webkit-animation-duration: 200ms;
    -moz-animation-duration: 200ms;
    -o-animation-duration: 200ms;
    animation-duration: 200ms;
    -webkit-animation-timing-function: ease-in-out;
    -moz-animation-timing-function: ease-in-out;
    -o-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out;
    background-color: rgba(140, 196, 116, 0.5);
    pointer-events: none;
    position: absolute
}
.docs-gm-dialogs .waffle-find-replace-active-cell-rect {
    border: 1px solid white;
    border-radius: 1px;
    box-shadow: 0px 0px 0px 2px black, 0 2px 3px 0 rgba(60, 64, 67, 0.30), 0 6px 10px 4px rgba(60, 64, 67, 0.15);
    margin: -1px 0 0 -1px
}
.waffle-find-replace-not-active-cell-rect {
    background-color: rgba(140, 196, 116, 0.25);
    pointer-events: none;
    position: absolute
}
@keyframes waffle-find-replace-pulse {
    from {
        -webkit-transform: scale(1.1, 1.3);
        -moz-transform: scale(1.1, 1.3);
        -ms-transform: scale(1.1, 1.3);
        -o-transform: scale(1.1, 1.3);
        transform: scale(1.1, 1.3);
        -webkit-border-radius: 4px;
        -moz-border-radius: 4px;
        border-radius: 4px
    }
}
#waffle-gotobar-button-go {
    margin-right: 8px
}
.docs-slidingdialog .docs-icon-next {
    filter: alpha(opacity=40);
    opacity: .40;
    -moz-opacity: .40
}
#waffle-gotobar-input {
    width: 200px
}
.waffle-gotobar-rangematcher-row-icon {
    width: 20px
}
.waffle-gotobar-rangematcher-row-suggestion {
    padding: 5px
}
.waffle-gotobar-rangematcher-row-message {
    color: #aaa;
    padding: 5px
}
#waffle-gotobar-error {
    color: #dd4b39;
    cursor: default;
    padding: 0 7px 0 0;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none
}
#waffle-gotobar-error-icon {
    background: #dd4b39;
    -webkit-border-radius: 10px;
    -moz-border-radius: 10px;
    border-radius: 10px;
    color: white;
    display: inline-block;
    font-weight: 500;
    padding: 0 5px;
    position: relative;
    text-decoration: none;
    top: -1px
}
#waffle-named-ranges-container {
    border-top: 1px solid #bcd;
    height: auto;
    overflow-y: auto
}
.docs-gm-sidebars #waffle-named-ranges-container {
    border: none
}
#waffle-named-ranges-add-range {
    background: white;
    border-bottom: 1px solid #ddd;
    cursor: pointer;
    font-size: 13px;
    font-weight: 500;
    height: 13px;
    padding: 13px 10px 13px 10px
}
.waffle-named-ranges-add-range-active {
    color: #dd4b39
}
.waffle-named-ranges-add-range-inactive {
    color: #15c
}
.docs-gm-sidebars .waffle-gm-sidebar #waffle-named-ranges-add-range {
    color: #188038;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    line-height: 16px;
    height: auto
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-named-ranges-add-range-icon {
    margin-top: -1px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-named-ranges-add-range-icon .docs-icon-img {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_green.svg)
}
.waffle-named-ranges-pill {
    border-bottom: 1px solid #ddd;
    cursor: default;
    padding: 10px 20px 10px 20px;
    position: relative
}
.waffle-named-ranges-pill:focus,
.waffle-named-ranges-pill:hover {
    background-color: #f3f3f3
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-named-ranges-pill:focus,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-named-ranges-pill:hover {
    background-color: white;
    outline: none
}
.docs-gm-sidebars .waffle-gm-sidebar #waffle-named-ranges-add-range,
.docs-gm-sidebars .waffle-gm-sidebar #waffle-named-ranges-add-range:focus {
    outline: none
}
.docs-gm-sidebars .waffle-gm-sidebar #waffle-named-ranges-add-range:hover {
    background-color: #f8fcf9
}
.docs-gm-sidebars .waffle-gm-sidebar #waffle-named-ranges-add-range:focus,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-named-ranges-pill:not(.waffle-named-ranges-edit-pill):focus {
    background-color: #e7f5eb
}
.docs-gm-sidebars .waffle-gm-sidebar #waffle-named-ranges-add-range:active {
    background-color: #dff2e4
}
.waffle-named-ranges-range-name,
.waffle-named-ranges-range-rect,
.waffle-named-ranges-edit-range-name {
    overflow: hidden;
    text-overflow: ellipsis
}
.waffle-named-ranges-pill:focus .waffle-named-ranges-edit-range-button,
.waffle-named-ranges-pill:hover .waffle-named-ranges-edit-range-button {
    display: inline-block
}
.waffle-named-ranges-edit-range-button {
    color: #15c;
    cursor: pointer;
    display: none;
    right: 1px;
    position: absolute;
    top: 12px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-named-ranges-edit-range-button {
    right: 24px;
    top: 13px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-named-ranges-edit-range-button {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: transparent;
    background-image: none;
    cursor: pointer;
    border-color: transparent!important;
    border-radius: 2px;
    border-width: 1px
}
.docs-gm-sidebars .waffle-gm-sidebar #waffle-named-ranges-edit-delete {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: white;
    background-image: none;
    cursor: pointer;
    border-color: transparent!important;
    border-radius: 2px;
    border-width: 1px
}
.docs-gm-sidebars .waffle-gm-sidebar #waffle-named-ranges-edit-delete .docs-icon {
    height: 24px;
    margin: 0;
    width: 24px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-named-ranges-edit-range-button.jfk-button-hover,
.docs-gm-sidebars .waffle-gm-sidebar #waffle-named-ranges-edit-delete.jfk-button-hover,
.docs-gm-sidebars .waffle-gm-sidebar #waffle-named-ranges-edit-delete.jfk-button-focus {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: rgba(0, 0, 0, .06);
    background-image: none;
    cursor: pointer;
    border-color: transparent!important;
    border-radius: 2px;
    border-width: 1px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-named-ranges-edit-range-button.jfk-button-active,
.docs-gm-sidebars .waffle-gm-sidebar #waffle-named-ranges-edit-delete.jfk-button-active {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
    background-color: rgba(0, 0, 0, 0.12);
    background-image: none;
    cursor: pointer;
    border-color: transparent!important;
    border-radius: 2px;
    border-width: 1px
}
.waffle-named-ranges-range-name {
    font-size: 14px;
    font-weight: 500
}
.waffle-named-ranges-edit-pill {
    background-color: #f3f3f3;
    cursor: default
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-named-ranges-edit-pill {
    background-color: #fff
}
.waffle-named-ranges-edit-title-bar {
    padding: 12px 0
}
.waffle-named-ranges-edit-range-name {
    font-size: 15px;
    font-weight: 500;
    margin: 0;
    max-width: 190px
}
#waffle-named-ranges-edit-delete {
    cursor: pointer;
    float: right;
    top: 8px
}
.docs-gm-sidebars .waffle-gm-sidebar #waffle-named-ranges-edit-delete {
    float: none;
    margin-left: 4px;
    margin-right: 0px;
    top: 0px
}
.waffle-named-ranges-add-range-name-input {
    margin: 5px 0 10px;
    position: relative;
    top: 2px;
    width: 150px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-named-ranges-add-range-name-input {
    width: calc(100%)
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-named-ranges-add-range-name-input.waffle-named-ranges-add-range-name-input-with-delete {
    width: calc(100% - 32px)
}
.waffle-named-ranges-select-error {
    border-color: #dd4b39
}
.waffle-named-ranges-range-select-listening {
    background-color: #fbf2cd;
    margin: 0 -20px 0;
    padding: 10px 20px
}
.docs-gm-sidebars .waffle-named-ranges-range-select-listening {
    background-color: transparent;
    background-color: unset;
    padding-top: 0
}
.waffle-named-ranges-edit-range-select-done {
    margin-top: 3px
}
.docs-gm-sidebars .waffle-named-ranges-edit-range-select-done {
    margin-top: 16px
}
.waffle-named-ranges-edit-range-select-message {
    display: none;
    margin-top: 3px;
    width: 110px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-named-ranges-edit-range-select-message {
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: 400
}
.waffle-named-ranges-range-select-listening .waffle-named-ranges-edit-range-select-message {
    display: inline-block
}
.waffle-named-ranges-edit-done,
.waffle-named-ranges-edit-cancel {
    margin-top: 10px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-named-ranges-edit-buttons {
    text-align: right
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-named-ranges-edit-buttons .jfk-button {
    margin-left: 16px;
    margin-right: 0px
}
#waffle-named-ranges-edit-validation-error {
    margin-top: 5px
}
.docs-gm-sidebars .waffle-gm-sidebar #waffle-named-ranges-edit-validation-error {
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 400;
    margin-top: 10px
}
#waffle-named-ranges-edit-validation-error-text {
    color: #dd4b39;
    padding: 0 7px 0 0
}
#waffle-named-ranges-edit-validation-error-icon {
    background: #dd4b39;
    -webkit-border-radius: 10px;
    -moz-border-radius: 10px;
    border-radius: 10px;
    color: white;
    display: inline-block;
    font-weight: 500;
    padding: 0 5px;
    position: relative;
    text-decoration: none;
    top: -1px
}
#waffle-named-ranges-arrowup {
    left: 14px;
    position: absolute;
    top: 32px
}
#waffle-named-ranges-arrowup:before,
#waffle-named-ranges-arrowup:after {
    content: "";
    display: block;
    height: 0;
    position: absolute;
    width: 0
}
#waffle-named-ranges-arrowup:before {
    border-color: #ddd transparent;
    border-width: 0 9px 9px 9px;
    border-style: solid;
    left: -9px
}
#waffle-named-ranges-arrowup:after {
    border-color: #f3f3f3 transparent;
    border-width: 0 8px 8px 8px;
    border-style: solid;
    left: -8px;
    top: 1px
}
#waffle-named-ranges-promo {
    cursor: default;
    padding: 0 15px 0 15px
}
.docs-gm-sidebars #waffle-named-ranges-promo {
    border-radius: 8px;
    background-color: #e6f4ea;
    margin: 16px;
    padding: 16px
}
.waffle-named-ranges-promo-title {
    color: #636363;
    font-size: 14px;
    font-weight: 500;
    margin-bottom: 10px
}
.docs-gm-sidebars .waffle-named-ranges-promo-title {
    align-items: center;
    color: #188038;
    display: flex
}
.docs-gm-sidebars .waffle-named-ranges-promo-title .docs-icon {
    margin: 0 8px 0 0
}
.docs-gm-sidebars .waffle-named-ranges-promo-title-text {
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500
}
.waffle-named-ranges-promo-content {
    color: #636363;
    margin: 20px 0 20px
}
.docs-gm-sidebars .waffle-named-ranges-promo-content {
    color: #188038;
    font-size: 12px;
    letter-spacing: .3px;
    margin: 24px 0
}
.docs-gm-sidebars .waffle-named-ranges-promo-example {
    align-items: center;
    background-color: #fff;
    border-radius: 4px;
    color: #202124;
    display: flex;
    margin-top: 8px;
    padding: 8px
}
.docs-gm-sidebars .waffle-named-ranges-promo-example .docs-icon {
    margin: 0 4px 0 0
}
.docs-gm-sidebars .waffle-named-ranges-promo-example .docs-icon-img:before {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_grey_dark.svg)
}
.docs-gm-sidebars .waffle-named-ranges-promo-example .docs-icon-img {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_grey_dark.svg)
}
.waffle-named-ranges-promo-separator {
    background-color: #ddd;
    border: none;
    color: #ddd;
    height: 1px;
    margin: 20px 0 20px;
    width: 95%
}
.waffle-named-ranges-promo-formulabar {
    border: solid #f3f3f3;
    border-width: 10px 0 10px 0;
    margin: 15px 0 20px
}
.docs-gm-sidebars .waffle-named-ranges-promo-footer {
    display: flex;
    justify-content: flex-end
}
.docs-gm-sidebars .waffle-named-ranges-promo-footer a {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #e6f4ea;
    color: #188038;
    display: inline-block
}
.docs-gm-sidebars .waffle-named-ranges-promo-footer a:hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #e6f4ea;
    color: #188038;
    text-decoration: none
}
.docs-gm-sidebars .waffle-named-ranges-promo-footer a:focus,
.docs-gm-sidebars .waffle-named-ranges-promo-footer a:hover:focus {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #ceead6;
    color: #188038
}
.docs-gm-sidebars .waffle-named-ranges-promo-footer a:active,
.docs-gm-sidebars .waffle-named-ranges-promo-footer a:hover:active {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #ceead6;
    color: #188038;
    box-shadow: 0 1px 3px 1px rgba(60, 64, 67, .15)
}
.waffle-named-ranges-promo-lock-container {
    height: 27px;
    margin-right: 12px;
    overflow: hidden;
    vertical-align: middle;
    width: 23px
}
.waffle-named-ranges-promo-lock:before {
    content: url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png")
}
.waffle-named-ranges-promo-lock {
    background: url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png");
    left: -618px;
    opacity: .60;
    position: relative;
    top: 0
}
.docs-icon.waffle-named-ranges-locked {
    height: 21px;
    margin-bottom: 3px;
    width: 21px
}
.docs-icon.waffle-named-ranges-unlocked {
    height: 21px;
    width: 21px
}
#waffle-named-ranges-edit-manage-named-ranges {
    color: #15c;
    cursor: pointer;
    margin-top: 5px;
    padding-bottom: 5px
}
.waffle-named-ranges-border {
    border-color: #8cc474;
    border-style: solid;
    line-height: 0
}
#waffle-ritz-protection-container {
    border-top: 1px solid #bcd;
    height: auto;
    overflow-y: auto;
    width: 250px
}
.docs-gm-sidebars .waffle-gm-sidebar #waffle-ritz-protection-container {
    border: none;
    width: 300px
}
.waffle-ritz-protection-link-button {
    background: white;
    cursor: pointer;
    font-size: 13px;
    height: 13px;
    padding: 13px 10px 13px 10px;
    color: #15c
}
.docs-gm-sidebars .waffle-ritz-protection-link-button {
    color: #188038;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 500;
    line-height: 16px;
    height: 16px;
    padding: 16px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-ritz-protection-add-range-icon {
    margin-top: -1px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-ritz-protection-add-range-icon .docs-icon-img {
    content: url(//ssl.gstatic.com/docs/common/material_common_sprite134_green.svg)
}
#waffle-ritz-protection-add-range {
    border-bottom: 1px solid #ddd
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-ritz-protection-link-button,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-ritz-protection-link-button:focus {
    outline: none
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-ritz-protection-link-button:hover {
    background-color: #f8fcf9
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-ritz-protection-link-button:focus {
    background-color: #e7f5eb
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-ritz-protection-link-button:active {
    background-color: #dff2e4
}
.waffle-ritz-protection-pill {
    border-bottom: 1px solid #ddd;
    cursor: default;
    padding-bottom: 10px;
    padding-top: 10px;
    position: relative
}
.waffle-ritz-protection-pill-contents {
    padding-left: 20px;
    padding-right: 20px
}
.docs-gm-sidebars .waffle-ritz-protection-pill-contents {
    color: #5f6368;
    font-size: 14px;
    padding-left: 16px;
    padding-right: 16px
}
.waffle-ritz-protection-edit-permissions {
    border-top: 1px solid #ddd;
    border-bottom: 1px solid #ddd;
    padding-bottom: 15px;
    padding-top: 15px;
    margin-top: 15px
}
.waffle-ritz-protection-edit-permissions-lock {
    left: -5px;
    width: 15px
}
.waffle-ritz-protection-edit-buttons {
    padding-top: 5px
}
.docs-gm-sidebars .waffle-ritz-protection-edit-buttons {
    display: flex;
    justify-content: flex-end;
    padding-top: 8px
}
.waffle-ritz-protection-edit-permissions-title {
    font-size: 14px;
    font-weight: 500;
    word-wrap: break-word
}
.waffle-ritz-protection-edit-permissions-description {
    color: gray
}
.waffle-ritz-protection-range-rect,
.waffle-ritz-protection-edit-range-name {
    overflow: hidden;
    text-overflow: ellipsis
}
.docs-gm-sidebars .waffle-ritz-protection-range-rect-holder {
    color: #202124;
    font-weight: 500
}
.waffle-ritz-protection-view-pill {
    cursor: pointer
}
.waffle-ritz-protection-view-pill:focus,
.waffle-ritz-protection-view-pill:hover {
    background-color: #f3f3f3
}
.waffle-ritz-protection-range-name {
    font-size: 14px;
    font-weight: 500;
    word-wrap: break-word
}
.waffle-ritz-protection-edit-pill {
    background-color: #fafafa;
    cursor: default
}
.docs-gm-sidebars .waffle-ritz-protection-edit-pill {
    background-color: #fff
}
.waffle-ritz-protection-edit-title-bar {
    padding: 12px 0
}
.waffle-ritz-protection-edit-range-name {
    font-size: 15px;
    font-weight: 500;
    margin: 0;
    max-width: 190px
}
#waffle-ritz-protection-edit-delete {
    cursor: pointer;
    float: right;
    top: 8px
}
.docs-gm-sidebars #waffle-ritz-protection-edit-delete {
    top: 16px
}
.docs-gm-sidebars #waffle-ritz-protection-edit-delete .docs-icon {
    height: 24px;
    margin: 0;
    width: 24px
}
.waffle-ritz-protection-add-description-input {
    margin: 5px 0 10px;
    position: relative;
    top: 2px;
    width: 150px
}
.docs-gm-sidebars .waffle-ritz-protection-add-description-input {
    width: 100%
}
.docs-gm-sidebars .waffle-ritz-protection-edit-description-input {
    width: 236px
}
.waffle-ritz-protection-select-error {
    border-color: #dd4b39
}
#waffle-ritz-protection-edit-sheet-select {
    margin: 0px;
    text-align: left;
    width: 180px
}
.docs-gm-sidebars #waffle-ritz-protection-edit-sheet-select {
    width: 100%
}
#waffle-ritz-protection-edit-sheet-select .goog-flat-menu-button-caption {
    text-overflow: ellipsis;
    overflow: hidden;
    width: inherit
}
#waffle-ritz-protection-edit-sheet-label {
    font-weight: 500;
    margin: 0px 5px;
    overflow: hidden;
    text-overflow: ellipsis
}
.waffle-ritz-protection-holes-checkbox-container {
    margin-bottom: 5px;
    margin-top: 10px
}
.docs-gm-sidebars .waffle-gm-sidebar #waffle-ritz-protection-holes-checkbox-label {
    color: #3c4043;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 14px;
    font-weight: 400;
    line-height: 24px;
    padding-left: 8px;
    vertical-align: middle
}
.waffle-ritz-protection-edit-done,
.waffle-ritz-protection-edit-cancel {
    margin-top: 10px
}
.docs-gm-sidebars .waffle-ritz-protection-edit-cancel {
    margin-right: 8px
}
.docs-gm-sidebars .waffle-ritz-protection-edit-done {
    margin-right: 0
}
.waffle-ritz-protection-edit-toggle-range,
.waffle-ritz-protection-edit-toggle-sheet {
    margin: 10px 0px;
    width: 85px
}
.docs-gm-sidebars .waffle-ritz-protection-tab-separator {
    border-top: 1px solid #dadce0;
    margin-left: -16px;
    padding-top: 16px;
    width: 300px
}
#waffle-ritz-protection-edit-validation-error {
    margin-top: 5px
}
#waffle-ritz-protection-edit-validation-error-text {
    color: #dd4b39;
    padding: 0 7px 0 0
}
#waffle-ritz-protection-edit-validation-error-icon {
    background: #dd4b39;
    -webkit-border-radius: 10px;
    -moz-border-radius: 10px;
    border-radius: 10px;
    color: white;
    display: inline-block;
    font-weight: 500;
    padding: 0 5px;
    position: relative;
    text-decoration: none;
    top: -1px
}
.waffle-ritz-protection-edit-permissions-button {
    margin-top: 10px;
    padding-right: 15px
}
#waffle-ritz-protection-promo {
    cursor: default;
    padding: 0 15px 0 15px
}
.waffle-ritz-protection-promo-content {
    color: #636363;
    margin: 20px 0 20px
}
.waffle-ritz-protection-promo-separator {
    background-color: #ddd;
    border: none;
    color: #ddd;
    height: 1px;
    margin: 20px 0 20px;
    width: 95%
}
.waffle-ritz-protection-promo-lock-container {
    height: 27px;
    margin-right: 12px;
    overflow: hidden;
    vertical-align: middle;
    width: 23px
}
.waffle-ritz-protection-promo-lock:before {
    content: url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png")
}
.waffle-ritz-protection-promo-lock {
    background: url("//ssl.gstatic.com/docs/spreadsheets/waffle_sprite53.png");
    left: -618px;
    opacity: .60;
    position: relative;
    top: 0
}
#waffle-ritz-protection-edit-manage-ritz-protection {
    color: #15c;
    cursor: pointer;
    margin-top: 5px;
    padding-bottom: 5px
}
.waffle-ritz-protection-border {
    border-color: #8cc474;
    border-style: solid;
    line-height: 0
}
.waffle-ritz-protection-acl-loading {
    width: 400px
}
.waffle-ritz-protection-acl-loading-spinner,
.waffle-ritz-protection-acl-loading-text {
    display: inline-block;
    position: relative;
    -webkit-transition: left 300ms ease-out;
    -moz-transition: left 300ms ease-out;
    -o-transition: left 300ms ease-out;
    transition: left 300ms ease-out;
    -webkit-transition: width 300ms ease-out;
    -moz-transition: width 300ms ease-out;
    -o-transition: width 300ms ease-out;
    transition: width 300ms ease-out;
    vertical-align: middle
}
.waffle-ritz-protection-type-buttons .jfk-radiobutton {
    display: block;
    margin-bottom: 4px
}
.waffle-ritz-protection-dropdown {
    margin: 4px 0 24px 27px
}
.waffle-ritz-protection-dropdown .goog-flat-menu-button-caption {
    font-size: 12px;
    text-align: left;
    width: 345px
}
.waffle-ritz-protection-custom-container {
    margin-left: 27px
}
.waffle-ritz-protection-acl-table-container {
    border-collapse: collapse;
    border-top: 1px solid #d6d6d6;
    font-family: arial, sans-serif;
    font-size: 13px;
    margin-bottom: 10px;
    max-height: 230px;
    overflow: auto;
    width: 373px
}
.waffle-ritz-protection-acl-header-name,
.waffle-ritz-protection-acl-header-edit {
    color: #616161;
    display: inline-block;
    font-family: arial, sans-serif;
    font-size: 11px;
    font-weight: 500
}
.waffle-ritz-protection-acl-header {
    margin-bottom: 10px
}
.waffle-ritz-protection-acl-header-edit {
    text-align: right
}
.waffle-ritz-protection-acl-scope-col,
.waffle-ritz-protection-acl-header-name {
    width: 85%
}
.waffle-ritz-protection-acl-edit-col,
.waffle-ritz-protection-acl-header-edit {
    width: 15%
}
.waffle-ritz-protection-acl-header-edit-checkbox {
    margin-right: 10px
}
.waffle-ritz-protection-acl-table {
    empty-cells: show;
    width: 100%
}
.waffle-ritz-protection-acl-table td {
    border-bottom: 1px solid #ebebeb;
    font-size: 13px;
    padding: 8px 0px
}
.waffle-ritz-protection-acl-missing {
    opacity: 0.5
}
.waffle-ritz-protection-acl-row td {
    text-overflow: ellipsis
}
.waffle-ritz-protection-acl-scope {
    width: 313px
}
.waffle-ritz-protection-acl-text {
    display: inline-block;
    margin-left: 15px;
    overflow: hidden;
    text-overflow: ellipsis;
    vertical-align: middle;
    width: 239px;
    white-space: nowrap
}
.waffle-ritz-protection-acl-email {
    color: #777;
    margin-left: 5px
}
.waffle-ritz-protection-acl-checkbox {
    display: block;
    margin-left: auto;
    margin-right: 10px
}
.waffle-ritz-protection-acl-default-icon {
    display: inline-block;
    filter: alpha(opacity=55);
    height: 21px;
    opacity: 0.55;
    margin-left: 4px;
    margin-top: 4px;
    width: 21px
}
.waffle-ritz-protection-acl-icon-container {
    background-color: #f5f5f5;
    display: inline-block;
    height: 29px;
    vertical-align: middle;
    width: 29px
}
.waffle-ritz-protection-acl-custom-icon {
    height: 29px;
    vertical-align: middle;
    width: 29px
}
.waffle-ritz-protection-acl-icon-disabled {
    filter: alpha(opacity=25);
    opacity: 0.25
}
.waffle-ritz-protection-add-editors-container {
    background-color: #f5f5f5;
    margin-bottom: 24px;
    padding: 16px
}
.waffle-ritz-protection-add-editors-label {
    font-size: 11px;
    font-weight: 500;
    padding-right: 15px
}
.waffle-ritz-protection-add-editors-input {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    padding-left: 8px;
    padding-right: 8px;
    -webkit-transition: height 200ms ease-out;
    -moz-transition: height 200ms ease-out;
    -o-transition: height 200ms ease-out;
    transition: height 200ms ease-out;
    width: 100%
}
.waffle-ritz-protection-ac-renderer {
    background: #fff;
    border: 1px solid #666;
    -webkit-box-shadow: 2px 2px 2px rgba(102, 102, 102, .4);
    -moz-box-shadow: 2px 2px 2px rgba(102, 102, 102, .4);
    box-shadow: 2px 2px 2px rgba(102, 102, 102, .4);
    color: #333;
    font-family: Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-size: 13px;
    font-weight: normal;
    max-height: 120px;
    overflow: hidden;
    position: absolute;
    width: 369px;
    white-space: nowrap;
    z-index: 1010
}
.waffle-ritz-protection-ac-renderer .goog-contacts-ui-autocomplete-new-section {
    border-top: 1px solid #666;
    padding-top: 2px
}
.waffle-ritz-protection-ac-renderer .ac-row {
    cursor: pointer;
    padding: 4px 10px 4px 4px
}
.waffle-ritz-protection-ac-renderer .ac-highlighted {
    color: #222
}
.waffle-ritz-protection-ac-renderer .ac-active {
    background: #eee
}
.waffle-ritz-protection-list {
    border-collapse: collapse;
    border-top: 1px solid #ebebeb;
    font-family: arial, sans-serif;
    font-size: 13px;
    margin-bottom: 24px;
    margin-left: 27px;
    max-height: 200px;
    outline: transparent;
    overflow: auto
}
.waffle-ritz-protection-item {
    border-bottom: 1px solid #ebebeb;
    padding: 5px 0
}
.waffle-ritz-protection-item-hover {
    background: #eee
}
.waffle-ritz-protection-item-name {
    font-size: 13px;
    font-weight: 500;
    word-wrap: break-word
}
.waffle-ritz-protection-item-range {
    color: gray;
    font-size: 12px;
    word-wrap: break-word
}
.waffle-ritz-protection-acl-butter {
    background: #f9edbe;
    border: 1px solid #f0c36d;
    color: #222;
    font-family: arial, sans-serif;
    font-size: 13px;
    margin-bottom: 10px;
    margin-top: 10px;
    max-width: 358px;
    padding: 5px;
    text-align: center;
    width: 100%
}
.waffle-ritz-protection-acl-butter-text {
    display: inline-block
}
.waffle-ritz-protection-acl-butter-href {
    text-decoration: underline
}
.waffle-ritz-protection-acl-butter-action {
    cursor: pointer;
    color: #15c;
    display: inline-block
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-flat-multi-range-select-done {
    margin-top: 8px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-flat-range-select-listening,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-flat-multi-range-select-listening {
    background-color: transparent;
    background-color: unset
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-ritz-protection-pill-contents .waffle-flat-multi-range-row {
    margin-bottom: 8px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-ritz-protection-pill-contents .waffle-flat-multi-range-add-another {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: white;
    border: 1px solid #dadce0!important;
    color: #188038;
    height: 24px;
    padding: 3px 12px 5px;
    display: inline-block;
    margin: 0
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-ritz-protection-pill-contents .waffle-flat-multi-range-add-another:focus {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #e7f5eb;
    border: 1px solid #bbe2c6!important;
    height: 24px;
    padding: 3px 12px 5px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-ritz-protection-pill-contents .waffle-flat-multi-range-add-another:hover {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #f8fcf9;
    border: 1px solid #c8e7d1!important;
    height: 24px;
    padding: 3px 12px 5px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-ritz-protection-pill-contents .waffle-flat-multi-range-add-another:hover:focus {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    border: 1px solid #b5e0c1!important;
    height: 24px;
    padding: 3px 12px 5px
}
.docs-gm-sidebars .waffle-gm-sidebar .waffle-ritz-protection-pill-contents .waffle-flat-multi-range-add-another:active,
.docs-gm-sidebars .waffle-gm-sidebar .waffle-ritz-protection-pill-contents .waffle-flat-multi-range-add-another:hover:active {
    background-image: none;
    border: 1px solid transparent!important;
    border-radius: 4px;
    box-shadow: none;
    box-sizing: border-box;
    font-family: "Google Sans", Roboto, RobotoDraft, Helvetica, Arial, sans-serif;
    font-weight: 500;
    font-size: 14px;
    height: 36px;
    letter-spacing: 0.25px;
    line-height: 16px;
    padding: 9px 24px 11px 24px;
    background: #dff2e4;
    border: 1px solid transparent!important;
    box-shadow: 0 2px 6px 2px rgba(60, 64, 67, .15);
    height: 24px;
    padding: 3px 12px 5px
}
.docs-gm-dialogs .goog-tab-bar.spreadsheet-settings-dialog-tab-bar .goog-tab.spreadsheet-settings-tab {
    color: #5f6368;
    text-align: center;
    width: 120px
}
.docs-gm-dialogs .goog-tab-bar.spreadsheet-settings-dialog-tab-bar {
    border-bottom-color: #e8eaed!important
}
.docs-gm-dialogs .goog-tab-bar.spreadsheet-settings-dialog-tab-bar .goog-tab.spreadsheet-settings-tab.goog-tab-selected,
.docs-gm-dialogs .goog-tab-bar.spreadsheet-settings-dialog-tab-bar .goog-tab.spreadsheet-settings-tab.goog-tab-hover {
    border-bottom: 2px solid #188038;
    color: #202124
}
.docs-gm-dialogs .dialog-settings .dialog-settings-input {
    width: 210px
}
.docs-gm-dialogs .dialog-settings .jfk-select {
    max-width: 210px
}
.docs-gm-dialogs .dialog-settings {
    width: 670px
}
.docs-gm-dialogs .dialog-settings-label {
    padding-bottom: 4px;
    padding-top: 4px
}
.docs-gm-dialogs .dialog-settings-display-language {
    padding-top: 4px
}
.docs-gm-dialogs .dialog-settings .goog-flat-menu-button-caption {
    text-align: left
}
.docs-gm-dialogs .modal-dialog.dialog-settings .jfk-select.goog-flat-menu-button {
    padding-left: 14px
}
.goog-tab-bar.spreadsheet-settings-dialog-tab-bar {
    background: none;
    border-bottom-color: silver!important;
    margin-bottom: 20px;
    padding-left: 0!important
}
.goog-tab-bar.spreadsheet-settings-dialog-tab-bar .goog-tab.spreadsheet-settings-tab {
    color: #bdbdbd;
    cursor: pointer;
    font-weight: 500;
    margin: 1px 15px 0 0;
    padding: 4px 8px;
    text-decoration: none;
    top: 1px
}
.goog-tab-bar.spreadsheet-settings-dialog-tab-bar .goog-tab.spreadsheet-settings-tab.goog-tab-selected,
.goog-tab-bar.spreadsheet-settings-dialog-tab-bar .goog-tab.spreadsheet-settings-tab.goog-tab-hover {
    background: none;
    border-bottom: 3px solid #4d90fe;
    border-left: none;
    border-right: none;
    border-top: none;
    color: black
}
.dialog-settings .dialog-settings-input {
    width: 175px
}
.dialog-settings .jfk-select {
    max-width: 171px;
    box-sizing: border-box
}
.dialog-settings .goog-flat-menu-button-caption {
    text-overflow: ellipsis
}
.grid-container {
    margin: 0 auto;
    width: auto;
    /*overflow: auto;*/
	margin: 0 auto;	
}

.waffle th {
    background: transparent;
    font-size: 1px;
    color: transparent !important;
    height: 0px;
    border: none;
    border-bottom: 1px solid #000;
}